/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|*Target Instruction Enum Values                                              *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

/* Capstone Disassembly Engine */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2015 */


#ifdef GET_INSTRINFO_ENUM
#undef GET_INSTRINFO_ENUM

enum {
    PPC_PHI	= 0,
    PPC_INLINEASM	= 1,
    PPC_CFI_INSTRUCTION	= 2,
    PPC_EH_LABEL	= 3,
    PPC_GC_LABEL	= 4,
    PPC_KILL	= 5,
    PPC_EXTRACT_SUBREG	= 6,
    PPC_INSERT_SUBREG	= 7,
    PPC_IMPLICIT_DEF	= 8,
    PPC_SUBREG_TO_REG	= 9,
    PPC_COPY_TO_REGCLASS	= 10,
    PPC_DBG_VALUE	= 11,
    PPC_REG_SEQUENCE	= 12,
    PPC_COPY	= 13,
    PPC_BUNDLE	= 14,
    PPC_LIFETIME_START	= 15,
    PPC_LIFETIME_END	= 16,
    PPC_STACKMAP	= 17,
    PPC_PATCHPOINT	= 18,
    PPC_LOAD_STACK_GUARD	= 19,
    PPC_STATEPOINT	= 20,
    PPC_FRAME_ALLOC	= 21,
    PPC_ADD4	= 22,
    PPC_ADD4TLS	= 23,
    PPC_ADD4o	= 24,
    PPC_ADD8	= 25,
    PPC_ADD8TLS	= 26,
    PPC_ADD8TLS_	= 27,
    PPC_ADD8o	= 28,
    PPC_ADDC	= 29,
    PPC_ADDC8	= 30,
    PPC_ADDC8o	= 31,
    PPC_ADDCo	= 32,
    PPC_ADDE	= 33,
    PPC_ADDE8	= 34,
    PPC_ADDE8o	= 35,
    PPC_ADDEo	= 36,
    PPC_ADDI	= 37,
    PPC_ADDI8	= 38,
    PPC_ADDIC	= 39,
    PPC_ADDIC8	= 40,
    PPC_ADDICo	= 41,
    PPC_ADDIS	= 42,
    PPC_ADDIS8	= 43,
    PPC_ADDISdtprelHA	= 44,
    PPC_ADDISdtprelHA32	= 45,
    PPC_ADDISgotTprelHA	= 46,
    PPC_ADDIStlsgdHA	= 47,
    PPC_ADDIStlsldHA	= 48,
    PPC_ADDIStocHA	= 49,
    PPC_ADDIdtprelL	= 50,
    PPC_ADDIdtprelL32	= 51,
    PPC_ADDItlsgdL	= 52,
    PPC_ADDItlsgdL32	= 53,
    PPC_ADDItlsgdLADDR	= 54,
    PPC_ADDItlsgdLADDR32	= 55,
    PPC_ADDItlsldL	= 56,
    PPC_ADDItlsldL32	= 57,
    PPC_ADDItlsldLADDR	= 58,
    PPC_ADDItlsldLADDR32	= 59,
    PPC_ADDItocL	= 60,
    PPC_ADDME	= 61,
    PPC_ADDME8	= 62,
    PPC_ADDME8o	= 63,
    PPC_ADDMEo	= 64,
    PPC_ADDZE	= 65,
    PPC_ADDZE8	= 66,
    PPC_ADDZE8o	= 67,
    PPC_ADDZEo	= 68,
    PPC_ADJCALLSTACKDOWN	= 69,
    PPC_ADJCALLSTACKUP	= 70,
    PPC_AND	= 71,
    PPC_AND8	= 72,
    PPC_AND8o	= 73,
    PPC_ANDC	= 74,
    PPC_ANDC8	= 75,
    PPC_ANDC8o	= 76,
    PPC_ANDCo	= 77,
    PPC_ANDISo	= 78,
    PPC_ANDISo8	= 79,
    PPC_ANDIo	= 80,
    PPC_ANDIo8	= 81,
    PPC_ANDIo_1_EQ_BIT	= 82,
    PPC_ANDIo_1_EQ_BIT8	= 83,
    PPC_ANDIo_1_GT_BIT	= 84,
    PPC_ANDIo_1_GT_BIT8	= 85,
    PPC_ANDo	= 86,
    PPC_ATOMIC_CMP_SWAP_I16	= 87,
    PPC_ATOMIC_CMP_SWAP_I32	= 88,
    PPC_ATOMIC_CMP_SWAP_I64	= 89,
    PPC_ATOMIC_CMP_SWAP_I8	= 90,
    PPC_ATOMIC_LOAD_ADD_I16	= 91,
    PPC_ATOMIC_LOAD_ADD_I32	= 92,
    PPC_ATOMIC_LOAD_ADD_I64	= 93,
    PPC_ATOMIC_LOAD_ADD_I8	= 94,
    PPC_ATOMIC_LOAD_AND_I16	= 95,
    PPC_ATOMIC_LOAD_AND_I32	= 96,
    PPC_ATOMIC_LOAD_AND_I64	= 97,
    PPC_ATOMIC_LOAD_AND_I8	= 98,
    PPC_ATOMIC_LOAD_NAND_I16	= 99,
    PPC_ATOMIC_LOAD_NAND_I32	= 100,
    PPC_ATOMIC_LOAD_NAND_I64	= 101,
    PPC_ATOMIC_LOAD_NAND_I8	= 102,
    PPC_ATOMIC_LOAD_OR_I16	= 103,
    PPC_ATOMIC_LOAD_OR_I32	= 104,
    PPC_ATOMIC_LOAD_OR_I64	= 105,
    PPC_ATOMIC_LOAD_OR_I8	= 106,
    PPC_ATOMIC_LOAD_SUB_I16	= 107,
    PPC_ATOMIC_LOAD_SUB_I32	= 108,
    PPC_ATOMIC_LOAD_SUB_I64	= 109,
    PPC_ATOMIC_LOAD_SUB_I8	= 110,
    PPC_ATOMIC_LOAD_XOR_I16	= 111,
    PPC_ATOMIC_LOAD_XOR_I32	= 112,
    PPC_ATOMIC_LOAD_XOR_I64	= 113,
    PPC_ATOMIC_LOAD_XOR_I8	= 114,
    PPC_ATOMIC_SWAP_I16	= 115,
    PPC_ATOMIC_SWAP_I32	= 116,
    PPC_ATOMIC_SWAP_I64	= 117,
    PPC_ATOMIC_SWAP_I8	= 118,
    PPC_ATTN	= 119,
    PPC_B	= 120,
    PPC_BA	= 121,
    PPC_BC	= 122,
    PPC_BCC	= 123,
    PPC_BCCA	= 124,
    PPC_BCCCTR	= 125,
    PPC_BCCCTR8	= 126,
    PPC_BCCCTRL	= 127,
    PPC_BCCCTRL8	= 128,
    PPC_BCCL	= 129,
    PPC_BCCLA	= 130,
    PPC_BCCLR	= 131,
    PPC_BCCLRL	= 132,
    PPC_BCCTR	= 133,
    PPC_BCCTR8	= 134,
    PPC_BCCTR8n	= 135,
    PPC_BCCTRL	= 136,
    PPC_BCCTRL8	= 137,
    PPC_BCCTRL8n	= 138,
    PPC_BCCTRLn	= 139,
    PPC_BCCTRn	= 140,
    PPC_BCL	= 141,
    PPC_BCLR	= 142,
    PPC_BCLRL	= 143,
    PPC_BCLRLn	= 144,
    PPC_BCLRn	= 145,
    PPC_BCLalways	= 146,
    PPC_BCLn	= 147,
    PPC_BCTR	= 148,
    PPC_BCTR8	= 149,
    PPC_BCTRL	= 150,
    PPC_BCTRL8	= 151,
    PPC_BCTRL8_LDinto_toc	= 152,
    PPC_BCn	= 153,
    PPC_BDNZ	= 154,
    PPC_BDNZ8	= 155,
    PPC_BDNZA	= 156,
    PPC_BDNZAm	= 157,
    PPC_BDNZAp	= 158,
    PPC_BDNZL	= 159,
    PPC_BDNZLA	= 160,
    PPC_BDNZLAm	= 161,
    PPC_BDNZLAp	= 162,
    PPC_BDNZLR	= 163,
    PPC_BDNZLR8	= 164,
    PPC_BDNZLRL	= 165,
    PPC_BDNZLRLm	= 166,
    PPC_BDNZLRLp	= 167,
    PPC_BDNZLRm	= 168,
    PPC_BDNZLRp	= 169,
    PPC_BDNZLm	= 170,
    PPC_BDNZLp	= 171,
    PPC_BDNZm	= 172,
    PPC_BDNZp	= 173,
    PPC_BDZ	= 174,
    PPC_BDZ8	= 175,
    PPC_BDZA	= 176,
    PPC_BDZAm	= 177,
    PPC_BDZAp	= 178,
    PPC_BDZL	= 179,
    PPC_BDZLA	= 180,
    PPC_BDZLAm	= 181,
    PPC_BDZLAp	= 182,
    PPC_BDZLR	= 183,
    PPC_BDZLR8	= 184,
    PPC_BDZLRL	= 185,
    PPC_BDZLRLm	= 186,
    PPC_BDZLRLp	= 187,
    PPC_BDZLRm	= 188,
    PPC_BDZLRp	= 189,
    PPC_BDZLm	= 190,
    PPC_BDZLp	= 191,
    PPC_BDZm	= 192,
    PPC_BDZp	= 193,
    PPC_BL	= 194,
    PPC_BL8	= 195,
    PPC_BL8_NOP	= 196,
    PPC_BL8_NOP_TLS	= 197,
    PPC_BL8_TLS	= 198,
    PPC_BL8_TLS_	= 199,
    PPC_BLA	= 200,
    PPC_BLA8	= 201,
    PPC_BLA8_NOP	= 202,
    PPC_BLR	= 203,
    PPC_BLR8	= 204,
    PPC_BLRL	= 205,
    PPC_BL_TLS	= 206,
    PPC_BRINC	= 207,
    PPC_CLRLSLDI	= 208,
    PPC_CLRLSLDIo	= 209,
    PPC_CLRLSLWI	= 210,
    PPC_CLRLSLWIo	= 211,
    PPC_CLRRDI	= 212,
    PPC_CLRRDIo	= 213,
    PPC_CLRRWI	= 214,
    PPC_CLRRWIo	= 215,
    PPC_CMPB	= 216,
    PPC_CMPB8	= 217,
    PPC_CMPD	= 218,
    PPC_CMPDI	= 219,
    PPC_CMPLD	= 220,
    PPC_CMPLDI	= 221,
    PPC_CMPLW	= 222,
    PPC_CMPLWI	= 223,
    PPC_CMPW	= 224,
    PPC_CMPWI	= 225,
    PPC_CNTLZD	= 226,
    PPC_CNTLZDo	= 227,
    PPC_CNTLZW	= 228,
    PPC_CNTLZW8	= 229,
    PPC_CNTLZW8o	= 230,
    PPC_CNTLZWo	= 231,
    PPC_CR6SET	= 232,
    PPC_CR6UNSET	= 233,
    PPC_CRAND	= 234,
    PPC_CRANDC	= 235,
    PPC_CREQV	= 236,
    PPC_CRNAND	= 237,
    PPC_CRNOR	= 238,
    PPC_CROR	= 239,
    PPC_CRORC	= 240,
    PPC_CRSET	= 241,
    PPC_CRUNSET	= 242,
    PPC_CRXOR	= 243,
    PPC_DCBA	= 244,
    PPC_DCBF	= 245,
    PPC_DCBI	= 246,
    PPC_DCBST	= 247,
    PPC_DCBT	= 248,
    PPC_DCBTST	= 249,
    PPC_DCBZ	= 250,
    PPC_DCBZL	= 251,
    PPC_DCCCI	= 252,
    PPC_DIVD	= 253,
    PPC_DIVDU	= 254,
    PPC_DIVDUo	= 255,
    PPC_DIVDo	= 256,
    PPC_DIVW	= 257,
    PPC_DIVWU	= 258,
    PPC_DIVWUo	= 259,
    PPC_DIVWo	= 260,
    PPC_DSS	= 261,
    PPC_DSSALL	= 262,
    PPC_DST	= 263,
    PPC_DST64	= 264,
    PPC_DSTST	= 265,
    PPC_DSTST64	= 266,
    PPC_DSTSTT	= 267,
    PPC_DSTSTT64	= 268,
    PPC_DSTT	= 269,
    PPC_DSTT64	= 270,
    PPC_DYNALLOC	= 271,
    PPC_DYNALLOC8	= 272,
    PPC_EH_SjLj_LongJmp32	= 273,
    PPC_EH_SjLj_LongJmp64	= 274,
    PPC_EH_SjLj_SetJmp32	= 275,
    PPC_EH_SjLj_SetJmp64	= 276,
    PPC_EH_SjLj_Setup	= 277,
    PPC_EQV	= 278,
    PPC_EQV8	= 279,
    PPC_EQV8o	= 280,
    PPC_EQVo	= 281,
    PPC_EVABS	= 282,
    PPC_EVADDIW	= 283,
    PPC_EVADDSMIAAW	= 284,
    PPC_EVADDSSIAAW	= 285,
    PPC_EVADDUMIAAW	= 286,
    PPC_EVADDUSIAAW	= 287,
    PPC_EVADDW	= 288,
    PPC_EVAND	= 289,
    PPC_EVANDC	= 290,
    PPC_EVCMPEQ	= 291,
    PPC_EVCMPGTS	= 292,
    PPC_EVCMPGTU	= 293,
    PPC_EVCMPLTS	= 294,
    PPC_EVCMPLTU	= 295,
    PPC_EVCNTLSW	= 296,
    PPC_EVCNTLZW	= 297,
    PPC_EVDIVWS	= 298,
    PPC_EVDIVWU	= 299,
    PPC_EVEQV	= 300,
    PPC_EVEXTSB	= 301,
    PPC_EVEXTSH	= 302,
    PPC_EVLDD	= 303,
    PPC_EVLDDX	= 304,
    PPC_EVLDH	= 305,
    PPC_EVLDHX	= 306,
    PPC_EVLDW	= 307,
    PPC_EVLDWX	= 308,
    PPC_EVLHHESPLAT	= 309,
    PPC_EVLHHESPLATX	= 310,
    PPC_EVLHHOSSPLAT	= 311,
    PPC_EVLHHOSSPLATX	= 312,
    PPC_EVLHHOUSPLAT	= 313,
    PPC_EVLHHOUSPLATX	= 314,
    PPC_EVLWHE	= 315,
    PPC_EVLWHEX	= 316,
    PPC_EVLWHOS	= 317,
    PPC_EVLWHOSX	= 318,
    PPC_EVLWHOU	= 319,
    PPC_EVLWHOUX	= 320,
    PPC_EVLWHSPLAT	= 321,
    PPC_EVLWHSPLATX	= 322,
    PPC_EVLWWSPLAT	= 323,
    PPC_EVLWWSPLATX	= 324,
    PPC_EVMERGEHI	= 325,
    PPC_EVMERGEHILO	= 326,
    PPC_EVMERGELO	= 327,
    PPC_EVMERGELOHI	= 328,
    PPC_EVMHEGSMFAA	= 329,
    PPC_EVMHEGSMFAN	= 330,
    PPC_EVMHEGSMIAA	= 331,
    PPC_EVMHEGSMIAN	= 332,
    PPC_EVMHEGUMIAA	= 333,
    PPC_EVMHEGUMIAN	= 334,
    PPC_EVMHESMF	= 335,
    PPC_EVMHESMFA	= 336,
    PPC_EVMHESMFAAW	= 337,
    PPC_EVMHESMFANW	= 338,
    PPC_EVMHESMI	= 339,
    PPC_EVMHESMIA	= 340,
    PPC_EVMHESMIAAW	= 341,
    PPC_EVMHESMIANW	= 342,
    PPC_EVMHESSF	= 343,
    PPC_EVMHESSFA	= 344,
    PPC_EVMHESSFAAW	= 345,
    PPC_EVMHESSFANW	= 346,
    PPC_EVMHESSIAAW	= 347,
    PPC_EVMHESSIANW	= 348,
    PPC_EVMHEUMI	= 349,
    PPC_EVMHEUMIA	= 350,
    PPC_EVMHEUMIAAW	= 351,
    PPC_EVMHEUMIANW	= 352,
    PPC_EVMHEUSIAAW	= 353,
    PPC_EVMHEUSIANW	= 354,
    PPC_EVMHOGSMFAA	= 355,
    PPC_EVMHOGSMFAN	= 356,
    PPC_EVMHOGSMIAA	= 357,
    PPC_EVMHOGSMIAN	= 358,
    PPC_EVMHOGUMIAA	= 359,
    PPC_EVMHOGUMIAN	= 360,
    PPC_EVMHOSMF	= 361,
    PPC_EVMHOSMFA	= 362,
    PPC_EVMHOSMFAAW	= 363,
    PPC_EVMHOSMFANW	= 364,
    PPC_EVMHOSMI	= 365,
    PPC_EVMHOSMIA	= 366,
    PPC_EVMHOSMIAAW	= 367,
    PPC_EVMHOSMIANW	= 368,
    PPC_EVMHOSSF	= 369,
    PPC_EVMHOSSFA	= 370,
    PPC_EVMHOSSFAAW	= 371,
    PPC_EVMHOSSFANW	= 372,
    PPC_EVMHOSSIAAW	= 373,
    PPC_EVMHOSSIANW	= 374,
    PPC_EVMHOUMI	= 375,
    PPC_EVMHOUMIA	= 376,
    PPC_EVMHOUMIAAW	= 377,
    PPC_EVMHOUMIANW	= 378,
    PPC_EVMHOUSIAAW	= 379,
    PPC_EVMHOUSIANW	= 380,
    PPC_EVMRA	= 381,
    PPC_EVMWHSMF	= 382,
    PPC_EVMWHSMFA	= 383,
    PPC_EVMWHSMI	= 384,
    PPC_EVMWHSMIA	= 385,
    PPC_EVMWHSSF	= 386,
    PPC_EVMWHSSFA	= 387,
    PPC_EVMWHUMI	= 388,
    PPC_EVMWHUMIA	= 389,
    PPC_EVMWLSMIAAW	= 390,
    PPC_EVMWLSMIANW	= 391,
    PPC_EVMWLSSIAAW	= 392,
    PPC_EVMWLSSIANW	= 393,
    PPC_EVMWLUMI	= 394,
    PPC_EVMWLUMIA	= 395,
    PPC_EVMWLUMIAAW	= 396,
    PPC_EVMWLUMIANW	= 397,
    PPC_EVMWLUSIAAW	= 398,
    PPC_EVMWLUSIANW	= 399,
    PPC_EVMWSMF	= 400,
    PPC_EVMWSMFA	= 401,
    PPC_EVMWSMFAA	= 402,
    PPC_EVMWSMFAN	= 403,
    PPC_EVMWSMI	= 404,
    PPC_EVMWSMIA	= 405,
    PPC_EVMWSMIAA	= 406,
    PPC_EVMWSMIAN	= 407,
    PPC_EVMWSSF	= 408,
    PPC_EVMWSSFA	= 409,
    PPC_EVMWSSFAA	= 410,
    PPC_EVMWSSFAN	= 411,
    PPC_EVMWUMI	= 412,
    PPC_EVMWUMIA	= 413,
    PPC_EVMWUMIAA	= 414,
    PPC_EVMWUMIAN	= 415,
    PPC_EVNAND	= 416,
    PPC_EVNEG	= 417,
    PPC_EVNOR	= 418,
    PPC_EVOR	= 419,
    PPC_EVORC	= 420,
    PPC_EVRLW	= 421,
    PPC_EVRLWI	= 422,
    PPC_EVRNDW	= 423,
    PPC_EVSLW	= 424,
    PPC_EVSLWI	= 425,
    PPC_EVSPLATFI	= 426,
    PPC_EVSPLATI	= 427,
    PPC_EVSRWIS	= 428,
    PPC_EVSRWIU	= 429,
    PPC_EVSRWS	= 430,
    PPC_EVSRWU	= 431,
    PPC_EVSTDD	= 432,
    PPC_EVSTDDX	= 433,
    PPC_EVSTDH	= 434,
    PPC_EVSTDHX	= 435,
    PPC_EVSTDW	= 436,
    PPC_EVSTDWX	= 437,
    PPC_EVSTWHE	= 438,
    PPC_EVSTWHEX	= 439,
    PPC_EVSTWHO	= 440,
    PPC_EVSTWHOX	= 441,
    PPC_EVSTWWE	= 442,
    PPC_EVSTWWEX	= 443,
    PPC_EVSTWWO	= 444,
    PPC_EVSTWWOX	= 445,
    PPC_EVSUBFSMIAAW	= 446,
    PPC_EVSUBFSSIAAW	= 447,
    PPC_EVSUBFUMIAAW	= 448,
    PPC_EVSUBFUSIAAW	= 449,
    PPC_EVSUBFW	= 450,
    PPC_EVSUBIFW	= 451,
    PPC_EVXOR	= 452,
    PPC_EXTLDI	= 453,
    PPC_EXTLDIo	= 454,
    PPC_EXTLWI	= 455,
    PPC_EXTLWIo	= 456,
    PPC_EXTRDI	= 457,
    PPC_EXTRDIo	= 458,
    PPC_EXTRWI	= 459,
    PPC_EXTRWIo	= 460,
    PPC_EXTSB	= 461,
    PPC_EXTSB8	= 462,
    PPC_EXTSB8_32_64	= 463,
    PPC_EXTSB8o	= 464,
    PPC_EXTSBo	= 465,
    PPC_EXTSH	= 466,
    PPC_EXTSH8	= 467,
    PPC_EXTSH8_32_64	= 468,
    PPC_EXTSH8o	= 469,
    PPC_EXTSHo	= 470,
    PPC_EXTSW	= 471,
    PPC_EXTSW_32_64	= 472,
    PPC_EXTSW_32_64o	= 473,
    PPC_EXTSWo	= 474,
    PPC_EnforceIEIO	= 475,
    PPC_FABSD	= 476,
    PPC_FABSDo	= 477,
    PPC_FABSS	= 478,
    PPC_FABSSo	= 479,
    PPC_FADD	= 480,
    PPC_FADDS	= 481,
    PPC_FADDSo	= 482,
    PPC_FADDo	= 483,
    PPC_FADDrtz	= 484,
    PPC_FCFID	= 485,
    PPC_FCFIDS	= 486,
    PPC_FCFIDSo	= 487,
    PPC_FCFIDU	= 488,
    PPC_FCFIDUS	= 489,
    PPC_FCFIDUSo	= 490,
    PPC_FCFIDUo	= 491,
    PPC_FCFIDo	= 492,
    PPC_FCMPUD	= 493,
    PPC_FCMPUS	= 494,
    PPC_FCPSGND	= 495,
    PPC_FCPSGNDo	= 496,
    PPC_FCPSGNS	= 497,
    PPC_FCPSGNSo	= 498,
    PPC_FCTID	= 499,
    PPC_FCTIDUZ	= 500,
    PPC_FCTIDUZo	= 501,
    PPC_FCTIDZ	= 502,
    PPC_FCTIDZo	= 503,
    PPC_FCTIDo	= 504,
    PPC_FCTIW	= 505,
    PPC_FCTIWUZ	= 506,
    PPC_FCTIWUZo	= 507,
    PPC_FCTIWZ	= 508,
    PPC_FCTIWZo	= 509,
    PPC_FCTIWo	= 510,
    PPC_FDIV	= 511,
    PPC_FDIVS	= 512,
    PPC_FDIVSo	= 513,
    PPC_FDIVo	= 514,
    PPC_FMADD	= 515,
    PPC_FMADDS	= 516,
    PPC_FMADDSo	= 517,
    PPC_FMADDo	= 518,
    PPC_FMR	= 519,
    PPC_FMRo	= 520,
    PPC_FMSUB	= 521,
    PPC_FMSUBS	= 522,
    PPC_FMSUBSo	= 523,
    PPC_FMSUBo	= 524,
    PPC_FMUL	= 525,
    PPC_FMULS	= 526,
    PPC_FMULSo	= 527,
    PPC_FMULo	= 528,
    PPC_FNABSD	= 529,
    PPC_FNABSDo	= 530,
    PPC_FNABSS	= 531,
    PPC_FNABSSo	= 532,
    PPC_FNEGD	= 533,
    PPC_FNEGDo	= 534,
    PPC_FNEGS	= 535,
    PPC_FNEGSo	= 536,
    PPC_FNMADD	= 537,
    PPC_FNMADDS	= 538,
    PPC_FNMADDSo	= 539,
    PPC_FNMADDo	= 540,
    PPC_FNMSUB	= 541,
    PPC_FNMSUBS	= 542,
    PPC_FNMSUBSo	= 543,
    PPC_FNMSUBo	= 544,
    PPC_FRE	= 545,
    PPC_FRES	= 546,
    PPC_FRESo	= 547,
    PPC_FREo	= 548,
    PPC_FRIMD	= 549,
    PPC_FRIMDo	= 550,
    PPC_FRIMS	= 551,
    PPC_FRIMSo	= 552,
    PPC_FRIND	= 553,
    PPC_FRINDo	= 554,
    PPC_FRINS	= 555,
    PPC_FRINSo	= 556,
    PPC_FRIPD	= 557,
    PPC_FRIPDo	= 558,
    PPC_FRIPS	= 559,
    PPC_FRIPSo	= 560,
    PPC_FRIZD	= 561,
    PPC_FRIZDo	= 562,
    PPC_FRIZS	= 563,
    PPC_FRIZSo	= 564,
    PPC_FRSP	= 565,
    PPC_FRSPo	= 566,
    PPC_FRSQRTE	= 567,
    PPC_FRSQRTES	= 568,
    PPC_FRSQRTESo	= 569,
    PPC_FRSQRTEo	= 570,
    PPC_FSELD	= 571,
    PPC_FSELDo	= 572,
    PPC_FSELS	= 573,
    PPC_FSELSo	= 574,
    PPC_FSQRT	= 575,
    PPC_FSQRTS	= 576,
    PPC_FSQRTSo	= 577,
    PPC_FSQRTo	= 578,
    PPC_FSUB	= 579,
    PPC_FSUBS	= 580,
    PPC_FSUBSo	= 581,
    PPC_FSUBo	= 582,
    PPC_GETtlsADDR	= 583,
    PPC_GETtlsADDR32	= 584,
    PPC_GETtlsldADDR	= 585,
    PPC_GETtlsldADDR32	= 586,
    PPC_ICBI	= 587,
    PPC_ICBT	= 588,
    PPC_ICCCI	= 589,
    PPC_INSLWI	= 590,
    PPC_INSLWIo	= 591,
    PPC_INSRDI	= 592,
    PPC_INSRDIo	= 593,
    PPC_INSRWI	= 594,
    PPC_INSRWIo	= 595,
    PPC_ISEL	= 596,
    PPC_ISEL8	= 597,
    PPC_ISYNC	= 598,
    PPC_LA	= 599,
    PPC_LAx	= 600,
    PPC_LBZ	= 601,
    PPC_LBZ8	= 602,
    PPC_LBZCIX	= 603,
    PPC_LBZU	= 604,
    PPC_LBZU8	= 605,
    PPC_LBZUX	= 606,
    PPC_LBZUX8	= 607,
    PPC_LBZX	= 608,
    PPC_LBZX8	= 609,
    PPC_LD	= 610,
    PPC_LDARX	= 611,
    PPC_LDBRX	= 612,
    PPC_LDCIX	= 613,
    PPC_LDU	= 614,
    PPC_LDUX	= 615,
    PPC_LDX	= 616,
    PPC_LDgotTprelL	= 617,
    PPC_LDgotTprelL32	= 618,
    PPC_LDtoc	= 619,
    PPC_LDtocBA	= 620,
    PPC_LDtocCPT	= 621,
    PPC_LDtocJTI	= 622,
    PPC_LDtocL	= 623,
    PPC_LFD	= 624,
    PPC_LFDU	= 625,
    PPC_LFDUX	= 626,
    PPC_LFDX	= 627,
    PPC_LFIWAX	= 628,
    PPC_LFIWZX	= 629,
    PPC_LFS	= 630,
    PPC_LFSU	= 631,
    PPC_LFSUX	= 632,
    PPC_LFSX	= 633,
    PPC_LHA	= 634,
    PPC_LHA8	= 635,
    PPC_LHAU	= 636,
    PPC_LHAU8	= 637,
    PPC_LHAUX	= 638,
    PPC_LHAUX8	= 639,
    PPC_LHAX	= 640,
    PPC_LHAX8	= 641,
    PPC_LHBRX	= 642,
    PPC_LHBRX8	= 643,
    PPC_LHZ	= 644,
    PPC_LHZ8	= 645,
    PPC_LHZCIX	= 646,
    PPC_LHZU	= 647,
    PPC_LHZU8	= 648,
    PPC_LHZUX	= 649,
    PPC_LHZUX8	= 650,
    PPC_LHZX	= 651,
    PPC_LHZX8	= 652,
    PPC_LI	= 653,
    PPC_LI8	= 654,
    PPC_LIS	= 655,
    PPC_LIS8	= 656,
    PPC_LMW	= 657,
    PPC_LSWI	= 658,
    PPC_LVEBX	= 659,
    PPC_LVEHX	= 660,
    PPC_LVEWX	= 661,
    PPC_LVSL	= 662,
    PPC_LVSR	= 663,
    PPC_LVX	= 664,
    PPC_LVXL	= 665,
    PPC_LWA	= 666,
    PPC_LWARX	= 667,
    PPC_LWAUX	= 668,
    PPC_LWAX	= 669,
    PPC_LWAX_32	= 670,
    PPC_LWA_32	= 671,
    PPC_LWBRX	= 672,
    PPC_LWBRX8	= 673,
    PPC_LWZ	= 674,
    PPC_LWZ8	= 675,
    PPC_LWZCIX	= 676,
    PPC_LWZU	= 677,
    PPC_LWZU8	= 678,
    PPC_LWZUX	= 679,
    PPC_LWZUX8	= 680,
    PPC_LWZX	= 681,
    PPC_LWZX8	= 682,
    PPC_LWZtoc	= 683,
    PPC_LXSDX	= 684,
    PPC_LXVD2X	= 685,
    PPC_LXVDSX	= 686,
    PPC_LXVW4X	= 687,
    PPC_MBAR	= 688,
    PPC_MCRF	= 689,
    PPC_MCRFS	= 690,
    PPC_MFCR	= 691,
    PPC_MFCR8	= 692,
    PPC_MFCTR	= 693,
    PPC_MFCTR8	= 694,
    PPC_MFDCR	= 695,
    PPC_MFFS	= 696,
    PPC_MFFSo	= 697,
    PPC_MFLR	= 698,
    PPC_MFLR8	= 699,
    PPC_MFMSR	= 700,
    PPC_MFOCRF	= 701,
    PPC_MFOCRF8	= 702,
    PPC_MFSPR	= 703,
    PPC_MFSR	= 704,
    PPC_MFSRIN	= 705,
    PPC_MFTB	= 706,
    PPC_MFTB8	= 707,
    PPC_MFVRSAVE	= 708,
    PPC_MFVRSAVEv	= 709,
    PPC_MFVSCR	= 710,
    PPC_MSYNC	= 711,
    PPC_MTCRF	= 712,
    PPC_MTCRF8	= 713,
    PPC_MTCTR	= 714,
    PPC_MTCTR8	= 715,
    PPC_MTCTR8loop	= 716,
    PPC_MTCTRloop	= 717,
    PPC_MTDCR	= 718,
    PPC_MTFSB0	= 719,
    PPC_MTFSB1	= 720,
    PPC_MTFSF	= 721,
    PPC_MTFSFI	= 722,
    PPC_MTFSFIo	= 723,
    PPC_MTFSFb	= 724,
    PPC_MTFSFo	= 725,
    PPC_MTLR	= 726,
    PPC_MTLR8	= 727,
    PPC_MTMSR	= 728,
    PPC_MTMSRD	= 729,
    PPC_MTOCRF	= 730,
    PPC_MTOCRF8	= 731,
    PPC_MTSPR	= 732,
    PPC_MTSR	= 733,
    PPC_MTSRIN	= 734,
    PPC_MTVRSAVE	= 735,
    PPC_MTVRSAVEv	= 736,
    PPC_MTVSCR	= 737,
    PPC_MULHD	= 738,
    PPC_MULHDU	= 739,
    PPC_MULHDUo	= 740,
    PPC_MULHDo	= 741,
    PPC_MULHW	= 742,
    PPC_MULHWU	= 743,
    PPC_MULHWUo	= 744,
    PPC_MULHWo	= 745,
    PPC_MULLD	= 746,
    PPC_MULLDo	= 747,
    PPC_MULLI	= 748,
    PPC_MULLI8	= 749,
    PPC_MULLW	= 750,
    PPC_MULLWo	= 751,
    PPC_MoveGOTtoLR	= 752,
    PPC_MovePCtoLR	= 753,
    PPC_MovePCtoLR8	= 754,
    PPC_NAND	= 755,
    PPC_NAND8	= 756,
    PPC_NAND8o	= 757,
    PPC_NANDo	= 758,
    PPC_NEG	= 759,
    PPC_NEG8	= 760,
    PPC_NEG8o	= 761,
    PPC_NEGo	= 762,
    PPC_NOP	= 763,
    PPC_NOP_GT_PWR6	= 764,
    PPC_NOP_GT_PWR7	= 765,
    PPC_NOR	= 766,
    PPC_NOR8	= 767,
    PPC_NOR8o	= 768,
    PPC_NORo	= 769,
    PPC_OR	= 770,
    PPC_OR8	= 771,
    PPC_OR8o	= 772,
    PPC_ORC	= 773,
    PPC_ORC8	= 774,
    PPC_ORC8o	= 775,
    PPC_ORCo	= 776,
    PPC_ORI	= 777,
    PPC_ORI8	= 778,
    PPC_ORIS	= 779,
    PPC_ORIS8	= 780,
    PPC_ORo	= 781,
    PPC_POPCNTD	= 782,
    PPC_POPCNTW	= 783,
    PPC_PPC32GOT	= 784,
    PPC_PPC32PICGOT	= 785,
    PPC_QVALIGNI	= 786,
    PPC_QVALIGNIb	= 787,
    PPC_QVALIGNIs	= 788,
    PPC_QVESPLATI	= 789,
    PPC_QVESPLATIb	= 790,
    PPC_QVESPLATIs	= 791,
    PPC_QVFABS	= 792,
    PPC_QVFABSs	= 793,
    PPC_QVFADD	= 794,
    PPC_QVFADDS	= 795,
    PPC_QVFADDSs	= 796,
    PPC_QVFCFID	= 797,
    PPC_QVFCFIDS	= 798,
    PPC_QVFCFIDU	= 799,
    PPC_QVFCFIDUS	= 800,
    PPC_QVFCFIDb	= 801,
    PPC_QVFCMPEQ	= 802,
    PPC_QVFCMPEQb	= 803,
    PPC_QVFCMPEQbs	= 804,
    PPC_QVFCMPGT	= 805,
    PPC_QVFCMPGTb	= 806,
    PPC_QVFCMPGTbs	= 807,
    PPC_QVFCMPLT	= 808,
    PPC_QVFCMPLTb	= 809,
    PPC_QVFCMPLTbs	= 810,
    PPC_QVFCPSGN	= 811,
    PPC_QVFCPSGNs	= 812,
    PPC_QVFCTID	= 813,
    PPC_QVFCTIDU	= 814,
    PPC_QVFCTIDUZ	= 815,
    PPC_QVFCTIDZ	= 816,
    PPC_QVFCTIDb	= 817,
    PPC_QVFCTIW	= 818,
    PPC_QVFCTIWU	= 819,
    PPC_QVFCTIWUZ	= 820,
    PPC_QVFCTIWZ	= 821,
    PPC_QVFLOGICAL	= 822,
    PPC_QVFLOGICALb	= 823,
    PPC_QVFLOGICALs	= 824,
    PPC_QVFMADD	= 825,
    PPC_QVFMADDS	= 826,
    PPC_QVFMADDSs	= 827,
    PPC_QVFMR	= 828,
    PPC_QVFMRb	= 829,
    PPC_QVFMRs	= 830,
    PPC_QVFMSUB	= 831,
    PPC_QVFMSUBS	= 832,
    PPC_QVFMSUBSs	= 833,
    PPC_QVFMUL	= 834,
    PPC_QVFMULS	= 835,
    PPC_QVFMULSs	= 836,
    PPC_QVFNABS	= 837,
    PPC_QVFNABSs	= 838,
    PPC_QVFNEG	= 839,
    PPC_QVFNEGs	= 840,
    PPC_QVFNMADD	= 841,
    PPC_QVFNMADDS	= 842,
    PPC_QVFNMADDSs	= 843,
    PPC_QVFNMSUB	= 844,
    PPC_QVFNMSUBS	= 845,
    PPC_QVFNMSUBSs	= 846,
    PPC_QVFPERM	= 847,
    PPC_QVFPERMs	= 848,
    PPC_QVFRE	= 849,
    PPC_QVFRES	= 850,
    PPC_QVFRESs	= 851,
    PPC_QVFRIM	= 852,
    PPC_QVFRIMs	= 853,
    PPC_QVFRIN	= 854,
    PPC_QVFRINs	= 855,
    PPC_QVFRIP	= 856,
    PPC_QVFRIPs	= 857,
    PPC_QVFRIZ	= 858,
    PPC_QVFRIZs	= 859,
    PPC_QVFRSP	= 860,
    PPC_QVFRSPs	= 861,
    PPC_QVFRSQRTE	= 862,
    PPC_QVFRSQRTES	= 863,
    PPC_QVFRSQRTESs	= 864,
    PPC_QVFSEL	= 865,
    PPC_QVFSELb	= 866,
    PPC_QVFSELbb	= 867,
    PPC_QVFSELbs	= 868,
    PPC_QVFSUB	= 869,
    PPC_QVFSUBS	= 870,
    PPC_QVFSUBSs	= 871,
    PPC_QVFTSTNAN	= 872,
    PPC_QVFTSTNANb	= 873,
    PPC_QVFTSTNANbs	= 874,
    PPC_QVFXMADD	= 875,
    PPC_QVFXMADDS	= 876,
    PPC_QVFXMUL	= 877,
    PPC_QVFXMULS	= 878,
    PPC_QVFXXCPNMADD	= 879,
    PPC_QVFXXCPNMADDS	= 880,
    PPC_QVFXXMADD	= 881,
    PPC_QVFXXMADDS	= 882,
    PPC_QVFXXNPMADD	= 883,
    PPC_QVFXXNPMADDS	= 884,
    PPC_QVGPCI	= 885,
    PPC_QVLFCDUX	= 886,
    PPC_QVLFCDUXA	= 887,
    PPC_QVLFCDX	= 888,
    PPC_QVLFCDXA	= 889,
    PPC_QVLFCSUX	= 890,
    PPC_QVLFCSUXA	= 891,
    PPC_QVLFCSX	= 892,
    PPC_QVLFCSXA	= 893,
    PPC_QVLFCSXs	= 894,
    PPC_QVLFDUX	= 895,
    PPC_QVLFDUXA	= 896,
    PPC_QVLFDX	= 897,
    PPC_QVLFDXA	= 898,
    PPC_QVLFDXb	= 899,
    PPC_QVLFIWAX	= 900,
    PPC_QVLFIWAXA	= 901,
    PPC_QVLFIWZX	= 902,
    PPC_QVLFIWZXA	= 903,
    PPC_QVLFSUX	= 904,
    PPC_QVLFSUXA	= 905,
    PPC_QVLFSX	= 906,
    PPC_QVLFSXA	= 907,
    PPC_QVLFSXb	= 908,
    PPC_QVLFSXs	= 909,
    PPC_QVLPCLDX	= 910,
    PPC_QVLPCLSX	= 911,
    PPC_QVLPCLSXint	= 912,
    PPC_QVLPCRDX	= 913,
    PPC_QVLPCRSX	= 914,
    PPC_QVSTFCDUX	= 915,
    PPC_QVSTFCDUXA	= 916,
    PPC_QVSTFCDUXI	= 917,
    PPC_QVSTFCDUXIA	= 918,
    PPC_QVSTFCDX	= 919,
    PPC_QVSTFCDXA	= 920,
    PPC_QVSTFCDXI	= 921,
    PPC_QVSTFCDXIA	= 922,
    PPC_QVSTFCSUX	= 923,
    PPC_QVSTFCSUXA	= 924,
    PPC_QVSTFCSUXI	= 925,
    PPC_QVSTFCSUXIA	= 926,
    PPC_QVSTFCSX	= 927,
    PPC_QVSTFCSXA	= 928,
    PPC_QVSTFCSXI	= 929,
    PPC_QVSTFCSXIA	= 930,
    PPC_QVSTFCSXs	= 931,
    PPC_QVSTFDUX	= 932,
    PPC_QVSTFDUXA	= 933,
    PPC_QVSTFDUXI	= 934,
    PPC_QVSTFDUXIA	= 935,
    PPC_QVSTFDX	= 936,
    PPC_QVSTFDXA	= 937,
    PPC_QVSTFDXI	= 938,
    PPC_QVSTFDXIA	= 939,
    PPC_QVSTFDXb	= 940,
    PPC_QVSTFIWX	= 941,
    PPC_QVSTFIWXA	= 942,
    PPC_QVSTFSUX	= 943,
    PPC_QVSTFSUXA	= 944,
    PPC_QVSTFSUXI	= 945,
    PPC_QVSTFSUXIA	= 946,
    PPC_QVSTFSUXs	= 947,
    PPC_QVSTFSX	= 948,
    PPC_QVSTFSXA	= 949,
    PPC_QVSTFSXI	= 950,
    PPC_QVSTFSXIA	= 951,
    PPC_QVSTFSXs	= 952,
    PPC_RESTORE_CR	= 953,
    PPC_RESTORE_CRBIT	= 954,
    PPC_RESTORE_VRSAVE	= 955,
    PPC_RFCI	= 956,
    PPC_RFDI	= 957,
    PPC_RFI	= 958,
    PPC_RFID	= 959,
    PPC_RFMCI	= 960,
    PPC_RLDCL	= 961,
    PPC_RLDCLo	= 962,
    PPC_RLDCR	= 963,
    PPC_RLDCRo	= 964,
    PPC_RLDIC	= 965,
    PPC_RLDICL	= 966,
    PPC_RLDICL_32_64	= 967,
    PPC_RLDICLo	= 968,
    PPC_RLDICR	= 969,
    PPC_RLDICRo	= 970,
    PPC_RLDICo	= 971,
    PPC_RLDIMI	= 972,
    PPC_RLDIMIo	= 973,
    PPC_RLWIMI	= 974,
    PPC_RLWIMI8	= 975,
    PPC_RLWIMI8o	= 976,
    PPC_RLWIMIo	= 977,
    PPC_RLWINM	= 978,
    PPC_RLWINM8	= 979,
    PPC_RLWINM8o	= 980,
    PPC_RLWINMo	= 981,
    PPC_RLWNM	= 982,
    PPC_RLWNM8	= 983,
    PPC_RLWNM8o	= 984,
    PPC_RLWNMo	= 985,
    PPC_ROTRDI	= 986,
    PPC_ROTRDIo	= 987,
    PPC_ROTRWI	= 988,
    PPC_ROTRWIo	= 989,
    PPC_ReadTB	= 990,
    PPC_SC	= 991,
    PPC_SELECT_CC_F4	= 992,
    PPC_SELECT_CC_F8	= 993,
    PPC_SELECT_CC_I4	= 994,
    PPC_SELECT_CC_I8	= 995,
    PPC_SELECT_CC_QBRC	= 996,
    PPC_SELECT_CC_QFRC	= 997,
    PPC_SELECT_CC_QSRC	= 998,
    PPC_SELECT_CC_VRRC	= 999,
    PPC_SELECT_CC_VSFRC	= 1000,
    PPC_SELECT_CC_VSRC	= 1001,
    PPC_SELECT_F4	= 1002,
    PPC_SELECT_F8	= 1003,
    PPC_SELECT_I4	= 1004,
    PPC_SELECT_I8	= 1005,
    PPC_SELECT_QBRC	= 1006,
    PPC_SELECT_QFRC	= 1007,
    PPC_SELECT_QSRC	= 1008,
    PPC_SELECT_VRRC	= 1009,
    PPC_SELECT_VSFRC	= 1010,
    PPC_SELECT_VSRC	= 1011,
    PPC_SLBIA	= 1012,
    PPC_SLBIE	= 1013,
    PPC_SLBMFEE	= 1014,
    PPC_SLBMTE	= 1015,
    PPC_SLD	= 1016,
    PPC_SLDI	= 1017,
    PPC_SLDIo	= 1018,
    PPC_SLDo	= 1019,
    PPC_SLW	= 1020,
    PPC_SLW8	= 1021,
    PPC_SLW8o	= 1022,
    PPC_SLWI	= 1023,
    PPC_SLWIo	= 1024,
    PPC_SLWo	= 1025,
    PPC_SPILL_CR	= 1026,
    PPC_SPILL_CRBIT	= 1027,
    PPC_SPILL_VRSAVE	= 1028,
    PPC_SRAD	= 1029,
    PPC_SRADI	= 1030,
    PPC_SRADIo	= 1031,
    PPC_SRADo	= 1032,
    PPC_SRAW	= 1033,
    PPC_SRAWI	= 1034,
    PPC_SRAWIo	= 1035,
    PPC_SRAWo	= 1036,
    PPC_SRD	= 1037,
    PPC_SRDI	= 1038,
    PPC_SRDIo	= 1039,
    PPC_SRDo	= 1040,
    PPC_SRW	= 1041,
    PPC_SRW8	= 1042,
    PPC_SRW8o	= 1043,
    PPC_SRWI	= 1044,
    PPC_SRWIo	= 1045,
    PPC_SRWo	= 1046,
    PPC_STB	= 1047,
    PPC_STB8	= 1048,
    PPC_STBCIX	= 1049,
    PPC_STBU	= 1050,
    PPC_STBU8	= 1051,
    PPC_STBUX	= 1052,
    PPC_STBUX8	= 1053,
    PPC_STBX	= 1054,
    PPC_STBX8	= 1055,
    PPC_STD	= 1056,
    PPC_STDBRX	= 1057,
    PPC_STDCIX	= 1058,
    PPC_STDCX	= 1059,
    PPC_STDU	= 1060,
    PPC_STDUX	= 1061,
    PPC_STDX	= 1062,
    PPC_STFD	= 1063,
    PPC_STFDU	= 1064,
    PPC_STFDUX	= 1065,
    PPC_STFDX	= 1066,
    PPC_STFIWX	= 1067,
    PPC_STFS	= 1068,
    PPC_STFSU	= 1069,
    PPC_STFSUX	= 1070,
    PPC_STFSX	= 1071,
    PPC_STH	= 1072,
    PPC_STH8	= 1073,
    PPC_STHBRX	= 1074,
    PPC_STHCIX	= 1075,
    PPC_STHU	= 1076,
    PPC_STHU8	= 1077,
    PPC_STHUX	= 1078,
    PPC_STHUX8	= 1079,
    PPC_STHX	= 1080,
    PPC_STHX8	= 1081,
    PPC_STMW	= 1082,
    PPC_STSWI	= 1083,
    PPC_STVEBX	= 1084,
    PPC_STVEHX	= 1085,
    PPC_STVEWX	= 1086,
    PPC_STVX	= 1087,
    PPC_STVXL	= 1088,
    PPC_STW	= 1089,
    PPC_STW8	= 1090,
    PPC_STWBRX	= 1091,
    PPC_STWCIX	= 1092,
    PPC_STWCX	= 1093,
    PPC_STWU	= 1094,
    PPC_STWU8	= 1095,
    PPC_STWUX	= 1096,
    PPC_STWUX8	= 1097,
    PPC_STWX	= 1098,
    PPC_STWX8	= 1099,
    PPC_STXSDX	= 1100,
    PPC_STXVD2X	= 1101,
    PPC_STXVW4X	= 1102,
    PPC_SUBF	= 1103,
    PPC_SUBF8	= 1104,
    PPC_SUBF8o	= 1105,
    PPC_SUBFC	= 1106,
    PPC_SUBFC8	= 1107,
    PPC_SUBFC8o	= 1108,
    PPC_SUBFCo	= 1109,
    PPC_SUBFE	= 1110,
    PPC_SUBFE8	= 1111,
    PPC_SUBFE8o	= 1112,
    PPC_SUBFEo	= 1113,
    PPC_SUBFIC	= 1114,
    PPC_SUBFIC8	= 1115,
    PPC_SUBFME	= 1116,
    PPC_SUBFME8	= 1117,
    PPC_SUBFME8o	= 1118,
    PPC_SUBFMEo	= 1119,
    PPC_SUBFZE	= 1120,
    PPC_SUBFZE8	= 1121,
    PPC_SUBFZE8o	= 1122,
    PPC_SUBFZEo	= 1123,
    PPC_SUBFo	= 1124,
    PPC_SUBI	= 1125,
    PPC_SUBIC	= 1126,
    PPC_SUBICo	= 1127,
    PPC_SUBIS	= 1128,
    PPC_SYNC	= 1129,
    PPC_TAILB	= 1130,
    PPC_TAILB8	= 1131,
    PPC_TAILBA	= 1132,
    PPC_TAILBA8	= 1133,
    PPC_TAILBCTR	= 1134,
    PPC_TAILBCTR8	= 1135,
    PPC_TCRETURNai	= 1136,
    PPC_TCRETURNai8	= 1137,
    PPC_TCRETURNdi	= 1138,
    PPC_TCRETURNdi8	= 1139,
    PPC_TCRETURNri	= 1140,
    PPC_TCRETURNri8	= 1141,
    PPC_TD	= 1142,
    PPC_TDI	= 1143,
    PPC_TLBIA	= 1144,
    PPC_TLBIE	= 1145,
    PPC_TLBIEL	= 1146,
    PPC_TLBIVAX	= 1147,
    PPC_TLBLD	= 1148,
    PPC_TLBLI	= 1149,
    PPC_TLBRE	= 1150,
    PPC_TLBRE2	= 1151,
    PPC_TLBSX	= 1152,
    PPC_TLBSX2	= 1153,
    PPC_TLBSX2D	= 1154,
    PPC_TLBSYNC	= 1155,
    PPC_TLBWE	= 1156,
    PPC_TLBWE2	= 1157,
    PPC_TRAP	= 1158,
    PPC_TW	= 1159,
    PPC_TWI	= 1160,
    PPC_UPDATE_VRSAVE	= 1161,
    PPC_UpdateGBR	= 1162,
    PPC_VADDCUW	= 1163,
    PPC_VADDFP	= 1164,
    PPC_VADDSBS	= 1165,
    PPC_VADDSHS	= 1166,
    PPC_VADDSWS	= 1167,
    PPC_VADDUBM	= 1168,
    PPC_VADDUBS	= 1169,
    PPC_VADDUDM	= 1170,
    PPC_VADDUHM	= 1171,
    PPC_VADDUHS	= 1172,
    PPC_VADDUWM	= 1173,
    PPC_VADDUWS	= 1174,
    PPC_VAND	= 1175,
    PPC_VANDC	= 1176,
    PPC_VAVGSB	= 1177,
    PPC_VAVGSH	= 1178,
    PPC_VAVGSW	= 1179,
    PPC_VAVGUB	= 1180,
    PPC_VAVGUH	= 1181,
    PPC_VAVGUW	= 1182,
    PPC_VCFSX	= 1183,
    PPC_VCFSX_0	= 1184,
    PPC_VCFUX	= 1185,
    PPC_VCFUX_0	= 1186,
    PPC_VCLZB	= 1187,
    PPC_VCLZD	= 1188,
    PPC_VCLZH	= 1189,
    PPC_VCLZW	= 1190,
    PPC_VCMPBFP	= 1191,
    PPC_VCMPBFPo	= 1192,
    PPC_VCMPEQFP	= 1193,
    PPC_VCMPEQFPo	= 1194,
    PPC_VCMPEQUB	= 1195,
    PPC_VCMPEQUBo	= 1196,
    PPC_VCMPEQUD	= 1197,
    PPC_VCMPEQUDo	= 1198,
    PPC_VCMPEQUH	= 1199,
    PPC_VCMPEQUHo	= 1200,
    PPC_VCMPEQUW	= 1201,
    PPC_VCMPEQUWo	= 1202,
    PPC_VCMPGEFP	= 1203,
    PPC_VCMPGEFPo	= 1204,
    PPC_VCMPGTFP	= 1205,
    PPC_VCMPGTFPo	= 1206,
    PPC_VCMPGTSB	= 1207,
    PPC_VCMPGTSBo	= 1208,
    PPC_VCMPGTSD	= 1209,
    PPC_VCMPGTSDo	= 1210,
    PPC_VCMPGTSH	= 1211,
    PPC_VCMPGTSHo	= 1212,
    PPC_VCMPGTSW	= 1213,
    PPC_VCMPGTSWo	= 1214,
    PPC_VCMPGTUB	= 1215,
    PPC_VCMPGTUBo	= 1216,
    PPC_VCMPGTUD	= 1217,
    PPC_VCMPGTUDo	= 1218,
    PPC_VCMPGTUH	= 1219,
    PPC_VCMPGTUHo	= 1220,
    PPC_VCMPGTUW	= 1221,
    PPC_VCMPGTUWo	= 1222,
    PPC_VCTSXS	= 1223,
    PPC_VCTSXS_0	= 1224,
    PPC_VCTUXS	= 1225,
    PPC_VCTUXS_0	= 1226,
    PPC_VEQV	= 1227,
    PPC_VEXPTEFP	= 1228,
    PPC_VLOGEFP	= 1229,
    PPC_VMADDFP	= 1230,
    PPC_VMAXFP	= 1231,
    PPC_VMAXSB	= 1232,
    PPC_VMAXSD	= 1233,
    PPC_VMAXSH	= 1234,
    PPC_VMAXSW	= 1235,
    PPC_VMAXUB	= 1236,
    PPC_VMAXUD	= 1237,
    PPC_VMAXUH	= 1238,
    PPC_VMAXUW	= 1239,
    PPC_VMHADDSHS	= 1240,
    PPC_VMHRADDSHS	= 1241,
    PPC_VMIDUD	= 1242,
    PPC_VMINFP	= 1243,
    PPC_VMINSB	= 1244,
    PPC_VMINSD	= 1245,
    PPC_VMINSH	= 1246,
    PPC_VMINSW	= 1247,
    PPC_VMINUB	= 1248,
    PPC_VMINUH	= 1249,
    PPC_VMINUW	= 1250,
    PPC_VMLADDUHM	= 1251,
    PPC_VMRGHB	= 1252,
    PPC_VMRGHH	= 1253,
    PPC_VMRGHW	= 1254,
    PPC_VMRGLB	= 1255,
    PPC_VMRGLH	= 1256,
    PPC_VMRGLW	= 1257,
    PPC_VMSUMMBM	= 1258,
    PPC_VMSUMSHM	= 1259,
    PPC_VMSUMSHS	= 1260,
    PPC_VMSUMUBM	= 1261,
    PPC_VMSUMUHM	= 1262,
    PPC_VMSUMUHS	= 1263,
    PPC_VMULESB	= 1264,
    PPC_VMULESH	= 1265,
    PPC_VMULESW	= 1266,
    PPC_VMULEUB	= 1267,
    PPC_VMULEUH	= 1268,
    PPC_VMULEUW	= 1269,
    PPC_VMULOSB	= 1270,
    PPC_VMULOSH	= 1271,
    PPC_VMULOSW	= 1272,
    PPC_VMULOUB	= 1273,
    PPC_VMULOUH	= 1274,
    PPC_VMULOUW	= 1275,
    PPC_VMULUWM	= 1276,
    PPC_VNAND	= 1277,
    PPC_VNMSUBFP	= 1278,
    PPC_VNOR	= 1279,
    PPC_VOR	= 1280,
    PPC_VORC	= 1281,
    PPC_VPERM	= 1282,
    PPC_VPKPX	= 1283,
    PPC_VPKSHSS	= 1284,
    PPC_VPKSHUS	= 1285,
    PPC_VPKSWSS	= 1286,
    PPC_VPKSWUS	= 1287,
    PPC_VPKUHUM	= 1288,
    PPC_VPKUHUS	= 1289,
    PPC_VPKUWUM	= 1290,
    PPC_VPKUWUS	= 1291,
    PPC_VPOPCNTB	= 1292,
    PPC_VPOPCNTD	= 1293,
    PPC_VPOPCNTH	= 1294,
    PPC_VPOPCNTW	= 1295,
    PPC_VREFP	= 1296,
    PPC_VRFIM	= 1297,
    PPC_VRFIN	= 1298,
    PPC_VRFIP	= 1299,
    PPC_VRFIZ	= 1300,
    PPC_VRLB	= 1301,
    PPC_VRLD	= 1302,
    PPC_VRLH	= 1303,
    PPC_VRLW	= 1304,
    PPC_VRSQRTEFP	= 1305,
    PPC_VSEL	= 1306,
    PPC_VSL	= 1307,
    PPC_VSLB	= 1308,
    PPC_VSLD	= 1309,
    PPC_VSLDOI	= 1310,
    PPC_VSLH	= 1311,
    PPC_VSLO	= 1312,
    PPC_VSLW	= 1313,
    PPC_VSPLTB	= 1314,
    PPC_VSPLTH	= 1315,
    PPC_VSPLTISB	= 1316,
    PPC_VSPLTISH	= 1317,
    PPC_VSPLTISW	= 1318,
    PPC_VSPLTW	= 1319,
    PPC_VSR	= 1320,
    PPC_VSRAB	= 1321,
    PPC_VSRAD	= 1322,
    PPC_VSRAH	= 1323,
    PPC_VSRAW	= 1324,
    PPC_VSRB	= 1325,
    PPC_VSRD	= 1326,
    PPC_VSRH	= 1327,
    PPC_VSRO	= 1328,
    PPC_VSRW	= 1329,
    PPC_VSUBCUW	= 1330,
    PPC_VSUBFP	= 1331,
    PPC_VSUBSBS	= 1332,
    PPC_VSUBSHS	= 1333,
    PPC_VSUBSWS	= 1334,
    PPC_VSUBUBM	= 1335,
    PPC_VSUBUBS	= 1336,
    PPC_VSUBUDM	= 1337,
    PPC_VSUBUHM	= 1338,
    PPC_VSUBUHS	= 1339,
    PPC_VSUBUWM	= 1340,
    PPC_VSUBUWS	= 1341,
    PPC_VSUM2SWS	= 1342,
    PPC_VSUM4SBS	= 1343,
    PPC_VSUM4SHS	= 1344,
    PPC_VSUM4UBS	= 1345,
    PPC_VSUMSWS	= 1346,
    PPC_VUPKHPX	= 1347,
    PPC_VUPKHSB	= 1348,
    PPC_VUPKHSH	= 1349,
    PPC_VUPKLPX	= 1350,
    PPC_VUPKLSB	= 1351,
    PPC_VUPKLSH	= 1352,
    PPC_VXOR	= 1353,
    PPC_V_SET0	= 1354,
    PPC_V_SET0B	= 1355,
    PPC_V_SET0H	= 1356,
    PPC_V_SETALLONES	= 1357,
    PPC_V_SETALLONESB	= 1358,
    PPC_V_SETALLONESH	= 1359,
    PPC_WAIT	= 1360,
    PPC_WRTEE	= 1361,
    PPC_WRTEEI	= 1362,
    PPC_XOR	= 1363,
    PPC_XOR8	= 1364,
    PPC_XOR8o	= 1365,
    PPC_XORI	= 1366,
    PPC_XORI8	= 1367,
    PPC_XORIS	= 1368,
    PPC_XORIS8	= 1369,
    PPC_XORo	= 1370,
    PPC_XSABSDP	= 1371,
    PPC_XSADDDP	= 1372,
    PPC_XSCMPODP	= 1373,
    PPC_XSCMPUDP	= 1374,
    PPC_XSCPSGNDP	= 1375,
    PPC_XSCVDPSP	= 1376,
    PPC_XSCVDPSXDS	= 1377,
    PPC_XSCVDPSXWS	= 1378,
    PPC_XSCVDPUXDS	= 1379,
    PPC_XSCVDPUXWS	= 1380,
    PPC_XSCVSPDP	= 1381,
    PPC_XSCVSXDDP	= 1382,
    PPC_XSCVUXDDP	= 1383,
    PPC_XSDIVDP	= 1384,
    PPC_XSMADDADP	= 1385,
    PPC_XSMADDMDP	= 1386,
    PPC_XSMAXDP	= 1387,
    PPC_XSMINDP	= 1388,
    PPC_XSMSUBADP	= 1389,
    PPC_XSMSUBMDP	= 1390,
    PPC_XSMULDP	= 1391,
    PPC_XSNABSDP	= 1392,
    PPC_XSNEGDP	= 1393,
    PPC_XSNMADDADP	= 1394,
    PPC_XSNMADDMDP	= 1395,
    PPC_XSNMSUBADP	= 1396,
    PPC_XSNMSUBMDP	= 1397,
    PPC_XSRDPI	= 1398,
    PPC_XSRDPIC	= 1399,
    PPC_XSRDPIM	= 1400,
    PPC_XSRDPIP	= 1401,
    PPC_XSRDPIZ	= 1402,
    PPC_XSREDP	= 1403,
    PPC_XSRSQRTEDP	= 1404,
    PPC_XSSQRTDP	= 1405,
    PPC_XSSUBDP	= 1406,
    PPC_XSTDIVDP	= 1407,
    PPC_XSTSQRTDP	= 1408,
    PPC_XVABSDP	= 1409,
    PPC_XVABSSP	= 1410,
    PPC_XVADDDP	= 1411,
    PPC_XVADDSP	= 1412,
    PPC_XVCMPEQDP	= 1413,
    PPC_XVCMPEQDPo	= 1414,
    PPC_XVCMPEQSP	= 1415,
    PPC_XVCMPEQSPo	= 1416,
    PPC_XVCMPGEDP	= 1417,
    PPC_XVCMPGEDPo	= 1418,
    PPC_XVCMPGESP	= 1419,
    PPC_XVCMPGESPo	= 1420,
    PPC_XVCMPGTDP	= 1421,
    PPC_XVCMPGTDPo	= 1422,
    PPC_XVCMPGTSP	= 1423,
    PPC_XVCMPGTSPo	= 1424,
    PPC_XVCPSGNDP	= 1425,
    PPC_XVCPSGNSP	= 1426,
    PPC_XVCVDPSP	= 1427,
    PPC_XVCVDPSXDS	= 1428,
    PPC_XVCVDPSXWS	= 1429,
    PPC_XVCVDPUXDS	= 1430,
    PPC_XVCVDPUXWS	= 1431,
    PPC_XVCVSPDP	= 1432,
    PPC_XVCVSPSXDS	= 1433,
    PPC_XVCVSPSXWS	= 1434,
    PPC_XVCVSPUXDS	= 1435,
    PPC_XVCVSPUXWS	= 1436,
    PPC_XVCVSXDDP	= 1437,
    PPC_XVCVSXDSP	= 1438,
    PPC_XVCVSXWDP	= 1439,
    PPC_XVCVSXWSP	= 1440,
    PPC_XVCVUXDDP	= 1441,
    PPC_XVCVUXDSP	= 1442,
    PPC_XVCVUXWDP	= 1443,
    PPC_XVCVUXWSP	= 1444,
    PPC_XVDIVDP	= 1445,
    PPC_XVDIVSP	= 1446,
    PPC_XVMADDADP	= 1447,
    PPC_XVMADDASP	= 1448,
    PPC_XVMADDMDP	= 1449,
    PPC_XVMADDMSP	= 1450,
    PPC_XVMAXDP	= 1451,
    PPC_XVMAXSP	= 1452,
    PPC_XVMINDP	= 1453,
    PPC_XVMINSP	= 1454,
    PPC_XVMSUBADP	= 1455,
    PPC_XVMSUBASP	= 1456,
    PPC_XVMSUBMDP	= 1457,
    PPC_XVMSUBMSP	= 1458,
    PPC_XVMULDP	= 1459,
    PPC_XVMULSP	= 1460,
    PPC_XVNABSDP	= 1461,
    PPC_XVNABSSP	= 1462,
    PPC_XVNEGDP	= 1463,
    PPC_XVNEGSP	= 1464,
    PPC_XVNMADDADP	= 1465,
    PPC_XVNMADDASP	= 1466,
    PPC_XVNMADDMDP	= 1467,
    PPC_XVNMADDMSP	= 1468,
    PPC_XVNMSUBADP	= 1469,
    PPC_XVNMSUBASP	= 1470,
    PPC_XVNMSUBMDP	= 1471,
    PPC_XVNMSUBMSP	= 1472,
    PPC_XVRDPI	= 1473,
    PPC_XVRDPIC	= 1474,
    PPC_XVRDPIM	= 1475,
    PPC_XVRDPIP	= 1476,
    PPC_XVRDPIZ	= 1477,
    PPC_XVREDP	= 1478,
    PPC_XVRESP	= 1479,
    PPC_XVRSPI	= 1480,
    PPC_XVRSPIC	= 1481,
    PPC_XVRSPIM	= 1482,
    PPC_XVRSPIP	= 1483,
    PPC_XVRSPIZ	= 1484,
    PPC_XVRSQRTEDP	= 1485,
    PPC_XVRSQRTESP	= 1486,
    PPC_XVSQRTDP	= 1487,
    PPC_XVSQRTSP	= 1488,
    PPC_XVSUBDP	= 1489,
    PPC_XVSUBSP	= 1490,
    PPC_XVTDIVDP	= 1491,
    PPC_XVTDIVSP	= 1492,
    PPC_XVTSQRTDP	= 1493,
    PPC_XVTSQRTSP	= 1494,
    PPC_XXLAND	= 1495,
    PPC_XXLANDC	= 1496,
    PPC_XXLEQV	= 1497,
    PPC_XXLNAND	= 1498,
    PPC_XXLNOR	= 1499,
    PPC_XXLOR	= 1500,
    PPC_XXLORC	= 1501,
    PPC_XXLORf	= 1502,
    PPC_XXLXOR	= 1503,
    PPC_XXMRGHW	= 1504,
    PPC_XXMRGLW	= 1505,
    PPC_XXPERMDI	= 1506,
    PPC_XXSEL	= 1507,
    PPC_XXSLDWI	= 1508,
    PPC_XXSPLTW	= 1509,
    PPC_gBC	= 1510,
    PPC_gBCA	= 1511,
    PPC_gBCCTR	= 1512,
    PPC_gBCCTRL	= 1513,
    PPC_gBCL	= 1514,
    PPC_gBCLA	= 1515,
    PPC_gBCLR	= 1516,
    PPC_gBCLRL	= 1517,
    PPC_INSTRUCTION_LIST_END = 1518
};

#endif // GET_INSTRINFO_ENUM
