/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|*Target Instruction Enum Values                                              *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

/* Capstone Disassembly Engine */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2015 */


#ifdef GET_INSTRINFO_ENUM
#undef GET_INSTRINFO_ENUM

enum {
    SystemZ_PHI	= 0,
    SystemZ_INLINEASM	= 1,
    SystemZ_CFI_INSTRUCTION	= 2,
    SystemZ_EH_LABEL	= 3,
    SystemZ_GC_LABEL	= 4,
    SystemZ_KILL	= 5,
    SystemZ_EXTRACT_SUBREG	= 6,
    SystemZ_INSERT_SUBREG	= 7,
    SystemZ_IMPLICIT_DEF	= 8,
    SystemZ_SUBREG_TO_REG	= 9,
    SystemZ_COPY_TO_REGCLASS	= 10,
    SystemZ_DBG_VALUE	= 11,
    SystemZ_REG_SEQUENCE	= 12,
    SystemZ_COPY	= 13,
    SystemZ_BUNDLE	= 14,
    SystemZ_LIFETIME_START	= 15,
    SystemZ_LIFETIME_END	= 16,
    SystemZ_STACKMAP	= 17,
    SystemZ_PATCHPOINT	= 18,
    SystemZ_LOAD_STACK_GUARD	= 19,
    SystemZ_STATEPOINT	= 20,
    SystemZ_FRAME_ALLOC	= 21,
    SystemZ_A	= 22,
    SystemZ_ADB	= 23,
    SystemZ_ADBR	= 24,
    SystemZ_ADJCALLSTACKDOWN	= 25,
    SystemZ_ADJCALLSTACKUP	= 26,
    SystemZ_ADJDYNALLOC	= 27,
    SystemZ_AEB	= 28,
    SystemZ_AEBR	= 29,
    SystemZ_AEXT128_64	= 30,
    SystemZ_AFI	= 31,
    SystemZ_AFIMux	= 32,
    SystemZ_AG	= 33,
    SystemZ_AGF	= 34,
    SystemZ_AGFI	= 35,
    SystemZ_AGFR	= 36,
    SystemZ_AGHI	= 37,
    SystemZ_AGHIK	= 38,
    SystemZ_AGR	= 39,
    SystemZ_AGRK	= 40,
    SystemZ_AGSI	= 41,
    SystemZ_AH	= 42,
    SystemZ_AHI	= 43,
    SystemZ_AHIK	= 44,
    SystemZ_AHIMux	= 45,
    SystemZ_AHIMuxK	= 46,
    SystemZ_AHY	= 47,
    SystemZ_AIH	= 48,
    SystemZ_AL	= 49,
    SystemZ_ALC	= 50,
    SystemZ_ALCG	= 51,
    SystemZ_ALCGR	= 52,
    SystemZ_ALCR	= 53,
    SystemZ_ALFI	= 54,
    SystemZ_ALG	= 55,
    SystemZ_ALGF	= 56,
    SystemZ_ALGFI	= 57,
    SystemZ_ALGFR	= 58,
    SystemZ_ALGHSIK	= 59,
    SystemZ_ALGR	= 60,
    SystemZ_ALGRK	= 61,
    SystemZ_ALHSIK	= 62,
    SystemZ_ALR	= 63,
    SystemZ_ALRK	= 64,
    SystemZ_ALY	= 65,
    SystemZ_AR	= 66,
    SystemZ_ARK	= 67,
    SystemZ_ASI	= 68,
    SystemZ_ATOMIC_CMP_SWAPW	= 69,
    SystemZ_ATOMIC_LOADW_AFI	= 70,
    SystemZ_ATOMIC_LOADW_AR	= 71,
    SystemZ_ATOMIC_LOADW_MAX	= 72,
    SystemZ_ATOMIC_LOADW_MIN	= 73,
    SystemZ_ATOMIC_LOADW_NILH	= 74,
    SystemZ_ATOMIC_LOADW_NILHi	= 75,
    SystemZ_ATOMIC_LOADW_NR	= 76,
    SystemZ_ATOMIC_LOADW_NRi	= 77,
    SystemZ_ATOMIC_LOADW_OILH	= 78,
    SystemZ_ATOMIC_LOADW_OR	= 79,
    SystemZ_ATOMIC_LOADW_SR	= 80,
    SystemZ_ATOMIC_LOADW_UMAX	= 81,
    SystemZ_ATOMIC_LOADW_UMIN	= 82,
    SystemZ_ATOMIC_LOADW_XILF	= 83,
    SystemZ_ATOMIC_LOADW_XR	= 84,
    SystemZ_ATOMIC_LOAD_AFI	= 85,
    SystemZ_ATOMIC_LOAD_AGFI	= 86,
    SystemZ_ATOMIC_LOAD_AGHI	= 87,
    SystemZ_ATOMIC_LOAD_AGR	= 88,
    SystemZ_ATOMIC_LOAD_AHI	= 89,
    SystemZ_ATOMIC_LOAD_AR	= 90,
    SystemZ_ATOMIC_LOAD_MAX_32	= 91,
    SystemZ_ATOMIC_LOAD_MAX_64	= 92,
    SystemZ_ATOMIC_LOAD_MIN_32	= 93,
    SystemZ_ATOMIC_LOAD_MIN_64	= 94,
    SystemZ_ATOMIC_LOAD_NGR	= 95,
    SystemZ_ATOMIC_LOAD_NGRi	= 96,
    SystemZ_ATOMIC_LOAD_NIHF64	= 97,
    SystemZ_ATOMIC_LOAD_NIHF64i	= 98,
    SystemZ_ATOMIC_LOAD_NIHH64	= 99,
    SystemZ_ATOMIC_LOAD_NIHH64i	= 100,
    SystemZ_ATOMIC_LOAD_NIHL64	= 101,
    SystemZ_ATOMIC_LOAD_NIHL64i	= 102,
    SystemZ_ATOMIC_LOAD_NILF	= 103,
    SystemZ_ATOMIC_LOAD_NILF64	= 104,
    SystemZ_ATOMIC_LOAD_NILF64i	= 105,
    SystemZ_ATOMIC_LOAD_NILFi	= 106,
    SystemZ_ATOMIC_LOAD_NILH	= 107,
    SystemZ_ATOMIC_LOAD_NILH64	= 108,
    SystemZ_ATOMIC_LOAD_NILH64i	= 109,
    SystemZ_ATOMIC_LOAD_NILHi	= 110,
    SystemZ_ATOMIC_LOAD_NILL	= 111,
    SystemZ_ATOMIC_LOAD_NILL64	= 112,
    SystemZ_ATOMIC_LOAD_NILL64i	= 113,
    SystemZ_ATOMIC_LOAD_NILLi	= 114,
    SystemZ_ATOMIC_LOAD_NR	= 115,
    SystemZ_ATOMIC_LOAD_NRi	= 116,
    SystemZ_ATOMIC_LOAD_OGR	= 117,
    SystemZ_ATOMIC_LOAD_OIHF64	= 118,
    SystemZ_ATOMIC_LOAD_OIHH64	= 119,
    SystemZ_ATOMIC_LOAD_OIHL64	= 120,
    SystemZ_ATOMIC_LOAD_OILF	= 121,
    SystemZ_ATOMIC_LOAD_OILF64	= 122,
    SystemZ_ATOMIC_LOAD_OILH	= 123,
    SystemZ_ATOMIC_LOAD_OILH64	= 124,
    SystemZ_ATOMIC_LOAD_OILL	= 125,
    SystemZ_ATOMIC_LOAD_OILL64	= 126,
    SystemZ_ATOMIC_LOAD_OR	= 127,
    SystemZ_ATOMIC_LOAD_SGR	= 128,
    SystemZ_ATOMIC_LOAD_SR	= 129,
    SystemZ_ATOMIC_LOAD_UMAX_32	= 130,
    SystemZ_ATOMIC_LOAD_UMAX_64	= 131,
    SystemZ_ATOMIC_LOAD_UMIN_32	= 132,
    SystemZ_ATOMIC_LOAD_UMIN_64	= 133,
    SystemZ_ATOMIC_LOAD_XGR	= 134,
    SystemZ_ATOMIC_LOAD_XIHF64	= 135,
    SystemZ_ATOMIC_LOAD_XILF	= 136,
    SystemZ_ATOMIC_LOAD_XILF64	= 137,
    SystemZ_ATOMIC_LOAD_XR	= 138,
    SystemZ_ATOMIC_SWAPW	= 139,
    SystemZ_ATOMIC_SWAP_32	= 140,
    SystemZ_ATOMIC_SWAP_64	= 141,
    SystemZ_AXBR	= 142,
    SystemZ_AY	= 143,
    SystemZ_AsmBCR	= 144,
    SystemZ_AsmBRC	= 145,
    SystemZ_AsmBRCL	= 146,
    SystemZ_AsmCGIJ	= 147,
    SystemZ_AsmCGRJ	= 148,
    SystemZ_AsmCIJ	= 149,
    SystemZ_AsmCLGIJ	= 150,
    SystemZ_AsmCLGRJ	= 151,
    SystemZ_AsmCLIJ	= 152,
    SystemZ_AsmCLRJ	= 153,
    SystemZ_AsmCRJ	= 154,
    SystemZ_AsmEBR	= 155,
    SystemZ_AsmEJ	= 156,
    SystemZ_AsmEJG	= 157,
    SystemZ_AsmELOC	= 158,
    SystemZ_AsmELOCG	= 159,
    SystemZ_AsmELOCGR	= 160,
    SystemZ_AsmELOCR	= 161,
    SystemZ_AsmESTOC	= 162,
    SystemZ_AsmESTOCG	= 163,
    SystemZ_AsmHBR	= 164,
    SystemZ_AsmHEBR	= 165,
    SystemZ_AsmHEJ	= 166,
    SystemZ_AsmHEJG	= 167,
    SystemZ_AsmHELOC	= 168,
    SystemZ_AsmHELOCG	= 169,
    SystemZ_AsmHELOCGR	= 170,
    SystemZ_AsmHELOCR	= 171,
    SystemZ_AsmHESTOC	= 172,
    SystemZ_AsmHESTOCG	= 173,
    SystemZ_AsmHJ	= 174,
    SystemZ_AsmHJG	= 175,
    SystemZ_AsmHLOC	= 176,
    SystemZ_AsmHLOCG	= 177,
    SystemZ_AsmHLOCGR	= 178,
    SystemZ_AsmHLOCR	= 179,
    SystemZ_AsmHSTOC	= 180,
    SystemZ_AsmHSTOCG	= 181,
    SystemZ_AsmJEAltCGI	= 182,
    SystemZ_AsmJEAltCGR	= 183,
    SystemZ_AsmJEAltCI	= 184,
    SystemZ_AsmJEAltCLGI	= 185,
    SystemZ_AsmJEAltCLGR	= 186,
    SystemZ_AsmJEAltCLI	= 187,
    SystemZ_AsmJEAltCLR	= 188,
    SystemZ_AsmJEAltCR	= 189,
    SystemZ_AsmJECGI	= 190,
    SystemZ_AsmJECGR	= 191,
    SystemZ_AsmJECI	= 192,
    SystemZ_AsmJECLGI	= 193,
    SystemZ_AsmJECLGR	= 194,
    SystemZ_AsmJECLI	= 195,
    SystemZ_AsmJECLR	= 196,
    SystemZ_AsmJECR	= 197,
    SystemZ_AsmJHAltCGI	= 198,
    SystemZ_AsmJHAltCGR	= 199,
    SystemZ_AsmJHAltCI	= 200,
    SystemZ_AsmJHAltCLGI	= 201,
    SystemZ_AsmJHAltCLGR	= 202,
    SystemZ_AsmJHAltCLI	= 203,
    SystemZ_AsmJHAltCLR	= 204,
    SystemZ_AsmJHAltCR	= 205,
    SystemZ_AsmJHCGI	= 206,
    SystemZ_AsmJHCGR	= 207,
    SystemZ_AsmJHCI	= 208,
    SystemZ_AsmJHCLGI	= 209,
    SystemZ_AsmJHCLGR	= 210,
    SystemZ_AsmJHCLI	= 211,
    SystemZ_AsmJHCLR	= 212,
    SystemZ_AsmJHCR	= 213,
    SystemZ_AsmJHEAltCGI	= 214,
    SystemZ_AsmJHEAltCGR	= 215,
    SystemZ_AsmJHEAltCI	= 216,
    SystemZ_AsmJHEAltCLGI	= 217,
    SystemZ_AsmJHEAltCLGR	= 218,
    SystemZ_AsmJHEAltCLI	= 219,
    SystemZ_AsmJHEAltCLR	= 220,
    SystemZ_AsmJHEAltCR	= 221,
    SystemZ_AsmJHECGI	= 222,
    SystemZ_AsmJHECGR	= 223,
    SystemZ_AsmJHECI	= 224,
    SystemZ_AsmJHECLGI	= 225,
    SystemZ_AsmJHECLGR	= 226,
    SystemZ_AsmJHECLI	= 227,
    SystemZ_AsmJHECLR	= 228,
    SystemZ_AsmJHECR	= 229,
    SystemZ_AsmJLAltCGI	= 230,
    SystemZ_AsmJLAltCGR	= 231,
    SystemZ_AsmJLAltCI	= 232,
    SystemZ_AsmJLAltCLGI	= 233,
    SystemZ_AsmJLAltCLGR	= 234,
    SystemZ_AsmJLAltCLI	= 235,
    SystemZ_AsmJLAltCLR	= 236,
    SystemZ_AsmJLAltCR	= 237,
    SystemZ_AsmJLCGI	= 238,
    SystemZ_AsmJLCGR	= 239,
    SystemZ_AsmJLCI	= 240,
    SystemZ_AsmJLCLGI	= 241,
    SystemZ_AsmJLCLGR	= 242,
    SystemZ_AsmJLCLI	= 243,
    SystemZ_AsmJLCLR	= 244,
    SystemZ_AsmJLCR	= 245,
    SystemZ_AsmJLEAltCGI	= 246,
    SystemZ_AsmJLEAltCGR	= 247,
    SystemZ_AsmJLEAltCI	= 248,
    SystemZ_AsmJLEAltCLGI	= 249,
    SystemZ_AsmJLEAltCLGR	= 250,
    SystemZ_AsmJLEAltCLI	= 251,
    SystemZ_AsmJLEAltCLR	= 252,
    SystemZ_AsmJLEAltCR	= 253,
    SystemZ_AsmJLECGI	= 254,
    SystemZ_AsmJLECGR	= 255,
    SystemZ_AsmJLECI	= 256,
    SystemZ_AsmJLECLGI	= 257,
    SystemZ_AsmJLECLGR	= 258,
    SystemZ_AsmJLECLI	= 259,
    SystemZ_AsmJLECLR	= 260,
    SystemZ_AsmJLECR	= 261,
    SystemZ_AsmJLHAltCGI	= 262,
    SystemZ_AsmJLHAltCGR	= 263,
    SystemZ_AsmJLHAltCI	= 264,
    SystemZ_AsmJLHAltCLGI	= 265,
    SystemZ_AsmJLHAltCLGR	= 266,
    SystemZ_AsmJLHAltCLI	= 267,
    SystemZ_AsmJLHAltCLR	= 268,
    SystemZ_AsmJLHAltCR	= 269,
    SystemZ_AsmJLHCGI	= 270,
    SystemZ_AsmJLHCGR	= 271,
    SystemZ_AsmJLHCI	= 272,
    SystemZ_AsmJLHCLGI	= 273,
    SystemZ_AsmJLHCLGR	= 274,
    SystemZ_AsmJLHCLI	= 275,
    SystemZ_AsmJLHCLR	= 276,
    SystemZ_AsmJLHCR	= 277,
    SystemZ_AsmLBR	= 278,
    SystemZ_AsmLEBR	= 279,
    SystemZ_AsmLEJ	= 280,
    SystemZ_AsmLEJG	= 281,
    SystemZ_AsmLELOC	= 282,
    SystemZ_AsmLELOCG	= 283,
    SystemZ_AsmLELOCGR	= 284,
    SystemZ_AsmLELOCR	= 285,
    SystemZ_AsmLESTOC	= 286,
    SystemZ_AsmLESTOCG	= 287,
    SystemZ_AsmLHBR	= 288,
    SystemZ_AsmLHJ	= 289,
    SystemZ_AsmLHJG	= 290,
    SystemZ_AsmLHLOC	= 291,
    SystemZ_AsmLHLOCG	= 292,
    SystemZ_AsmLHLOCGR	= 293,
    SystemZ_AsmLHLOCR	= 294,
    SystemZ_AsmLHSTOC	= 295,
    SystemZ_AsmLHSTOCG	= 296,
    SystemZ_AsmLJ	= 297,
    SystemZ_AsmLJG	= 298,
    SystemZ_AsmLLOC	= 299,
    SystemZ_AsmLLOCG	= 300,
    SystemZ_AsmLLOCGR	= 301,
    SystemZ_AsmLLOCR	= 302,
    SystemZ_AsmLOC	= 303,
    SystemZ_AsmLOCG	= 304,
    SystemZ_AsmLOCGR	= 305,
    SystemZ_AsmLOCR	= 306,
    SystemZ_AsmLSTOC	= 307,
    SystemZ_AsmLSTOCG	= 308,
    SystemZ_AsmNEBR	= 309,
    SystemZ_AsmNEJ	= 310,
    SystemZ_AsmNEJG	= 311,
    SystemZ_AsmNELOC	= 312,
    SystemZ_AsmNELOCG	= 313,
    SystemZ_AsmNELOCGR	= 314,
    SystemZ_AsmNELOCR	= 315,
    SystemZ_AsmNESTOC	= 316,
    SystemZ_AsmNESTOCG	= 317,
    SystemZ_AsmNHBR	= 318,
    SystemZ_AsmNHEBR	= 319,
    SystemZ_AsmNHEJ	= 320,
    SystemZ_AsmNHEJG	= 321,
    SystemZ_AsmNHELOC	= 322,
    SystemZ_AsmNHELOCG	= 323,
    SystemZ_AsmNHELOCGR	= 324,
    SystemZ_AsmNHELOCR	= 325,
    SystemZ_AsmNHESTOC	= 326,
    SystemZ_AsmNHESTOCG	= 327,
    SystemZ_AsmNHJ	= 328,
    SystemZ_AsmNHJG	= 329,
    SystemZ_AsmNHLOC	= 330,
    SystemZ_AsmNHLOCG	= 331,
    SystemZ_AsmNHLOCGR	= 332,
    SystemZ_AsmNHLOCR	= 333,
    SystemZ_AsmNHSTOC	= 334,
    SystemZ_AsmNHSTOCG	= 335,
    SystemZ_AsmNLBR	= 336,
    SystemZ_AsmNLEBR	= 337,
    SystemZ_AsmNLEJ	= 338,
    SystemZ_AsmNLEJG	= 339,
    SystemZ_AsmNLELOC	= 340,
    SystemZ_AsmNLELOCG	= 341,
    SystemZ_AsmNLELOCGR	= 342,
    SystemZ_AsmNLELOCR	= 343,
    SystemZ_AsmNLESTOC	= 344,
    SystemZ_AsmNLESTOCG	= 345,
    SystemZ_AsmNLHBR	= 346,
    SystemZ_AsmNLHJ	= 347,
    SystemZ_AsmNLHJG	= 348,
    SystemZ_AsmNLHLOC	= 349,
    SystemZ_AsmNLHLOCG	= 350,
    SystemZ_AsmNLHLOCGR	= 351,
    SystemZ_AsmNLHLOCR	= 352,
    SystemZ_AsmNLHSTOC	= 353,
    SystemZ_AsmNLHSTOCG	= 354,
    SystemZ_AsmNLJ	= 355,
    SystemZ_AsmNLJG	= 356,
    SystemZ_AsmNLLOC	= 357,
    SystemZ_AsmNLLOCG	= 358,
    SystemZ_AsmNLLOCGR	= 359,
    SystemZ_AsmNLLOCR	= 360,
    SystemZ_AsmNLSTOC	= 361,
    SystemZ_AsmNLSTOCG	= 362,
    SystemZ_AsmNOBR	= 363,
    SystemZ_AsmNOJ	= 364,
    SystemZ_AsmNOJG	= 365,
    SystemZ_AsmNOLOC	= 366,
    SystemZ_AsmNOLOCG	= 367,
    SystemZ_AsmNOLOCGR	= 368,
    SystemZ_AsmNOLOCR	= 369,
    SystemZ_AsmNOSTOC	= 370,
    SystemZ_AsmNOSTOCG	= 371,
    SystemZ_AsmOBR	= 372,
    SystemZ_AsmOJ	= 373,
    SystemZ_AsmOJG	= 374,
    SystemZ_AsmOLOC	= 375,
    SystemZ_AsmOLOCG	= 376,
    SystemZ_AsmOLOCGR	= 377,
    SystemZ_AsmOLOCR	= 378,
    SystemZ_AsmOSTOC	= 379,
    SystemZ_AsmOSTOCG	= 380,
    SystemZ_AsmSTOC	= 381,
    SystemZ_AsmSTOCG	= 382,
    SystemZ_BASR	= 383,
    SystemZ_BR	= 384,
    SystemZ_BRAS	= 385,
    SystemZ_BRASL	= 386,
    SystemZ_BRC	= 387,
    SystemZ_BRCL	= 388,
    SystemZ_BRCT	= 389,
    SystemZ_BRCTG	= 390,
    SystemZ_C	= 391,
    SystemZ_CDB	= 392,
    SystemZ_CDBR	= 393,
    SystemZ_CDFBR	= 394,
    SystemZ_CDGBR	= 395,
    SystemZ_CDLFBR	= 396,
    SystemZ_CDLGBR	= 397,
    SystemZ_CEB	= 398,
    SystemZ_CEBR	= 399,
    SystemZ_CEFBR	= 400,
    SystemZ_CEGBR	= 401,
    SystemZ_CELFBR	= 402,
    SystemZ_CELGBR	= 403,
    SystemZ_CFDBR	= 404,
    SystemZ_CFEBR	= 405,
    SystemZ_CFI	= 406,
    SystemZ_CFIMux	= 407,
    SystemZ_CFXBR	= 408,
    SystemZ_CG	= 409,
    SystemZ_CGDBR	= 410,
    SystemZ_CGEBR	= 411,
    SystemZ_CGF	= 412,
    SystemZ_CGFI	= 413,
    SystemZ_CGFR	= 414,
    SystemZ_CGFRL	= 415,
    SystemZ_CGH	= 416,
    SystemZ_CGHI	= 417,
    SystemZ_CGHRL	= 418,
    SystemZ_CGHSI	= 419,
    SystemZ_CGIJ	= 420,
    SystemZ_CGR	= 421,
    SystemZ_CGRJ	= 422,
    SystemZ_CGRL	= 423,
    SystemZ_CGXBR	= 424,
    SystemZ_CH	= 425,
    SystemZ_CHF	= 426,
    SystemZ_CHHSI	= 427,
    SystemZ_CHI	= 428,
    SystemZ_CHRL	= 429,
    SystemZ_CHSI	= 430,
    SystemZ_CHY	= 431,
    SystemZ_CIH	= 432,
    SystemZ_CIJ	= 433,
    SystemZ_CL	= 434,
    SystemZ_CLC	= 435,
    SystemZ_CLCLoop	= 436,
    SystemZ_CLCSequence	= 437,
    SystemZ_CLFDBR	= 438,
    SystemZ_CLFEBR	= 439,
    SystemZ_CLFHSI	= 440,
    SystemZ_CLFI	= 441,
    SystemZ_CLFIMux	= 442,
    SystemZ_CLFXBR	= 443,
    SystemZ_CLG	= 444,
    SystemZ_CLGDBR	= 445,
    SystemZ_CLGEBR	= 446,
    SystemZ_CLGF	= 447,
    SystemZ_CLGFI	= 448,
    SystemZ_CLGFR	= 449,
    SystemZ_CLGFRL	= 450,
    SystemZ_CLGHRL	= 451,
    SystemZ_CLGHSI	= 452,
    SystemZ_CLGIJ	= 453,
    SystemZ_CLGR	= 454,
    SystemZ_CLGRJ	= 455,
    SystemZ_CLGRL	= 456,
    SystemZ_CLGXBR	= 457,
    SystemZ_CLHF	= 458,
    SystemZ_CLHHSI	= 459,
    SystemZ_CLHRL	= 460,
    SystemZ_CLI	= 461,
    SystemZ_CLIH	= 462,
    SystemZ_CLIJ	= 463,
    SystemZ_CLIY	= 464,
    SystemZ_CLMux	= 465,
    SystemZ_CLR	= 466,
    SystemZ_CLRJ	= 467,
    SystemZ_CLRL	= 468,
    SystemZ_CLST	= 469,
    SystemZ_CLSTLoop	= 470,
    SystemZ_CLY	= 471,
    SystemZ_CMux	= 472,
    SystemZ_CPSDRdd	= 473,
    SystemZ_CPSDRds	= 474,
    SystemZ_CPSDRsd	= 475,
    SystemZ_CPSDRss	= 476,
    SystemZ_CR	= 477,
    SystemZ_CRJ	= 478,
    SystemZ_CRL	= 479,
    SystemZ_CS	= 480,
    SystemZ_CSG	= 481,
    SystemZ_CSY	= 482,
    SystemZ_CXBR	= 483,
    SystemZ_CXFBR	= 484,
    SystemZ_CXGBR	= 485,
    SystemZ_CXLFBR	= 486,
    SystemZ_CXLGBR	= 487,
    SystemZ_CY	= 488,
    SystemZ_CallBASR	= 489,
    SystemZ_CallBR	= 490,
    SystemZ_CallBRASL	= 491,
    SystemZ_CallJG	= 492,
    SystemZ_CondStore16	= 493,
    SystemZ_CondStore16Inv	= 494,
    SystemZ_CondStore16Mux	= 495,
    SystemZ_CondStore16MuxInv	= 496,
    SystemZ_CondStore32	= 497,
    SystemZ_CondStore32Inv	= 498,
    SystemZ_CondStore64	= 499,
    SystemZ_CondStore64Inv	= 500,
    SystemZ_CondStore8	= 501,
    SystemZ_CondStore8Inv	= 502,
    SystemZ_CondStore8Mux	= 503,
    SystemZ_CondStore8MuxInv	= 504,
    SystemZ_CondStoreF32	= 505,
    SystemZ_CondStoreF32Inv	= 506,
    SystemZ_CondStoreF64	= 507,
    SystemZ_CondStoreF64Inv	= 508,
    SystemZ_DDB	= 509,
    SystemZ_DDBR	= 510,
    SystemZ_DEB	= 511,
    SystemZ_DEBR	= 512,
    SystemZ_DL	= 513,
    SystemZ_DLG	= 514,
    SystemZ_DLGR	= 515,
    SystemZ_DLR	= 516,
    SystemZ_DSG	= 517,
    SystemZ_DSGF	= 518,
    SystemZ_DSGFR	= 519,
    SystemZ_DSGR	= 520,
    SystemZ_DXBR	= 521,
    SystemZ_EAR	= 522,
    SystemZ_FIDBR	= 523,
    SystemZ_FIDBRA	= 524,
    SystemZ_FIEBR	= 525,
    SystemZ_FIEBRA	= 526,
    SystemZ_FIXBR	= 527,
    SystemZ_FIXBRA	= 528,
    SystemZ_FLOGR	= 529,
    SystemZ_GOT	= 530,
    SystemZ_IC	= 531,
    SystemZ_IC32	= 532,
    SystemZ_IC32Y	= 533,
    SystemZ_ICY	= 534,
    SystemZ_IIFMux	= 535,
    SystemZ_IIHF	= 536,
    SystemZ_IIHF64	= 537,
    SystemZ_IIHH	= 538,
    SystemZ_IIHH64	= 539,
    SystemZ_IIHL	= 540,
    SystemZ_IIHL64	= 541,
    SystemZ_IIHMux	= 542,
    SystemZ_IILF	= 543,
    SystemZ_IILF64	= 544,
    SystemZ_IILH	= 545,
    SystemZ_IILH64	= 546,
    SystemZ_IILL	= 547,
    SystemZ_IILL64	= 548,
    SystemZ_IILMux	= 549,
    SystemZ_IPM	= 550,
    SystemZ_J	= 551,
    SystemZ_JG	= 552,
    SystemZ_L	= 553,
    SystemZ_L128	= 554,
    SystemZ_LA	= 555,
    SystemZ_LAA	= 556,
    SystemZ_LAAG	= 557,
    SystemZ_LAAL	= 558,
    SystemZ_LAALG	= 559,
    SystemZ_LAN	= 560,
    SystemZ_LANG	= 561,
    SystemZ_LAO	= 562,
    SystemZ_LAOG	= 563,
    SystemZ_LARL	= 564,
    SystemZ_LAX	= 565,
    SystemZ_LAXG	= 566,
    SystemZ_LAY	= 567,
    SystemZ_LB	= 568,
    SystemZ_LBH	= 569,
    SystemZ_LBMux	= 570,
    SystemZ_LBR	= 571,
    SystemZ_LCDBR	= 572,
    SystemZ_LCEBR	= 573,
    SystemZ_LCGFR	= 574,
    SystemZ_LCGR	= 575,
    SystemZ_LCR	= 576,
    SystemZ_LCXBR	= 577,
    SystemZ_LD	= 578,
    SystemZ_LDEB	= 579,
    SystemZ_LDEBR	= 580,
    SystemZ_LDGR	= 581,
    SystemZ_LDR	= 582,
    SystemZ_LDXBR	= 583,
    SystemZ_LDXBRA	= 584,
    SystemZ_LDY	= 585,
    SystemZ_LE	= 586,
    SystemZ_LEDBR	= 587,
    SystemZ_LEDBRA	= 588,
    SystemZ_LER	= 589,
    SystemZ_LEXBR	= 590,
    SystemZ_LEXBRA	= 591,
    SystemZ_LEY	= 592,
    SystemZ_LFH	= 593,
    SystemZ_LG	= 594,
    SystemZ_LGB	= 595,
    SystemZ_LGBR	= 596,
    SystemZ_LGDR	= 597,
    SystemZ_LGF	= 598,
    SystemZ_LGFI	= 599,
    SystemZ_LGFR	= 600,
    SystemZ_LGFRL	= 601,
    SystemZ_LGH	= 602,
    SystemZ_LGHI	= 603,
    SystemZ_LGHR	= 604,
    SystemZ_LGHRL	= 605,
    SystemZ_LGR	= 606,
    SystemZ_LGRL	= 607,
    SystemZ_LH	= 608,
    SystemZ_LHH	= 609,
    SystemZ_LHI	= 610,
    SystemZ_LHIMux	= 611,
    SystemZ_LHMux	= 612,
    SystemZ_LHR	= 613,
    SystemZ_LHRL	= 614,
    SystemZ_LHY	= 615,
    SystemZ_LLC	= 616,
    SystemZ_LLCH	= 617,
    SystemZ_LLCMux	= 618,
    SystemZ_LLCR	= 619,
    SystemZ_LLCRMux	= 620,
    SystemZ_LLGC	= 621,
    SystemZ_LLGCR	= 622,
    SystemZ_LLGF	= 623,
    SystemZ_LLGFR	= 624,
    SystemZ_LLGFRL	= 625,
    SystemZ_LLGH	= 626,
    SystemZ_LLGHR	= 627,
    SystemZ_LLGHRL	= 628,
    SystemZ_LLH	= 629,
    SystemZ_LLHH	= 630,
    SystemZ_LLHMux	= 631,
    SystemZ_LLHR	= 632,
    SystemZ_LLHRL	= 633,
    SystemZ_LLHRMux	= 634,
    SystemZ_LLIHF	= 635,
    SystemZ_LLIHH	= 636,
    SystemZ_LLIHL	= 637,
    SystemZ_LLILF	= 638,
    SystemZ_LLILH	= 639,
    SystemZ_LLILL	= 640,
    SystemZ_LMG	= 641,
    SystemZ_LMux	= 642,
    SystemZ_LNDBR	= 643,
    SystemZ_LNEBR	= 644,
    SystemZ_LNGFR	= 645,
    SystemZ_LNGR	= 646,
    SystemZ_LNR	= 647,
    SystemZ_LNXBR	= 648,
    SystemZ_LOC	= 649,
    SystemZ_LOCG	= 650,
    SystemZ_LOCGR	= 651,
    SystemZ_LOCR	= 652,
    SystemZ_LPDBR	= 653,
    SystemZ_LPEBR	= 654,
    SystemZ_LPGFR	= 655,
    SystemZ_LPGR	= 656,
    SystemZ_LPR	= 657,
    SystemZ_LPXBR	= 658,
    SystemZ_LR	= 659,
    SystemZ_LRL	= 660,
    SystemZ_LRMux	= 661,
    SystemZ_LRV	= 662,
    SystemZ_LRVG	= 663,
    SystemZ_LRVGR	= 664,
    SystemZ_LRVR	= 665,
    SystemZ_LT	= 666,
    SystemZ_LTDBR	= 667,
    SystemZ_LTDBRCompare	= 668,
    SystemZ_LTEBR	= 669,
    SystemZ_LTEBRCompare	= 670,
    SystemZ_LTG	= 671,
    SystemZ_LTGF	= 672,
    SystemZ_LTGFR	= 673,
    SystemZ_LTGR	= 674,
    SystemZ_LTR	= 675,
    SystemZ_LTXBR	= 676,
    SystemZ_LTXBRCompare	= 677,
    SystemZ_LX	= 678,
    SystemZ_LXDB	= 679,
    SystemZ_LXDBR	= 680,
    SystemZ_LXEB	= 681,
    SystemZ_LXEBR	= 682,
    SystemZ_LXR	= 683,
    SystemZ_LY	= 684,
    SystemZ_LZDR	= 685,
    SystemZ_LZER	= 686,
    SystemZ_LZXR	= 687,
    SystemZ_MADB	= 688,
    SystemZ_MADBR	= 689,
    SystemZ_MAEB	= 690,
    SystemZ_MAEBR	= 691,
    SystemZ_MDB	= 692,
    SystemZ_MDBR	= 693,
    SystemZ_MDEB	= 694,
    SystemZ_MDEBR	= 695,
    SystemZ_MEEB	= 696,
    SystemZ_MEEBR	= 697,
    SystemZ_MGHI	= 698,
    SystemZ_MH	= 699,
    SystemZ_MHI	= 700,
    SystemZ_MHY	= 701,
    SystemZ_MLG	= 702,
    SystemZ_MLGR	= 703,
    SystemZ_MS	= 704,
    SystemZ_MSDB	= 705,
    SystemZ_MSDBR	= 706,
    SystemZ_MSEB	= 707,
    SystemZ_MSEBR	= 708,
    SystemZ_MSFI	= 709,
    SystemZ_MSG	= 710,
    SystemZ_MSGF	= 711,
    SystemZ_MSGFI	= 712,
    SystemZ_MSGFR	= 713,
    SystemZ_MSGR	= 714,
    SystemZ_MSR	= 715,
    SystemZ_MSY	= 716,
    SystemZ_MVC	= 717,
    SystemZ_MVCLoop	= 718,
    SystemZ_MVCSequence	= 719,
    SystemZ_MVGHI	= 720,
    SystemZ_MVHHI	= 721,
    SystemZ_MVHI	= 722,
    SystemZ_MVI	= 723,
    SystemZ_MVIY	= 724,
    SystemZ_MVST	= 725,
    SystemZ_MVSTLoop	= 726,
    SystemZ_MXBR	= 727,
    SystemZ_MXDB	= 728,
    SystemZ_MXDBR	= 729,
    SystemZ_N	= 730,
    SystemZ_NC	= 731,
    SystemZ_NCLoop	= 732,
    SystemZ_NCSequence	= 733,
    SystemZ_NG	= 734,
    SystemZ_NGR	= 735,
    SystemZ_NGRK	= 736,
    SystemZ_NI	= 737,
    SystemZ_NIFMux	= 738,
    SystemZ_NIHF	= 739,
    SystemZ_NIHF64	= 740,
    SystemZ_NIHH	= 741,
    SystemZ_NIHH64	= 742,
    SystemZ_NIHL	= 743,
    SystemZ_NIHL64	= 744,
    SystemZ_NIHMux	= 745,
    SystemZ_NILF	= 746,
    SystemZ_NILF64	= 747,
    SystemZ_NILH	= 748,
    SystemZ_NILH64	= 749,
    SystemZ_NILL	= 750,
    SystemZ_NILL64	= 751,
    SystemZ_NILMux	= 752,
    SystemZ_NIY	= 753,
    SystemZ_NR	= 754,
    SystemZ_NRK	= 755,
    SystemZ_NY	= 756,
    SystemZ_O	= 757,
    SystemZ_OC	= 758,
    SystemZ_OCLoop	= 759,
    SystemZ_OCSequence	= 760,
    SystemZ_OG	= 761,
    SystemZ_OGR	= 762,
    SystemZ_OGRK	= 763,
    SystemZ_OI	= 764,
    SystemZ_OIFMux	= 765,
    SystemZ_OIHF	= 766,
    SystemZ_OIHF64	= 767,
    SystemZ_OIHH	= 768,
    SystemZ_OIHH64	= 769,
    SystemZ_OIHL	= 770,
    SystemZ_OIHL64	= 771,
    SystemZ_OIHMux	= 772,
    SystemZ_OILF	= 773,
    SystemZ_OILF64	= 774,
    SystemZ_OILH	= 775,
    SystemZ_OILH64	= 776,
    SystemZ_OILL	= 777,
    SystemZ_OILL64	= 778,
    SystemZ_OILMux	= 779,
    SystemZ_OIY	= 780,
    SystemZ_OR	= 781,
    SystemZ_ORK	= 782,
    SystemZ_OY	= 783,
    SystemZ_PFD	= 784,
    SystemZ_PFDRL	= 785,
    SystemZ_RISBG	= 786,
    SystemZ_RISBG32	= 787,
    SystemZ_RISBHG	= 788,
    SystemZ_RISBHH	= 789,
    SystemZ_RISBHL	= 790,
    SystemZ_RISBLG	= 791,
    SystemZ_RISBLH	= 792,
    SystemZ_RISBLL	= 793,
    SystemZ_RISBMux	= 794,
    SystemZ_RLL	= 795,
    SystemZ_RLLG	= 796,
    SystemZ_RNSBG	= 797,
    SystemZ_ROSBG	= 798,
    SystemZ_RXSBG	= 799,
    SystemZ_Return	= 800,
    SystemZ_S	= 801,
    SystemZ_SDB	= 802,
    SystemZ_SDBR	= 803,
    SystemZ_SEB	= 804,
    SystemZ_SEBR	= 805,
    SystemZ_SG	= 806,
    SystemZ_SGF	= 807,
    SystemZ_SGFR	= 808,
    SystemZ_SGR	= 809,
    SystemZ_SGRK	= 810,
    SystemZ_SH	= 811,
    SystemZ_SHY	= 812,
    SystemZ_SL	= 813,
    SystemZ_SLB	= 814,
    SystemZ_SLBG	= 815,
    SystemZ_SLBR	= 816,
    SystemZ_SLFI	= 817,
    SystemZ_SLG	= 818,
    SystemZ_SLGBR	= 819,
    SystemZ_SLGF	= 820,
    SystemZ_SLGFI	= 821,
    SystemZ_SLGFR	= 822,
    SystemZ_SLGR	= 823,
    SystemZ_SLGRK	= 824,
    SystemZ_SLL	= 825,
    SystemZ_SLLG	= 826,
    SystemZ_SLLK	= 827,
    SystemZ_SLR	= 828,
    SystemZ_SLRK	= 829,
    SystemZ_SLY	= 830,
    SystemZ_SQDB	= 831,
    SystemZ_SQDBR	= 832,
    SystemZ_SQEB	= 833,
    SystemZ_SQEBR	= 834,
    SystemZ_SQXBR	= 835,
    SystemZ_SR	= 836,
    SystemZ_SRA	= 837,
    SystemZ_SRAG	= 838,
    SystemZ_SRAK	= 839,
    SystemZ_SRK	= 840,
    SystemZ_SRL	= 841,
    SystemZ_SRLG	= 842,
    SystemZ_SRLK	= 843,
    SystemZ_SRST	= 844,
    SystemZ_SRSTLoop	= 845,
    SystemZ_ST	= 846,
    SystemZ_ST128	= 847,
    SystemZ_STC	= 848,
    SystemZ_STCH	= 849,
    SystemZ_STCMux	= 850,
    SystemZ_STCY	= 851,
    SystemZ_STD	= 852,
    SystemZ_STDY	= 853,
    SystemZ_STE	= 854,
    SystemZ_STEY	= 855,
    SystemZ_STFH	= 856,
    SystemZ_STG	= 857,
    SystemZ_STGRL	= 858,
    SystemZ_STH	= 859,
    SystemZ_STHH	= 860,
    SystemZ_STHMux	= 861,
    SystemZ_STHRL	= 862,
    SystemZ_STHY	= 863,
    SystemZ_STMG	= 864,
    SystemZ_STMux	= 865,
    SystemZ_STOC	= 866,
    SystemZ_STOCG	= 867,
    SystemZ_STRL	= 868,
    SystemZ_STRV	= 869,
    SystemZ_STRVG	= 870,
    SystemZ_STX	= 871,
    SystemZ_STY	= 872,
    SystemZ_SXBR	= 873,
    SystemZ_SY	= 874,
    SystemZ_Select32	= 875,
    SystemZ_Select32Mux	= 876,
    SystemZ_Select64	= 877,
    SystemZ_SelectF128	= 878,
    SystemZ_SelectF32	= 879,
    SystemZ_SelectF64	= 880,
    SystemZ_Serialize	= 881,
    SystemZ_TLS_GDCALL	= 882,
    SystemZ_TLS_LDCALL	= 883,
    SystemZ_TM	= 884,
    SystemZ_TMHH	= 885,
    SystemZ_TMHH64	= 886,
    SystemZ_TMHL	= 887,
    SystemZ_TMHL64	= 888,
    SystemZ_TMHMux	= 889,
    SystemZ_TMLH	= 890,
    SystemZ_TMLH64	= 891,
    SystemZ_TMLL	= 892,
    SystemZ_TMLL64	= 893,
    SystemZ_TMLMux	= 894,
    SystemZ_TMY	= 895,
    SystemZ_X	= 896,
    SystemZ_XC	= 897,
    SystemZ_XCLoop	= 898,
    SystemZ_XCSequence	= 899,
    SystemZ_XG	= 900,
    SystemZ_XGR	= 901,
    SystemZ_XGRK	= 902,
    SystemZ_XI	= 903,
    SystemZ_XIFMux	= 904,
    SystemZ_XIHF	= 905,
    SystemZ_XIHF64	= 906,
    SystemZ_XILF	= 907,
    SystemZ_XILF64	= 908,
    SystemZ_XIY	= 909,
    SystemZ_XR	= 910,
    SystemZ_XRK	= 911,
    SystemZ_XY	= 912,
    SystemZ_ZEXT128_32	= 913,
    SystemZ_ZEXT128_64	= 914,
    SystemZ_INSTRUCTION_LIST_END = 915
};

#endif // GET_INSTRINFO_ENUM
