/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* * X86 Disassembler                                                         *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2015 */

static const struct OpcodeDecision emptyTable = {
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
};

static const struct OperandSpecifier x86OperandSets[][6] = {
  { /* 0 */
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1 */
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 2 */
    { ENCODING_Iv, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 3 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_Iv, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 4 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_IB, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 5 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 6 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_Iv, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 7 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_IB, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 8 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 9 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 10 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 11 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 12 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 13 */
    { ENCODING_ID, TYPE_IMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 14 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_ID, TYPE_IMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 15 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_IB, TYPE_IMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 16 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 17 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_ID, TYPE_IMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 18 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_IB, TYPE_IMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 19 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 20 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 21 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 22 */
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 23 */
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_REG, TYPE_R8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 24 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_R8 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 25 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_R8 },
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 26 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_R8 },
    { ENCODING_REG, TYPE_R8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 27 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_R8 },
    { ENCODING_RM, TYPE_R8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 28 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 29 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 30 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 31 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 32 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 33 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 34 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 35 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 36 */
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 37 */
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 38 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 39 */
    { ENCODING_FP, TYPE_ST },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 40 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 41 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 42 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 43 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 44 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 45 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 46 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 47 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 48 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_VVVV, TYPE_R32 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 49 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_VVVV, TYPE_R32 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 50 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_VVVV, TYPE_R64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 51 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_VVVV, TYPE_R64 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 52 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_REG, TYPE_R16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 53 */
    { ENCODING_RM, TYPE_R16 },
    { ENCODING_REG, TYPE_R16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 54 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_VVVV, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 55 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_VVVV, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 56 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_VVVV, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 57 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_VVVV, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 58 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_Iv, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 59 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_Iv, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 60 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_ID, TYPE_IMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 61 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_ID, TYPE_IMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 62 */
    { ENCODING_VVVV, TYPE_R32 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 63 */
    { ENCODING_VVVV, TYPE_R32 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 64 */
    { ENCODING_VVVV, TYPE_R64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 65 */
    { ENCODING_VVVV, TYPE_R64 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 66 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 67 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 68 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 69 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 70 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_Rv, TYPE_Rv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 71 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RO, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 72 */
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_IB, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 73 */
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 74 */
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 75 */
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_IB, TYPE_IMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 76 */
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 77 */
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 78 */
    { ENCODING_ID, TYPE_REL64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 79 */
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 80 */
    { ENCODING_IW, TYPE_REL16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 81 */
    { ENCODING_ID, TYPE_REL32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 82 */
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 83 */
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_Iv, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 84 */
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_ID, TYPE_IMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 85 */
    { ENCODING_RM, TYPE_R8 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 86 */
    { ENCODING_REG, TYPE_R8 },
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 87 */
    { ENCODING_RM, TYPE_R8 },
    { ENCODING_REG, TYPE_R8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 88 */
    { ENCODING_REG, TYPE_R8 },
    { ENCODING_RM, TYPE_R8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 89 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_IB, TYPE_IMM3 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 90 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_IMM3 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 91 */
    { ENCODING_DI, TYPE_DSTIDX8 },
    { ENCODING_SI, TYPE_SRCIDX8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 92 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_IB, TYPE_IMM3 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 93 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_IB, TYPE_IMM3 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 94 */
    { ENCODING_DI, TYPE_DSTIDX32 },
    { ENCODING_SI, TYPE_SRCIDX32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 95 */
    { ENCODING_DI, TYPE_DSTIDX64 },
    { ENCODING_SI, TYPE_SRCIDX64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 96 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_IB, TYPE_IMM3 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 97 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_IB, TYPE_IMM3 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 98 */
    { ENCODING_DI, TYPE_DSTIDX16 },
    { ENCODING_SI, TYPE_SRCIDX16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 99 */
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 100 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 101 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 102 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_R8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 103 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 104 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_R8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 105 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 106 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 107 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 108 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 109 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 110 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 111 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 112 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 113 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 114 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 115 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 116 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 117 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 118 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 119 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 120 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 121 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 122 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 123 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 124 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 125 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 126 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 127 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 128 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 129 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_R8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 130 */
    { ENCODING_RM, TYPE_R8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 131 */
    { ENCODING_IW, TYPE_IMM16 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 132 */
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 133 */
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 134 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 135 */
    { ENCODING_Iv, TYPE_IMMv },
    { ENCODING_Iv, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 136 */
    { ENCODING_RM, TYPE_M1616 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 137 */
    { ENCODING_Iv, TYPE_IMMv },
    { ENCODING_IW, TYPE_IMM16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 138 */
    { ENCODING_RM, TYPE_M1632 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 139 */
    { ENCODING_RM, TYPE_M1664 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 140 */
    { ENCODING_RM, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 141 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_Iv, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 142 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_IB, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 143 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_Iv, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 144 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_IB, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 145 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 146 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 147 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_IB, TYPE_IMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 148 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_IB, TYPE_IMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 149 */
    { ENCODING_DI, TYPE_DSTIDX8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 150 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 151 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 152 */
    { ENCODING_DI, TYPE_DSTIDX32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 153 */
    { ENCODING_DI, TYPE_DSTIDX16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 154 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 155 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 156 */
    { ENCODING_IB, TYPE_REL8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 157 */
    { ENCODING_Iv, TYPE_RELv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 158 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_VK8 },
    { ENCODING_RM, TYPE_VK8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 159 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_VK32 },
    { ENCODING_RM, TYPE_VK32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 160 */
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_VVVV, TYPE_VK64 },
    { ENCODING_RM, TYPE_VK64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 161 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_VK16 },
    { ENCODING_RM, TYPE_VK16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 162 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_RM, TYPE_VK8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 163 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 164 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 165 */
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 166 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_VK8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 167 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_RM, TYPE_VK32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 168 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 169 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 170 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 171 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_VK32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 172 */
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_RM, TYPE_VK64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 173 */
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 174 */
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 175 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 176 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_VK64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 177 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_RM, TYPE_VK16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 178 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 179 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 180 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 181 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_VK16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 182 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_RM, TYPE_VK8 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 183 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_RM, TYPE_VK32 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 184 */
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_RM, TYPE_VK64 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 185 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_RM, TYPE_VK16 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 186 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 187 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_M1616 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 188 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_M1632 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 189 */
    { ENCODING_RM, TYPE_M80FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 190 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_M },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 191 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_LEA },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 192 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_LEA },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 193 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_M1664 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 194 */
    { ENCODING_RM, TYPE_R16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 195 */
    { ENCODING_SI, TYPE_SRCIDX8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 196 */
    { ENCODING_SI, TYPE_SRCIDX32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 197 */
    { ENCODING_SI, TYPE_SRCIDX64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 198 */
    { ENCODING_SI, TYPE_SRCIDX16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 199 */
    { ENCODING_IW, TYPE_IMM16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 200 */
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 201 */
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 202 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_MM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 203 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 204 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_MM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 205 */
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 206 */
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_MM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 207 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 208 */
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 209 */
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 210 */
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 211 */
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 212 */
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 213 */
    { ENCODING_RM, TYPE_MM64 },
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 214 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 215 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_MM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 216 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 217 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_MM64 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 218 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_MM64 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 219 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 220 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_MM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 221 */
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 222 */
    { ENCODING_REG, TYPE_MM64 },
    { ENCODING_RM, TYPE_MM64 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 223 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_MM64 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 224 */
    { ENCODING_Ia, TYPE_MOFFS16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 225 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_REG, TYPE_SEGMENTREG },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 226 */
    { ENCODING_Rv, TYPE_Rv },
    { ENCODING_Iv, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 227 */
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_REG, TYPE_SEGMENTREG },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 228 */
    { ENCODING_REG, TYPE_SEGMENTREG },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 229 */
    { ENCODING_REG, TYPE_SEGMENTREG },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 230 */
    { ENCODING_Ia, TYPE_MOFFS32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 231 */
    { ENCODING_REG, TYPE_CONTROLREG },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 232 */
    { ENCODING_REG, TYPE_DEBUGREG },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 233 */
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_REG, TYPE_CONTROLREG },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 234 */
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_REG, TYPE_DEBUGREG },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 235 */
    { ENCODING_Ia, TYPE_MOFFS64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 236 */
    { ENCODING_REG, TYPE_CONTROLREG },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 237 */
    { ENCODING_REG, TYPE_DEBUGREG },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 238 */
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_REG, TYPE_CONTROLREG },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 239 */
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_REG, TYPE_DEBUGREG },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 240 */
    { ENCODING_RO, TYPE_R64 },
    { ENCODING_IO, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 241 */
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_REG, TYPE_SEGMENTREG },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 242 */
    { ENCODING_REG, TYPE_SEGMENTREG },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 243 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 244 */
    { ENCODING_Ia, TYPE_MOFFS8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 245 */
    { ENCODING_RB, TYPE_R8 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 246 */
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 247 */
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 248 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 249 */
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 250 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 251 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 252 */
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 253 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 254 */
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 255 */
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 256 */
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 257 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 258 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 259 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 260 */
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 261 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 262 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 263 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 264 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 265 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_R8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 266 */
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_RM, TYPE_R16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 267 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 268 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_R16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 269 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_R8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 270 */
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 271 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 272 */
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 273 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 274 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 275 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 276 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 277 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 278 */
    { ENCODING_Rv, TYPE_Rv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 279 */
    { ENCODING_RO, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 280 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 281 */
    { ENCODING_IB, TYPE_IMMv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 282 */
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 283 */
    { ENCODING_IB, TYPE_IMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 284 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 285 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 286 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 287 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 288 */
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 289 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 290 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 291 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 292 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 293 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 294 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 295 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 296 */
    { ENCODING_DI, TYPE_DSTIDX64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 297 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 298 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_Rv },
    { ENCODING_REG, TYPE_Rv },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 299 */
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 300 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 301 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 302 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 303 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 304 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 305 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 306 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 307 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 308 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 309 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 310 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 311 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 312 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 313 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 314 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 315 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 316 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 317 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 318 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 319 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 320 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 321 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 322 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 323 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM32 },
  },
  { /* 324 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 325 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 326 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 327 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 328 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 329 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 330 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 331 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 332 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 333 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 334 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 335 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 336 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 337 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 338 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 339 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 340 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 341 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 342 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 343 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 344 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 345 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 346 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 347 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 348 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 349 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 350 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 351 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM32 },
  },
  { /* 352 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 353 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 354 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 355 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 356 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 357 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 358 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 359 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 360 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 361 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 362 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 363 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 364 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 365 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 366 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 367 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_IB, TYPE_IMM32 },
  },
  { /* 368 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 369 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 370 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 371 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 372 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 373 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 374 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 375 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 376 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 377 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 378 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_IB, TYPE_IMM32 },
  },
  { /* 379 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 380 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 381 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 382 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 383 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 384 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
  },
  { /* 385 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 386 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
  },
  { /* 387 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 388 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M256 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 389 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_XMM256 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 390 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 391 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 392 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M256 },
    { ENCODING_IB, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 393 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_XMM256 },
    { ENCODING_IB, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 394 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_IB, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 395 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 396 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 397 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 398 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 399 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 400 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 401 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 402 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 403 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 404 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 405 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 406 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 407 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 408 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 409 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 410 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 411 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 412 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 413 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 414 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 415 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 416 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 417 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 418 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 419 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 420 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 421 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 422 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 423 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 424 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 425 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 426 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 427 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 428 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 429 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 430 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 431 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 432 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 433 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 434 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 435 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M256 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 436 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_XMM256 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 437 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 438 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 439 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 440 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 441 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 442 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 443 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 444 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 445 */
    { ENCODING_REG, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD16, TYPE_M64FP },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 446 */
    { ENCODING_REG, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD16, TYPE_XMM64 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 447 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 448 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 449 */
    { ENCODING_REG, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD16, TYPE_M32FP },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 450 */
    { ENCODING_REG, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD16, TYPE_XMM32 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 451 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 452 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_IB, TYPE_IMM5 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 453 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 454 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 455 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 456 */
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 457 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 458 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 459 */
    { ENCODING_RM_CD8, TYPE_M256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 460 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 461 */
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 462 */
    { ENCODING_RM_CD8, TYPE_M512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 463 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 464 */
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 465 */
    { ENCODING_RM_CD4, TYPE_M128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 466 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 467 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 468 */
    { ENCODING_RM_CD4, TYPE_M256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 469 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 470 */
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 471 */
    { ENCODING_RM_CD4, TYPE_M512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 472 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 473 */
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 474 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 475 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 476 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 477 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 478 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 479 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 480 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 481 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 482 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 483 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 484 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 485 */
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 486 */
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 487 */
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 488 */
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 489 */
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 490 */
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 491 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 492 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 493 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 494 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 495 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 496 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD16, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 497 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 498 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 499 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 500 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 501 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 502 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD4, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 503 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 504 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 505 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 506 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 507 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD4, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 508 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 509 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 510 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD8, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 511 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 512 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD8, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 513 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 514 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD16, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 515 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 516 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 517 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 518 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 519 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 520 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 521 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM_CD8, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 522 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM_CD8, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 523 */
    { ENCODING_REG, TYPE_R64 },
    { ENCODING_RM_CD4, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 524 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM_CD4, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 525 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 526 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD4, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 527 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD4, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 528 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 529 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 530 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 531 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD4, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 532 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD4, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 533 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 534 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 535 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD4, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 536 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD4, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 537 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 538 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 539 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD4, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 540 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD4, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 541 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 542 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 543 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 544 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 545 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 546 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 547 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD8, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 548 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD8, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 549 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 550 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 551 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD8, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 552 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD8, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 553 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD4, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 554 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD4, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 555 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 556 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 557 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD4, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 558 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD4, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 559 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 560 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 561 */
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 562 */
    { ENCODING_RM_CD64, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 563 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD64, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 564 */
    { ENCODING_RM_CD64, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 565 */
    { ENCODING_RM_CD64, TYPE_XMM256 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 566 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD64, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 567 */
    { ENCODING_RM_CD64, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 568 */
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 569 */
    { ENCODING_RM_CD16, TYPE_R32 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 570 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 571 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 572 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 573 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 574 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 575 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 576 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 577 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 578 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 579 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_IB, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 580 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_IB, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 581 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_IB, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 582 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_IB, TYPE_XMM256 },
    { ENCODING_RM, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 583 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 584 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 585 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 586 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 587 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 588 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 589 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 590 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 591 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 592 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 593 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 594 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_XMM512 },
    { ENCODING_IB, TYPE_IMM32 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 595 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_IB, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 596 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_IB, TYPE_XMM64 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 597 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_IB, TYPE_XMM64 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 598 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_IB, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 599 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 600 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD8, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 601 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 602 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 603 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_IB, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 604 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_IB, TYPE_XMM32 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 605 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_IB, TYPE_XMM32 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 606 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_IB, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 607 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD4, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 608 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD4, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 609 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 610 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 611 */
    { ENCODING_DUP, TYPE_DUP2 },
    { ENCODING_DUP, TYPE_DUP4 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M64 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 612 */
    { ENCODING_DUP, TYPE_DUP2 },
    { ENCODING_DUP, TYPE_DUP3 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD8, TYPE_M64 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 613 */
    { ENCODING_DUP, TYPE_DUP2 },
    { ENCODING_DUP, TYPE_DUP4 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M64 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 614 */
    { ENCODING_DUP, TYPE_DUP2 },
    { ENCODING_DUP, TYPE_DUP4 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M32 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 615 */
    { ENCODING_DUP, TYPE_DUP2 },
    { ENCODING_DUP, TYPE_DUP3 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD4, TYPE_M32 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 616 */
    { ENCODING_DUP, TYPE_DUP2 },
    { ENCODING_DUP, TYPE_DUP4 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M32 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 617 */
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD4, TYPE_M32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 618 */
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD4, TYPE_M32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 619 */
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD8, TYPE_M64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 620 */
    { ENCODING_DUP, TYPE_DUP2 },
    { ENCODING_DUP, TYPE_DUP3 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD4, TYPE_M64 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 621 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 622 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 623 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 624 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 625 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 626 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM256 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 627 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M32FP },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 628 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 629 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 630 */
    { ENCODING_RM, TYPE_M256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 631 */
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 632 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 633 */
    { ENCODING_RM, TYPE_M256 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 634 */
    { ENCODING_RM, TYPE_XMM256 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 635 */
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 636 */
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 637 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 638 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 639 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 640 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 641 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 642 */
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 643 */
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 644 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 645 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 646 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 647 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 648 */
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 649 */
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 650 */
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 651 */
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 652 */
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 653 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 654 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 655 */
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 656 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 657 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 658 */
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 659 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 660 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 661 */
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 662 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 663 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 664 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 665 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 666 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 667 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 668 */
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 669 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 670 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 671 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 672 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 673 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 674 */
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 675 */
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 676 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 677 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 678 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 679 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 680 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 681 */
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 682 */
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 683 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 684 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 685 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 686 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 687 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 688 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 689 */
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 690 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 691 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 692 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 693 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 694 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 695 */
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 696 */
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 697 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 698 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 699 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 700 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 701 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 702 */
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 703 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 704 */
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_RM, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 705 */
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 706 */
    { ENCODING_RM_CD16, TYPE_R32 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 707 */
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 708 */
    { ENCODING_RM_CD16, TYPE_R64 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 709 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 710 */
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 711 */
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 712 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 713 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 714 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 715 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD8, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 716 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 717 */
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 718 */
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 719 */
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 720 */
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 721 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 722 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 723 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 724 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD4, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 725 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 726 */
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 727 */
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_REG, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 728 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 729 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 730 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 731 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 732 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 733 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 734 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 735 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 736 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 737 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 738 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 739 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 740 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 741 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 742 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 743 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 744 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 745 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 746 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 747 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 748 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 749 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 750 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 751 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 752 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 753 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 754 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 755 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 756 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 757 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 758 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 759 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 760 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 761 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 762 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 763 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 764 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 765 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 766 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 767 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 768 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 769 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 770 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 771 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 772 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 773 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 774 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 775 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD16, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 776 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD16, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 777 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 778 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_RM_CD32, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 779 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_RM_CD32, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 780 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 781 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_RM_CD64, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 782 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_RM_CD64, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 783 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 784 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 785 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD16, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 786 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD16, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 787 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD32, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 788 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD32, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 789 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD64, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 790 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD64, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 791 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_VK8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 792 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_VK8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 793 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_VK8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 794 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_VK16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 795 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_VK16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 796 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_VK16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 797 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_RM_CD16, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 798 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_RM_CD16, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 799 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 800 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD32, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 801 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_RM_CD32, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 802 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 803 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD64, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 804 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD64, TYPE_R64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 805 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD16, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 806 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD16, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 807 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD32, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 808 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD32, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 809 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_RM_CD64, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 810 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_RM_CD64, TYPE_R32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 811 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 812 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 813 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 814 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 815 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 816 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 817 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 818 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 819 */
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 820 */
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 821 */
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 822 */
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 823 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 824 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 825 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 826 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 827 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 828 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 829 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 830 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 831 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 832 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 833 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 834 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 835 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 836 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 837 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 838 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 839 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 840 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 841 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 842 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 843 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 844 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 845 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 846 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 847 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 848 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 849 */
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 850 */
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 851 */
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 852 */
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_WRITEMASK, TYPE_VK64 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 853 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 854 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 855 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 856 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 857 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 858 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 859 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 860 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 861 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 862 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 863 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 864 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 865 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 866 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 867 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 868 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 869 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 870 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 871 */
    { ENCODING_REG, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 872 */
    { ENCODING_REG, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 873 */
    { ENCODING_REG, TYPE_VK2 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 874 */
    { ENCODING_REG, TYPE_VK2 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 875 */
    { ENCODING_REG, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 876 */
    { ENCODING_REG, TYPE_VK2 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 877 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 878 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 879 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 880 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 881 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 882 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 883 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 884 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 885 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 886 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 887 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 888 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 889 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 890 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 891 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 892 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 893 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 894 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 895 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 896 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 897 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 898 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 899 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 900 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 901 */
    { ENCODING_REG, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 902 */
    { ENCODING_REG, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 903 */
    { ENCODING_REG, TYPE_VK2 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 904 */
    { ENCODING_REG, TYPE_VK2 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 905 */
    { ENCODING_REG, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 906 */
    { ENCODING_REG, TYPE_VK2 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 907 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 908 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 909 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 910 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 911 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 912 */
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_WRITEMASK, TYPE_VK4 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 913 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 914 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 915 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 916 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 917 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 918 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 919 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 920 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 921 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 922 */
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 923 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 924 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 925 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 926 */
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 927 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 928 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 929 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 930 */
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_WRITEMASK, TYPE_VK32 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_AVX512ICC },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 931 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_IB, TYPE_IMM3 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 932 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_IMM3 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 933 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD4, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 934 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD8, TYPE_Mv },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 935 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_IB, TYPE_XMM128 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 936 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M256 },
    { ENCODING_IB, TYPE_XMM256 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 937 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_IB, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 938 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_IB, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M256 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 939 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_XMM128 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 940 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_XMM256 },
    { ENCODING_IB, TYPE_XMM256 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 941 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M256 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 942 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_RM, TYPE_XMM256 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 943 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 944 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 945 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M8 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 946 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_R32 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 947 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_Mv },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 948 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_R64 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 949 */
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 950 */
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 951 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 952 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 953 */
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 954 */
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 955 */
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 956 */
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 957 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 958 */
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 959 */
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_REG, TYPE_VK64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 960 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 961 */
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 962 */
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 963 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_REG, TYPE_VK2 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 964 */
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_REG, TYPE_VK4 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 965 */
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 966 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_REG, TYPE_VK8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 967 */
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_REG, TYPE_VK16 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 968 */
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_REG, TYPE_VK32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 969 */
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 970 */
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 971 */
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 972 */
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 973 */
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 974 */
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 975 */
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 976 */
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 977 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 978 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 979 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 980 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 981 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD32, TYPE_M256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 982 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 983 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD32, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 984 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 985 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 986 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 987 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 988 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_IMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 989 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 990 */
    { ENCODING_DUP, TYPE_DUP2 },
    { ENCODING_RM_CD4, TYPE_M32 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 991 */
    { ENCODING_DUP, TYPE_DUP2 },
    { ENCODING_RM_CD8, TYPE_M64 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 992 */
    { ENCODING_DUP, TYPE_DUP2 },
    { ENCODING_RM_CD4, TYPE_M64 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 993 */
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_XMM256 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 994 */
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 995 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 996 */
    { ENCODING_REG, TYPE_XMM256 },
    { ENCODING_VVVV, TYPE_XMM256 },
    { ENCODING_RM, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 997 */
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 998 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 999 */
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1000 */
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1001 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1002 */
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1003 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1004 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1005 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1006 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1007 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1008 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1009 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1010 */
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD64, TYPE_M512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1011 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1012 */
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_RM_CD64, TYPE_XMM512 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1013 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1014 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_M128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1015 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1016 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_XMM128 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1017 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1018 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1019 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1020 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1021 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1022 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK16 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1023 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1024 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_M512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1025 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1026 */
    { ENCODING_REG, TYPE_XMM512 },
    { ENCODING_WRITEMASK, TYPE_VK8 },
    { ENCODING_VVVV, TYPE_XMM512 },
    { ENCODING_RM_CD16, TYPE_XMM512 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1027 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1028 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1029 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK2 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1030 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD8, TYPE_M64FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1031 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD8, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1032 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD4, TYPE_M32FP },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1033 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD4, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1034 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1035 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_IB, TYPE_UIMM8 },
  },
  { /* 1036 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_M128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1037 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1038 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
  },
  { /* 1039 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD8, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1040 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1041 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M128 },
    { ENCODING_IB, TYPE_UIMM8 },
  },
  { /* 1042 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_M128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1043 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1044 */
    { ENCODING_DUP, TYPE_DUP1 },
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
  },
  { /* 1045 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_WRITEMASK, TYPE_VK1 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM_CD4, TYPE_XMM128 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1046 */
    { ENCODING_REG, TYPE_XMM128 },
    { ENCODING_VVVV, TYPE_XMM128 },
    { ENCODING_RM, TYPE_M64FP },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1047 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM, TYPE_XMM64 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1048 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM, TYPE_XMM32 },
    { ENCODING_IB, TYPE_UIMM8 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1049 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_VVVV, TYPE_XMM64 },
    { ENCODING_RM_CD16, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1050 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_VVVV, TYPE_XMM32 },
    { ENCODING_RM_CD16, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1051 */
    { ENCODING_REG, TYPE_XMM64 },
    { ENCODING_RM_CD8, TYPE_XMM64 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
  { /* 1052 */
    { ENCODING_REG, TYPE_XMM32 },
    { ENCODING_RM_CD4, TYPE_XMM32 },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
    { ENCODING_NONE, TYPE_NONE },
  },
};

static const struct InstructionSpecifier x86DisassemblerInstrSpecifiers[8853] = {
  { /* 0 */
    0,
    /*  */
  },
  { /* 1 */
    0,
    /*  */
  },
  { /* 2 */
    0,
    /*  */
  },
  { /* 3 */
    0,
    /*  */
  },
  { /* 4 */
    0,
    /*  */
  },
  { /* 5 */
    0,
    /*  */
  },
  { /* 6 */
    0,
    /*  */
  },
  { /* 7 */
    0,
    /*  */
  },
  { /* 8 */
    0,
    /*  */
  },
  { /* 9 */
    0,
    /*  */
  },
  { /* 10 */
    0,
    /*  */
  },
  { /* 11 */
    0,
    /*  */
  },
  { /* 12 */
    0,
    /*  */
  },
  { /* 13 */
    0,
    /*  */
  },
  { /* 14 */
    0,
    /*  */
  },
  { /* 15 */
    0,
    /*  */
  },
  { /* 16 */
    0,
    /*  */
  },
  { /* 17 */
    0,
    /*  */
  },
  { /* 18 */
    0,
    /*  */
  },
  { /* 19 */
    0,
    /*  */
  },
  { /* 20 */
    0,
    /*  */
  },
  { /* 21 */
    0,
    /*  */
  },
  { /* 22 */
    0,
    /* AAA */
  },
  { /* 23 */
    1,
    /* AAD8i8 */
  },
  { /* 24 */
    1,
    /* AAM8i8 */
  },
  { /* 25 */
    0,
    /* AAS */
  },
  { /* 26 */
    0,
    /* ABS_F */
  },
  { /* 27 */
    0,
    /*  */
  },
  { /* 28 */
    0,
    /*  */
  },
  { /* 29 */
    0,
    /*  */
  },
  { /* 30 */
    0,
    /*  */
  },
  { /* 31 */
    0,
    /*  */
  },
  { /* 32 */
    0,
    /*  */
  },
  { /* 33 */
    0,
    /*  */
  },
  { /* 34 */
    2,
    /* ADC16i16 */
  },
  { /* 35 */
    3,
    /* ADC16mi */
  },
  { /* 36 */
    4,
    /* ADC16mi8 */
  },
  { /* 37 */
    5,
    /* ADC16mr */
  },
  { /* 38 */
    6,
    /* ADC16ri */
  },
  { /* 39 */
    7,
    /* ADC16ri8 */
  },
  { /* 40 */
    8,
    /* ADC16rm */
  },
  { /* 41 */
    9,
    /* ADC16rr */
  },
  { /* 42 */
    10,
    /* ADC16rr_REV */
  },
  { /* 43 */
    2,
    /* ADC32i32 */
  },
  { /* 44 */
    3,
    /* ADC32mi */
  },
  { /* 45 */
    11,
    /* ADC32mi8 */
  },
  { /* 46 */
    5,
    /* ADC32mr */
  },
  { /* 47 */
    6,
    /* ADC32ri */
  },
  { /* 48 */
    12,
    /* ADC32ri8 */
  },
  { /* 49 */
    8,
    /* ADC32rm */
  },
  { /* 50 */
    9,
    /* ADC32rr */
  },
  { /* 51 */
    10,
    /* ADC32rr_REV */
  },
  { /* 52 */
    13,
    /* ADC64i32 */
  },
  { /* 53 */
    14,
    /* ADC64mi32 */
  },
  { /* 54 */
    15,
    /* ADC64mi8 */
  },
  { /* 55 */
    16,
    /* ADC64mr */
  },
  { /* 56 */
    17,
    /* ADC64ri32 */
  },
  { /* 57 */
    18,
    /* ADC64ri8 */
  },
  { /* 58 */
    19,
    /* ADC64rm */
  },
  { /* 59 */
    20,
    /* ADC64rr */
  },
  { /* 60 */
    21,
    /* ADC64rr_REV */
  },
  { /* 61 */
    1,
    /* ADC8i8 */
  },
  { /* 62 */
    22,
    /* ADC8mi */
  },
  { /* 63 */
    22,
    /* ADC8mi8 */
  },
  { /* 64 */
    23,
    /* ADC8mr */
  },
  { /* 65 */
    24,
    /* ADC8ri */
  },
  { /* 66 */
    24,
    /* ADC8ri8 */
  },
  { /* 67 */
    25,
    /* ADC8rm */
  },
  { /* 68 */
    26,
    /* ADC8rr */
  },
  { /* 69 */
    27,
    /* ADC8rr_REV */
  },
  { /* 70 */
    28,
    /* ADCX32rm */
  },
  { /* 71 */
    29,
    /* ADCX32rr */
  },
  { /* 72 */
    19,
    /* ADCX64rm */
  },
  { /* 73 */
    21,
    /* ADCX64rr */
  },
  { /* 74 */
    2,
    /* ADD16i16 */
  },
  { /* 75 */
    3,
    /* ADD16mi */
  },
  { /* 76 */
    4,
    /* ADD16mi8 */
  },
  { /* 77 */
    5,
    /* ADD16mr */
  },
  { /* 78 */
    6,
    /* ADD16ri */
  },
  { /* 79 */
    7,
    /* ADD16ri8 */
  },
  { /* 80 */
    0,
    /*  */
  },
  { /* 81 */
    0,
    /*  */
  },
  { /* 82 */
    8,
    /* ADD16rm */
  },
  { /* 83 */
    9,
    /* ADD16rr */
  },
  { /* 84 */
    0,
    /*  */
  },
  { /* 85 */
    10,
    /* ADD16rr_REV */
  },
  { /* 86 */
    2,
    /* ADD32i32 */
  },
  { /* 87 */
    3,
    /* ADD32mi */
  },
  { /* 88 */
    11,
    /* ADD32mi8 */
  },
  { /* 89 */
    5,
    /* ADD32mr */
  },
  { /* 90 */
    6,
    /* ADD32ri */
  },
  { /* 91 */
    12,
    /* ADD32ri8 */
  },
  { /* 92 */
    0,
    /*  */
  },
  { /* 93 */
    0,
    /*  */
  },
  { /* 94 */
    8,
    /* ADD32rm */
  },
  { /* 95 */
    9,
    /* ADD32rr */
  },
  { /* 96 */
    0,
    /*  */
  },
  { /* 97 */
    10,
    /* ADD32rr_REV */
  },
  { /* 98 */
    13,
    /* ADD64i32 */
  },
  { /* 99 */
    14,
    /* ADD64mi32 */
  },
  { /* 100 */
    15,
    /* ADD64mi8 */
  },
  { /* 101 */
    16,
    /* ADD64mr */
  },
  { /* 102 */
    17,
    /* ADD64ri32 */
  },
  { /* 103 */
    0,
    /*  */
  },
  { /* 104 */
    18,
    /* ADD64ri8 */
  },
  { /* 105 */
    0,
    /*  */
  },
  { /* 106 */
    19,
    /* ADD64rm */
  },
  { /* 107 */
    20,
    /* ADD64rr */
  },
  { /* 108 */
    0,
    /*  */
  },
  { /* 109 */
    21,
    /* ADD64rr_REV */
  },
  { /* 110 */
    1,
    /* ADD8i8 */
  },
  { /* 111 */
    22,
    /* ADD8mi */
  },
  { /* 112 */
    22,
    /* ADD8mi8 */
  },
  { /* 113 */
    23,
    /* ADD8mr */
  },
  { /* 114 */
    24,
    /* ADD8ri */
  },
  { /* 115 */
    24,
    /* ADD8ri8 */
  },
  { /* 116 */
    25,
    /* ADD8rm */
  },
  { /* 117 */
    26,
    /* ADD8rr */
  },
  { /* 118 */
    27,
    /* ADD8rr_REV */
  },
  { /* 119 */
    30,
    /* ADDPDrm */
  },
  { /* 120 */
    31,
    /* ADDPDrr */
  },
  { /* 121 */
    30,
    /* ADDPSrm */
  },
  { /* 122 */
    31,
    /* ADDPSrr */
  },
  { /* 123 */
    32,
    /* ADDSDrm */
  },
  { /* 124 */
    0,
    /*  */
  },
  { /* 125 */
    33,
    /* ADDSDrr */
  },
  { /* 126 */
    0,
    /*  */
  },
  { /* 127 */
    34,
    /* ADDSSrm */
  },
  { /* 128 */
    0,
    /*  */
  },
  { /* 129 */
    35,
    /* ADDSSrr */
  },
  { /* 130 */
    0,
    /*  */
  },
  { /* 131 */
    30,
    /* ADDSUBPDrm */
  },
  { /* 132 */
    31,
    /* ADDSUBPDrr */
  },
  { /* 133 */
    30,
    /* ADDSUBPSrm */
  },
  { /* 134 */
    31,
    /* ADDSUBPSrr */
  },
  { /* 135 */
    36,
    /* ADD_F32m */
  },
  { /* 136 */
    37,
    /* ADD_F64m */
  },
  { /* 137 */
    38,
    /* ADD_FI16m */
  },
  { /* 138 */
    38,
    /* ADD_FI32m */
  },
  { /* 139 */
    39,
    /* ADD_FPrST0 */
  },
  { /* 140 */
    39,
    /* ADD_FST0r */
  },
  { /* 141 */
    0,
    /*  */
  },
  { /* 142 */
    0,
    /*  */
  },
  { /* 143 */
    0,
    /*  */
  },
  { /* 144 */
    0,
    /*  */
  },
  { /* 145 */
    0,
    /*  */
  },
  { /* 146 */
    0,
    /*  */
  },
  { /* 147 */
    0,
    /*  */
  },
  { /* 148 */
    0,
    /*  */
  },
  { /* 149 */
    0,
    /*  */
  },
  { /* 150 */
    0,
    /*  */
  },
  { /* 151 */
    0,
    /*  */
  },
  { /* 152 */
    0,
    /*  */
  },
  { /* 153 */
    0,
    /*  */
  },
  { /* 154 */
    0,
    /*  */
  },
  { /* 155 */
    39,
    /* ADD_FrST0 */
  },
  { /* 156 */
    0,
    /*  */
  },
  { /* 157 */
    0,
    /*  */
  },
  { /* 158 */
    0,
    /*  */
  },
  { /* 159 */
    0,
    /*  */
  },
  { /* 160 */
    40,
    /* ADOX32rm */
  },
  { /* 161 */
    41,
    /* ADOX32rr */
  },
  { /* 162 */
    42,
    /* ADOX64rm */
  },
  { /* 163 */
    43,
    /* ADOX64rr */
  },
  { /* 164 */
    30,
    /* AESDECLASTrm */
  },
  { /* 165 */
    31,
    /* AESDECLASTrr */
  },
  { /* 166 */
    30,
    /* AESDECrm */
  },
  { /* 167 */
    31,
    /* AESDECrr */
  },
  { /* 168 */
    30,
    /* AESENCLASTrm */
  },
  { /* 169 */
    31,
    /* AESENCLASTrr */
  },
  { /* 170 */
    30,
    /* AESENCrm */
  },
  { /* 171 */
    31,
    /* AESENCrr */
  },
  { /* 172 */
    44,
    /* AESIMCrm */
  },
  { /* 173 */
    45,
    /* AESIMCrr */
  },
  { /* 174 */
    46,
    /* AESKEYGENASSIST128rm */
  },
  { /* 175 */
    47,
    /* AESKEYGENASSIST128rr */
  },
  { /* 176 */
    2,
    /* AND16i16 */
  },
  { /* 177 */
    3,
    /* AND16mi */
  },
  { /* 178 */
    4,
    /* AND16mi8 */
  },
  { /* 179 */
    5,
    /* AND16mr */
  },
  { /* 180 */
    6,
    /* AND16ri */
  },
  { /* 181 */
    7,
    /* AND16ri8 */
  },
  { /* 182 */
    8,
    /* AND16rm */
  },
  { /* 183 */
    9,
    /* AND16rr */
  },
  { /* 184 */
    10,
    /* AND16rr_REV */
  },
  { /* 185 */
    2,
    /* AND32i32 */
  },
  { /* 186 */
    3,
    /* AND32mi */
  },
  { /* 187 */
    11,
    /* AND32mi8 */
  },
  { /* 188 */
    5,
    /* AND32mr */
  },
  { /* 189 */
    6,
    /* AND32ri */
  },
  { /* 190 */
    12,
    /* AND32ri8 */
  },
  { /* 191 */
    8,
    /* AND32rm */
  },
  { /* 192 */
    9,
    /* AND32rr */
  },
  { /* 193 */
    10,
    /* AND32rr_REV */
  },
  { /* 194 */
    13,
    /* AND64i32 */
  },
  { /* 195 */
    14,
    /* AND64mi32 */
  },
  { /* 196 */
    15,
    /* AND64mi8 */
  },
  { /* 197 */
    16,
    /* AND64mr */
  },
  { /* 198 */
    17,
    /* AND64ri32 */
  },
  { /* 199 */
    18,
    /* AND64ri8 */
  },
  { /* 200 */
    19,
    /* AND64rm */
  },
  { /* 201 */
    20,
    /* AND64rr */
  },
  { /* 202 */
    21,
    /* AND64rr_REV */
  },
  { /* 203 */
    1,
    /* AND8i8 */
  },
  { /* 204 */
    22,
    /* AND8mi */
  },
  { /* 205 */
    22,
    /* AND8mi8 */
  },
  { /* 206 */
    23,
    /* AND8mr */
  },
  { /* 207 */
    24,
    /* AND8ri */
  },
  { /* 208 */
    24,
    /* AND8ri8 */
  },
  { /* 209 */
    25,
    /* AND8rm */
  },
  { /* 210 */
    26,
    /* AND8rr */
  },
  { /* 211 */
    27,
    /* AND8rr_REV */
  },
  { /* 212 */
    48,
    /* ANDN32rm */
  },
  { /* 213 */
    49,
    /* ANDN32rr */
  },
  { /* 214 */
    50,
    /* ANDN64rm */
  },
  { /* 215 */
    51,
    /* ANDN64rr */
  },
  { /* 216 */
    30,
    /* ANDNPDrm */
  },
  { /* 217 */
    31,
    /* ANDNPDrr */
  },
  { /* 218 */
    30,
    /* ANDNPSrm */
  },
  { /* 219 */
    31,
    /* ANDNPSrr */
  },
  { /* 220 */
    30,
    /* ANDPDrm */
  },
  { /* 221 */
    31,
    /* ANDPDrr */
  },
  { /* 222 */
    30,
    /* ANDPSrm */
  },
  { /* 223 */
    31,
    /* ANDPSrr */
  },
  { /* 224 */
    52,
    /* ARPL16mr */
  },
  { /* 225 */
    53,
    /* ARPL16rr */
  },
  { /* 226 */
    0,
    /*  */
  },
  { /* 227 */
    0,
    /*  */
  },
  { /* 228 */
    0,
    /*  */
  },
  { /* 229 */
    54,
    /* BEXTR32rm */
  },
  { /* 230 */
    55,
    /* BEXTR32rr */
  },
  { /* 231 */
    56,
    /* BEXTR64rm */
  },
  { /* 232 */
    57,
    /* BEXTR64rr */
  },
  { /* 233 */
    58,
    /* BEXTRI32mi */
  },
  { /* 234 */
    59,
    /* BEXTRI32ri */
  },
  { /* 235 */
    60,
    /* BEXTRI64mi */
  },
  { /* 236 */
    61,
    /* BEXTRI64ri */
  },
  { /* 237 */
    62,
    /* BLCFILL32rm */
  },
  { /* 238 */
    63,
    /* BLCFILL32rr */
  },
  { /* 239 */
    64,
    /* BLCFILL64rm */
  },
  { /* 240 */
    65,
    /* BLCFILL64rr */
  },
  { /* 241 */
    62,
    /* BLCI32rm */
  },
  { /* 242 */
    63,
    /* BLCI32rr */
  },
  { /* 243 */
    64,
    /* BLCI64rm */
  },
  { /* 244 */
    65,
    /* BLCI64rr */
  },
  { /* 245 */
    62,
    /* BLCIC32rm */
  },
  { /* 246 */
    63,
    /* BLCIC32rr */
  },
  { /* 247 */
    64,
    /* BLCIC64rm */
  },
  { /* 248 */
    65,
    /* BLCIC64rr */
  },
  { /* 249 */
    62,
    /* BLCMSK32rm */
  },
  { /* 250 */
    63,
    /* BLCMSK32rr */
  },
  { /* 251 */
    64,
    /* BLCMSK64rm */
  },
  { /* 252 */
    65,
    /* BLCMSK64rr */
  },
  { /* 253 */
    62,
    /* BLCS32rm */
  },
  { /* 254 */
    63,
    /* BLCS32rr */
  },
  { /* 255 */
    64,
    /* BLCS64rm */
  },
  { /* 256 */
    65,
    /* BLCS64rr */
  },
  { /* 257 */
    66,
    /* BLENDPDrmi */
  },
  { /* 258 */
    67,
    /* BLENDPDrri */
  },
  { /* 259 */
    66,
    /* BLENDPSrmi */
  },
  { /* 260 */
    67,
    /* BLENDPSrri */
  },
  { /* 261 */
    30,
    /* BLENDVPDrm0 */
  },
  { /* 262 */
    31,
    /* BLENDVPDrr0 */
  },
  { /* 263 */
    30,
    /* BLENDVPSrm0 */
  },
  { /* 264 */
    31,
    /* BLENDVPSrr0 */
  },
  { /* 265 */
    62,
    /* BLSFILL32rm */
  },
  { /* 266 */
    63,
    /* BLSFILL32rr */
  },
  { /* 267 */
    64,
    /* BLSFILL64rm */
  },
  { /* 268 */
    65,
    /* BLSFILL64rr */
  },
  { /* 269 */
    62,
    /* BLSI32rm */
  },
  { /* 270 */
    63,
    /* BLSI32rr */
  },
  { /* 271 */
    64,
    /* BLSI64rm */
  },
  { /* 272 */
    65,
    /* BLSI64rr */
  },
  { /* 273 */
    62,
    /* BLSIC32rm */
  },
  { /* 274 */
    63,
    /* BLSIC32rr */
  },
  { /* 275 */
    64,
    /* BLSIC64rm */
  },
  { /* 276 */
    65,
    /* BLSIC64rr */
  },
  { /* 277 */
    62,
    /* BLSMSK32rm */
  },
  { /* 278 */
    63,
    /* BLSMSK32rr */
  },
  { /* 279 */
    64,
    /* BLSMSK64rm */
  },
  { /* 280 */
    65,
    /* BLSMSK64rr */
  },
  { /* 281 */
    62,
    /* BLSR32rm */
  },
  { /* 282 */
    63,
    /* BLSR32rr */
  },
  { /* 283 */
    64,
    /* BLSR64rm */
  },
  { /* 284 */
    65,
    /* BLSR64rr */
  },
  { /* 285 */
    68,
    /* BOUNDS16rm */
  },
  { /* 286 */
    68,
    /* BOUNDS32rm */
  },
  { /* 287 */
    68,
    /* BSF16rm */
  },
  { /* 288 */
    69,
    /* BSF16rr */
  },
  { /* 289 */
    68,
    /* BSF32rm */
  },
  { /* 290 */
    69,
    /* BSF32rr */
  },
  { /* 291 */
    42,
    /* BSF64rm */
  },
  { /* 292 */
    43,
    /* BSF64rr */
  },
  { /* 293 */
    68,
    /* BSR16rm */
  },
  { /* 294 */
    69,
    /* BSR16rr */
  },
  { /* 295 */
    68,
    /* BSR32rm */
  },
  { /* 296 */
    69,
    /* BSR32rr */
  },
  { /* 297 */
    42,
    /* BSR64rm */
  },
  { /* 298 */
    43,
    /* BSR64rr */
  },
  { /* 299 */
    70,
    /* BSWAP32r */
  },
  { /* 300 */
    71,
    /* BSWAP64r */
  },
  { /* 301 */
    4,
    /* BT16mi8 */
  },
  { /* 302 */
    5,
    /* BT16mr */
  },
  { /* 303 */
    72,
    /* BT16ri8 */
  },
  { /* 304 */
    73,
    /* BT16rr */
  },
  { /* 305 */
    11,
    /* BT32mi8 */
  },
  { /* 306 */
    5,
    /* BT32mr */
  },
  { /* 307 */
    74,
    /* BT32ri8 */
  },
  { /* 308 */
    73,
    /* BT32rr */
  },
  { /* 309 */
    15,
    /* BT64mi8 */
  },
  { /* 310 */
    16,
    /* BT64mr */
  },
  { /* 311 */
    75,
    /* BT64ri8 */
  },
  { /* 312 */
    76,
    /* BT64rr */
  },
  { /* 313 */
    4,
    /* BTC16mi8 */
  },
  { /* 314 */
    5,
    /* BTC16mr */
  },
  { /* 315 */
    72,
    /* BTC16ri8 */
  },
  { /* 316 */
    73,
    /* BTC16rr */
  },
  { /* 317 */
    11,
    /* BTC32mi8 */
  },
  { /* 318 */
    5,
    /* BTC32mr */
  },
  { /* 319 */
    74,
    /* BTC32ri8 */
  },
  { /* 320 */
    73,
    /* BTC32rr */
  },
  { /* 321 */
    15,
    /* BTC64mi8 */
  },
  { /* 322 */
    16,
    /* BTC64mr */
  },
  { /* 323 */
    75,
    /* BTC64ri8 */
  },
  { /* 324 */
    76,
    /* BTC64rr */
  },
  { /* 325 */
    4,
    /* BTR16mi8 */
  },
  { /* 326 */
    5,
    /* BTR16mr */
  },
  { /* 327 */
    72,
    /* BTR16ri8 */
  },
  { /* 328 */
    73,
    /* BTR16rr */
  },
  { /* 329 */
    11,
    /* BTR32mi8 */
  },
  { /* 330 */
    5,
    /* BTR32mr */
  },
  { /* 331 */
    74,
    /* BTR32ri8 */
  },
  { /* 332 */
    73,
    /* BTR32rr */
  },
  { /* 333 */
    15,
    /* BTR64mi8 */
  },
  { /* 334 */
    16,
    /* BTR64mr */
  },
  { /* 335 */
    75,
    /* BTR64ri8 */
  },
  { /* 336 */
    76,
    /* BTR64rr */
  },
  { /* 337 */
    4,
    /* BTS16mi8 */
  },
  { /* 338 */
    5,
    /* BTS16mr */
  },
  { /* 339 */
    72,
    /* BTS16ri8 */
  },
  { /* 340 */
    73,
    /* BTS16rr */
  },
  { /* 341 */
    11,
    /* BTS32mi8 */
  },
  { /* 342 */
    5,
    /* BTS32mr */
  },
  { /* 343 */
    74,
    /* BTS32ri8 */
  },
  { /* 344 */
    73,
    /* BTS32rr */
  },
  { /* 345 */
    15,
    /* BTS64mi8 */
  },
  { /* 346 */
    16,
    /* BTS64mr */
  },
  { /* 347 */
    75,
    /* BTS64ri8 */
  },
  { /* 348 */
    76,
    /* BTS64rr */
  },
  { /* 349 */
    54,
    /* BZHI32rm */
  },
  { /* 350 */
    55,
    /* BZHI32rr */
  },
  { /* 351 */
    56,
    /* BZHI64rm */
  },
  { /* 352 */
    57,
    /* BZHI64rr */
  },
  { /* 353 */
    38,
    /* CALL16m */
  },
  { /* 354 */
    77,
    /* CALL16r */
  },
  { /* 355 */
    38,
    /* CALL32m */
  },
  { /* 356 */
    77,
    /* CALL32r */
  },
  { /* 357 */
    38,
    /* CALL64m */
  },
  { /* 358 */
    78,
    /* CALL64pcrel32 */
  },
  { /* 359 */
    79,
    /* CALL64r */
  },
  { /* 360 */
    80,
    /* CALLpcrel16 */
  },
  { /* 361 */
    81,
    /* CALLpcrel32 */
  },
  { /* 362 */
    0,
    /* CBW */
  },
  { /* 363 */
    0,
    /* CDQ */
  },
  { /* 364 */
    0,
    /* CDQE */
  },
  { /* 365 */
    0,
    /* CHS_F */
  },
  { /* 366 */
    0,
    /*  */
  },
  { /* 367 */
    0,
    /*  */
  },
  { /* 368 */
    0,
    /*  */
  },
  { /* 369 */
    0,
    /* CLAC */
  },
  { /* 370 */
    0,
    /* CLC */
  },
  { /* 371 */
    0,
    /* CLD */
  },
  { /* 372 */
    82,
    /* CLFLUSH */
  },
  { /* 373 */
    82,
    /* CLFLUSHOPT */
  },
  { /* 374 */
    0,
    /* CLGI */
  },
  { /* 375 */
    0,
    /* CLI */
  },
  { /* 376 */
    0,
    /* CLTS */
  },
  { /* 377 */
    82,
    /* CLWB */
  },
  { /* 378 */
    0,
    /* CMC */
  },
  { /* 379 */
    8,
    /* CMOVA16rm */
  },
  { /* 380 */
    10,
    /* CMOVA16rr */
  },
  { /* 381 */
    8,
    /* CMOVA32rm */
  },
  { /* 382 */
    10,
    /* CMOVA32rr */
  },
  { /* 383 */
    19,
    /* CMOVA64rm */
  },
  { /* 384 */
    21,
    /* CMOVA64rr */
  },
  { /* 385 */
    8,
    /* CMOVAE16rm */
  },
  { /* 386 */
    10,
    /* CMOVAE16rr */
  },
  { /* 387 */
    8,
    /* CMOVAE32rm */
  },
  { /* 388 */
    10,
    /* CMOVAE32rr */
  },
  { /* 389 */
    19,
    /* CMOVAE64rm */
  },
  { /* 390 */
    21,
    /* CMOVAE64rr */
  },
  { /* 391 */
    8,
    /* CMOVB16rm */
  },
  { /* 392 */
    10,
    /* CMOVB16rr */
  },
  { /* 393 */
    8,
    /* CMOVB32rm */
  },
  { /* 394 */
    10,
    /* CMOVB32rr */
  },
  { /* 395 */
    19,
    /* CMOVB64rm */
  },
  { /* 396 */
    21,
    /* CMOVB64rr */
  },
  { /* 397 */
    8,
    /* CMOVBE16rm */
  },
  { /* 398 */
    10,
    /* CMOVBE16rr */
  },
  { /* 399 */
    8,
    /* CMOVBE32rm */
  },
  { /* 400 */
    10,
    /* CMOVBE32rr */
  },
  { /* 401 */
    19,
    /* CMOVBE64rm */
  },
  { /* 402 */
    21,
    /* CMOVBE64rr */
  },
  { /* 403 */
    39,
    /* CMOVBE_F */
  },
  { /* 404 */
    0,
    /*  */
  },
  { /* 405 */
    0,
    /*  */
  },
  { /* 406 */
    0,
    /*  */
  },
  { /* 407 */
    39,
    /* CMOVB_F */
  },
  { /* 408 */
    0,
    /*  */
  },
  { /* 409 */
    0,
    /*  */
  },
  { /* 410 */
    0,
    /*  */
  },
  { /* 411 */
    8,
    /* CMOVE16rm */
  },
  { /* 412 */
    10,
    /* CMOVE16rr */
  },
  { /* 413 */
    8,
    /* CMOVE32rm */
  },
  { /* 414 */
    10,
    /* CMOVE32rr */
  },
  { /* 415 */
    19,
    /* CMOVE64rm */
  },
  { /* 416 */
    21,
    /* CMOVE64rr */
  },
  { /* 417 */
    39,
    /* CMOVE_F */
  },
  { /* 418 */
    0,
    /*  */
  },
  { /* 419 */
    0,
    /*  */
  },
  { /* 420 */
    0,
    /*  */
  },
  { /* 421 */
    8,
    /* CMOVG16rm */
  },
  { /* 422 */
    10,
    /* CMOVG16rr */
  },
  { /* 423 */
    8,
    /* CMOVG32rm */
  },
  { /* 424 */
    10,
    /* CMOVG32rr */
  },
  { /* 425 */
    19,
    /* CMOVG64rm */
  },
  { /* 426 */
    21,
    /* CMOVG64rr */
  },
  { /* 427 */
    8,
    /* CMOVGE16rm */
  },
  { /* 428 */
    10,
    /* CMOVGE16rr */
  },
  { /* 429 */
    8,
    /* CMOVGE32rm */
  },
  { /* 430 */
    10,
    /* CMOVGE32rr */
  },
  { /* 431 */
    19,
    /* CMOVGE64rm */
  },
  { /* 432 */
    21,
    /* CMOVGE64rr */
  },
  { /* 433 */
    8,
    /* CMOVL16rm */
  },
  { /* 434 */
    10,
    /* CMOVL16rr */
  },
  { /* 435 */
    8,
    /* CMOVL32rm */
  },
  { /* 436 */
    10,
    /* CMOVL32rr */
  },
  { /* 437 */
    19,
    /* CMOVL64rm */
  },
  { /* 438 */
    21,
    /* CMOVL64rr */
  },
  { /* 439 */
    8,
    /* CMOVLE16rm */
  },
  { /* 440 */
    10,
    /* CMOVLE16rr */
  },
  { /* 441 */
    8,
    /* CMOVLE32rm */
  },
  { /* 442 */
    10,
    /* CMOVLE32rr */
  },
  { /* 443 */
    19,
    /* CMOVLE64rm */
  },
  { /* 444 */
    21,
    /* CMOVLE64rr */
  },
  { /* 445 */
    39,
    /* CMOVNBE_F */
  },
  { /* 446 */
    0,
    /*  */
  },
  { /* 447 */
    0,
    /*  */
  },
  { /* 448 */
    0,
    /*  */
  },
  { /* 449 */
    39,
    /* CMOVNB_F */
  },
  { /* 450 */
    0,
    /*  */
  },
  { /* 451 */
    0,
    /*  */
  },
  { /* 452 */
    0,
    /*  */
  },
  { /* 453 */
    8,
    /* CMOVNE16rm */
  },
  { /* 454 */
    10,
    /* CMOVNE16rr */
  },
  { /* 455 */
    8,
    /* CMOVNE32rm */
  },
  { /* 456 */
    10,
    /* CMOVNE32rr */
  },
  { /* 457 */
    19,
    /* CMOVNE64rm */
  },
  { /* 458 */
    21,
    /* CMOVNE64rr */
  },
  { /* 459 */
    39,
    /* CMOVNE_F */
  },
  { /* 460 */
    0,
    /*  */
  },
  { /* 461 */
    0,
    /*  */
  },
  { /* 462 */
    0,
    /*  */
  },
  { /* 463 */
    8,
    /* CMOVNO16rm */
  },
  { /* 464 */
    10,
    /* CMOVNO16rr */
  },
  { /* 465 */
    8,
    /* CMOVNO32rm */
  },
  { /* 466 */
    10,
    /* CMOVNO32rr */
  },
  { /* 467 */
    19,
    /* CMOVNO64rm */
  },
  { /* 468 */
    21,
    /* CMOVNO64rr */
  },
  { /* 469 */
    8,
    /* CMOVNP16rm */
  },
  { /* 470 */
    10,
    /* CMOVNP16rr */
  },
  { /* 471 */
    8,
    /* CMOVNP32rm */
  },
  { /* 472 */
    10,
    /* CMOVNP32rr */
  },
  { /* 473 */
    19,
    /* CMOVNP64rm */
  },
  { /* 474 */
    21,
    /* CMOVNP64rr */
  },
  { /* 475 */
    39,
    /* CMOVNP_F */
  },
  { /* 476 */
    0,
    /*  */
  },
  { /* 477 */
    0,
    /*  */
  },
  { /* 478 */
    0,
    /*  */
  },
  { /* 479 */
    8,
    /* CMOVNS16rm */
  },
  { /* 480 */
    10,
    /* CMOVNS16rr */
  },
  { /* 481 */
    8,
    /* CMOVNS32rm */
  },
  { /* 482 */
    10,
    /* CMOVNS32rr */
  },
  { /* 483 */
    19,
    /* CMOVNS64rm */
  },
  { /* 484 */
    21,
    /* CMOVNS64rr */
  },
  { /* 485 */
    8,
    /* CMOVO16rm */
  },
  { /* 486 */
    10,
    /* CMOVO16rr */
  },
  { /* 487 */
    8,
    /* CMOVO32rm */
  },
  { /* 488 */
    10,
    /* CMOVO32rr */
  },
  { /* 489 */
    19,
    /* CMOVO64rm */
  },
  { /* 490 */
    21,
    /* CMOVO64rr */
  },
  { /* 491 */
    8,
    /* CMOVP16rm */
  },
  { /* 492 */
    10,
    /* CMOVP16rr */
  },
  { /* 493 */
    8,
    /* CMOVP32rm */
  },
  { /* 494 */
    10,
    /* CMOVP32rr */
  },
  { /* 495 */
    19,
    /* CMOVP64rm */
  },
  { /* 496 */
    21,
    /* CMOVP64rr */
  },
  { /* 497 */
    39,
    /* CMOVP_F */
  },
  { /* 498 */
    0,
    /*  */
  },
  { /* 499 */
    0,
    /*  */
  },
  { /* 500 */
    0,
    /*  */
  },
  { /* 501 */
    8,
    /* CMOVS16rm */
  },
  { /* 502 */
    10,
    /* CMOVS16rr */
  },
  { /* 503 */
    8,
    /* CMOVS32rm */
  },
  { /* 504 */
    10,
    /* CMOVS32rr */
  },
  { /* 505 */
    19,
    /* CMOVS64rm */
  },
  { /* 506 */
    21,
    /* CMOVS64rr */
  },
  { /* 507 */
    0,
    /*  */
  },
  { /* 508 */
    0,
    /*  */
  },
  { /* 509 */
    0,
    /*  */
  },
  { /* 510 */
    0,
    /*  */
  },
  { /* 511 */
    0,
    /*  */
  },
  { /* 512 */
    0,
    /*  */
  },
  { /* 513 */
    0,
    /*  */
  },
  { /* 514 */
    0,
    /*  */
  },
  { /* 515 */
    0,
    /*  */
  },
  { /* 516 */
    0,
    /*  */
  },
  { /* 517 */
    0,
    /*  */
  },
  { /* 518 */
    0,
    /*  */
  },
  { /* 519 */
    0,
    /*  */
  },
  { /* 520 */
    0,
    /*  */
  },
  { /* 521 */
    0,
    /*  */
  },
  { /* 522 */
    0,
    /*  */
  },
  { /* 523 */
    0,
    /*  */
  },
  { /* 524 */
    2,
    /* CMP16i16 */
  },
  { /* 525 */
    3,
    /* CMP16mi */
  },
  { /* 526 */
    4,
    /* CMP16mi8 */
  },
  { /* 527 */
    5,
    /* CMP16mr */
  },
  { /* 528 */
    83,
    /* CMP16ri */
  },
  { /* 529 */
    72,
    /* CMP16ri8 */
  },
  { /* 530 */
    68,
    /* CMP16rm */
  },
  { /* 531 */
    73,
    /* CMP16rr */
  },
  { /* 532 */
    69,
    /* CMP16rr_REV */
  },
  { /* 533 */
    2,
    /* CMP32i32 */
  },
  { /* 534 */
    3,
    /* CMP32mi */
  },
  { /* 535 */
    11,
    /* CMP32mi8 */
  },
  { /* 536 */
    5,
    /* CMP32mr */
  },
  { /* 537 */
    83,
    /* CMP32ri */
  },
  { /* 538 */
    74,
    /* CMP32ri8 */
  },
  { /* 539 */
    68,
    /* CMP32rm */
  },
  { /* 540 */
    73,
    /* CMP32rr */
  },
  { /* 541 */
    69,
    /* CMP32rr_REV */
  },
  { /* 542 */
    13,
    /* CMP64i32 */
  },
  { /* 543 */
    14,
    /* CMP64mi32 */
  },
  { /* 544 */
    15,
    /* CMP64mi8 */
  },
  { /* 545 */
    16,
    /* CMP64mr */
  },
  { /* 546 */
    84,
    /* CMP64ri32 */
  },
  { /* 547 */
    75,
    /* CMP64ri8 */
  },
  { /* 548 */
    42,
    /* CMP64rm */
  },
  { /* 549 */
    76,
    /* CMP64rr */
  },
  { /* 550 */
    43,
    /* CMP64rr_REV */
  },
  { /* 551 */
    1,
    /* CMP8i8 */
  },
  { /* 552 */
    22,
    /* CMP8mi */
  },
  { /* 553 */
    22,
    /* CMP8mi8 */
  },
  { /* 554 */
    23,
    /* CMP8mr */
  },
  { /* 555 */
    85,
    /* CMP8ri */
  },
  { /* 556 */
    85,
    /* CMP8ri8 */
  },
  { /* 557 */
    86,
    /* CMP8rm */
  },
  { /* 558 */
    87,
    /* CMP8rr */
  },
  { /* 559 */
    88,
    /* CMP8rr_REV */
  },
  { /* 560 */
    89,
    /* CMPPDrmi */
  },
  { /* 561 */
    0,
    /*  */
  },
  { /* 562 */
    90,
    /* CMPPDrri */
  },
  { /* 563 */
    0,
    /*  */
  },
  { /* 564 */
    89,
    /* CMPPSrmi */
  },
  { /* 565 */
    0,
    /*  */
  },
  { /* 566 */
    90,
    /* CMPPSrri */
  },
  { /* 567 */
    0,
    /*  */
  },
  { /* 568 */
    91,
    /* CMPSB */
  },
  { /* 569 */
    92,
    /* CMPSDrm */
  },
  { /* 570 */
    0,
    /*  */
  },
  { /* 571 */
    93,
    /* CMPSDrr */
  },
  { /* 572 */
    0,
    /*  */
  },
  { /* 573 */
    94,
    /* CMPSL */
  },
  { /* 574 */
    95,
    /* CMPSQ */
  },
  { /* 575 */
    96,
    /* CMPSSrm */
  },
  { /* 576 */
    0,
    /*  */
  },
  { /* 577 */
    97,
    /* CMPSSrr */
  },
  { /* 578 */
    0,
    /*  */
  },
  { /* 579 */
    98,
    /* CMPSW */
  },
  { /* 580 */
    99,
    /* CMPXCHG16B */
  },
  { /* 581 */
    5,
    /* CMPXCHG16rm */
  },
  { /* 582 */
    73,
    /* CMPXCHG16rr */
  },
  { /* 583 */
    5,
    /* CMPXCHG32rm */
  },
  { /* 584 */
    73,
    /* CMPXCHG32rr */
  },
  { /* 585 */
    16,
    /* CMPXCHG64rm */
  },
  { /* 586 */
    76,
    /* CMPXCHG64rr */
  },
  { /* 587 */
    38,
    /* CMPXCHG8B */
  },
  { /* 588 */
    23,
    /* CMPXCHG8rm */
  },
  { /* 589 */
    87,
    /* CMPXCHG8rr */
  },
  { /* 590 */
    44,
    /* COMISDrm */
  },
  { /* 591 */
    45,
    /* COMISDrr */
  },
  { /* 592 */
    44,
    /* COMISSrm */
  },
  { /* 593 */
    45,
    /* COMISSrr */
  },
  { /* 594 */
    39,
    /* COMP_FST0r */
  },
  { /* 595 */
    39,
    /* COM_FIPr */
  },
  { /* 596 */
    39,
    /* COM_FIr */
  },
  { /* 597 */
    39,
    /* COM_FST0r */
  },
  { /* 598 */
    0,
    /* COS_F */
  },
  { /* 599 */
    0,
    /*  */
  },
  { /* 600 */
    0,
    /*  */
  },
  { /* 601 */
    0,
    /*  */
  },
  { /* 602 */
    0,
    /* CPUID */
  },
  { /* 603 */
    0,
    /* CQO */
  },
  { /* 604 */
    28,
    /* CRC32r32m16 */
  },
  { /* 605 */
    8,
    /* CRC32r32m32 */
  },
  { /* 606 */
    100,
    /* CRC32r32m8 */
  },
  { /* 607 */
    101,
    /* CRC32r32r16 */
  },
  { /* 608 */
    10,
    /* CRC32r32r32 */
  },
  { /* 609 */
    102,
    /* CRC32r32r8 */
  },
  { /* 610 */
    19,
    /* CRC32r64m64 */
  },
  { /* 611 */
    103,
    /* CRC32r64m8 */
  },
  { /* 612 */
    21,
    /* CRC32r64r64 */
  },
  { /* 613 */
    104,
    /* CRC32r64r8 */
  },
  { /* 614 */
    105,
    /* CVTDQ2PDrm */
  },
  { /* 615 */
    45,
    /* CVTDQ2PDrr */
  },
  { /* 616 */
    44,
    /* CVTDQ2PSrm */
  },
  { /* 617 */
    45,
    /* CVTDQ2PSrr */
  },
  { /* 618 */
    44,
    /* CVTPD2DQrm */
  },
  { /* 619 */
    45,
    /* CVTPD2DQrr */
  },
  { /* 620 */
    44,
    /* CVTPD2PSrm */
  },
  { /* 621 */
    45,
    /* CVTPD2PSrr */
  },
  { /* 622 */
    44,
    /* CVTPS2DQrm */
  },
  { /* 623 */
    45,
    /* CVTPS2DQrr */
  },
  { /* 624 */
    106,
    /* CVTPS2PDrm */
  },
  { /* 625 */
    45,
    /* CVTPS2PDrr */
  },
  { /* 626 */
    107,
    /* CVTSD2SI64rm */
  },
  { /* 627 */
    108,
    /* CVTSD2SI64rr */
  },
  { /* 628 */
    109,
    /* CVTSD2SIrm */
  },
  { /* 629 */
    110,
    /* CVTSD2SIrr */
  },
  { /* 630 */
    111,
    /* CVTSD2SSrm */
  },
  { /* 631 */
    112,
    /* CVTSD2SSrr */
  },
  { /* 632 */
    113,
    /* CVTSI2SD64rm */
  },
  { /* 633 */
    114,
    /* CVTSI2SD64rr */
  },
  { /* 634 */
    113,
    /* CVTSI2SDrm */
  },
  { /* 635 */
    115,
    /* CVTSI2SDrr */
  },
  { /* 636 */
    116,
    /* CVTSI2SS64rm */
  },
  { /* 637 */
    117,
    /* CVTSI2SS64rr */
  },
  { /* 638 */
    116,
    /* CVTSI2SSrm */
  },
  { /* 639 */
    118,
    /* CVTSI2SSrr */
  },
  { /* 640 */
    119,
    /* CVTSS2SDrm */
  },
  { /* 641 */
    120,
    /* CVTSS2SDrr */
  },
  { /* 642 */
    121,
    /* CVTSS2SI64rm */
  },
  { /* 643 */
    108,
    /* CVTSS2SI64rr */
  },
  { /* 644 */
    122,
    /* CVTSS2SIrm */
  },
  { /* 645 */
    110,
    /* CVTSS2SIrr */
  },
  { /* 646 */
    44,
    /* CVTTPD2DQrm */
  },
  { /* 647 */
    45,
    /* CVTTPD2DQrr */
  },
  { /* 648 */
    44,
    /* CVTTPS2DQrm */
  },
  { /* 649 */
    45,
    /* CVTTPS2DQrr */
  },
  { /* 650 */
    107,
    /* CVTTSD2SI64rm */
  },
  { /* 651 */
    123,
    /* CVTTSD2SI64rr */
  },
  { /* 652 */
    109,
    /* CVTTSD2SIrm */
  },
  { /* 653 */
    124,
    /* CVTTSD2SIrr */
  },
  { /* 654 */
    121,
    /* CVTTSS2SI64rm */
  },
  { /* 655 */
    125,
    /* CVTTSS2SI64rr */
  },
  { /* 656 */
    122,
    /* CVTTSS2SIrm */
  },
  { /* 657 */
    126,
    /* CVTTSS2SIrr */
  },
  { /* 658 */
    0,
    /* CWD */
  },
  { /* 659 */
    0,
    /* CWDE */
  },
  { /* 660 */
    0,
    /* DAA */
  },
  { /* 661 */
    0,
    /* DAS */
  },
  { /* 662 */
    0,
    /* DATA16_PREFIX */
  },
  { /* 663 */
    38,
    /* DEC16m */
  },
  { /* 664 */
    127,
    /* DEC16r */
  },
  { /* 665 */
    70,
    /* DEC16r_alt */
  },
  { /* 666 */
    38,
    /* DEC32m */
  },
  { /* 667 */
    127,
    /* DEC32r */
  },
  { /* 668 */
    70,
    /* DEC32r_alt */
  },
  { /* 669 */
    38,
    /* DEC64m */
  },
  { /* 670 */
    128,
    /* DEC64r */
  },
  { /* 671 */
    82,
    /* DEC8m */
  },
  { /* 672 */
    129,
    /* DEC8r */
  },
  { /* 673 */
    38,
    /* DIV16m */
  },
  { /* 674 */
    77,
    /* DIV16r */
  },
  { /* 675 */
    38,
    /* DIV32m */
  },
  { /* 676 */
    77,
    /* DIV32r */
  },
  { /* 677 */
    38,
    /* DIV64m */
  },
  { /* 678 */
    79,
    /* DIV64r */
  },
  { /* 679 */
    82,
    /* DIV8m */
  },
  { /* 680 */
    130,
    /* DIV8r */
  },
  { /* 681 */
    30,
    /* DIVPDrm */
  },
  { /* 682 */
    31,
    /* DIVPDrr */
  },
  { /* 683 */
    30,
    /* DIVPSrm */
  },
  { /* 684 */
    31,
    /* DIVPSrr */
  },
  { /* 685 */
    36,
    /* DIVR_F32m */
  },
  { /* 686 */
    37,
    /* DIVR_F64m */
  },
  { /* 687 */
    38,
    /* DIVR_FI16m */
  },
  { /* 688 */
    38,
    /* DIVR_FI32m */
  },
  { /* 689 */
    39,
    /* DIVR_FPrST0 */
  },
  { /* 690 */
    39,
    /* DIVR_FST0r */
  },
  { /* 691 */
    0,
    /*  */
  },
  { /* 692 */
    0,
    /*  */
  },
  { /* 693 */
    0,
    /*  */
  },
  { /* 694 */
    0,
    /*  */
  },
  { /* 695 */
    0,
    /*  */
  },
  { /* 696 */
    0,
    /*  */
  },
  { /* 697 */
    0,
    /*  */
  },
  { /* 698 */
    0,
    /*  */
  },
  { /* 699 */
    0,
    /*  */
  },
  { /* 700 */
    0,
    /*  */
  },
  { /* 701 */
    0,
    /*  */
  },
  { /* 702 */
    39,
    /* DIVR_FrST0 */
  },
  { /* 703 */
    32,
    /* DIVSDrm */
  },
  { /* 704 */
    0,
    /*  */
  },
  { /* 705 */
    33,
    /* DIVSDrr */
  },
  { /* 706 */
    0,
    /*  */
  },
  { /* 707 */
    34,
    /* DIVSSrm */
  },
  { /* 708 */
    0,
    /*  */
  },
  { /* 709 */
    35,
    /* DIVSSrr */
  },
  { /* 710 */
    0,
    /*  */
  },
  { /* 711 */
    36,
    /* DIV_F32m */
  },
  { /* 712 */
    37,
    /* DIV_F64m */
  },
  { /* 713 */
    38,
    /* DIV_FI16m */
  },
  { /* 714 */
    38,
    /* DIV_FI32m */
  },
  { /* 715 */
    39,
    /* DIV_FPrST0 */
  },
  { /* 716 */
    39,
    /* DIV_FST0r */
  },
  { /* 717 */
    0,
    /*  */
  },
  { /* 718 */
    0,
    /*  */
  },
  { /* 719 */
    0,
    /*  */
  },
  { /* 720 */
    0,
    /*  */
  },
  { /* 721 */
    0,
    /*  */
  },
  { /* 722 */
    0,
    /*  */
  },
  { /* 723 */
    0,
    /*  */
  },
  { /* 724 */
    0,
    /*  */
  },
  { /* 725 */
    0,
    /*  */
  },
  { /* 726 */
    0,
    /*  */
  },
  { /* 727 */
    0,
    /*  */
  },
  { /* 728 */
    0,
    /*  */
  },
  { /* 729 */
    0,
    /*  */
  },
  { /* 730 */
    0,
    /*  */
  },
  { /* 731 */
    39,
    /* DIV_FrST0 */
  },
  { /* 732 */
    66,
    /* DPPDrmi */
  },
  { /* 733 */
    67,
    /* DPPDrri */
  },
  { /* 734 */
    66,
    /* DPPSrmi */
  },
  { /* 735 */
    67,
    /* DPPSrri */
  },
  { /* 736 */
    0,
    /*  */
  },
  { /* 737 */
    0,
    /*  */
  },
  { /* 738 */
    0,
    /*  */
  },
  { /* 739 */
    0,
    /*  */
  },
  { /* 740 */
    0,
    /*  */
  },
  { /* 741 */
    0,
    /*  */
  },
  { /* 742 */
    0,
    /*  */
  },
  { /* 743 */
    0,
    /* ENCLS */
  },
  { /* 744 */
    0,
    /* ENCLU */
  },
  { /* 745 */
    131,
    /* ENTER */
  },
  { /* 746 */
    132,
    /* EXTRACTPSmr */
  },
  { /* 747 */
    133,
    /* EXTRACTPSrr */
  },
  { /* 748 */
    31,
    /* EXTRQ */
  },
  { /* 749 */
    134,
    /* EXTRQI */
  },
  { /* 750 */
    0,
    /* F2XM1 */
  },
  { /* 751 */
    135,
    /* FARCALL16i */
  },
  { /* 752 */
    136,
    /* FARCALL16m */
  },
  { /* 753 */
    137,
    /* FARCALL32i */
  },
  { /* 754 */
    138,
    /* FARCALL32m */
  },
  { /* 755 */
    139,
    /* FARCALL64 */
  },
  { /* 756 */
    135,
    /* FARJMP16i */
  },
  { /* 757 */
    136,
    /* FARJMP16m */
  },
  { /* 758 */
    137,
    /* FARJMP32i */
  },
  { /* 759 */
    138,
    /* FARJMP32m */
  },
  { /* 760 */
    139,
    /* FARJMP64 */
  },
  { /* 761 */
    36,
    /* FBLDm */
  },
  { /* 762 */
    36,
    /* FBSTPm */
  },
  { /* 763 */
    36,
    /* FCOM32m */
  },
  { /* 764 */
    37,
    /* FCOM64m */
  },
  { /* 765 */
    36,
    /* FCOMP32m */
  },
  { /* 766 */
    37,
    /* FCOMP64m */
  },
  { /* 767 */
    0,
    /* FCOMPP */
  },
  { /* 768 */
    0,
    /* FDECSTP */
  },
  { /* 769 */
    0,
    /* FEMMS */
  },
  { /* 770 */
    39,
    /* FFREE */
  },
  { /* 771 */
    38,
    /* FICOM16m */
  },
  { /* 772 */
    38,
    /* FICOM32m */
  },
  { /* 773 */
    38,
    /* FICOMP16m */
  },
  { /* 774 */
    38,
    /* FICOMP32m */
  },
  { /* 775 */
    0,
    /* FINCSTP */
  },
  { /* 776 */
    38,
    /* FLDCW16m */
  },
  { /* 777 */
    36,
    /* FLDENVm */
  },
  { /* 778 */
    0,
    /* FLDL2E */
  },
  { /* 779 */
    0,
    /* FLDL2T */
  },
  { /* 780 */
    0,
    /* FLDLG2 */
  },
  { /* 781 */
    0,
    /* FLDLN2 */
  },
  { /* 782 */
    0,
    /* FLDPI */
  },
  { /* 783 */
    0,
    /* FNCLEX */
  },
  { /* 784 */
    0,
    /* FNINIT */
  },
  { /* 785 */
    0,
    /* FNOP */
  },
  { /* 786 */
    38,
    /* FNSTCW16m */
  },
  { /* 787 */
    0,
    /* FNSTSW16r */
  },
  { /* 788 */
    36,
    /* FNSTSWm */
  },
  { /* 789 */
    0,
    /*  */
  },
  { /* 790 */
    0,
    /*  */
  },
  { /* 791 */
    0,
    /*  */
  },
  { /* 792 */
    0,
    /*  */
  },
  { /* 793 */
    0,
    /*  */
  },
  { /* 794 */
    0,
    /*  */
  },
  { /* 795 */
    0,
    /*  */
  },
  { /* 796 */
    0,
    /*  */
  },
  { /* 797 */
    0,
    /*  */
  },
  { /* 798 */
    0,
    /* FPATAN */
  },
  { /* 799 */
    0,
    /* FPREM */
  },
  { /* 800 */
    0,
    /* FPREM1 */
  },
  { /* 801 */
    0,
    /* FPTAN */
  },
  { /* 802 */
    39,
    /* FP_FFREEP */
  },
  { /* 803 */
    0,
    /* FRNDINT */
  },
  { /* 804 */
    36,
    /* FRSTORm */
  },
  { /* 805 */
    36,
    /* FSAVEm */
  },
  { /* 806 */
    0,
    /* FSCALE */
  },
  { /* 807 */
    0,
    /* FSETPM */
  },
  { /* 808 */
    0,
    /* FSINCOS */
  },
  { /* 809 */
    36,
    /* FSTENVm */
  },
  { /* 810 */
    0,
    /* FXAM */
  },
  { /* 811 */
    140,
    /* FXRSTOR */
  },
  { /* 812 */
    140,
    /* FXRSTOR64 */
  },
  { /* 813 */
    140,
    /* FXSAVE */
  },
  { /* 814 */
    140,
    /* FXSAVE64 */
  },
  { /* 815 */
    0,
    /* FXTRACT */
  },
  { /* 816 */
    0,
    /* FYL2X */
  },
  { /* 817 */
    0,
    /* FYL2XP1 */
  },
  { /* 818 */
    0,
    /*  */
  },
  { /* 819 */
    0,
    /*  */
  },
  { /* 820 */
    0,
    /*  */
  },
  { /* 821 */
    0,
    /*  */
  },
  { /* 822 */
    0,
    /*  */
  },
  { /* 823 */
    0,
    /*  */
  },
  { /* 824 */
    0,
    /*  */
  },
  { /* 825 */
    0,
    /*  */
  },
  { /* 826 */
    0,
    /*  */
  },
  { /* 827 */
    0,
    /*  */
  },
  { /* 828 */
    0,
    /*  */
  },
  { /* 829 */
    0,
    /*  */
  },
  { /* 830 */
    0,
    /*  */
  },
  { /* 831 */
    0,
    /*  */
  },
  { /* 832 */
    0,
    /*  */
  },
  { /* 833 */
    0,
    /*  */
  },
  { /* 834 */
    0,
    /*  */
  },
  { /* 835 */
    0,
    /*  */
  },
  { /* 836 */
    0,
    /*  */
  },
  { /* 837 */
    0,
    /*  */
  },
  { /* 838 */
    0,
    /*  */
  },
  { /* 839 */
    0,
    /*  */
  },
  { /* 840 */
    0,
    /*  */
  },
  { /* 841 */
    0,
    /*  */
  },
  { /* 842 */
    0,
    /*  */
  },
  { /* 843 */
    0,
    /*  */
  },
  { /* 844 */
    0,
    /*  */
  },
  { /* 845 */
    0,
    /*  */
  },
  { /* 846 */
    0,
    /*  */
  },
  { /* 847 */
    0,
    /*  */
  },
  { /* 848 */
    0,
    /*  */
  },
  { /* 849 */
    0,
    /*  */
  },
  { /* 850 */
    0,
    /*  */
  },
  { /* 851 */
    0,
    /*  */
  },
  { /* 852 */
    0,
    /*  */
  },
  { /* 853 */
    0,
    /*  */
  },
  { /* 854 */
    0,
    /*  */
  },
  { /* 855 */
    0,
    /*  */
  },
  { /* 856 */
    0,
    /* GETSEC */
  },
  { /* 857 */
    30,
    /* HADDPDrm */
  },
  { /* 858 */
    31,
    /* HADDPDrr */
  },
  { /* 859 */
    30,
    /* HADDPSrm */
  },
  { /* 860 */
    31,
    /* HADDPSrr */
  },
  { /* 861 */
    0,
    /* HLT */
  },
  { /* 862 */
    30,
    /* HSUBPDrm */
  },
  { /* 863 */
    31,
    /* HSUBPDrr */
  },
  { /* 864 */
    30,
    /* HSUBPSrm */
  },
  { /* 865 */
    31,
    /* HSUBPSrr */
  },
  { /* 866 */
    38,
    /* IDIV16m */
  },
  { /* 867 */
    77,
    /* IDIV16r */
  },
  { /* 868 */
    38,
    /* IDIV32m */
  },
  { /* 869 */
    77,
    /* IDIV32r */
  },
  { /* 870 */
    38,
    /* IDIV64m */
  },
  { /* 871 */
    79,
    /* IDIV64r */
  },
  { /* 872 */
    82,
    /* IDIV8m */
  },
  { /* 873 */
    130,
    /* IDIV8r */
  },
  { /* 874 */
    38,
    /* ILD_F16m */
  },
  { /* 875 */
    38,
    /* ILD_F32m */
  },
  { /* 876 */
    38,
    /* ILD_F64m */
  },
  { /* 877 */
    0,
    /*  */
  },
  { /* 878 */
    0,
    /*  */
  },
  { /* 879 */
    0,
    /*  */
  },
  { /* 880 */
    0,
    /*  */
  },
  { /* 881 */
    0,
    /*  */
  },
  { /* 882 */
    0,
    /*  */
  },
  { /* 883 */
    0,
    /*  */
  },
  { /* 884 */
    0,
    /*  */
  },
  { /* 885 */
    0,
    /*  */
  },
  { /* 886 */
    38,
    /* IMUL16m */
  },
  { /* 887 */
    77,
    /* IMUL16r */
  },
  { /* 888 */
    8,
    /* IMUL16rm */
  },
  { /* 889 */
    141,
    /* IMUL16rmi */
  },
  { /* 890 */
    142,
    /* IMUL16rmi8 */
  },
  { /* 891 */
    10,
    /* IMUL16rr */
  },
  { /* 892 */
    143,
    /* IMUL16rri */
  },
  { /* 893 */
    144,
    /* IMUL16rri8 */
  },
  { /* 894 */
    38,
    /* IMUL32m */
  },
  { /* 895 */
    77,
    /* IMUL32r */
  },
  { /* 896 */
    8,
    /* IMUL32rm */
  },
  { /* 897 */
    141,
    /* IMUL32rmi */
  },
  { /* 898 */
    145,
    /* IMUL32rmi8 */
  },
  { /* 899 */
    10,
    /* IMUL32rr */
  },
  { /* 900 */
    143,
    /* IMUL32rri */
  },
  { /* 901 */
    146,
    /* IMUL32rri8 */
  },
  { /* 902 */
    38,
    /* IMUL64m */
  },
  { /* 903 */
    79,
    /* IMUL64r */
  },
  { /* 904 */
    19,
    /* IMUL64rm */
  },
  { /* 905 */
    60,
    /* IMUL64rmi32 */
  },
  { /* 906 */
    147,
    /* IMUL64rmi8 */
  },
  { /* 907 */
    21,
    /* IMUL64rr */
  },
  { /* 908 */
    61,
    /* IMUL64rri32 */
  },
  { /* 909 */
    148,
    /* IMUL64rri8 */
  },
  { /* 910 */
    82,
    /* IMUL8m */
  },
  { /* 911 */
    130,
    /* IMUL8r */
  },
  { /* 912 */
    1,
    /* IN16ri */
  },
  { /* 913 */
    0,
    /* IN16rr */
  },
  { /* 914 */
    1,
    /* IN32ri */
  },
  { /* 915 */
    0,
    /* IN32rr */
  },
  { /* 916 */
    1,
    /* IN8ri */
  },
  { /* 917 */
    0,
    /* IN8rr */
  },
  { /* 918 */
    38,
    /* INC16m */
  },
  { /* 919 */
    127,
    /* INC16r */
  },
  { /* 920 */
    70,
    /* INC16r_alt */
  },
  { /* 921 */
    38,
    /* INC32m */
  },
  { /* 922 */
    127,
    /* INC32r */
  },
  { /* 923 */
    70,
    /* INC32r_alt */
  },
  { /* 924 */
    38,
    /* INC64m */
  },
  { /* 925 */
    128,
    /* INC64r */
  },
  { /* 926 */
    82,
    /* INC8m */
  },
  { /* 927 */
    129,
    /* INC8r */
  },
  { /* 928 */
    149,
    /* INSB */
  },
  { /* 929 */
    150,
    /* INSERTPSrm */
  },
  { /* 930 */
    67,
    /* INSERTPSrr */
  },
  { /* 931 */
    31,
    /* INSERTQ */
  },
  { /* 932 */
    151,
    /* INSERTQI */
  },
  { /* 933 */
    152,
    /* INSL */
  },
  { /* 934 */
    153,
    /* INSW */
  },
  { /* 935 */
    1,
    /* INT */
  },
  { /* 936 */
    0,
    /* INT1 */
  },
  { /* 937 */
    0,
    /* INT3 */
  },
  { /* 938 */
    0,
    /* INTO */
  },
  { /* 939 */
    0,
    /* INVD */
  },
  { /* 940 */
    154,
    /* INVEPT32 */
  },
  { /* 941 */
    155,
    /* INVEPT64 */
  },
  { /* 942 */
    82,
    /* INVLPG */
  },
  { /* 943 */
    0,
    /* INVLPGA32 */
  },
  { /* 944 */
    0,
    /* INVLPGA64 */
  },
  { /* 945 */
    154,
    /* INVPCID32 */
  },
  { /* 946 */
    155,
    /* INVPCID64 */
  },
  { /* 947 */
    154,
    /* INVVPID32 */
  },
  { /* 948 */
    155,
    /* INVVPID64 */
  },
  { /* 949 */
    0,
    /* IRET16 */
  },
  { /* 950 */
    0,
    /* IRET32 */
  },
  { /* 951 */
    0,
    /* IRET64 */
  },
  { /* 952 */
    38,
    /* ISTT_FP16m */
  },
  { /* 953 */
    38,
    /* ISTT_FP32m */
  },
  { /* 954 */
    38,
    /* ISTT_FP64m */
  },
  { /* 955 */
    0,
    /*  */
  },
  { /* 956 */
    0,
    /*  */
  },
  { /* 957 */
    0,
    /*  */
  },
  { /* 958 */
    0,
    /*  */
  },
  { /* 959 */
    0,
    /*  */
  },
  { /* 960 */
    0,
    /*  */
  },
  { /* 961 */
    0,
    /*  */
  },
  { /* 962 */
    0,
    /*  */
  },
  { /* 963 */
    0,
    /*  */
  },
  { /* 964 */
    38,
    /* IST_F16m */
  },
  { /* 965 */
    38,
    /* IST_F32m */
  },
  { /* 966 */
    38,
    /* IST_FP16m */
  },
  { /* 967 */
    38,
    /* IST_FP32m */
  },
  { /* 968 */
    38,
    /* IST_FP64m */
  },
  { /* 969 */
    0,
    /*  */
  },
  { /* 970 */
    0,
    /*  */
  },
  { /* 971 */
    0,
    /*  */
  },
  { /* 972 */
    0,
    /*  */
  },
  { /* 973 */
    0,
    /*  */
  },
  { /* 974 */
    0,
    /*  */
  },
  { /* 975 */
    0,
    /*  */
  },
  { /* 976 */
    0,
    /*  */
  },
  { /* 977 */
    0,
    /*  */
  },
  { /* 978 */
    0,
    /*  */
  },
  { /* 979 */
    0,
    /*  */
  },
  { /* 980 */
    0,
    /*  */
  },
  { /* 981 */
    0,
    /*  */
  },
  { /* 982 */
    0,
    /*  */
  },
  { /* 983 */
    0,
    /*  */
  },
  { /* 984 */
    0,
    /*  */
  },
  { /* 985 */
    0,
    /*  */
  },
  { /* 986 */
    0,
    /*  */
  },
  { /* 987 */
    0,
    /*  */
  },
  { /* 988 */
    0,
    /*  */
  },
  { /* 989 */
    0,
    /*  */
  },
  { /* 990 */
    0,
    /*  */
  },
  { /* 991 */
    0,
    /*  */
  },
  { /* 992 */
    0,
    /*  */
  },
  { /* 993 */
    0,
    /*  */
  },
  { /* 994 */
    0,
    /*  */
  },
  { /* 995 */
    0,
    /*  */
  },
  { /* 996 */
    0,
    /*  */
  },
  { /* 997 */
    0,
    /*  */
  },
  { /* 998 */
    0,
    /*  */
  },
  { /* 999 */
    0,
    /*  */
  },
  { /* 1000 */
    0,
    /*  */
  },
  { /* 1001 */
    0,
    /*  */
  },
  { /* 1002 */
    0,
    /*  */
  },
  { /* 1003 */
    0,
    /*  */
  },
  { /* 1004 */
    0,
    /*  */
  },
  { /* 1005 */
    0,
    /*  */
  },
  { /* 1006 */
    0,
    /*  */
  },
  { /* 1007 */
    0,
    /*  */
  },
  { /* 1008 */
    0,
    /*  */
  },
  { /* 1009 */
    0,
    /*  */
  },
  { /* 1010 */
    0,
    /*  */
  },
  { /* 1011 */
    0,
    /*  */
  },
  { /* 1012 */
    0,
    /*  */
  },
  { /* 1013 */
    0,
    /*  */
  },
  { /* 1014 */
    0,
    /*  */
  },
  { /* 1015 */
    0,
    /*  */
  },
  { /* 1016 */
    0,
    /*  */
  },
  { /* 1017 */
    0,
    /*  */
  },
  { /* 1018 */
    0,
    /*  */
  },
  { /* 1019 */
    0,
    /*  */
  },
  { /* 1020 */
    0,
    /*  */
  },
  { /* 1021 */
    0,
    /*  */
  },
  { /* 1022 */
    0,
    /*  */
  },
  { /* 1023 */
    0,
    /*  */
  },
  { /* 1024 */
    0,
    /*  */
  },
  { /* 1025 */
    0,
    /*  */
  },
  { /* 1026 */
    0,
    /*  */
  },
  { /* 1027 */
    0,
    /*  */
  },
  { /* 1028 */
    0,
    /*  */
  },
  { /* 1029 */
    0,
    /*  */
  },
  { /* 1030 */
    0,
    /*  */
  },
  { /* 1031 */
    0,
    /*  */
  },
  { /* 1032 */
    0,
    /*  */
  },
  { /* 1033 */
    0,
    /*  */
  },
  { /* 1034 */
    0,
    /*  */
  },
  { /* 1035 */
    0,
    /*  */
  },
  { /* 1036 */
    0,
    /*  */
  },
  { /* 1037 */
    0,
    /*  */
  },
  { /* 1038 */
    0,
    /*  */
  },
  { /* 1039 */
    0,
    /*  */
  },
  { /* 1040 */
    0,
    /*  */
  },
  { /* 1041 */
    0,
    /*  */
  },
  { /* 1042 */
    0,
    /*  */
  },
  { /* 1043 */
    0,
    /*  */
  },
  { /* 1044 */
    0,
    /*  */
  },
  { /* 1045 */
    0,
    /*  */
  },
  { /* 1046 */
    0,
    /*  */
  },
  { /* 1047 */
    0,
    /*  */
  },
  { /* 1048 */
    0,
    /*  */
  },
  { /* 1049 */
    0,
    /*  */
  },
  { /* 1050 */
    0,
    /*  */
  },
  { /* 1051 */
    0,
    /*  */
  },
  { /* 1052 */
    0,
    /*  */
  },
  { /* 1053 */
    0,
    /*  */
  },
  { /* 1054 */
    0,
    /*  */
  },
  { /* 1055 */
    0,
    /*  */
  },
  { /* 1056 */
    0,
    /*  */
  },
  { /* 1057 */
    0,
    /*  */
  },
  { /* 1058 */
    0,
    /*  */
  },
  { /* 1059 */
    0,
    /*  */
  },
  { /* 1060 */
    0,
    /*  */
  },
  { /* 1061 */
    0,
    /*  */
  },
  { /* 1062 */
    0,
    /*  */
  },
  { /* 1063 */
    0,
    /*  */
  },
  { /* 1064 */
    0,
    /*  */
  },
  { /* 1065 */
    0,
    /*  */
  },
  { /* 1066 */
    0,
    /*  */
  },
  { /* 1067 */
    0,
    /*  */
  },
  { /* 1068 */
    0,
    /*  */
  },
  { /* 1069 */
    0,
    /*  */
  },
  { /* 1070 */
    0,
    /*  */
  },
  { /* 1071 */
    0,
    /*  */
  },
  { /* 1072 */
    0,
    /*  */
  },
  { /* 1073 */
    0,
    /*  */
  },
  { /* 1074 */
    0,
    /*  */
  },
  { /* 1075 */
    0,
    /*  */
  },
  { /* 1076 */
    0,
    /*  */
  },
  { /* 1077 */
    0,
    /*  */
  },
  { /* 1078 */
    0,
    /*  */
  },
  { /* 1079 */
    0,
    /*  */
  },
  { /* 1080 */
    0,
    /*  */
  },
  { /* 1081 */
    0,
    /*  */
  },
  { /* 1082 */
    0,
    /*  */
  },
  { /* 1083 */
    156,
    /* JAE_1 */
  },
  { /* 1084 */
    157,
    /* JAE_2 */
  },
  { /* 1085 */
    157,
    /* JAE_4 */
  },
  { /* 1086 */
    156,
    /* JA_1 */
  },
  { /* 1087 */
    157,
    /* JA_2 */
  },
  { /* 1088 */
    157,
    /* JA_4 */
  },
  { /* 1089 */
    156,
    /* JBE_1 */
  },
  { /* 1090 */
    157,
    /* JBE_2 */
  },
  { /* 1091 */
    157,
    /* JBE_4 */
  },
  { /* 1092 */
    156,
    /* JB_1 */
  },
  { /* 1093 */
    157,
    /* JB_2 */
  },
  { /* 1094 */
    157,
    /* JB_4 */
  },
  { /* 1095 */
    156,
    /* JCXZ */
  },
  { /* 1096 */
    156,
    /* JECXZ */
  },
  { /* 1097 */
    156,
    /* JE_1 */
  },
  { /* 1098 */
    157,
    /* JE_2 */
  },
  { /* 1099 */
    157,
    /* JE_4 */
  },
  { /* 1100 */
    156,
    /* JGE_1 */
  },
  { /* 1101 */
    157,
    /* JGE_2 */
  },
  { /* 1102 */
    157,
    /* JGE_4 */
  },
  { /* 1103 */
    156,
    /* JG_1 */
  },
  { /* 1104 */
    157,
    /* JG_2 */
  },
  { /* 1105 */
    157,
    /* JG_4 */
  },
  { /* 1106 */
    156,
    /* JLE_1 */
  },
  { /* 1107 */
    157,
    /* JLE_2 */
  },
  { /* 1108 */
    157,
    /* JLE_4 */
  },
  { /* 1109 */
    156,
    /* JL_1 */
  },
  { /* 1110 */
    157,
    /* JL_2 */
  },
  { /* 1111 */
    157,
    /* JL_4 */
  },
  { /* 1112 */
    38,
    /* JMP16m */
  },
  { /* 1113 */
    77,
    /* JMP16r */
  },
  { /* 1114 */
    38,
    /* JMP32m */
  },
  { /* 1115 */
    77,
    /* JMP32r */
  },
  { /* 1116 */
    38,
    /* JMP64m */
  },
  { /* 1117 */
    79,
    /* JMP64r */
  },
  { /* 1118 */
    156,
    /* JMP_1 */
  },
  { /* 1119 */
    157,
    /* JMP_2 */
  },
  { /* 1120 */
    157,
    /* JMP_4 */
  },
  { /* 1121 */
    156,
    /* JNE_1 */
  },
  { /* 1122 */
    157,
    /* JNE_2 */
  },
  { /* 1123 */
    157,
    /* JNE_4 */
  },
  { /* 1124 */
    156,
    /* JNO_1 */
  },
  { /* 1125 */
    157,
    /* JNO_2 */
  },
  { /* 1126 */
    157,
    /* JNO_4 */
  },
  { /* 1127 */
    156,
    /* JNP_1 */
  },
  { /* 1128 */
    157,
    /* JNP_2 */
  },
  { /* 1129 */
    157,
    /* JNP_4 */
  },
  { /* 1130 */
    156,
    /* JNS_1 */
  },
  { /* 1131 */
    157,
    /* JNS_2 */
  },
  { /* 1132 */
    157,
    /* JNS_4 */
  },
  { /* 1133 */
    156,
    /* JO_1 */
  },
  { /* 1134 */
    157,
    /* JO_2 */
  },
  { /* 1135 */
    157,
    /* JO_4 */
  },
  { /* 1136 */
    156,
    /* JP_1 */
  },
  { /* 1137 */
    157,
    /* JP_2 */
  },
  { /* 1138 */
    157,
    /* JP_4 */
  },
  { /* 1139 */
    156,
    /* JRCXZ */
  },
  { /* 1140 */
    156,
    /* JS_1 */
  },
  { /* 1141 */
    157,
    /* JS_2 */
  },
  { /* 1142 */
    157,
    /* JS_4 */
  },
  { /* 1143 */
    158,
    /* KANDBrr */
  },
  { /* 1144 */
    159,
    /* KANDDrr */
  },
  { /* 1145 */
    158,
    /* KANDNBrr */
  },
  { /* 1146 */
    159,
    /* KANDNDrr */
  },
  { /* 1147 */
    160,
    /* KANDNQrr */
  },
  { /* 1148 */
    161,
    /* KANDNWrr */
  },
  { /* 1149 */
    160,
    /* KANDQrr */
  },
  { /* 1150 */
    161,
    /* KANDWrr */
  },
  { /* 1151 */
    162,
    /* KMOVBkk */
  },
  { /* 1152 */
    163,
    /* KMOVBkm */
  },
  { /* 1153 */
    164,
    /* KMOVBkr */
  },
  { /* 1154 */
    165,
    /* KMOVBmk */
  },
  { /* 1155 */
    166,
    /* KMOVBrk */
  },
  { /* 1156 */
    167,
    /* KMOVDkk */
  },
  { /* 1157 */
    168,
    /* KMOVDkm */
  },
  { /* 1158 */
    169,
    /* KMOVDkr */
  },
  { /* 1159 */
    170,
    /* KMOVDmk */
  },
  { /* 1160 */
    171,
    /* KMOVDrk */
  },
  { /* 1161 */
    172,
    /* KMOVQkk */
  },
  { /* 1162 */
    173,
    /* KMOVQkm */
  },
  { /* 1163 */
    174,
    /* KMOVQkr */
  },
  { /* 1164 */
    175,
    /* KMOVQmk */
  },
  { /* 1165 */
    176,
    /* KMOVQrk */
  },
  { /* 1166 */
    177,
    /* KMOVWkk */
  },
  { /* 1167 */
    178,
    /* KMOVWkm */
  },
  { /* 1168 */
    179,
    /* KMOVWkr */
  },
  { /* 1169 */
    180,
    /* KMOVWmk */
  },
  { /* 1170 */
    181,
    /* KMOVWrk */
  },
  { /* 1171 */
    162,
    /* KNOTBrr */
  },
  { /* 1172 */
    167,
    /* KNOTDrr */
  },
  { /* 1173 */
    172,
    /* KNOTQrr */
  },
  { /* 1174 */
    177,
    /* KNOTWrr */
  },
  { /* 1175 */
    158,
    /* KORBrr */
  },
  { /* 1176 */
    159,
    /* KORDrr */
  },
  { /* 1177 */
    160,
    /* KORQrr */
  },
  { /* 1178 */
    162,
    /* KORTESTBrr */
  },
  { /* 1179 */
    167,
    /* KORTESTDrr */
  },
  { /* 1180 */
    172,
    /* KORTESTQrr */
  },
  { /* 1181 */
    177,
    /* KORTESTWrr */
  },
  { /* 1182 */
    161,
    /* KORWrr */
  },
  { /* 1183 */
    0,
    /*  */
  },
  { /* 1184 */
    0,
    /*  */
  },
  { /* 1185 */
    0,
    /*  */
  },
  { /* 1186 */
    0,
    /*  */
  },
  { /* 1187 */
    182,
    /* KSHIFTLBri */
  },
  { /* 1188 */
    183,
    /* KSHIFTLDri */
  },
  { /* 1189 */
    184,
    /* KSHIFTLQri */
  },
  { /* 1190 */
    185,
    /* KSHIFTLWri */
  },
  { /* 1191 */
    182,
    /* KSHIFTRBri */
  },
  { /* 1192 */
    183,
    /* KSHIFTRDri */
  },
  { /* 1193 */
    184,
    /* KSHIFTRQri */
  },
  { /* 1194 */
    185,
    /* KSHIFTRWri */
  },
  { /* 1195 */
    161,
    /* KUNPCKBWrr */
  },
  { /* 1196 */
    158,
    /* KXNORBrr */
  },
  { /* 1197 */
    159,
    /* KXNORDrr */
  },
  { /* 1198 */
    160,
    /* KXNORQrr */
  },
  { /* 1199 */
    161,
    /* KXNORWrr */
  },
  { /* 1200 */
    158,
    /* KXORBrr */
  },
  { /* 1201 */
    159,
    /* KXORDrr */
  },
  { /* 1202 */
    160,
    /* KXORQrr */
  },
  { /* 1203 */
    161,
    /* KXORWrr */
  },
  { /* 1204 */
    0,
    /* LAHF */
  },
  { /* 1205 */
    68,
    /* LAR16rm */
  },
  { /* 1206 */
    69,
    /* LAR16rr */
  },
  { /* 1207 */
    68,
    /* LAR32rm */
  },
  { /* 1208 */
    69,
    /* LAR32rr */
  },
  { /* 1209 */
    42,
    /* LAR64rm */
  },
  { /* 1210 */
    186,
    /* LAR64rr */
  },
  { /* 1211 */
    0,
    /*  */
  },
  { /* 1212 */
    0,
    /*  */
  },
  { /* 1213 */
    0,
    /*  */
  },
  { /* 1214 */
    0,
    /*  */
  },
  { /* 1215 */
    0,
    /*  */
  },
  { /* 1216 */
    0,
    /*  */
  },
  { /* 1217 */
    44,
    /* LDDQUrm */
  },
  { /* 1218 */
    38,
    /* LDMXCSR */
  },
  { /* 1219 */
    187,
    /* LDS16rm */
  },
  { /* 1220 */
    188,
    /* LDS32rm */
  },
  { /* 1221 */
    0,
    /* LD_F0 */
  },
  { /* 1222 */
    0,
    /* LD_F1 */
  },
  { /* 1223 */
    36,
    /* LD_F32m */
  },
  { /* 1224 */
    37,
    /* LD_F64m */
  },
  { /* 1225 */
    189,
    /* LD_F80m */
  },
  { /* 1226 */
    0,
    /*  */
  },
  { /* 1227 */
    0,
    /*  */
  },
  { /* 1228 */
    0,
    /*  */
  },
  { /* 1229 */
    0,
    /*  */
  },
  { /* 1230 */
    0,
    /*  */
  },
  { /* 1231 */
    0,
    /*  */
  },
  { /* 1232 */
    0,
    /*  */
  },
  { /* 1233 */
    0,
    /*  */
  },
  { /* 1234 */
    0,
    /*  */
  },
  { /* 1235 */
    0,
    /*  */
  },
  { /* 1236 */
    0,
    /*  */
  },
  { /* 1237 */
    0,
    /*  */
  },
  { /* 1238 */
    39,
    /* LD_Frr */
  },
  { /* 1239 */
    190,
    /* LEA16r */
  },
  { /* 1240 */
    190,
    /* LEA32r */
  },
  { /* 1241 */
    191,
    /* LEA64_32r */
  },
  { /* 1242 */
    192,
    /* LEA64r */
  },
  { /* 1243 */
    0,
    /* LEAVE */
  },
  { /* 1244 */
    0,
    /* LEAVE64 */
  },
  { /* 1245 */
    187,
    /* LES16rm */
  },
  { /* 1246 */
    188,
    /* LES32rm */
  },
  { /* 1247 */
    0,
    /* LFENCE */
  },
  { /* 1248 */
    187,
    /* LFS16rm */
  },
  { /* 1249 */
    188,
    /* LFS32rm */
  },
  { /* 1250 */
    193,
    /* LFS64rm */
  },
  { /* 1251 */
    138,
    /* LGDT16m */
  },
  { /* 1252 */
    138,
    /* LGDT32m */
  },
  { /* 1253 */
    139,
    /* LGDT64m */
  },
  { /* 1254 */
    187,
    /* LGS16rm */
  },
  { /* 1255 */
    188,
    /* LGS32rm */
  },
  { /* 1256 */
    193,
    /* LGS64rm */
  },
  { /* 1257 */
    138,
    /* LIDT16m */
  },
  { /* 1258 */
    138,
    /* LIDT32m */
  },
  { /* 1259 */
    139,
    /* LIDT64m */
  },
  { /* 1260 */
    38,
    /* LLDT16m */
  },
  { /* 1261 */
    194,
    /* LLDT16r */
  },
  { /* 1262 */
    38,
    /* LMSW16m */
  },
  { /* 1263 */
    194,
    /* LMSW16r */
  },
  { /* 1264 */
    0,
    /*  */
  },
  { /* 1265 */
    0,
    /*  */
  },
  { /* 1266 */
    0,
    /*  */
  },
  { /* 1267 */
    0,
    /*  */
  },
  { /* 1268 */
    0,
    /*  */
  },
  { /* 1269 */
    0,
    /*  */
  },
  { /* 1270 */
    0,
    /*  */
  },
  { /* 1271 */
    0,
    /*  */
  },
  { /* 1272 */
    0,
    /*  */
  },
  { /* 1273 */
    0,
    /*  */
  },
  { /* 1274 */
    0,
    /*  */
  },
  { /* 1275 */
    0,
    /*  */
  },
  { /* 1276 */
    0,
    /*  */
  },
  { /* 1277 */
    0,
    /*  */
  },
  { /* 1278 */
    0,
    /*  */
  },
  { /* 1279 */
    0,
    /*  */
  },
  { /* 1280 */
    0,
    /*  */
  },
  { /* 1281 */
    0,
    /*  */
  },
  { /* 1282 */
    0,
    /*  */
  },
  { /* 1283 */
    0,
    /*  */
  },
  { /* 1284 */
    0,
    /*  */
  },
  { /* 1285 */
    0,
    /*  */
  },
  { /* 1286 */
    0,
    /*  */
  },
  { /* 1287 */
    0,
    /*  */
  },
  { /* 1288 */
    0,
    /*  */
  },
  { /* 1289 */
    0,
    /*  */
  },
  { /* 1290 */
    0,
    /*  */
  },
  { /* 1291 */
    0,
    /*  */
  },
  { /* 1292 */
    0,
    /*  */
  },
  { /* 1293 */
    0,
    /*  */
  },
  { /* 1294 */
    0,
    /*  */
  },
  { /* 1295 */
    0,
    /*  */
  },
  { /* 1296 */
    0,
    /*  */
  },
  { /* 1297 */
    0,
    /*  */
  },
  { /* 1298 */
    0,
    /*  */
  },
  { /* 1299 */
    0,
    /*  */
  },
  { /* 1300 */
    0,
    /*  */
  },
  { /* 1301 */
    0,
    /*  */
  },
  { /* 1302 */
    0,
    /*  */
  },
  { /* 1303 */
    0,
    /*  */
  },
  { /* 1304 */
    0,
    /*  */
  },
  { /* 1305 */
    0,
    /* LOCK_PREFIX */
  },
  { /* 1306 */
    0,
    /*  */
  },
  { /* 1307 */
    0,
    /*  */
  },
  { /* 1308 */
    0,
    /*  */
  },
  { /* 1309 */
    0,
    /*  */
  },
  { /* 1310 */
    0,
    /*  */
  },
  { /* 1311 */
    0,
    /*  */
  },
  { /* 1312 */
    0,
    /*  */
  },
  { /* 1313 */
    0,
    /*  */
  },
  { /* 1314 */
    0,
    /*  */
  },
  { /* 1315 */
    0,
    /*  */
  },
  { /* 1316 */
    0,
    /*  */
  },
  { /* 1317 */
    0,
    /*  */
  },
  { /* 1318 */
    0,
    /*  */
  },
  { /* 1319 */
    0,
    /*  */
  },
  { /* 1320 */
    0,
    /*  */
  },
  { /* 1321 */
    0,
    /*  */
  },
  { /* 1322 */
    0,
    /*  */
  },
  { /* 1323 */
    0,
    /*  */
  },
  { /* 1324 */
    0,
    /*  */
  },
  { /* 1325 */
    0,
    /*  */
  },
  { /* 1326 */
    0,
    /*  */
  },
  { /* 1327 */
    0,
    /*  */
  },
  { /* 1328 */
    195,
    /* LODSB */
  },
  { /* 1329 */
    196,
    /* LODSL */
  },
  { /* 1330 */
    197,
    /* LODSQ */
  },
  { /* 1331 */
    198,
    /* LODSW */
  },
  { /* 1332 */
    156,
    /* LOOP */
  },
  { /* 1333 */
    156,
    /* LOOPE */
  },
  { /* 1334 */
    156,
    /* LOOPNE */
  },
  { /* 1335 */
    199,
    /* LRETIL */
  },
  { /* 1336 */
    199,
    /* LRETIQ */
  },
  { /* 1337 */
    2,
    /* LRETIW */
  },
  { /* 1338 */
    0,
    /* LRETL */
  },
  { /* 1339 */
    0,
    /* LRETQ */
  },
  { /* 1340 */
    0,
    /* LRETW */
  },
  { /* 1341 */
    68,
    /* LSL16rm */
  },
  { /* 1342 */
    69,
    /* LSL16rr */
  },
  { /* 1343 */
    68,
    /* LSL32rm */
  },
  { /* 1344 */
    69,
    /* LSL32rr */
  },
  { /* 1345 */
    42,
    /* LSL64rm */
  },
  { /* 1346 */
    43,
    /* LSL64rr */
  },
  { /* 1347 */
    187,
    /* LSS16rm */
  },
  { /* 1348 */
    188,
    /* LSS32rm */
  },
  { /* 1349 */
    193,
    /* LSS64rm */
  },
  { /* 1350 */
    38,
    /* LTRm */
  },
  { /* 1351 */
    194,
    /* LTRr */
  },
  { /* 1352 */
    0,
    /*  */
  },
  { /* 1353 */
    0,
    /*  */
  },
  { /* 1354 */
    0,
    /*  */
  },
  { /* 1355 */
    0,
    /*  */
  },
  { /* 1356 */
    68,
    /* LZCNT16rm */
  },
  { /* 1357 */
    69,
    /* LZCNT16rr */
  },
  { /* 1358 */
    68,
    /* LZCNT32rm */
  },
  { /* 1359 */
    69,
    /* LZCNT32rr */
  },
  { /* 1360 */
    42,
    /* LZCNT64rm */
  },
  { /* 1361 */
    43,
    /* LZCNT64rr */
  },
  { /* 1362 */
    45,
    /* MASKMOVDQU */
  },
  { /* 1363 */
    45,
    /* MASKMOVDQU64 */
  },
  { /* 1364 */
    0,
    /*  */
  },
  { /* 1365 */
    0,
    /*  */
  },
  { /* 1366 */
    0,
    /*  */
  },
  { /* 1367 */
    0,
    /*  */
  },
  { /* 1368 */
    0,
    /*  */
  },
  { /* 1369 */
    0,
    /*  */
  },
  { /* 1370 */
    0,
    /*  */
  },
  { /* 1371 */
    0,
    /*  */
  },
  { /* 1372 */
    30,
    /* MAXPDrm */
  },
  { /* 1373 */
    31,
    /* MAXPDrr */
  },
  { /* 1374 */
    30,
    /* MAXPSrm */
  },
  { /* 1375 */
    31,
    /* MAXPSrr */
  },
  { /* 1376 */
    32,
    /* MAXSDrm */
  },
  { /* 1377 */
    0,
    /*  */
  },
  { /* 1378 */
    33,
    /* MAXSDrr */
  },
  { /* 1379 */
    0,
    /*  */
  },
  { /* 1380 */
    34,
    /* MAXSSrm */
  },
  { /* 1381 */
    0,
    /*  */
  },
  { /* 1382 */
    35,
    /* MAXSSrr */
  },
  { /* 1383 */
    0,
    /*  */
  },
  { /* 1384 */
    0,
    /* MFENCE */
  },
  { /* 1385 */
    0,
    /*  */
  },
  { /* 1386 */
    0,
    /*  */
  },
  { /* 1387 */
    0,
    /*  */
  },
  { /* 1388 */
    0,
    /*  */
  },
  { /* 1389 */
    0,
    /*  */
  },
  { /* 1390 */
    0,
    /*  */
  },
  { /* 1391 */
    0,
    /*  */
  },
  { /* 1392 */
    0,
    /*  */
  },
  { /* 1393 */
    30,
    /* MINPDrm */
  },
  { /* 1394 */
    31,
    /* MINPDrr */
  },
  { /* 1395 */
    30,
    /* MINPSrm */
  },
  { /* 1396 */
    31,
    /* MINPSrr */
  },
  { /* 1397 */
    32,
    /* MINSDrm */
  },
  { /* 1398 */
    0,
    /*  */
  },
  { /* 1399 */
    33,
    /* MINSDrr */
  },
  { /* 1400 */
    0,
    /*  */
  },
  { /* 1401 */
    34,
    /* MINSSrm */
  },
  { /* 1402 */
    0,
    /*  */
  },
  { /* 1403 */
    35,
    /* MINSSrr */
  },
  { /* 1404 */
    0,
    /*  */
  },
  { /* 1405 */
    200,
    /* MMX_CVTPD2PIirm */
  },
  { /* 1406 */
    201,
    /* MMX_CVTPD2PIirr */
  },
  { /* 1407 */
    105,
    /* MMX_CVTPI2PDirm */
  },
  { /* 1408 */
    202,
    /* MMX_CVTPI2PDirr */
  },
  { /* 1409 */
    203,
    /* MMX_CVTPI2PSirm */
  },
  { /* 1410 */
    204,
    /* MMX_CVTPI2PSirr */
  },
  { /* 1411 */
    205,
    /* MMX_CVTPS2PIirm */
  },
  { /* 1412 */
    201,
    /* MMX_CVTPS2PIirr */
  },
  { /* 1413 */
    200,
    /* MMX_CVTTPD2PIirm */
  },
  { /* 1414 */
    201,
    /* MMX_CVTTPD2PIirr */
  },
  { /* 1415 */
    205,
    /* MMX_CVTTPS2PIirm */
  },
  { /* 1416 */
    201,
    /* MMX_CVTTPS2PIirr */
  },
  { /* 1417 */
    0,
    /* MMX_EMMS */
  },
  { /* 1418 */
    206,
    /* MMX_MASKMOVQ */
  },
  { /* 1419 */
    206,
    /* MMX_MASKMOVQ64 */
  },
  { /* 1420 */
    207,
    /* MMX_MOVD64from64rm */
  },
  { /* 1421 */
    208,
    /* MMX_MOVD64from64rr */
  },
  { /* 1422 */
    209,
    /* MMX_MOVD64grr */
  },
  { /* 1423 */
    207,
    /* MMX_MOVD64mr */
  },
  { /* 1424 */
    210,
    /* MMX_MOVD64rm */
  },
  { /* 1425 */
    211,
    /* MMX_MOVD64rr */
  },
  { /* 1426 */
    210,
    /* MMX_MOVD64to64rm */
  },
  { /* 1427 */
    212,
    /* MMX_MOVD64to64rr */
  },
  { /* 1428 */
    201,
    /* MMX_MOVDQ2Qrr */
  },
  { /* 1429 */
    0,
    /*  */
  },
  { /* 1430 */
    207,
    /* MMX_MOVNTQmr */
  },
  { /* 1431 */
    202,
    /* MMX_MOVQ2DQrr */
  },
  { /* 1432 */
    0,
    /*  */
  },
  { /* 1433 */
    207,
    /* MMX_MOVQ64mr */
  },
  { /* 1434 */
    210,
    /* MMX_MOVQ64rm */
  },
  { /* 1435 */
    206,
    /* MMX_MOVQ64rr */
  },
  { /* 1436 */
    213,
    /* MMX_MOVQ64rr_REV */
  },
  { /* 1437 */
    210,
    /* MMX_PABSBrm64 */
  },
  { /* 1438 */
    206,
    /* MMX_PABSBrr64 */
  },
  { /* 1439 */
    210,
    /* MMX_PABSDrm64 */
  },
  { /* 1440 */
    206,
    /* MMX_PABSDrr64 */
  },
  { /* 1441 */
    210,
    /* MMX_PABSWrm64 */
  },
  { /* 1442 */
    206,
    /* MMX_PABSWrr64 */
  },
  { /* 1443 */
    214,
    /* MMX_PACKSSDWirm */
  },
  { /* 1444 */
    215,
    /* MMX_PACKSSDWirr */
  },
  { /* 1445 */
    214,
    /* MMX_PACKSSWBirm */
  },
  { /* 1446 */
    215,
    /* MMX_PACKSSWBirr */
  },
  { /* 1447 */
    214,
    /* MMX_PACKUSWBirm */
  },
  { /* 1448 */
    215,
    /* MMX_PACKUSWBirr */
  },
  { /* 1449 */
    214,
    /* MMX_PADDBirm */
  },
  { /* 1450 */
    215,
    /* MMX_PADDBirr */
  },
  { /* 1451 */
    214,
    /* MMX_PADDDirm */
  },
  { /* 1452 */
    215,
    /* MMX_PADDDirr */
  },
  { /* 1453 */
    214,
    /* MMX_PADDQirm */
  },
  { /* 1454 */
    215,
    /* MMX_PADDQirr */
  },
  { /* 1455 */
    214,
    /* MMX_PADDSBirm */
  },
  { /* 1456 */
    215,
    /* MMX_PADDSBirr */
  },
  { /* 1457 */
    214,
    /* MMX_PADDSWirm */
  },
  { /* 1458 */
    215,
    /* MMX_PADDSWirr */
  },
  { /* 1459 */
    214,
    /* MMX_PADDUSBirm */
  },
  { /* 1460 */
    215,
    /* MMX_PADDUSBirr */
  },
  { /* 1461 */
    214,
    /* MMX_PADDUSWirm */
  },
  { /* 1462 */
    215,
    /* MMX_PADDUSWirr */
  },
  { /* 1463 */
    214,
    /* MMX_PADDWirm */
  },
  { /* 1464 */
    215,
    /* MMX_PADDWirr */
  },
  { /* 1465 */
    216,
    /* MMX_PALIGNR64irm */
  },
  { /* 1466 */
    217,
    /* MMX_PALIGNR64irr */
  },
  { /* 1467 */
    214,
    /* MMX_PANDNirm */
  },
  { /* 1468 */
    215,
    /* MMX_PANDNirr */
  },
  { /* 1469 */
    214,
    /* MMX_PANDirm */
  },
  { /* 1470 */
    215,
    /* MMX_PANDirr */
  },
  { /* 1471 */
    214,
    /* MMX_PAVGBirm */
  },
  { /* 1472 */
    215,
    /* MMX_PAVGBirr */
  },
  { /* 1473 */
    214,
    /* MMX_PAVGWirm */
  },
  { /* 1474 */
    215,
    /* MMX_PAVGWirr */
  },
  { /* 1475 */
    214,
    /* MMX_PCMPEQBirm */
  },
  { /* 1476 */
    215,
    /* MMX_PCMPEQBirr */
  },
  { /* 1477 */
    214,
    /* MMX_PCMPEQDirm */
  },
  { /* 1478 */
    215,
    /* MMX_PCMPEQDirr */
  },
  { /* 1479 */
    214,
    /* MMX_PCMPEQWirm */
  },
  { /* 1480 */
    215,
    /* MMX_PCMPEQWirr */
  },
  { /* 1481 */
    214,
    /* MMX_PCMPGTBirm */
  },
  { /* 1482 */
    215,
    /* MMX_PCMPGTBirr */
  },
  { /* 1483 */
    214,
    /* MMX_PCMPGTDirm */
  },
  { /* 1484 */
    215,
    /* MMX_PCMPGTDirr */
  },
  { /* 1485 */
    214,
    /* MMX_PCMPGTWirm */
  },
  { /* 1486 */
    215,
    /* MMX_PCMPGTWirr */
  },
  { /* 1487 */
    218,
    /* MMX_PEXTRWirri */
  },
  { /* 1488 */
    214,
    /* MMX_PHADDSWrm64 */
  },
  { /* 1489 */
    215,
    /* MMX_PHADDSWrr64 */
  },
  { /* 1490 */
    214,
    /* MMX_PHADDWrm64 */
  },
  { /* 1491 */
    215,
    /* MMX_PHADDWrr64 */
  },
  { /* 1492 */
    214,
    /* MMX_PHADDrm64 */
  },
  { /* 1493 */
    215,
    /* MMX_PHADDrr64 */
  },
  { /* 1494 */
    214,
    /* MMX_PHSUBDrm64 */
  },
  { /* 1495 */
    215,
    /* MMX_PHSUBDrr64 */
  },
  { /* 1496 */
    214,
    /* MMX_PHSUBSWrm64 */
  },
  { /* 1497 */
    215,
    /* MMX_PHSUBSWrr64 */
  },
  { /* 1498 */
    214,
    /* MMX_PHSUBWrm64 */
  },
  { /* 1499 */
    215,
    /* MMX_PHSUBWrr64 */
  },
  { /* 1500 */
    216,
    /* MMX_PINSRWirmi */
  },
  { /* 1501 */
    219,
    /* MMX_PINSRWirri */
  },
  { /* 1502 */
    214,
    /* MMX_PMADDUBSWrm64 */
  },
  { /* 1503 */
    215,
    /* MMX_PMADDUBSWrr64 */
  },
  { /* 1504 */
    214,
    /* MMX_PMADDWDirm */
  },
  { /* 1505 */
    215,
    /* MMX_PMADDWDirr */
  },
  { /* 1506 */
    214,
    /* MMX_PMAXSWirm */
  },
  { /* 1507 */
    215,
    /* MMX_PMAXSWirr */
  },
  { /* 1508 */
    214,
    /* MMX_PMAXUBirm */
  },
  { /* 1509 */
    215,
    /* MMX_PMAXUBirr */
  },
  { /* 1510 */
    214,
    /* MMX_PMINSWirm */
  },
  { /* 1511 */
    215,
    /* MMX_PMINSWirr */
  },
  { /* 1512 */
    214,
    /* MMX_PMINUBirm */
  },
  { /* 1513 */
    215,
    /* MMX_PMINUBirr */
  },
  { /* 1514 */
    220,
    /* MMX_PMOVMSKBrr */
  },
  { /* 1515 */
    214,
    /* MMX_PMULHRSWrm64 */
  },
  { /* 1516 */
    215,
    /* MMX_PMULHRSWrr64 */
  },
  { /* 1517 */
    214,
    /* MMX_PMULHUWirm */
  },
  { /* 1518 */
    215,
    /* MMX_PMULHUWirr */
  },
  { /* 1519 */
    214,
    /* MMX_PMULHWirm */
  },
  { /* 1520 */
    215,
    /* MMX_PMULHWirr */
  },
  { /* 1521 */
    214,
    /* MMX_PMULLWirm */
  },
  { /* 1522 */
    215,
    /* MMX_PMULLWirr */
  },
  { /* 1523 */
    214,
    /* MMX_PMULUDQirm */
  },
  { /* 1524 */
    215,
    /* MMX_PMULUDQirr */
  },
  { /* 1525 */
    214,
    /* MMX_PORirm */
  },
  { /* 1526 */
    215,
    /* MMX_PORirr */
  },
  { /* 1527 */
    214,
    /* MMX_PSADBWirm */
  },
  { /* 1528 */
    215,
    /* MMX_PSADBWirr */
  },
  { /* 1529 */
    214,
    /* MMX_PSHUFBrm64 */
  },
  { /* 1530 */
    215,
    /* MMX_PSHUFBrr64 */
  },
  { /* 1531 */
    221,
    /* MMX_PSHUFWmi */
  },
  { /* 1532 */
    222,
    /* MMX_PSHUFWri */
  },
  { /* 1533 */
    214,
    /* MMX_PSIGNBrm64 */
  },
  { /* 1534 */
    215,
    /* MMX_PSIGNBrr64 */
  },
  { /* 1535 */
    214,
    /* MMX_PSIGNDrm64 */
  },
  { /* 1536 */
    215,
    /* MMX_PSIGNDrr64 */
  },
  { /* 1537 */
    214,
    /* MMX_PSIGNWrm64 */
  },
  { /* 1538 */
    215,
    /* MMX_PSIGNWrr64 */
  },
  { /* 1539 */
    223,
    /* MMX_PSLLDri */
  },
  { /* 1540 */
    214,
    /* MMX_PSLLDrm */
  },
  { /* 1541 */
    215,
    /* MMX_PSLLDrr */
  },
  { /* 1542 */
    223,
    /* MMX_PSLLQri */
  },
  { /* 1543 */
    214,
    /* MMX_PSLLQrm */
  },
  { /* 1544 */
    215,
    /* MMX_PSLLQrr */
  },
  { /* 1545 */
    223,
    /* MMX_PSLLWri */
  },
  { /* 1546 */
    214,
    /* MMX_PSLLWrm */
  },
  { /* 1547 */
    215,
    /* MMX_PSLLWrr */
  },
  { /* 1548 */
    223,
    /* MMX_PSRADri */
  },
  { /* 1549 */
    214,
    /* MMX_PSRADrm */
  },
  { /* 1550 */
    215,
    /* MMX_PSRADrr */
  },
  { /* 1551 */
    223,
    /* MMX_PSRAWri */
  },
  { /* 1552 */
    214,
    /* MMX_PSRAWrm */
  },
  { /* 1553 */
    215,
    /* MMX_PSRAWrr */
  },
  { /* 1554 */
    223,
    /* MMX_PSRLDri */
  },
  { /* 1555 */
    214,
    /* MMX_PSRLDrm */
  },
  { /* 1556 */
    215,
    /* MMX_PSRLDrr */
  },
  { /* 1557 */
    223,
    /* MMX_PSRLQri */
  },
  { /* 1558 */
    214,
    /* MMX_PSRLQrm */
  },
  { /* 1559 */
    215,
    /* MMX_PSRLQrr */
  },
  { /* 1560 */
    223,
    /* MMX_PSRLWri */
  },
  { /* 1561 */
    214,
    /* MMX_PSRLWrm */
  },
  { /* 1562 */
    215,
    /* MMX_PSRLWrr */
  },
  { /* 1563 */
    214,
    /* MMX_PSUBBirm */
  },
  { /* 1564 */
    215,
    /* MMX_PSUBBirr */
  },
  { /* 1565 */
    214,
    /* MMX_PSUBDirm */
  },
  { /* 1566 */
    215,
    /* MMX_PSUBDirr */
  },
  { /* 1567 */
    214,
    /* MMX_PSUBQirm */
  },
  { /* 1568 */
    215,
    /* MMX_PSUBQirr */
  },
  { /* 1569 */
    214,
    /* MMX_PSUBSBirm */
  },
  { /* 1570 */
    215,
    /* MMX_PSUBSBirr */
  },
  { /* 1571 */
    214,
    /* MMX_PSUBSWirm */
  },
  { /* 1572 */
    215,
    /* MMX_PSUBSWirr */
  },
  { /* 1573 */
    214,
    /* MMX_PSUBUSBirm */
  },
  { /* 1574 */
    215,
    /* MMX_PSUBUSBirr */
  },
  { /* 1575 */
    214,
    /* MMX_PSUBUSWirm */
  },
  { /* 1576 */
    215,
    /* MMX_PSUBUSWirr */
  },
  { /* 1577 */
    214,
    /* MMX_PSUBWirm */
  },
  { /* 1578 */
    215,
    /* MMX_PSUBWirr */
  },
  { /* 1579 */
    214,
    /* MMX_PUNPCKHBWirm */
  },
  { /* 1580 */
    215,
    /* MMX_PUNPCKHBWirr */
  },
  { /* 1581 */
    214,
    /* MMX_PUNPCKHDQirm */
  },
  { /* 1582 */
    215,
    /* MMX_PUNPCKHDQirr */
  },
  { /* 1583 */
    214,
    /* MMX_PUNPCKHWDirm */
  },
  { /* 1584 */
    215,
    /* MMX_PUNPCKHWDirr */
  },
  { /* 1585 */
    214,
    /* MMX_PUNPCKLBWirm */
  },
  { /* 1586 */
    215,
    /* MMX_PUNPCKLBWirr */
  },
  { /* 1587 */
    214,
    /* MMX_PUNPCKLDQirm */
  },
  { /* 1588 */
    215,
    /* MMX_PUNPCKLDQirr */
  },
  { /* 1589 */
    214,
    /* MMX_PUNPCKLWDirm */
  },
  { /* 1590 */
    215,
    /* MMX_PUNPCKLWDirr */
  },
  { /* 1591 */
    214,
    /* MMX_PXORirm */
  },
  { /* 1592 */
    215,
    /* MMX_PXORirr */
  },
  { /* 1593 */
    0,
    /*  */
  },
  { /* 1594 */
    0,
    /* MONITORrrr */
  },
  { /* 1595 */
    0,
    /* MONTMUL */
  },
  { /* 1596 */
    0,
    /*  */
  },
  { /* 1597 */
    0,
    /*  */
  },
  { /* 1598 */
    224,
    /* MOV16ao16 */
  },
  { /* 1599 */
    224,
    /* MOV16ao32 */
  },
  { /* 1600 */
    224,
    /* MOV16ao64 */
  },
  { /* 1601 */
    3,
    /* MOV16mi */
  },
  { /* 1602 */
    5,
    /* MOV16mr */
  },
  { /* 1603 */
    225,
    /* MOV16ms */
  },
  { /* 1604 */
    224,
    /* MOV16o16a */
  },
  { /* 1605 */
    224,
    /* MOV16o32a */
  },
  { /* 1606 */
    224,
    /* MOV16o64a */
  },
  { /* 1607 */
    226,
    /* MOV16ri */
  },
  { /* 1608 */
    83,
    /* MOV16ri_alt */
  },
  { /* 1609 */
    68,
    /* MOV16rm */
  },
  { /* 1610 */
    73,
    /* MOV16rr */
  },
  { /* 1611 */
    69,
    /* MOV16rr_REV */
  },
  { /* 1612 */
    227,
    /* MOV16rs */
  },
  { /* 1613 */
    228,
    /* MOV16sm */
  },
  { /* 1614 */
    229,
    /* MOV16sr */
  },
  { /* 1615 */
    230,
    /* MOV32ao16 */
  },
  { /* 1616 */
    230,
    /* MOV32ao32 */
  },
  { /* 1617 */
    230,
    /* MOV32ao64 */
  },
  { /* 1618 */
    231,
    /* MOV32cr */
  },
  { /* 1619 */
    232,
    /* MOV32dr */
  },
  { /* 1620 */
    3,
    /* MOV32mi */
  },
  { /* 1621 */
    5,
    /* MOV32mr */
  },
  { /* 1622 */
    225,
    /* MOV32ms */
  },
  { /* 1623 */
    230,
    /* MOV32o16a */
  },
  { /* 1624 */
    230,
    /* MOV32o32a */
  },
  { /* 1625 */
    230,
    /* MOV32o64a */
  },
  { /* 1626 */
    0,
    /*  */
  },
  { /* 1627 */
    233,
    /* MOV32rc */
  },
  { /* 1628 */
    234,
    /* MOV32rd */
  },
  { /* 1629 */
    226,
    /* MOV32ri */
  },
  { /* 1630 */
    0,
    /*  */
  },
  { /* 1631 */
    83,
    /* MOV32ri_alt */
  },
  { /* 1632 */
    68,
    /* MOV32rm */
  },
  { /* 1633 */
    73,
    /* MOV32rr */
  },
  { /* 1634 */
    69,
    /* MOV32rr_REV */
  },
  { /* 1635 */
    227,
    /* MOV32rs */
  },
  { /* 1636 */
    228,
    /* MOV32sm */
  },
  { /* 1637 */
    229,
    /* MOV32sr */
  },
  { /* 1638 */
    235,
    /* MOV64ao32 */
  },
  { /* 1639 */
    235,
    /* MOV64ao64 */
  },
  { /* 1640 */
    236,
    /* MOV64cr */
  },
  { /* 1641 */
    237,
    /* MOV64dr */
  },
  { /* 1642 */
    14,
    /* MOV64mi32 */
  },
  { /* 1643 */
    16,
    /* MOV64mr */
  },
  { /* 1644 */
    225,
    /* MOV64ms */
  },
  { /* 1645 */
    235,
    /* MOV64o32a */
  },
  { /* 1646 */
    235,
    /* MOV64o64a */
  },
  { /* 1647 */
    238,
    /* MOV64rc */
  },
  { /* 1648 */
    239,
    /* MOV64rd */
  },
  { /* 1649 */
    240,
    /* MOV64ri */
  },
  { /* 1650 */
    84,
    /* MOV64ri32 */
  },
  { /* 1651 */
    42,
    /* MOV64rm */
  },
  { /* 1652 */
    76,
    /* MOV64rr */
  },
  { /* 1653 */
    43,
    /* MOV64rr_REV */
  },
  { /* 1654 */
    241,
    /* MOV64rs */
  },
  { /* 1655 */
    228,
    /* MOV64sm */
  },
  { /* 1656 */
    242,
    /* MOV64sr */
  },
  { /* 1657 */
    105,
    /* MOV64toPQIrm */
  },
  { /* 1658 */
    243,
    /* MOV64toPQIrr */
  },
  { /* 1659 */
    0,
    /*  */
  },
  { /* 1660 */
    0,
    /*  */
  },
  { /* 1661 */
    244,
    /* MOV8ao16 */
  },
  { /* 1662 */
    244,
    /* MOV8ao32 */
  },
  { /* 1663 */
    244,
    /* MOV8ao64 */
  },
  { /* 1664 */
    22,
    /* MOV8mi */
  },
  { /* 1665 */
    23,
    /* MOV8mr */
  },
  { /* 1666 */
    0,
    /*  */
  },
  { /* 1667 */
    244,
    /* MOV8o16a */
  },
  { /* 1668 */
    244,
    /* MOV8o32a */
  },
  { /* 1669 */
    244,
    /* MOV8o64a */
  },
  { /* 1670 */
    245,
    /* MOV8ri */
  },
  { /* 1671 */
    85,
    /* MOV8ri_alt */
  },
  { /* 1672 */
    86,
    /* MOV8rm */
  },
  { /* 1673 */
    0,
    /*  */
  },
  { /* 1674 */
    87,
    /* MOV8rr */
  },
  { /* 1675 */
    0,
    /*  */
  },
  { /* 1676 */
    88,
    /* MOV8rr_REV */
  },
  { /* 1677 */
    246,
    /* MOVAPDmr */
  },
  { /* 1678 */
    44,
    /* MOVAPDrm */
  },
  { /* 1679 */
    45,
    /* MOVAPDrr */
  },
  { /* 1680 */
    247,
    /* MOVAPDrr_REV */
  },
  { /* 1681 */
    246,
    /* MOVAPSmr */
  },
  { /* 1682 */
    44,
    /* MOVAPSrm */
  },
  { /* 1683 */
    45,
    /* MOVAPSrr */
  },
  { /* 1684 */
    247,
    /* MOVAPSrr_REV */
  },
  { /* 1685 */
    5,
    /* MOVBE16mr */
  },
  { /* 1686 */
    68,
    /* MOVBE16rm */
  },
  { /* 1687 */
    5,
    /* MOVBE32mr */
  },
  { /* 1688 */
    68,
    /* MOVBE32rm */
  },
  { /* 1689 */
    16,
    /* MOVBE64mr */
  },
  { /* 1690 */
    42,
    /* MOVBE64rm */
  },
  { /* 1691 */
    106,
    /* MOVDDUPrm */
  },
  { /* 1692 */
    45,
    /* MOVDDUPrr */
  },
  { /* 1693 */
    105,
    /* MOVDI2PDIrm */
  },
  { /* 1694 */
    248,
    /* MOVDI2PDIrr */
  },
  { /* 1695 */
    0,
    /*  */
  },
  { /* 1696 */
    0,
    /*  */
  },
  { /* 1697 */
    246,
    /* MOVDQAmr */
  },
  { /* 1698 */
    44,
    /* MOVDQArm */
  },
  { /* 1699 */
    45,
    /* MOVDQArr */
  },
  { /* 1700 */
    247,
    /* MOVDQArr_REV */
  },
  { /* 1701 */
    246,
    /* MOVDQUmr */
  },
  { /* 1702 */
    44,
    /* MOVDQUrm */
  },
  { /* 1703 */
    45,
    /* MOVDQUrr */
  },
  { /* 1704 */
    247,
    /* MOVDQUrr_REV */
  },
  { /* 1705 */
    31,
    /* MOVHLPSrr */
  },
  { /* 1706 */
    249,
    /* MOVHPDmr */
  },
  { /* 1707 */
    250,
    /* MOVHPDrm */
  },
  { /* 1708 */
    249,
    /* MOVHPSmr */
  },
  { /* 1709 */
    250,
    /* MOVHPSrm */
  },
  { /* 1710 */
    31,
    /* MOVLHPSrr */
  },
  { /* 1711 */
    249,
    /* MOVLPDmr */
  },
  { /* 1712 */
    250,
    /* MOVLPDrm */
  },
  { /* 1713 */
    249,
    /* MOVLPSmr */
  },
  { /* 1714 */
    250,
    /* MOVLPSrm */
  },
  { /* 1715 */
    110,
    /* MOVMSKPDrr */
  },
  { /* 1716 */
    110,
    /* MOVMSKPSrr */
  },
  { /* 1717 */
    44,
    /* MOVNTDQArm */
  },
  { /* 1718 */
    246,
    /* MOVNTDQmr */
  },
  { /* 1719 */
    16,
    /* MOVNTI_64mr */
  },
  { /* 1720 */
    251,
    /* MOVNTImr */
  },
  { /* 1721 */
    246,
    /* MOVNTPDmr */
  },
  { /* 1722 */
    246,
    /* MOVNTPSmr */
  },
  { /* 1723 */
    249,
    /* MOVNTSD */
  },
  { /* 1724 */
    252,
    /* MOVNTSS */
  },
  { /* 1725 */
    0,
    /*  */
  },
  { /* 1726 */
    253,
    /* MOVPDI2DImr */
  },
  { /* 1727 */
    254,
    /* MOVPDI2DIrr */
  },
  { /* 1728 */
    253,
    /* MOVPQI2QImr */
  },
  { /* 1729 */
    247,
    /* MOVPQI2QIrr */
  },
  { /* 1730 */
    253,
    /* MOVPQIto64rm */
  },
  { /* 1731 */
    255,
    /* MOVPQIto64rr */
  },
  { /* 1732 */
    105,
    /* MOVQI2PQIrm */
  },
  { /* 1733 */
    91,
    /* MOVSB */
  },
  { /* 1734 */
    256,
    /* MOVSDmr */
  },
  { /* 1735 */
    257,
    /* MOVSDrm */
  },
  { /* 1736 */
    258,
    /* MOVSDrr */
  },
  { /* 1737 */
    259,
    /* MOVSDrr_REV */
  },
  { /* 1738 */
    0,
    /*  */
  },
  { /* 1739 */
    0,
    /*  */
  },
  { /* 1740 */
    44,
    /* MOVSHDUPrm */
  },
  { /* 1741 */
    45,
    /* MOVSHDUPrr */
  },
  { /* 1742 */
    94,
    /* MOVSL */
  },
  { /* 1743 */
    44,
    /* MOVSLDUPrm */
  },
  { /* 1744 */
    45,
    /* MOVSLDUPrr */
  },
  { /* 1745 */
    95,
    /* MOVSQ */
  },
  { /* 1746 */
    0,
    /*  */
  },
  { /* 1747 */
    0,
    /*  */
  },
  { /* 1748 */
    260,
    /* MOVSSmr */
  },
  { /* 1749 */
    261,
    /* MOVSSrm */
  },
  { /* 1750 */
    262,
    /* MOVSSrr */
  },
  { /* 1751 */
    263,
    /* MOVSSrr_REV */
  },
  { /* 1752 */
    98,
    /* MOVSW */
  },
  { /* 1753 */
    264,
    /* MOVSX16rm8 */
  },
  { /* 1754 */
    265,
    /* MOVSX16rr8 */
  },
  { /* 1755 */
    0,
    /*  */
  },
  { /* 1756 */
    0,
    /*  */
  },
  { /* 1757 */
    68,
    /* MOVSX32rm16 */
  },
  { /* 1758 */
    264,
    /* MOVSX32rm8 */
  },
  { /* 1759 */
    266,
    /* MOVSX32rr16 */
  },
  { /* 1760 */
    265,
    /* MOVSX32rr8 */
  },
  { /* 1761 */
    186,
    /* MOVSX64_NOREXrr32 */
  },
  { /* 1762 */
    42,
    /* MOVSX64rm16 */
  },
  { /* 1763 */
    42,
    /* MOVSX64rm32 */
  },
  { /* 1764 */
    42,
    /* MOVSX64rm32_alt */
  },
  { /* 1765 */
    267,
    /* MOVSX64rm8 */
  },
  { /* 1766 */
    268,
    /* MOVSX64rr16 */
  },
  { /* 1767 */
    186,
    /* MOVSX64rr32 */
  },
  { /* 1768 */
    269,
    /* MOVSX64rr8 */
  },
  { /* 1769 */
    246,
    /* MOVUPDmr */
  },
  { /* 1770 */
    44,
    /* MOVUPDrm */
  },
  { /* 1771 */
    45,
    /* MOVUPDrr */
  },
  { /* 1772 */
    247,
    /* MOVUPDrr_REV */
  },
  { /* 1773 */
    246,
    /* MOVUPSmr */
  },
  { /* 1774 */
    44,
    /* MOVUPSrm */
  },
  { /* 1775 */
    45,
    /* MOVUPSrr */
  },
  { /* 1776 */
    247,
    /* MOVUPSrr_REV */
  },
  { /* 1777 */
    0,
    /*  */
  },
  { /* 1778 */
    45,
    /* MOVZPQILo2PQIrr */
  },
  { /* 1779 */
    0,
    /*  */
  },
  { /* 1780 */
    0,
    /*  */
  },
  { /* 1781 */
    264,
    /* MOVZX16rm8 */
  },
  { /* 1782 */
    265,
    /* MOVZX16rr8 */
  },
  { /* 1783 */
    0,
    /*  */
  },
  { /* 1784 */
    0,
    /*  */
  },
  { /* 1785 */
    68,
    /* MOVZX32rm16 */
  },
  { /* 1786 */
    264,
    /* MOVZX32rm8 */
  },
  { /* 1787 */
    266,
    /* MOVZX32rr16 */
  },
  { /* 1788 */
    265,
    /* MOVZX32rr8 */
  },
  { /* 1789 */
    42,
    /* MOVZX64rm16_Q */
  },
  { /* 1790 */
    267,
    /* MOVZX64rm8_Q */
  },
  { /* 1791 */
    268,
    /* MOVZX64rr16_Q */
  },
  { /* 1792 */
    269,
    /* MOVZX64rr8_Q */
  },
  { /* 1793 */
    66,
    /* MPSADBWrmi */
  },
  { /* 1794 */
    67,
    /* MPSADBWrri */
  },
  { /* 1795 */
    38,
    /* MUL16m */
  },
  { /* 1796 */
    77,
    /* MUL16r */
  },
  { /* 1797 */
    38,
    /* MUL32m */
  },
  { /* 1798 */
    77,
    /* MUL32r */
  },
  { /* 1799 */
    38,
    /* MUL64m */
  },
  { /* 1800 */
    79,
    /* MUL64r */
  },
  { /* 1801 */
    82,
    /* MUL8m */
  },
  { /* 1802 */
    130,
    /* MUL8r */
  },
  { /* 1803 */
    30,
    /* MULPDrm */
  },
  { /* 1804 */
    31,
    /* MULPDrr */
  },
  { /* 1805 */
    30,
    /* MULPSrm */
  },
  { /* 1806 */
    31,
    /* MULPSrr */
  },
  { /* 1807 */
    32,
    /* MULSDrm */
  },
  { /* 1808 */
    0,
    /*  */
  },
  { /* 1809 */
    33,
    /* MULSDrr */
  },
  { /* 1810 */
    0,
    /*  */
  },
  { /* 1811 */
    34,
    /* MULSSrm */
  },
  { /* 1812 */
    0,
    /*  */
  },
  { /* 1813 */
    35,
    /* MULSSrr */
  },
  { /* 1814 */
    0,
    /*  */
  },
  { /* 1815 */
    48,
    /* MULX32rm */
  },
  { /* 1816 */
    49,
    /* MULX32rr */
  },
  { /* 1817 */
    50,
    /* MULX64rm */
  },
  { /* 1818 */
    51,
    /* MULX64rr */
  },
  { /* 1819 */
    36,
    /* MUL_F32m */
  },
  { /* 1820 */
    37,
    /* MUL_F64m */
  },
  { /* 1821 */
    38,
    /* MUL_FI16m */
  },
  { /* 1822 */
    38,
    /* MUL_FI32m */
  },
  { /* 1823 */
    39,
    /* MUL_FPrST0 */
  },
  { /* 1824 */
    39,
    /* MUL_FST0r */
  },
  { /* 1825 */
    0,
    /*  */
  },
  { /* 1826 */
    0,
    /*  */
  },
  { /* 1827 */
    0,
    /*  */
  },
  { /* 1828 */
    0,
    /*  */
  },
  { /* 1829 */
    0,
    /*  */
  },
  { /* 1830 */
    0,
    /*  */
  },
  { /* 1831 */
    0,
    /*  */
  },
  { /* 1832 */
    0,
    /*  */
  },
  { /* 1833 */
    0,
    /*  */
  },
  { /* 1834 */
    0,
    /*  */
  },
  { /* 1835 */
    0,
    /*  */
  },
  { /* 1836 */
    0,
    /*  */
  },
  { /* 1837 */
    0,
    /*  */
  },
  { /* 1838 */
    0,
    /*  */
  },
  { /* 1839 */
    39,
    /* MUL_FrST0 */
  },
  { /* 1840 */
    0,
    /* MWAITrr */
  },
  { /* 1841 */
    38,
    /* NEG16m */
  },
  { /* 1842 */
    127,
    /* NEG16r */
  },
  { /* 1843 */
    38,
    /* NEG32m */
  },
  { /* 1844 */
    127,
    /* NEG32r */
  },
  { /* 1845 */
    38,
    /* NEG64m */
  },
  { /* 1846 */
    128,
    /* NEG64r */
  },
  { /* 1847 */
    82,
    /* NEG8m */
  },
  { /* 1848 */
    129,
    /* NEG8r */
  },
  { /* 1849 */
    0,
    /* NOOP */
  },
  { /* 1850 */
    38,
    /* NOOP18_16m4 */
  },
  { /* 1851 */
    38,
    /* NOOP18_16m5 */
  },
  { /* 1852 */
    38,
    /* NOOP18_16m6 */
  },
  { /* 1853 */
    38,
    /* NOOP18_16m7 */
  },
  { /* 1854 */
    77,
    /* NOOP18_16r4 */
  },
  { /* 1855 */
    77,
    /* NOOP18_16r5 */
  },
  { /* 1856 */
    77,
    /* NOOP18_16r6 */
  },
  { /* 1857 */
    77,
    /* NOOP18_16r7 */
  },
  { /* 1858 */
    38,
    /* NOOP18_m4 */
  },
  { /* 1859 */
    38,
    /* NOOP18_m5 */
  },
  { /* 1860 */
    38,
    /* NOOP18_m6 */
  },
  { /* 1861 */
    38,
    /* NOOP18_m7 */
  },
  { /* 1862 */
    77,
    /* NOOP18_r4 */
  },
  { /* 1863 */
    77,
    /* NOOP18_r5 */
  },
  { /* 1864 */
    77,
    /* NOOP18_r6 */
  },
  { /* 1865 */
    77,
    /* NOOP18_r7 */
  },
  { /* 1866 */
    69,
    /* NOOP19rr */
  },
  { /* 1867 */
    38,
    /* NOOPL */
  },
  { /* 1868 */
    38,
    /* NOOPL_19 */
  },
  { /* 1869 */
    38,
    /* NOOPL_1a */
  },
  { /* 1870 */
    38,
    /* NOOPL_1b */
  },
  { /* 1871 */
    38,
    /* NOOPL_1c */
  },
  { /* 1872 */
    38,
    /* NOOPL_1d */
  },
  { /* 1873 */
    38,
    /* NOOPL_1e */
  },
  { /* 1874 */
    38,
    /* NOOPW */
  },
  { /* 1875 */
    38,
    /* NOOPW_19 */
  },
  { /* 1876 */
    38,
    /* NOOPW_1a */
  },
  { /* 1877 */
    38,
    /* NOOPW_1b */
  },
  { /* 1878 */
    38,
    /* NOOPW_1c */
  },
  { /* 1879 */
    38,
    /* NOOPW_1d */
  },
  { /* 1880 */
    38,
    /* NOOPW_1e */
  },
  { /* 1881 */
    38,
    /* NOT16m */
  },
  { /* 1882 */
    127,
    /* NOT16r */
  },
  { /* 1883 */
    38,
    /* NOT32m */
  },
  { /* 1884 */
    127,
    /* NOT32r */
  },
  { /* 1885 */
    38,
    /* NOT64m */
  },
  { /* 1886 */
    128,
    /* NOT64r */
  },
  { /* 1887 */
    82,
    /* NOT8m */
  },
  { /* 1888 */
    129,
    /* NOT8r */
  },
  { /* 1889 */
    2,
    /* OR16i16 */
  },
  { /* 1890 */
    3,
    /* OR16mi */
  },
  { /* 1891 */
    4,
    /* OR16mi8 */
  },
  { /* 1892 */
    5,
    /* OR16mr */
  },
  { /* 1893 */
    6,
    /* OR16ri */
  },
  { /* 1894 */
    7,
    /* OR16ri8 */
  },
  { /* 1895 */
    8,
    /* OR16rm */
  },
  { /* 1896 */
    9,
    /* OR16rr */
  },
  { /* 1897 */
    10,
    /* OR16rr_REV */
  },
  { /* 1898 */
    2,
    /* OR32i32 */
  },
  { /* 1899 */
    3,
    /* OR32mi */
  },
  { /* 1900 */
    11,
    /* OR32mi8 */
  },
  { /* 1901 */
    5,
    /* OR32mr */
  },
  { /* 1902 */
    0,
    /*  */
  },
  { /* 1903 */
    6,
    /* OR32ri */
  },
  { /* 1904 */
    12,
    /* OR32ri8 */
  },
  { /* 1905 */
    8,
    /* OR32rm */
  },
  { /* 1906 */
    9,
    /* OR32rr */
  },
  { /* 1907 */
    10,
    /* OR32rr_REV */
  },
  { /* 1908 */
    13,
    /* OR64i32 */
  },
  { /* 1909 */
    14,
    /* OR64mi32 */
  },
  { /* 1910 */
    15,
    /* OR64mi8 */
  },
  { /* 1911 */
    16,
    /* OR64mr */
  },
  { /* 1912 */
    17,
    /* OR64ri32 */
  },
  { /* 1913 */
    18,
    /* OR64ri8 */
  },
  { /* 1914 */
    19,
    /* OR64rm */
  },
  { /* 1915 */
    20,
    /* OR64rr */
  },
  { /* 1916 */
    21,
    /* OR64rr_REV */
  },
  { /* 1917 */
    1,
    /* OR8i8 */
  },
  { /* 1918 */
    22,
    /* OR8mi */
  },
  { /* 1919 */
    22,
    /* OR8mi8 */
  },
  { /* 1920 */
    23,
    /* OR8mr */
  },
  { /* 1921 */
    24,
    /* OR8ri */
  },
  { /* 1922 */
    24,
    /* OR8ri8 */
  },
  { /* 1923 */
    25,
    /* OR8rm */
  },
  { /* 1924 */
    26,
    /* OR8rr */
  },
  { /* 1925 */
    27,
    /* OR8rr_REV */
  },
  { /* 1926 */
    30,
    /* ORPDrm */
  },
  { /* 1927 */
    31,
    /* ORPDrr */
  },
  { /* 1928 */
    30,
    /* ORPSrm */
  },
  { /* 1929 */
    31,
    /* ORPSrr */
  },
  { /* 1930 */
    1,
    /* OUT16ir */
  },
  { /* 1931 */
    0,
    /* OUT16rr */
  },
  { /* 1932 */
    1,
    /* OUT32ir */
  },
  { /* 1933 */
    0,
    /* OUT32rr */
  },
  { /* 1934 */
    1,
    /* OUT8ir */
  },
  { /* 1935 */
    0,
    /* OUT8rr */
  },
  { /* 1936 */
    195,
    /* OUTSB */
  },
  { /* 1937 */
    196,
    /* OUTSL */
  },
  { /* 1938 */
    198,
    /* OUTSW */
  },
  { /* 1939 */
    44,
    /* PABSBrm128 */
  },
  { /* 1940 */
    45,
    /* PABSBrr128 */
  },
  { /* 1941 */
    44,
    /* PABSDrm128 */
  },
  { /* 1942 */
    45,
    /* PABSDrr128 */
  },
  { /* 1943 */
    44,
    /* PABSWrm128 */
  },
  { /* 1944 */
    45,
    /* PABSWrr128 */
  },
  { /* 1945 */
    30,
    /* PACKSSDWrm */
  },
  { /* 1946 */
    31,
    /* PACKSSDWrr */
  },
  { /* 1947 */
    30,
    /* PACKSSWBrm */
  },
  { /* 1948 */
    31,
    /* PACKSSWBrr */
  },
  { /* 1949 */
    30,
    /* PACKUSDWrm */
  },
  { /* 1950 */
    31,
    /* PACKUSDWrr */
  },
  { /* 1951 */
    30,
    /* PACKUSWBrm */
  },
  { /* 1952 */
    31,
    /* PACKUSWBrr */
  },
  { /* 1953 */
    30,
    /* PADDBrm */
  },
  { /* 1954 */
    31,
    /* PADDBrr */
  },
  { /* 1955 */
    30,
    /* PADDDrm */
  },
  { /* 1956 */
    31,
    /* PADDDrr */
  },
  { /* 1957 */
    30,
    /* PADDQrm */
  },
  { /* 1958 */
    31,
    /* PADDQrr */
  },
  { /* 1959 */
    30,
    /* PADDSBrm */
  },
  { /* 1960 */
    31,
    /* PADDSBrr */
  },
  { /* 1961 */
    30,
    /* PADDSWrm */
  },
  { /* 1962 */
    31,
    /* PADDSWrr */
  },
  { /* 1963 */
    30,
    /* PADDUSBrm */
  },
  { /* 1964 */
    31,
    /* PADDUSBrr */
  },
  { /* 1965 */
    30,
    /* PADDUSWrm */
  },
  { /* 1966 */
    31,
    /* PADDUSWrr */
  },
  { /* 1967 */
    30,
    /* PADDWrm */
  },
  { /* 1968 */
    31,
    /* PADDWrr */
  },
  { /* 1969 */
    66,
    /* PALIGNR128rm */
  },
  { /* 1970 */
    67,
    /* PALIGNR128rr */
  },
  { /* 1971 */
    30,
    /* PANDNrm */
  },
  { /* 1972 */
    31,
    /* PANDNrr */
  },
  { /* 1973 */
    30,
    /* PANDrm */
  },
  { /* 1974 */
    31,
    /* PANDrr */
  },
  { /* 1975 */
    0,
    /* PAUSE */
  },
  { /* 1976 */
    30,
    /* PAVGBrm */
  },
  { /* 1977 */
    31,
    /* PAVGBrr */
  },
  { /* 1978 */
    214,
    /* PAVGUSBrm */
  },
  { /* 1979 */
    215,
    /* PAVGUSBrr */
  },
  { /* 1980 */
    30,
    /* PAVGWrm */
  },
  { /* 1981 */
    31,
    /* PAVGWrr */
  },
  { /* 1982 */
    30,
    /* PBLENDVBrm0 */
  },
  { /* 1983 */
    31,
    /* PBLENDVBrr0 */
  },
  { /* 1984 */
    66,
    /* PBLENDWrmi */
  },
  { /* 1985 */
    67,
    /* PBLENDWrri */
  },
  { /* 1986 */
    66,
    /* PCLMULQDQrm */
  },
  { /* 1987 */
    67,
    /* PCLMULQDQrr */
  },
  { /* 1988 */
    30,
    /* PCMPEQBrm */
  },
  { /* 1989 */
    31,
    /* PCMPEQBrr */
  },
  { /* 1990 */
    30,
    /* PCMPEQDrm */
  },
  { /* 1991 */
    31,
    /* PCMPEQDrr */
  },
  { /* 1992 */
    30,
    /* PCMPEQQrm */
  },
  { /* 1993 */
    31,
    /* PCMPEQQrr */
  },
  { /* 1994 */
    30,
    /* PCMPEQWrm */
  },
  { /* 1995 */
    31,
    /* PCMPEQWrr */
  },
  { /* 1996 */
    0,
    /*  */
  },
  { /* 1997 */
    0,
    /*  */
  },
  { /* 1998 */
    46,
    /* PCMPESTRIrm */
  },
  { /* 1999 */
    47,
    /* PCMPESTRIrr */
  },
  { /* 2000 */
    0,
    /*  */
  },
  { /* 2001 */
    0,
    /*  */
  },
  { /* 2002 */
    46,
    /* PCMPESTRM128rm */
  },
  { /* 2003 */
    47,
    /* PCMPESTRM128rr */
  },
  { /* 2004 */
    30,
    /* PCMPGTBrm */
  },
  { /* 2005 */
    31,
    /* PCMPGTBrr */
  },
  { /* 2006 */
    30,
    /* PCMPGTDrm */
  },
  { /* 2007 */
    31,
    /* PCMPGTDrr */
  },
  { /* 2008 */
    30,
    /* PCMPGTQrm */
  },
  { /* 2009 */
    31,
    /* PCMPGTQrr */
  },
  { /* 2010 */
    30,
    /* PCMPGTWrm */
  },
  { /* 2011 */
    31,
    /* PCMPGTWrr */
  },
  { /* 2012 */
    0,
    /*  */
  },
  { /* 2013 */
    0,
    /*  */
  },
  { /* 2014 */
    46,
    /* PCMPISTRIrm */
  },
  { /* 2015 */
    47,
    /* PCMPISTRIrr */
  },
  { /* 2016 */
    0,
    /*  */
  },
  { /* 2017 */
    0,
    /*  */
  },
  { /* 2018 */
    46,
    /* PCMPISTRM128rm */
  },
  { /* 2019 */
    47,
    /* PCMPISTRM128rr */
  },
  { /* 2020 */
    0,
    /* PCOMMIT */
  },
  { /* 2021 */
    48,
    /* PDEP32rm */
  },
  { /* 2022 */
    49,
    /* PDEP32rr */
  },
  { /* 2023 */
    50,
    /* PDEP64rm */
  },
  { /* 2024 */
    51,
    /* PDEP64rr */
  },
  { /* 2025 */
    48,
    /* PEXT32rm */
  },
  { /* 2026 */
    49,
    /* PEXT32rr */
  },
  { /* 2027 */
    50,
    /* PEXT64rm */
  },
  { /* 2028 */
    51,
    /* PEXT64rr */
  },
  { /* 2029 */
    270,
    /* PEXTRBmr */
  },
  { /* 2030 */
    133,
    /* PEXTRBrr */
  },
  { /* 2031 */
    271,
    /* PEXTRDmr */
  },
  { /* 2032 */
    133,
    /* PEXTRDrr */
  },
  { /* 2033 */
    271,
    /* PEXTRQmr */
  },
  { /* 2034 */
    272,
    /* PEXTRQrr */
  },
  { /* 2035 */
    271,
    /* PEXTRWmr */
  },
  { /* 2036 */
    273,
    /* PEXTRWri */
  },
  { /* 2037 */
    133,
    /* PEXTRWrr_REV */
  },
  { /* 2038 */
    210,
    /* PF2IDrm */
  },
  { /* 2039 */
    206,
    /* PF2IDrr */
  },
  { /* 2040 */
    210,
    /* PF2IWrm */
  },
  { /* 2041 */
    206,
    /* PF2IWrr */
  },
  { /* 2042 */
    214,
    /* PFACCrm */
  },
  { /* 2043 */
    215,
    /* PFACCrr */
  },
  { /* 2044 */
    214,
    /* PFADDrm */
  },
  { /* 2045 */
    215,
    /* PFADDrr */
  },
  { /* 2046 */
    214,
    /* PFCMPEQrm */
  },
  { /* 2047 */
    215,
    /* PFCMPEQrr */
  },
  { /* 2048 */
    214,
    /* PFCMPGErm */
  },
  { /* 2049 */
    215,
    /* PFCMPGErr */
  },
  { /* 2050 */
    214,
    /* PFCMPGTrm */
  },
  { /* 2051 */
    215,
    /* PFCMPGTrr */
  },
  { /* 2052 */
    214,
    /* PFMAXrm */
  },
  { /* 2053 */
    215,
    /* PFMAXrr */
  },
  { /* 2054 */
    214,
    /* PFMINrm */
  },
  { /* 2055 */
    215,
    /* PFMINrr */
  },
  { /* 2056 */
    214,
    /* PFMULrm */
  },
  { /* 2057 */
    215,
    /* PFMULrr */
  },
  { /* 2058 */
    214,
    /* PFNACCrm */
  },
  { /* 2059 */
    215,
    /* PFNACCrr */
  },
  { /* 2060 */
    214,
    /* PFPNACCrm */
  },
  { /* 2061 */
    215,
    /* PFPNACCrr */
  },
  { /* 2062 */
    214,
    /* PFRCPIT1rm */
  },
  { /* 2063 */
    215,
    /* PFRCPIT1rr */
  },
  { /* 2064 */
    214,
    /* PFRCPIT2rm */
  },
  { /* 2065 */
    215,
    /* PFRCPIT2rr */
  },
  { /* 2066 */
    210,
    /* PFRCPrm */
  },
  { /* 2067 */
    206,
    /* PFRCPrr */
  },
  { /* 2068 */
    214,
    /* PFRSQIT1rm */
  },
  { /* 2069 */
    215,
    /* PFRSQIT1rr */
  },
  { /* 2070 */
    210,
    /* PFRSQRTrm */
  },
  { /* 2071 */
    206,
    /* PFRSQRTrr */
  },
  { /* 2072 */
    214,
    /* PFSUBRrm */
  },
  { /* 2073 */
    215,
    /* PFSUBRrr */
  },
  { /* 2074 */
    214,
    /* PFSUBrm */
  },
  { /* 2075 */
    215,
    /* PFSUBrr */
  },
  { /* 2076 */
    30,
    /* PHADDDrm */
  },
  { /* 2077 */
    31,
    /* PHADDDrr */
  },
  { /* 2078 */
    30,
    /* PHADDSWrm128 */
  },
  { /* 2079 */
    31,
    /* PHADDSWrr128 */
  },
  { /* 2080 */
    30,
    /* PHADDWrm */
  },
  { /* 2081 */
    31,
    /* PHADDWrr */
  },
  { /* 2082 */
    44,
    /* PHMINPOSUWrm128 */
  },
  { /* 2083 */
    45,
    /* PHMINPOSUWrr128 */
  },
  { /* 2084 */
    30,
    /* PHSUBDrm */
  },
  { /* 2085 */
    31,
    /* PHSUBDrr */
  },
  { /* 2086 */
    30,
    /* PHSUBSWrm128 */
  },
  { /* 2087 */
    31,
    /* PHSUBSWrr128 */
  },
  { /* 2088 */
    30,
    /* PHSUBWrm */
  },
  { /* 2089 */
    31,
    /* PHSUBWrr */
  },
  { /* 2090 */
    210,
    /* PI2FDrm */
  },
  { /* 2091 */
    206,
    /* PI2FDrr */
  },
  { /* 2092 */
    210,
    /* PI2FWrm */
  },
  { /* 2093 */
    206,
    /* PI2FWrr */
  },
  { /* 2094 */
    274,
    /* PINSRBrm */
  },
  { /* 2095 */
    275,
    /* PINSRBrr */
  },
  { /* 2096 */
    276,
    /* PINSRDrm */
  },
  { /* 2097 */
    275,
    /* PINSRDrr */
  },
  { /* 2098 */
    276,
    /* PINSRQrm */
  },
  { /* 2099 */
    277,
    /* PINSRQrr */
  },
  { /* 2100 */
    276,
    /* PINSRWrmi */
  },
  { /* 2101 */
    275,
    /* PINSRWrri */
  },
  { /* 2102 */
    30,
    /* PMADDUBSWrm128 */
  },
  { /* 2103 */
    31,
    /* PMADDUBSWrr128 */
  },
  { /* 2104 */
    30,
    /* PMADDWDrm */
  },
  { /* 2105 */
    31,
    /* PMADDWDrr */
  },
  { /* 2106 */
    30,
    /* PMAXSBrm */
  },
  { /* 2107 */
    31,
    /* PMAXSBrr */
  },
  { /* 2108 */
    30,
    /* PMAXSDrm */
  },
  { /* 2109 */
    31,
    /* PMAXSDrr */
  },
  { /* 2110 */
    30,
    /* PMAXSWrm */
  },
  { /* 2111 */
    31,
    /* PMAXSWrr */
  },
  { /* 2112 */
    30,
    /* PMAXUBrm */
  },
  { /* 2113 */
    31,
    /* PMAXUBrr */
  },
  { /* 2114 */
    30,
    /* PMAXUDrm */
  },
  { /* 2115 */
    31,
    /* PMAXUDrr */
  },
  { /* 2116 */
    30,
    /* PMAXUWrm */
  },
  { /* 2117 */
    31,
    /* PMAXUWrr */
  },
  { /* 2118 */
    30,
    /* PMINSBrm */
  },
  { /* 2119 */
    31,
    /* PMINSBrr */
  },
  { /* 2120 */
    30,
    /* PMINSDrm */
  },
  { /* 2121 */
    31,
    /* PMINSDrr */
  },
  { /* 2122 */
    30,
    /* PMINSWrm */
  },
  { /* 2123 */
    31,
    /* PMINSWrr */
  },
  { /* 2124 */
    30,
    /* PMINUBrm */
  },
  { /* 2125 */
    31,
    /* PMINUBrr */
  },
  { /* 2126 */
    30,
    /* PMINUDrm */
  },
  { /* 2127 */
    31,
    /* PMINUDrr */
  },
  { /* 2128 */
    30,
    /* PMINUWrm */
  },
  { /* 2129 */
    31,
    /* PMINUWrr */
  },
  { /* 2130 */
    110,
    /* PMOVMSKBrr */
  },
  { /* 2131 */
    105,
    /* PMOVSXBDrm */
  },
  { /* 2132 */
    45,
    /* PMOVSXBDrr */
  },
  { /* 2133 */
    105,
    /* PMOVSXBQrm */
  },
  { /* 2134 */
    45,
    /* PMOVSXBQrr */
  },
  { /* 2135 */
    105,
    /* PMOVSXBWrm */
  },
  { /* 2136 */
    45,
    /* PMOVSXBWrr */
  },
  { /* 2137 */
    105,
    /* PMOVSXDQrm */
  },
  { /* 2138 */
    45,
    /* PMOVSXDQrr */
  },
  { /* 2139 */
    105,
    /* PMOVSXWDrm */
  },
  { /* 2140 */
    45,
    /* PMOVSXWDrr */
  },
  { /* 2141 */
    105,
    /* PMOVSXWQrm */
  },
  { /* 2142 */
    45,
    /* PMOVSXWQrr */
  },
  { /* 2143 */
    105,
    /* PMOVZXBDrm */
  },
  { /* 2144 */
    45,
    /* PMOVZXBDrr */
  },
  { /* 2145 */
    105,
    /* PMOVZXBQrm */
  },
  { /* 2146 */
    45,
    /* PMOVZXBQrr */
  },
  { /* 2147 */
    105,
    /* PMOVZXBWrm */
  },
  { /* 2148 */
    45,
    /* PMOVZXBWrr */
  },
  { /* 2149 */
    105,
    /* PMOVZXDQrm */
  },
  { /* 2150 */
    45,
    /* PMOVZXDQrr */
  },
  { /* 2151 */
    105,
    /* PMOVZXWDrm */
  },
  { /* 2152 */
    45,
    /* PMOVZXWDrr */
  },
  { /* 2153 */
    105,
    /* PMOVZXWQrm */
  },
  { /* 2154 */
    45,
    /* PMOVZXWQrr */
  },
  { /* 2155 */
    30,
    /* PMULDQrm */
  },
  { /* 2156 */
    31,
    /* PMULDQrr */
  },
  { /* 2157 */
    30,
    /* PMULHRSWrm128 */
  },
  { /* 2158 */
    31,
    /* PMULHRSWrr128 */
  },
  { /* 2159 */
    214,
    /* PMULHRWrm */
  },
  { /* 2160 */
    215,
    /* PMULHRWrr */
  },
  { /* 2161 */
    30,
    /* PMULHUWrm */
  },
  { /* 2162 */
    31,
    /* PMULHUWrr */
  },
  { /* 2163 */
    30,
    /* PMULHWrm */
  },
  { /* 2164 */
    31,
    /* PMULHWrr */
  },
  { /* 2165 */
    30,
    /* PMULLDrm */
  },
  { /* 2166 */
    31,
    /* PMULLDrr */
  },
  { /* 2167 */
    30,
    /* PMULLWrm */
  },
  { /* 2168 */
    31,
    /* PMULLWrr */
  },
  { /* 2169 */
    30,
    /* PMULUDQrm */
  },
  { /* 2170 */
    31,
    /* PMULUDQrr */
  },
  { /* 2171 */
    278,
    /* POP16r */
  },
  { /* 2172 */
    38,
    /* POP16rmm */
  },
  { /* 2173 */
    77,
    /* POP16rmr */
  },
  { /* 2174 */
    278,
    /* POP32r */
  },
  { /* 2175 */
    38,
    /* POP32rmm */
  },
  { /* 2176 */
    77,
    /* POP32rmr */
  },
  { /* 2177 */
    279,
    /* POP64r */
  },
  { /* 2178 */
    38,
    /* POP64rmm */
  },
  { /* 2179 */
    79,
    /* POP64rmr */
  },
  { /* 2180 */
    0,
    /* POPA16 */
  },
  { /* 2181 */
    0,
    /* POPA32 */
  },
  { /* 2182 */
    68,
    /* POPCNT16rm */
  },
  { /* 2183 */
    69,
    /* POPCNT16rr */
  },
  { /* 2184 */
    68,
    /* POPCNT32rm */
  },
  { /* 2185 */
    69,
    /* POPCNT32rr */
  },
  { /* 2186 */
    42,
    /* POPCNT64rm */
  },
  { /* 2187 */
    43,
    /* POPCNT64rr */
  },
  { /* 2188 */
    0,
    /* POPDS16 */
  },
  { /* 2189 */
    0,
    /* POPDS32 */
  },
  { /* 2190 */
    0,
    /* POPES16 */
  },
  { /* 2191 */
    0,
    /* POPES32 */
  },
  { /* 2192 */
    0,
    /* POPF16 */
  },
  { /* 2193 */
    0,
    /* POPF32 */
  },
  { /* 2194 */
    0,
    /* POPF64 */
  },
  { /* 2195 */
    0,
    /* POPFS16 */
  },
  { /* 2196 */
    0,
    /* POPFS32 */
  },
  { /* 2197 */
    0,
    /* POPFS64 */
  },
  { /* 2198 */
    0,
    /* POPGS16 */
  },
  { /* 2199 */
    0,
    /* POPGS32 */
  },
  { /* 2200 */
    0,
    /* POPGS64 */
  },
  { /* 2201 */
    0,
    /* POPSS16 */
  },
  { /* 2202 */
    0,
    /* POPSS32 */
  },
  { /* 2203 */
    30,
    /* PORrm */
  },
  { /* 2204 */
    31,
    /* PORrr */
  },
  { /* 2205 */
    82,
    /* PREFETCH */
  },
  { /* 2206 */
    82,
    /* PREFETCHNTA */
  },
  { /* 2207 */
    82,
    /* PREFETCHT0 */
  },
  { /* 2208 */
    82,
    /* PREFETCHT1 */
  },
  { /* 2209 */
    82,
    /* PREFETCHT2 */
  },
  { /* 2210 */
    82,
    /* PREFETCHW */
  },
  { /* 2211 */
    30,
    /* PSADBWrm */
  },
  { /* 2212 */
    31,
    /* PSADBWrr */
  },
  { /* 2213 */
    30,
    /* PSHUFBrm */
  },
  { /* 2214 */
    31,
    /* PSHUFBrr */
  },
  { /* 2215 */
    46,
    /* PSHUFDmi */
  },
  { /* 2216 */
    47,
    /* PSHUFDri */
  },
  { /* 2217 */
    46,
    /* PSHUFHWmi */
  },
  { /* 2218 */
    47,
    /* PSHUFHWri */
  },
  { /* 2219 */
    46,
    /* PSHUFLWmi */
  },
  { /* 2220 */
    47,
    /* PSHUFLWri */
  },
  { /* 2221 */
    30,
    /* PSIGNBrm */
  },
  { /* 2222 */
    31,
    /* PSIGNBrr */
  },
  { /* 2223 */
    30,
    /* PSIGNDrm */
  },
  { /* 2224 */
    31,
    /* PSIGNDrr */
  },
  { /* 2225 */
    30,
    /* PSIGNWrm */
  },
  { /* 2226 */
    31,
    /* PSIGNWrr */
  },
  { /* 2227 */
    280,
    /* PSLLDQri */
  },
  { /* 2228 */
    280,
    /* PSLLDri */
  },
  { /* 2229 */
    30,
    /* PSLLDrm */
  },
  { /* 2230 */
    31,
    /* PSLLDrr */
  },
  { /* 2231 */
    280,
    /* PSLLQri */
  },
  { /* 2232 */
    30,
    /* PSLLQrm */
  },
  { /* 2233 */
    31,
    /* PSLLQrr */
  },
  { /* 2234 */
    280,
    /* PSLLWri */
  },
  { /* 2235 */
    30,
    /* PSLLWrm */
  },
  { /* 2236 */
    31,
    /* PSLLWrr */
  },
  { /* 2237 */
    280,
    /* PSRADri */
  },
  { /* 2238 */
    30,
    /* PSRADrm */
  },
  { /* 2239 */
    31,
    /* PSRADrr */
  },
  { /* 2240 */
    280,
    /* PSRAWri */
  },
  { /* 2241 */
    30,
    /* PSRAWrm */
  },
  { /* 2242 */
    31,
    /* PSRAWrr */
  },
  { /* 2243 */
    280,
    /* PSRLDQri */
  },
  { /* 2244 */
    280,
    /* PSRLDri */
  },
  { /* 2245 */
    30,
    /* PSRLDrm */
  },
  { /* 2246 */
    31,
    /* PSRLDrr */
  },
  { /* 2247 */
    280,
    /* PSRLQri */
  },
  { /* 2248 */
    30,
    /* PSRLQrm */
  },
  { /* 2249 */
    31,
    /* PSRLQrr */
  },
  { /* 2250 */
    280,
    /* PSRLWri */
  },
  { /* 2251 */
    30,
    /* PSRLWrm */
  },
  { /* 2252 */
    31,
    /* PSRLWrr */
  },
  { /* 2253 */
    30,
    /* PSUBBrm */
  },
  { /* 2254 */
    31,
    /* PSUBBrr */
  },
  { /* 2255 */
    30,
    /* PSUBDrm */
  },
  { /* 2256 */
    31,
    /* PSUBDrr */
  },
  { /* 2257 */
    30,
    /* PSUBQrm */
  },
  { /* 2258 */
    31,
    /* PSUBQrr */
  },
  { /* 2259 */
    30,
    /* PSUBSBrm */
  },
  { /* 2260 */
    31,
    /* PSUBSBrr */
  },
  { /* 2261 */
    30,
    /* PSUBSWrm */
  },
  { /* 2262 */
    31,
    /* PSUBSWrr */
  },
  { /* 2263 */
    30,
    /* PSUBUSBrm */
  },
  { /* 2264 */
    31,
    /* PSUBUSBrr */
  },
  { /* 2265 */
    30,
    /* PSUBUSWrm */
  },
  { /* 2266 */
    31,
    /* PSUBUSWrr */
  },
  { /* 2267 */
    30,
    /* PSUBWrm */
  },
  { /* 2268 */
    31,
    /* PSUBWrr */
  },
  { /* 2269 */
    210,
    /* PSWAPDrm */
  },
  { /* 2270 */
    206,
    /* PSWAPDrr */
  },
  { /* 2271 */
    44,
    /* PTESTrm */
  },
  { /* 2272 */
    45,
    /* PTESTrr */
  },
  { /* 2273 */
    30,
    /* PUNPCKHBWrm */
  },
  { /* 2274 */
    31,
    /* PUNPCKHBWrr */
  },
  { /* 2275 */
    30,
    /* PUNPCKHDQrm */
  },
  { /* 2276 */
    31,
    /* PUNPCKHDQrr */
  },
  { /* 2277 */
    30,
    /* PUNPCKHQDQrm */
  },
  { /* 2278 */
    31,
    /* PUNPCKHQDQrr */
  },
  { /* 2279 */
    30,
    /* PUNPCKHWDrm */
  },
  { /* 2280 */
    31,
    /* PUNPCKHWDrr */
  },
  { /* 2281 */
    30,
    /* PUNPCKLBWrm */
  },
  { /* 2282 */
    31,
    /* PUNPCKLBWrr */
  },
  { /* 2283 */
    30,
    /* PUNPCKLDQrm */
  },
  { /* 2284 */
    31,
    /* PUNPCKLDQrr */
  },
  { /* 2285 */
    30,
    /* PUNPCKLQDQrm */
  },
  { /* 2286 */
    31,
    /* PUNPCKLQDQrr */
  },
  { /* 2287 */
    30,
    /* PUNPCKLWDrm */
  },
  { /* 2288 */
    31,
    /* PUNPCKLWDrr */
  },
  { /* 2289 */
    281,
    /* PUSH16i8 */
  },
  { /* 2290 */
    278,
    /* PUSH16r */
  },
  { /* 2291 */
    38,
    /* PUSH16rmm */
  },
  { /* 2292 */
    77,
    /* PUSH16rmr */
  },
  { /* 2293 */
    282,
    /* PUSH32i8 */
  },
  { /* 2294 */
    278,
    /* PUSH32r */
  },
  { /* 2295 */
    38,
    /* PUSH32rmm */
  },
  { /* 2296 */
    77,
    /* PUSH32rmr */
  },
  { /* 2297 */
    2,
    /* PUSH64i16 */
  },
  { /* 2298 */
    13,
    /* PUSH64i32 */
  },
  { /* 2299 */
    283,
    /* PUSH64i8 */
  },
  { /* 2300 */
    279,
    /* PUSH64r */
  },
  { /* 2301 */
    38,
    /* PUSH64rmm */
  },
  { /* 2302 */
    79,
    /* PUSH64rmr */
  },
  { /* 2303 */
    0,
    /* PUSHA16 */
  },
  { /* 2304 */
    0,
    /* PUSHA32 */
  },
  { /* 2305 */
    0,
    /* PUSHCS16 */
  },
  { /* 2306 */
    0,
    /* PUSHCS32 */
  },
  { /* 2307 */
    0,
    /* PUSHDS16 */
  },
  { /* 2308 */
    0,
    /* PUSHDS32 */
  },
  { /* 2309 */
    0,
    /* PUSHES16 */
  },
  { /* 2310 */
    0,
    /* PUSHES32 */
  },
  { /* 2311 */
    0,
    /* PUSHF16 */
  },
  { /* 2312 */
    0,
    /* PUSHF32 */
  },
  { /* 2313 */
    0,
    /* PUSHF64 */
  },
  { /* 2314 */
    0,
    /* PUSHFS16 */
  },
  { /* 2315 */
    0,
    /* PUSHFS32 */
  },
  { /* 2316 */
    0,
    /* PUSHFS64 */
  },
  { /* 2317 */
    0,
    /* PUSHGS16 */
  },
  { /* 2318 */
    0,
    /* PUSHGS32 */
  },
  { /* 2319 */
    0,
    /* PUSHGS64 */
  },
  { /* 2320 */
    0,
    /* PUSHSS16 */
  },
  { /* 2321 */
    0,
    /* PUSHSS32 */
  },
  { /* 2322 */
    2,
    /* PUSHi16 */
  },
  { /* 2323 */
    2,
    /* PUSHi32 */
  },
  { /* 2324 */
    30,
    /* PXORrm */
  },
  { /* 2325 */
    31,
    /* PXORrr */
  },
  { /* 2326 */
    38,
    /* RCL16m1 */
  },
  { /* 2327 */
    38,
    /* RCL16mCL */
  },
  { /* 2328 */
    284,
    /* RCL16mi */
  },
  { /* 2329 */
    127,
    /* RCL16r1 */
  },
  { /* 2330 */
    127,
    /* RCL16rCL */
  },
  { /* 2331 */
    285,
    /* RCL16ri */
  },
  { /* 2332 */
    38,
    /* RCL32m1 */
  },
  { /* 2333 */
    38,
    /* RCL32mCL */
  },
  { /* 2334 */
    284,
    /* RCL32mi */
  },
  { /* 2335 */
    127,
    /* RCL32r1 */
  },
  { /* 2336 */
    127,
    /* RCL32rCL */
  },
  { /* 2337 */
    285,
    /* RCL32ri */
  },
  { /* 2338 */
    38,
    /* RCL64m1 */
  },
  { /* 2339 */
    38,
    /* RCL64mCL */
  },
  { /* 2340 */
    284,
    /* RCL64mi */
  },
  { /* 2341 */
    128,
    /* RCL64r1 */
  },
  { /* 2342 */
    128,
    /* RCL64rCL */
  },
  { /* 2343 */
    286,
    /* RCL64ri */
  },
  { /* 2344 */
    82,
    /* RCL8m1 */
  },
  { /* 2345 */
    82,
    /* RCL8mCL */
  },
  { /* 2346 */
    22,
    /* RCL8mi */
  },
  { /* 2347 */
    129,
    /* RCL8r1 */
  },
  { /* 2348 */
    129,
    /* RCL8rCL */
  },
  { /* 2349 */
    24,
    /* RCL8ri */
  },
  { /* 2350 */
    44,
    /* RCPPSm */
  },
  { /* 2351 */
    0,
    /*  */
  },
  { /* 2352 */
    45,
    /* RCPPSr */
  },
  { /* 2353 */
    0,
    /*  */
  },
  { /* 2354 */
    261,
    /* RCPSSm */
  },
  { /* 2355 */
    0,
    /*  */
  },
  { /* 2356 */
    287,
    /* RCPSSr */
  },
  { /* 2357 */
    0,
    /*  */
  },
  { /* 2358 */
    38,
    /* RCR16m1 */
  },
  { /* 2359 */
    38,
    /* RCR16mCL */
  },
  { /* 2360 */
    284,
    /* RCR16mi */
  },
  { /* 2361 */
    127,
    /* RCR16r1 */
  },
  { /* 2362 */
    127,
    /* RCR16rCL */
  },
  { /* 2363 */
    285,
    /* RCR16ri */
  },
  { /* 2364 */
    38,
    /* RCR32m1 */
  },
  { /* 2365 */
    38,
    /* RCR32mCL */
  },
  { /* 2366 */
    284,
    /* RCR32mi */
  },
  { /* 2367 */
    127,
    /* RCR32r1 */
  },
  { /* 2368 */
    127,
    /* RCR32rCL */
  },
  { /* 2369 */
    285,
    /* RCR32ri */
  },
  { /* 2370 */
    38,
    /* RCR64m1 */
  },
  { /* 2371 */
    38,
    /* RCR64mCL */
  },
  { /* 2372 */
    284,
    /* RCR64mi */
  },
  { /* 2373 */
    128,
    /* RCR64r1 */
  },
  { /* 2374 */
    128,
    /* RCR64rCL */
  },
  { /* 2375 */
    286,
    /* RCR64ri */
  },
  { /* 2376 */
    82,
    /* RCR8m1 */
  },
  { /* 2377 */
    82,
    /* RCR8mCL */
  },
  { /* 2378 */
    22,
    /* RCR8mi */
  },
  { /* 2379 */
    129,
    /* RCR8r1 */
  },
  { /* 2380 */
    129,
    /* RCR8rCL */
  },
  { /* 2381 */
    24,
    /* RCR8ri */
  },
  { /* 2382 */
    288,
    /* RDFSBASE */
  },
  { /* 2383 */
    79,
    /* RDFSBASE64 */
  },
  { /* 2384 */
    288,
    /* RDGSBASE */
  },
  { /* 2385 */
    79,
    /* RDGSBASE64 */
  },
  { /* 2386 */
    0,
    /* RDMSR */
  },
  { /* 2387 */
    0,
    /* RDPMC */
  },
  { /* 2388 */
    77,
    /* RDRAND16r */
  },
  { /* 2389 */
    77,
    /* RDRAND32r */
  },
  { /* 2390 */
    79,
    /* RDRAND64r */
  },
  { /* 2391 */
    77,
    /* RDSEED16r */
  },
  { /* 2392 */
    77,
    /* RDSEED32r */
  },
  { /* 2393 */
    79,
    /* RDSEED64r */
  },
  { /* 2394 */
    0,
    /* RDTSC */
  },
  { /* 2395 */
    0,
    /* RDTSCP */
  },
  { /* 2396 */
    0,
    /*  */
  },
  { /* 2397 */
    0,
    /*  */
  },
  { /* 2398 */
    0,
    /*  */
  },
  { /* 2399 */
    0,
    /*  */
  },
  { /* 2400 */
    0,
    /*  */
  },
  { /* 2401 */
    0,
    /*  */
  },
  { /* 2402 */
    0,
    /*  */
  },
  { /* 2403 */
    0,
    /*  */
  },
  { /* 2404 */
    0,
    /*  */
  },
  { /* 2405 */
    0,
    /*  */
  },
  { /* 2406 */
    0,
    /*  */
  },
  { /* 2407 */
    0,
    /*  */
  },
  { /* 2408 */
    0,
    /*  */
  },
  { /* 2409 */
    0,
    /*  */
  },
  { /* 2410 */
    0,
    /*  */
  },
  { /* 2411 */
    0,
    /*  */
  },
  { /* 2412 */
    0,
    /*  */
  },
  { /* 2413 */
    0,
    /*  */
  },
  { /* 2414 */
    0,
    /*  */
  },
  { /* 2415 */
    0,
    /*  */
  },
  { /* 2416 */
    0,
    /*  */
  },
  { /* 2417 */
    0,
    /*  */
  },
  { /* 2418 */
    0,
    /*  */
  },
  { /* 2419 */
    0,
    /*  */
  },
  { /* 2420 */
    0,
    /*  */
  },
  { /* 2421 */
    0,
    /*  */
  },
  { /* 2422 */
    0,
    /*  */
  },
  { /* 2423 */
    0,
    /*  */
  },
  { /* 2424 */
    0,
    /* REPNE_PREFIX */
  },
  { /* 2425 */
    0,
    /*  */
  },
  { /* 2426 */
    0,
    /*  */
  },
  { /* 2427 */
    0,
    /*  */
  },
  { /* 2428 */
    0,
    /*  */
  },
  { /* 2429 */
    0,
    /*  */
  },
  { /* 2430 */
    0,
    /*  */
  },
  { /* 2431 */
    0,
    /*  */
  },
  { /* 2432 */
    0,
    /* REP_PREFIX */
  },
  { /* 2433 */
    0,
    /*  */
  },
  { /* 2434 */
    0,
    /*  */
  },
  { /* 2435 */
    0,
    /*  */
  },
  { /* 2436 */
    0,
    /*  */
  },
  { /* 2437 */
    0,
    /*  */
  },
  { /* 2438 */
    0,
    /*  */
  },
  { /* 2439 */
    0,
    /*  */
  },
  { /* 2440 */
    199,
    /* RETIL */
  },
  { /* 2441 */
    199,
    /* RETIQ */
  },
  { /* 2442 */
    2,
    /* RETIW */
  },
  { /* 2443 */
    0,
    /* RETL */
  },
  { /* 2444 */
    0,
    /* RETQ */
  },
  { /* 2445 */
    0,
    /* RETW */
  },
  { /* 2446 */
    0,
    /* REX64_PREFIX */
  },
  { /* 2447 */
    38,
    /* ROL16m1 */
  },
  { /* 2448 */
    38,
    /* ROL16mCL */
  },
  { /* 2449 */
    284,
    /* ROL16mi */
  },
  { /* 2450 */
    127,
    /* ROL16r1 */
  },
  { /* 2451 */
    127,
    /* ROL16rCL */
  },
  { /* 2452 */
    285,
    /* ROL16ri */
  },
  { /* 2453 */
    38,
    /* ROL32m1 */
  },
  { /* 2454 */
    38,
    /* ROL32mCL */
  },
  { /* 2455 */
    284,
    /* ROL32mi */
  },
  { /* 2456 */
    127,
    /* ROL32r1 */
  },
  { /* 2457 */
    127,
    /* ROL32rCL */
  },
  { /* 2458 */
    285,
    /* ROL32ri */
  },
  { /* 2459 */
    38,
    /* ROL64m1 */
  },
  { /* 2460 */
    38,
    /* ROL64mCL */
  },
  { /* 2461 */
    284,
    /* ROL64mi */
  },
  { /* 2462 */
    128,
    /* ROL64r1 */
  },
  { /* 2463 */
    128,
    /* ROL64rCL */
  },
  { /* 2464 */
    286,
    /* ROL64ri */
  },
  { /* 2465 */
    82,
    /* ROL8m1 */
  },
  { /* 2466 */
    82,
    /* ROL8mCL */
  },
  { /* 2467 */
    22,
    /* ROL8mi */
  },
  { /* 2468 */
    129,
    /* ROL8r1 */
  },
  { /* 2469 */
    129,
    /* ROL8rCL */
  },
  { /* 2470 */
    24,
    /* ROL8ri */
  },
  { /* 2471 */
    38,
    /* ROR16m1 */
  },
  { /* 2472 */
    38,
    /* ROR16mCL */
  },
  { /* 2473 */
    284,
    /* ROR16mi */
  },
  { /* 2474 */
    127,
    /* ROR16r1 */
  },
  { /* 2475 */
    127,
    /* ROR16rCL */
  },
  { /* 2476 */
    285,
    /* ROR16ri */
  },
  { /* 2477 */
    38,
    /* ROR32m1 */
  },
  { /* 2478 */
    38,
    /* ROR32mCL */
  },
  { /* 2479 */
    284,
    /* ROR32mi */
  },
  { /* 2480 */
    127,
    /* ROR32r1 */
  },
  { /* 2481 */
    127,
    /* ROR32rCL */
  },
  { /* 2482 */
    285,
    /* ROR32ri */
  },
  { /* 2483 */
    38,
    /* ROR64m1 */
  },
  { /* 2484 */
    38,
    /* ROR64mCL */
  },
  { /* 2485 */
    284,
    /* ROR64mi */
  },
  { /* 2486 */
    128,
    /* ROR64r1 */
  },
  { /* 2487 */
    128,
    /* ROR64rCL */
  },
  { /* 2488 */
    286,
    /* ROR64ri */
  },
  { /* 2489 */
    82,
    /* ROR8m1 */
  },
  { /* 2490 */
    82,
    /* ROR8mCL */
  },
  { /* 2491 */
    22,
    /* ROR8mi */
  },
  { /* 2492 */
    129,
    /* ROR8r1 */
  },
  { /* 2493 */
    129,
    /* ROR8rCL */
  },
  { /* 2494 */
    24,
    /* ROR8ri */
  },
  { /* 2495 */
    289,
    /* RORX32mi */
  },
  { /* 2496 */
    290,
    /* RORX32ri */
  },
  { /* 2497 */
    291,
    /* RORX64mi */
  },
  { /* 2498 */
    292,
    /* RORX64ri */
  },
  { /* 2499 */
    46,
    /* ROUNDPDm */
  },
  { /* 2500 */
    47,
    /* ROUNDPDr */
  },
  { /* 2501 */
    46,
    /* ROUNDPSm */
  },
  { /* 2502 */
    47,
    /* ROUNDPSr */
  },
  { /* 2503 */
    293,
    /* ROUNDSDm */
  },
  { /* 2504 */
    294,
    /* ROUNDSDr */
  },
  { /* 2505 */
    0,
    /*  */
  },
  { /* 2506 */
    150,
    /* ROUNDSSm */
  },
  { /* 2507 */
    295,
    /* ROUNDSSr */
  },
  { /* 2508 */
    0,
    /*  */
  },
  { /* 2509 */
    0,
    /* RSM */
  },
  { /* 2510 */
    44,
    /* RSQRTPSm */
  },
  { /* 2511 */
    0,
    /*  */
  },
  { /* 2512 */
    45,
    /* RSQRTPSr */
  },
  { /* 2513 */
    0,
    /*  */
  },
  { /* 2514 */
    261,
    /* RSQRTSSm */
  },
  { /* 2515 */
    0,
    /*  */
  },
  { /* 2516 */
    287,
    /* RSQRTSSr */
  },
  { /* 2517 */
    0,
    /*  */
  },
  { /* 2518 */
    0,
    /* SAHF */
  },
  { /* 2519 */
    38,
    /* SAL16m1 */
  },
  { /* 2520 */
    38,
    /* SAL16mCL */
  },
  { /* 2521 */
    284,
    /* SAL16mi */
  },
  { /* 2522 */
    127,
    /* SAL16r1 */
  },
  { /* 2523 */
    127,
    /* SAL16rCL */
  },
  { /* 2524 */
    285,
    /* SAL16ri */
  },
  { /* 2525 */
    38,
    /* SAL32m1 */
  },
  { /* 2526 */
    38,
    /* SAL32mCL */
  },
  { /* 2527 */
    284,
    /* SAL32mi */
  },
  { /* 2528 */
    127,
    /* SAL32r1 */
  },
  { /* 2529 */
    127,
    /* SAL32rCL */
  },
  { /* 2530 */
    285,
    /* SAL32ri */
  },
  { /* 2531 */
    38,
    /* SAL64m1 */
  },
  { /* 2532 */
    38,
    /* SAL64mCL */
  },
  { /* 2533 */
    284,
    /* SAL64mi */
  },
  { /* 2534 */
    128,
    /* SAL64r1 */
  },
  { /* 2535 */
    128,
    /* SAL64rCL */
  },
  { /* 2536 */
    286,
    /* SAL64ri */
  },
  { /* 2537 */
    82,
    /* SAL8m1 */
  },
  { /* 2538 */
    82,
    /* SAL8mCL */
  },
  { /* 2539 */
    22,
    /* SAL8mi */
  },
  { /* 2540 */
    129,
    /* SAL8r1 */
  },
  { /* 2541 */
    129,
    /* SAL8rCL */
  },
  { /* 2542 */
    24,
    /* SAL8ri */
  },
  { /* 2543 */
    0,
    /* SALC */
  },
  { /* 2544 */
    38,
    /* SAR16m1 */
  },
  { /* 2545 */
    38,
    /* SAR16mCL */
  },
  { /* 2546 */
    284,
    /* SAR16mi */
  },
  { /* 2547 */
    127,
    /* SAR16r1 */
  },
  { /* 2548 */
    127,
    /* SAR16rCL */
  },
  { /* 2549 */
    285,
    /* SAR16ri */
  },
  { /* 2550 */
    38,
    /* SAR32m1 */
  },
  { /* 2551 */
    38,
    /* SAR32mCL */
  },
  { /* 2552 */
    284,
    /* SAR32mi */
  },
  { /* 2553 */
    127,
    /* SAR32r1 */
  },
  { /* 2554 */
    127,
    /* SAR32rCL */
  },
  { /* 2555 */
    285,
    /* SAR32ri */
  },
  { /* 2556 */
    38,
    /* SAR64m1 */
  },
  { /* 2557 */
    38,
    /* SAR64mCL */
  },
  { /* 2558 */
    284,
    /* SAR64mi */
  },
  { /* 2559 */
    128,
    /* SAR64r1 */
  },
  { /* 2560 */
    128,
    /* SAR64rCL */
  },
  { /* 2561 */
    286,
    /* SAR64ri */
  },
  { /* 2562 */
    82,
    /* SAR8m1 */
  },
  { /* 2563 */
    82,
    /* SAR8mCL */
  },
  { /* 2564 */
    22,
    /* SAR8mi */
  },
  { /* 2565 */
    129,
    /* SAR8r1 */
  },
  { /* 2566 */
    129,
    /* SAR8rCL */
  },
  { /* 2567 */
    24,
    /* SAR8ri */
  },
  { /* 2568 */
    54,
    /* SARX32rm */
  },
  { /* 2569 */
    55,
    /* SARX32rr */
  },
  { /* 2570 */
    56,
    /* SARX64rm */
  },
  { /* 2571 */
    57,
    /* SARX64rr */
  },
  { /* 2572 */
    2,
    /* SBB16i16 */
  },
  { /* 2573 */
    3,
    /* SBB16mi */
  },
  { /* 2574 */
    4,
    /* SBB16mi8 */
  },
  { /* 2575 */
    5,
    /* SBB16mr */
  },
  { /* 2576 */
    6,
    /* SBB16ri */
  },
  { /* 2577 */
    7,
    /* SBB16ri8 */
  },
  { /* 2578 */
    8,
    /* SBB16rm */
  },
  { /* 2579 */
    9,
    /* SBB16rr */
  },
  { /* 2580 */
    10,
    /* SBB16rr_REV */
  },
  { /* 2581 */
    2,
    /* SBB32i32 */
  },
  { /* 2582 */
    3,
    /* SBB32mi */
  },
  { /* 2583 */
    11,
    /* SBB32mi8 */
  },
  { /* 2584 */
    5,
    /* SBB32mr */
  },
  { /* 2585 */
    6,
    /* SBB32ri */
  },
  { /* 2586 */
    12,
    /* SBB32ri8 */
  },
  { /* 2587 */
    8,
    /* SBB32rm */
  },
  { /* 2588 */
    9,
    /* SBB32rr */
  },
  { /* 2589 */
    10,
    /* SBB32rr_REV */
  },
  { /* 2590 */
    13,
    /* SBB64i32 */
  },
  { /* 2591 */
    14,
    /* SBB64mi32 */
  },
  { /* 2592 */
    15,
    /* SBB64mi8 */
  },
  { /* 2593 */
    16,
    /* SBB64mr */
  },
  { /* 2594 */
    17,
    /* SBB64ri32 */
  },
  { /* 2595 */
    18,
    /* SBB64ri8 */
  },
  { /* 2596 */
    19,
    /* SBB64rm */
  },
  { /* 2597 */
    20,
    /* SBB64rr */
  },
  { /* 2598 */
    21,
    /* SBB64rr_REV */
  },
  { /* 2599 */
    1,
    /* SBB8i8 */
  },
  { /* 2600 */
    22,
    /* SBB8mi */
  },
  { /* 2601 */
    22,
    /* SBB8mi8 */
  },
  { /* 2602 */
    23,
    /* SBB8mr */
  },
  { /* 2603 */
    24,
    /* SBB8ri */
  },
  { /* 2604 */
    24,
    /* SBB8ri8 */
  },
  { /* 2605 */
    25,
    /* SBB8rm */
  },
  { /* 2606 */
    26,
    /* SBB8rr */
  },
  { /* 2607 */
    27,
    /* SBB8rr_REV */
  },
  { /* 2608 */
    149,
    /* SCASB */
  },
  { /* 2609 */
    152,
    /* SCASL */
  },
  { /* 2610 */
    296,
    /* SCASQ */
  },
  { /* 2611 */
    153,
    /* SCASW */
  },
  { /* 2612 */
    0,
    /*  */
  },
  { /* 2613 */
    0,
    /*  */
  },
  { /* 2614 */
    0,
    /*  */
  },
  { /* 2615 */
    0,
    /*  */
  },
  { /* 2616 */
    0,
    /*  */
  },
  { /* 2617 */
    0,
    /*  */
  },
  { /* 2618 */
    0,
    /*  */
  },
  { /* 2619 */
    0,
    /*  */
  },
  { /* 2620 */
    0,
    /*  */
  },
  { /* 2621 */
    0,
    /*  */
  },
  { /* 2622 */
    82,
    /* SETAEm */
  },
  { /* 2623 */
    130,
    /* SETAEr */
  },
  { /* 2624 */
    82,
    /* SETAm */
  },
  { /* 2625 */
    130,
    /* SETAr */
  },
  { /* 2626 */
    82,
    /* SETBEm */
  },
  { /* 2627 */
    130,
    /* SETBEr */
  },
  { /* 2628 */
    0,
    /*  */
  },
  { /* 2629 */
    0,
    /*  */
  },
  { /* 2630 */
    0,
    /*  */
  },
  { /* 2631 */
    0,
    /*  */
  },
  { /* 2632 */
    82,
    /* SETBm */
  },
  { /* 2633 */
    130,
    /* SETBr */
  },
  { /* 2634 */
    82,
    /* SETEm */
  },
  { /* 2635 */
    130,
    /* SETEr */
  },
  { /* 2636 */
    82,
    /* SETGEm */
  },
  { /* 2637 */
    130,
    /* SETGEr */
  },
  { /* 2638 */
    82,
    /* SETGm */
  },
  { /* 2639 */
    130,
    /* SETGr */
  },
  { /* 2640 */
    82,
    /* SETLEm */
  },
  { /* 2641 */
    130,
    /* SETLEr */
  },
  { /* 2642 */
    82,
    /* SETLm */
  },
  { /* 2643 */
    130,
    /* SETLr */
  },
  { /* 2644 */
    82,
    /* SETNEm */
  },
  { /* 2645 */
    130,
    /* SETNEr */
  },
  { /* 2646 */
    82,
    /* SETNOm */
  },
  { /* 2647 */
    130,
    /* SETNOr */
  },
  { /* 2648 */
    82,
    /* SETNPm */
  },
  { /* 2649 */
    130,
    /* SETNPr */
  },
  { /* 2650 */
    82,
    /* SETNSm */
  },
  { /* 2651 */
    130,
    /* SETNSr */
  },
  { /* 2652 */
    82,
    /* SETOm */
  },
  { /* 2653 */
    130,
    /* SETOr */
  },
  { /* 2654 */
    82,
    /* SETPm */
  },
  { /* 2655 */
    130,
    /* SETPr */
  },
  { /* 2656 */
    82,
    /* SETSm */
  },
  { /* 2657 */
    130,
    /* SETSr */
  },
  { /* 2658 */
    0,
    /* SFENCE */
  },
  { /* 2659 */
    138,
    /* SGDT16m */
  },
  { /* 2660 */
    138,
    /* SGDT32m */
  },
  { /* 2661 */
    139,
    /* SGDT64m */
  },
  { /* 2662 */
    30,
    /* SHA1MSG1rm */
  },
  { /* 2663 */
    31,
    /* SHA1MSG1rr */
  },
  { /* 2664 */
    30,
    /* SHA1MSG2rm */
  },
  { /* 2665 */
    31,
    /* SHA1MSG2rr */
  },
  { /* 2666 */
    30,
    /* SHA1NEXTErm */
  },
  { /* 2667 */
    31,
    /* SHA1NEXTErr */
  },
  { /* 2668 */
    66,
    /* SHA1RNDS4rmi */
  },
  { /* 2669 */
    67,
    /* SHA1RNDS4rri */
  },
  { /* 2670 */
    30,
    /* SHA256MSG1rm */
  },
  { /* 2671 */
    31,
    /* SHA256MSG1rr */
  },
  { /* 2672 */
    30,
    /* SHA256MSG2rm */
  },
  { /* 2673 */
    31,
    /* SHA256MSG2rr */
  },
  { /* 2674 */
    30,
    /* SHA256RNDS2rm */
  },
  { /* 2675 */
    31,
    /* SHA256RNDS2rr */
  },
  { /* 2676 */
    38,
    /* SHL16m1 */
  },
  { /* 2677 */
    38,
    /* SHL16mCL */
  },
  { /* 2678 */
    284,
    /* SHL16mi */
  },
  { /* 2679 */
    127,
    /* SHL16r1 */
  },
  { /* 2680 */
    127,
    /* SHL16rCL */
  },
  { /* 2681 */
    285,
    /* SHL16ri */
  },
  { /* 2682 */
    38,
    /* SHL32m1 */
  },
  { /* 2683 */
    38,
    /* SHL32mCL */
  },
  { /* 2684 */
    284,
    /* SHL32mi */
  },
  { /* 2685 */
    127,
    /* SHL32r1 */
  },
  { /* 2686 */
    127,
    /* SHL32rCL */
  },
  { /* 2687 */
    285,
    /* SHL32ri */
  },
  { /* 2688 */
    38,
    /* SHL64m1 */
  },
  { /* 2689 */
    38,
    /* SHL64mCL */
  },
  { /* 2690 */
    284,
    /* SHL64mi */
  },
  { /* 2691 */
    128,
    /* SHL64r1 */
  },
  { /* 2692 */
    128,
    /* SHL64rCL */
  },
  { /* 2693 */
    286,
    /* SHL64ri */
  },
  { /* 2694 */
    82,
    /* SHL8m1 */
  },
  { /* 2695 */
    82,
    /* SHL8mCL */
  },
  { /* 2696 */
    22,
    /* SHL8mi */
  },
  { /* 2697 */
    129,
    /* SHL8r1 */
  },
  { /* 2698 */
    129,
    /* SHL8rCL */
  },
  { /* 2699 */
    24,
    /* SHL8ri */
  },
  { /* 2700 */
    5,
    /* SHLD16mrCL */
  },
  { /* 2701 */
    297,
    /* SHLD16mri8 */
  },
  { /* 2702 */
    9,
    /* SHLD16rrCL */
  },
  { /* 2703 */
    298,
    /* SHLD16rri8 */
  },
  { /* 2704 */
    5,
    /* SHLD32mrCL */
  },
  { /* 2705 */
    297,
    /* SHLD32mri8 */
  },
  { /* 2706 */
    9,
    /* SHLD32rrCL */
  },
  { /* 2707 */
    298,
    /* SHLD32rri8 */
  },
  { /* 2708 */
    16,
    /* SHLD64mrCL */
  },
  { /* 2709 */
    299,
    /* SHLD64mri8 */
  },
  { /* 2710 */
    20,
    /* SHLD64rrCL */
  },
  { /* 2711 */
    300,
    /* SHLD64rri8 */
  },
  { /* 2712 */
    54,
    /* SHLX32rm */
  },
  { /* 2713 */
    55,
    /* SHLX32rr */
  },
  { /* 2714 */
    56,
    /* SHLX64rm */
  },
  { /* 2715 */
    57,
    /* SHLX64rr */
  },
  { /* 2716 */
    38,
    /* SHR16m1 */
  },
  { /* 2717 */
    38,
    /* SHR16mCL */
  },
  { /* 2718 */
    284,
    /* SHR16mi */
  },
  { /* 2719 */
    127,
    /* SHR16r1 */
  },
  { /* 2720 */
    127,
    /* SHR16rCL */
  },
  { /* 2721 */
    285,
    /* SHR16ri */
  },
  { /* 2722 */
    38,
    /* SHR32m1 */
  },
  { /* 2723 */
    38,
    /* SHR32mCL */
  },
  { /* 2724 */
    284,
    /* SHR32mi */
  },
  { /* 2725 */
    127,
    /* SHR32r1 */
  },
  { /* 2726 */
    127,
    /* SHR32rCL */
  },
  { /* 2727 */
    285,
    /* SHR32ri */
  },
  { /* 2728 */
    38,
    /* SHR64m1 */
  },
  { /* 2729 */
    38,
    /* SHR64mCL */
  },
  { /* 2730 */
    284,
    /* SHR64mi */
  },
  { /* 2731 */
    128,
    /* SHR64r1 */
  },
  { /* 2732 */
    128,
    /* SHR64rCL */
  },
  { /* 2733 */
    286,
    /* SHR64ri */
  },
  { /* 2734 */
    82,
    /* SHR8m1 */
  },
  { /* 2735 */
    82,
    /* SHR8mCL */
  },
  { /* 2736 */
    22,
    /* SHR8mi */
  },
  { /* 2737 */
    129,
    /* SHR8r1 */
  },
  { /* 2738 */
    129,
    /* SHR8rCL */
  },
  { /* 2739 */
    24,
    /* SHR8ri */
  },
  { /* 2740 */
    5,
    /* SHRD16mrCL */
  },
  { /* 2741 */
    297,
    /* SHRD16mri8 */
  },
  { /* 2742 */
    9,
    /* SHRD16rrCL */
  },
  { /* 2743 */
    298,
    /* SHRD16rri8 */
  },
  { /* 2744 */
    5,
    /* SHRD32mrCL */
  },
  { /* 2745 */
    297,
    /* SHRD32mri8 */
  },
  { /* 2746 */
    9,
    /* SHRD32rrCL */
  },
  { /* 2747 */
    298,
    /* SHRD32rri8 */
  },
  { /* 2748 */
    16,
    /* SHRD64mrCL */
  },
  { /* 2749 */
    299,
    /* SHRD64mri8 */
  },
  { /* 2750 */
    20,
    /* SHRD64rrCL */
  },
  { /* 2751 */
    300,
    /* SHRD64rri8 */
  },
  { /* 2752 */
    54,
    /* SHRX32rm */
  },
  { /* 2753 */
    55,
    /* SHRX32rr */
  },
  { /* 2754 */
    56,
    /* SHRX64rm */
  },
  { /* 2755 */
    57,
    /* SHRX64rr */
  },
  { /* 2756 */
    66,
    /* SHUFPDrmi */
  },
  { /* 2757 */
    67,
    /* SHUFPDrri */
  },
  { /* 2758 */
    66,
    /* SHUFPSrmi */
  },
  { /* 2759 */
    67,
    /* SHUFPSrri */
  },
  { /* 2760 */
    138,
    /* SIDT16m */
  },
  { /* 2761 */
    138,
    /* SIDT32m */
  },
  { /* 2762 */
    139,
    /* SIDT64m */
  },
  { /* 2763 */
    0,
    /* SIN_F */
  },
  { /* 2764 */
    0,
    /*  */
  },
  { /* 2765 */
    0,
    /*  */
  },
  { /* 2766 */
    0,
    /*  */
  },
  { /* 2767 */
    0,
    /* SKINIT */
  },
  { /* 2768 */
    38,
    /* SLDT16m */
  },
  { /* 2769 */
    77,
    /* SLDT16r */
  },
  { /* 2770 */
    77,
    /* SLDT32r */
  },
  { /* 2771 */
    38,
    /* SLDT64m */
  },
  { /* 2772 */
    79,
    /* SLDT64r */
  },
  { /* 2773 */
    38,
    /* SMSW16m */
  },
  { /* 2774 */
    77,
    /* SMSW16r */
  },
  { /* 2775 */
    77,
    /* SMSW32r */
  },
  { /* 2776 */
    79,
    /* SMSW64r */
  },
  { /* 2777 */
    44,
    /* SQRTPDm */
  },
  { /* 2778 */
    45,
    /* SQRTPDr */
  },
  { /* 2779 */
    44,
    /* SQRTPSm */
  },
  { /* 2780 */
    45,
    /* SQRTPSr */
  },
  { /* 2781 */
    257,
    /* SQRTSDm */
  },
  { /* 2782 */
    0,
    /*  */
  },
  { /* 2783 */
    301,
    /* SQRTSDr */
  },
  { /* 2784 */
    0,
    /*  */
  },
  { /* 2785 */
    261,
    /* SQRTSSm */
  },
  { /* 2786 */
    0,
    /*  */
  },
  { /* 2787 */
    287,
    /* SQRTSSr */
  },
  { /* 2788 */
    0,
    /*  */
  },
  { /* 2789 */
    0,
    /* SQRT_F */
  },
  { /* 2790 */
    0,
    /*  */
  },
  { /* 2791 */
    0,
    /*  */
  },
  { /* 2792 */
    0,
    /*  */
  },
  { /* 2793 */
    0,
    /* STAC */
  },
  { /* 2794 */
    0,
    /* STC */
  },
  { /* 2795 */
    0,
    /* STD */
  },
  { /* 2796 */
    0,
    /* STGI */
  },
  { /* 2797 */
    0,
    /* STI */
  },
  { /* 2798 */
    38,
    /* STMXCSR */
  },
  { /* 2799 */
    149,
    /* STOSB */
  },
  { /* 2800 */
    152,
    /* STOSL */
  },
  { /* 2801 */
    296,
    /* STOSQ */
  },
  { /* 2802 */
    153,
    /* STOSW */
  },
  { /* 2803 */
    77,
    /* STR16r */
  },
  { /* 2804 */
    77,
    /* STR32r */
  },
  { /* 2805 */
    79,
    /* STR64r */
  },
  { /* 2806 */
    38,
    /* STRm */
  },
  { /* 2807 */
    36,
    /* ST_F32m */
  },
  { /* 2808 */
    37,
    /* ST_F64m */
  },
  { /* 2809 */
    39,
    /* ST_FCOMPST0r */
  },
  { /* 2810 */
    39,
    /* ST_FCOMPST0r_alt */
  },
  { /* 2811 */
    39,
    /* ST_FCOMST0r */
  },
  { /* 2812 */
    36,
    /* ST_FP32m */
  },
  { /* 2813 */
    37,
    /* ST_FP64m */
  },
  { /* 2814 */
    189,
    /* ST_FP80m */
  },
  { /* 2815 */
    39,
    /* ST_FPNCEST0r */
  },
  { /* 2816 */
    39,
    /* ST_FPST0r */
  },
  { /* 2817 */
    39,
    /* ST_FPST0r_alt */
  },
  { /* 2818 */
    39,
    /* ST_FPrr */
  },
  { /* 2819 */
    39,
    /* ST_FXCHST0r */
  },
  { /* 2820 */
    39,
    /* ST_FXCHST0r_alt */
  },
  { /* 2821 */
    0,
    /*  */
  },
  { /* 2822 */
    0,
    /*  */
  },
  { /* 2823 */
    0,
    /*  */
  },
  { /* 2824 */
    0,
    /*  */
  },
  { /* 2825 */
    0,
    /*  */
  },
  { /* 2826 */
    0,
    /*  */
  },
  { /* 2827 */
    0,
    /*  */
  },
  { /* 2828 */
    0,
    /*  */
  },
  { /* 2829 */
    0,
    /*  */
  },
  { /* 2830 */
    0,
    /*  */
  },
  { /* 2831 */
    0,
    /*  */
  },
  { /* 2832 */
    39,
    /* ST_Frr */
  },
  { /* 2833 */
    2,
    /* SUB16i16 */
  },
  { /* 2834 */
    3,
    /* SUB16mi */
  },
  { /* 2835 */
    4,
    /* SUB16mi8 */
  },
  { /* 2836 */
    5,
    /* SUB16mr */
  },
  { /* 2837 */
    6,
    /* SUB16ri */
  },
  { /* 2838 */
    7,
    /* SUB16ri8 */
  },
  { /* 2839 */
    8,
    /* SUB16rm */
  },
  { /* 2840 */
    9,
    /* SUB16rr */
  },
  { /* 2841 */
    10,
    /* SUB16rr_REV */
  },
  { /* 2842 */
    2,
    /* SUB32i32 */
  },
  { /* 2843 */
    3,
    /* SUB32mi */
  },
  { /* 2844 */
    11,
    /* SUB32mi8 */
  },
  { /* 2845 */
    5,
    /* SUB32mr */
  },
  { /* 2846 */
    6,
    /* SUB32ri */
  },
  { /* 2847 */
    12,
    /* SUB32ri8 */
  },
  { /* 2848 */
    8,
    /* SUB32rm */
  },
  { /* 2849 */
    9,
    /* SUB32rr */
  },
  { /* 2850 */
    10,
    /* SUB32rr_REV */
  },
  { /* 2851 */
    13,
    /* SUB64i32 */
  },
  { /* 2852 */
    14,
    /* SUB64mi32 */
  },
  { /* 2853 */
    15,
    /* SUB64mi8 */
  },
  { /* 2854 */
    16,
    /* SUB64mr */
  },
  { /* 2855 */
    17,
    /* SUB64ri32 */
  },
  { /* 2856 */
    18,
    /* SUB64ri8 */
  },
  { /* 2857 */
    19,
    /* SUB64rm */
  },
  { /* 2858 */
    20,
    /* SUB64rr */
  },
  { /* 2859 */
    21,
    /* SUB64rr_REV */
  },
  { /* 2860 */
    1,
    /* SUB8i8 */
  },
  { /* 2861 */
    22,
    /* SUB8mi */
  },
  { /* 2862 */
    22,
    /* SUB8mi8 */
  },
  { /* 2863 */
    23,
    /* SUB8mr */
  },
  { /* 2864 */
    24,
    /* SUB8ri */
  },
  { /* 2865 */
    24,
    /* SUB8ri8 */
  },
  { /* 2866 */
    25,
    /* SUB8rm */
  },
  { /* 2867 */
    26,
    /* SUB8rr */
  },
  { /* 2868 */
    27,
    /* SUB8rr_REV */
  },
  { /* 2869 */
    30,
    /* SUBPDrm */
  },
  { /* 2870 */
    31,
    /* SUBPDrr */
  },
  { /* 2871 */
    30,
    /* SUBPSrm */
  },
  { /* 2872 */
    31,
    /* SUBPSrr */
  },
  { /* 2873 */
    36,
    /* SUBR_F32m */
  },
  { /* 2874 */
    37,
    /* SUBR_F64m */
  },
  { /* 2875 */
    38,
    /* SUBR_FI16m */
  },
  { /* 2876 */
    38,
    /* SUBR_FI32m */
  },
  { /* 2877 */
    39,
    /* SUBR_FPrST0 */
  },
  { /* 2878 */
    39,
    /* SUBR_FST0r */
  },
  { /* 2879 */
    0,
    /*  */
  },
  { /* 2880 */
    0,
    /*  */
  },
  { /* 2881 */
    0,
    /*  */
  },
  { /* 2882 */
    0,
    /*  */
  },
  { /* 2883 */
    0,
    /*  */
  },
  { /* 2884 */
    0,
    /*  */
  },
  { /* 2885 */
    0,
    /*  */
  },
  { /* 2886 */
    0,
    /*  */
  },
  { /* 2887 */
    0,
    /*  */
  },
  { /* 2888 */
    0,
    /*  */
  },
  { /* 2889 */
    0,
    /*  */
  },
  { /* 2890 */
    39,
    /* SUBR_FrST0 */
  },
  { /* 2891 */
    32,
    /* SUBSDrm */
  },
  { /* 2892 */
    0,
    /*  */
  },
  { /* 2893 */
    33,
    /* SUBSDrr */
  },
  { /* 2894 */
    0,
    /*  */
  },
  { /* 2895 */
    34,
    /* SUBSSrm */
  },
  { /* 2896 */
    0,
    /*  */
  },
  { /* 2897 */
    35,
    /* SUBSSrr */
  },
  { /* 2898 */
    0,
    /*  */
  },
  { /* 2899 */
    36,
    /* SUB_F32m */
  },
  { /* 2900 */
    37,
    /* SUB_F64m */
  },
  { /* 2901 */
    38,
    /* SUB_FI16m */
  },
  { /* 2902 */
    38,
    /* SUB_FI32m */
  },
  { /* 2903 */
    39,
    /* SUB_FPrST0 */
  },
  { /* 2904 */
    39,
    /* SUB_FST0r */
  },
  { /* 2905 */
    0,
    /*  */
  },
  { /* 2906 */
    0,
    /*  */
  },
  { /* 2907 */
    0,
    /*  */
  },
  { /* 2908 */
    0,
    /*  */
  },
  { /* 2909 */
    0,
    /*  */
  },
  { /* 2910 */
    0,
    /*  */
  },
  { /* 2911 */
    0,
    /*  */
  },
  { /* 2912 */
    0,
    /*  */
  },
  { /* 2913 */
    0,
    /*  */
  },
  { /* 2914 */
    0,
    /*  */
  },
  { /* 2915 */
    0,
    /*  */
  },
  { /* 2916 */
    0,
    /*  */
  },
  { /* 2917 */
    0,
    /*  */
  },
  { /* 2918 */
    0,
    /*  */
  },
  { /* 2919 */
    39,
    /* SUB_FrST0 */
  },
  { /* 2920 */
    0,
    /* SWAPGS */
  },
  { /* 2921 */
    0,
    /* SYSCALL */
  },
  { /* 2922 */
    0,
    /* SYSENTER */
  },
  { /* 2923 */
    0,
    /* SYSEXIT */
  },
  { /* 2924 */
    0,
    /* SYSEXIT64 */
  },
  { /* 2925 */
    0,
    /* SYSRET */
  },
  { /* 2926 */
    0,
    /* SYSRET64 */
  },
  { /* 2927 */
    62,
    /* T1MSKC32rm */
  },
  { /* 2928 */
    63,
    /* T1MSKC32rr */
  },
  { /* 2929 */
    64,
    /* T1MSKC64rm */
  },
  { /* 2930 */
    65,
    /* T1MSKC64rr */
  },
  { /* 2931 */
    0,
    /*  */
  },
  { /* 2932 */
    0,
    /*  */
  },
  { /* 2933 */
    0,
    /*  */
  },
  { /* 2934 */
    0,
    /*  */
  },
  { /* 2935 */
    0,
    /*  */
  },
  { /* 2936 */
    0,
    /*  */
  },
  { /* 2937 */
    0,
    /*  */
  },
  { /* 2938 */
    0,
    /*  */
  },
  { /* 2939 */
    0,
    /*  */
  },
  { /* 2940 */
    0,
    /*  */
  },
  { /* 2941 */
    0,
    /*  */
  },
  { /* 2942 */
    0,
    /*  */
  },
  { /* 2943 */
    0,
    /*  */
  },
  { /* 2944 */
    0,
    /*  */
  },
  { /* 2945 */
    0,
    /*  */
  },
  { /* 2946 */
    2,
    /* TEST16i16 */
  },
  { /* 2947 */
    3,
    /* TEST16mi */
  },
  { /* 2948 */
    3,
    /* TEST16mi_alt */
  },
  { /* 2949 */
    83,
    /* TEST16ri */
  },
  { /* 2950 */
    83,
    /* TEST16ri_alt */
  },
  { /* 2951 */
    68,
    /* TEST16rm */
  },
  { /* 2952 */
    73,
    /* TEST16rr */
  },
  { /* 2953 */
    2,
    /* TEST32i32 */
  },
  { /* 2954 */
    3,
    /* TEST32mi */
  },
  { /* 2955 */
    3,
    /* TEST32mi_alt */
  },
  { /* 2956 */
    83,
    /* TEST32ri */
  },
  { /* 2957 */
    83,
    /* TEST32ri_alt */
  },
  { /* 2958 */
    68,
    /* TEST32rm */
  },
  { /* 2959 */
    73,
    /* TEST32rr */
  },
  { /* 2960 */
    13,
    /* TEST64i32 */
  },
  { /* 2961 */
    14,
    /* TEST64mi32 */
  },
  { /* 2962 */
    14,
    /* TEST64mi32_alt */
  },
  { /* 2963 */
    84,
    /* TEST64ri32 */
  },
  { /* 2964 */
    84,
    /* TEST64ri32_alt */
  },
  { /* 2965 */
    42,
    /* TEST64rm */
  },
  { /* 2966 */
    76,
    /* TEST64rr */
  },
  { /* 2967 */
    1,
    /* TEST8i8 */
  },
  { /* 2968 */
    22,
    /* TEST8mi */
  },
  { /* 2969 */
    22,
    /* TEST8mi_alt */
  },
  { /* 2970 */
    85,
    /* TEST8ri */
  },
  { /* 2971 */
    0,
    /*  */
  },
  { /* 2972 */
    85,
    /* TEST8ri_alt */
  },
  { /* 2973 */
    86,
    /* TEST8rm */
  },
  { /* 2974 */
    87,
    /* TEST8rr */
  },
  { /* 2975 */
    0,
    /*  */
  },
  { /* 2976 */
    0,
    /*  */
  },
  { /* 2977 */
    0,
    /*  */
  },
  { /* 2978 */
    0,
    /*  */
  },
  { /* 2979 */
    0,
    /*  */
  },
  { /* 2980 */
    0,
    /*  */
  },
  { /* 2981 */
    0,
    /* TRAP */
  },
  { /* 2982 */
    0,
    /* TST_F */
  },
  { /* 2983 */
    0,
    /*  */
  },
  { /* 2984 */
    0,
    /*  */
  },
  { /* 2985 */
    0,
    /*  */
  },
  { /* 2986 */
    68,
    /* TZCNT16rm */
  },
  { /* 2987 */
    69,
    /* TZCNT16rr */
  },
  { /* 2988 */
    68,
    /* TZCNT32rm */
  },
  { /* 2989 */
    69,
    /* TZCNT32rr */
  },
  { /* 2990 */
    42,
    /* TZCNT64rm */
  },
  { /* 2991 */
    43,
    /* TZCNT64rr */
  },
  { /* 2992 */
    62,
    /* TZMSK32rm */
  },
  { /* 2993 */
    63,
    /* TZMSK32rr */
  },
  { /* 2994 */
    64,
    /* TZMSK64rm */
  },
  { /* 2995 */
    65,
    /* TZMSK64rr */
  },
  { /* 2996 */
    257,
    /* UCOMISDrm */
  },
  { /* 2997 */
    301,
    /* UCOMISDrr */
  },
  { /* 2998 */
    261,
    /* UCOMISSrm */
  },
  { /* 2999 */
    287,
    /* UCOMISSrr */
  },
  { /* 3000 */
    39,
    /* UCOM_FIPr */
  },
  { /* 3001 */
    39,
    /* UCOM_FIr */
  },
  { /* 3002 */
    0,
    /* UCOM_FPPr */
  },
  { /* 3003 */
    39,
    /* UCOM_FPr */
  },
  { /* 3004 */
    0,
    /*  */
  },
  { /* 3005 */
    0,
    /*  */
  },
  { /* 3006 */
    0,
    /*  */
  },
  { /* 3007 */
    0,
    /*  */
  },
  { /* 3008 */
    0,
    /*  */
  },
  { /* 3009 */
    0,
    /*  */
  },
  { /* 3010 */
    39,
    /* UCOM_Fr */
  },
  { /* 3011 */
    0,
    /* UD2B */
  },
  { /* 3012 */
    30,
    /* UNPCKHPDrm */
  },
  { /* 3013 */
    31,
    /* UNPCKHPDrr */
  },
  { /* 3014 */
    30,
    /* UNPCKHPSrm */
  },
  { /* 3015 */
    31,
    /* UNPCKHPSrr */
  },
  { /* 3016 */
    30,
    /* UNPCKLPDrm */
  },
  { /* 3017 */
    31,
    /* UNPCKLPDrr */
  },
  { /* 3018 */
    30,
    /* UNPCKLPSrm */
  },
  { /* 3019 */
    31,
    /* UNPCKLPSrr */
  },
  { /* 3020 */
    0,
    /*  */
  },
  { /* 3021 */
    302,
    /* VADDPDYrm */
  },
  { /* 3022 */
    303,
    /* VADDPDYrr */
  },
  { /* 3023 */
    304,
    /* VADDPDZ128rm */
  },
  { /* 3024 */
    305,
    /* VADDPDZ128rmb */
  },
  { /* 3025 */
    306,
    /* VADDPDZ128rmbk */
  },
  { /* 3026 */
    307,
    /* VADDPDZ128rmbkz */
  },
  { /* 3027 */
    308,
    /* VADDPDZ128rmk */
  },
  { /* 3028 */
    309,
    /* VADDPDZ128rmkz */
  },
  { /* 3029 */
    310,
    /* VADDPDZ128rr */
  },
  { /* 3030 */
    311,
    /* VADDPDZ128rrk */
  },
  { /* 3031 */
    312,
    /* VADDPDZ128rrkz */
  },
  { /* 3032 */
    313,
    /* VADDPDZ256rm */
  },
  { /* 3033 */
    314,
    /* VADDPDZ256rmb */
  },
  { /* 3034 */
    315,
    /* VADDPDZ256rmbk */
  },
  { /* 3035 */
    316,
    /* VADDPDZ256rmbkz */
  },
  { /* 3036 */
    317,
    /* VADDPDZ256rmk */
  },
  { /* 3037 */
    318,
    /* VADDPDZ256rmkz */
  },
  { /* 3038 */
    319,
    /* VADDPDZ256rr */
  },
  { /* 3039 */
    320,
    /* VADDPDZ256rrk */
  },
  { /* 3040 */
    321,
    /* VADDPDZ256rrkz */
  },
  { /* 3041 */
    322,
    /* VADDPDZrb */
  },
  { /* 3042 */
    323,
    /* VADDPDZrbk */
  },
  { /* 3043 */
    324,
    /* VADDPDZrbkz */
  },
  { /* 3044 */
    325,
    /* VADDPDZrm */
  },
  { /* 3045 */
    326,
    /* VADDPDZrmb */
  },
  { /* 3046 */
    327,
    /* VADDPDZrmbk */
  },
  { /* 3047 */
    328,
    /* VADDPDZrmbkz */
  },
  { /* 3048 */
    329,
    /* VADDPDZrmk */
  },
  { /* 3049 */
    330,
    /* VADDPDZrmkz */
  },
  { /* 3050 */
    331,
    /* VADDPDZrr */
  },
  { /* 3051 */
    332,
    /* VADDPDZrrk */
  },
  { /* 3052 */
    333,
    /* VADDPDZrrkz */
  },
  { /* 3053 */
    334,
    /* VADDPDrm */
  },
  { /* 3054 */
    335,
    /* VADDPDrr */
  },
  { /* 3055 */
    302,
    /* VADDPSYrm */
  },
  { /* 3056 */
    303,
    /* VADDPSYrr */
  },
  { /* 3057 */
    304,
    /* VADDPSZ128rm */
  },
  { /* 3058 */
    336,
    /* VADDPSZ128rmb */
  },
  { /* 3059 */
    337,
    /* VADDPSZ128rmbk */
  },
  { /* 3060 */
    338,
    /* VADDPSZ128rmbkz */
  },
  { /* 3061 */
    339,
    /* VADDPSZ128rmk */
  },
  { /* 3062 */
    340,
    /* VADDPSZ128rmkz */
  },
  { /* 3063 */
    310,
    /* VADDPSZ128rr */
  },
  { /* 3064 */
    341,
    /* VADDPSZ128rrk */
  },
  { /* 3065 */
    342,
    /* VADDPSZ128rrkz */
  },
  { /* 3066 */
    313,
    /* VADDPSZ256rm */
  },
  { /* 3067 */
    343,
    /* VADDPSZ256rmb */
  },
  { /* 3068 */
    344,
    /* VADDPSZ256rmbk */
  },
  { /* 3069 */
    345,
    /* VADDPSZ256rmbkz */
  },
  { /* 3070 */
    346,
    /* VADDPSZ256rmk */
  },
  { /* 3071 */
    347,
    /* VADDPSZ256rmkz */
  },
  { /* 3072 */
    319,
    /* VADDPSZ256rr */
  },
  { /* 3073 */
    348,
    /* VADDPSZ256rrk */
  },
  { /* 3074 */
    349,
    /* VADDPSZ256rrkz */
  },
  { /* 3075 */
    350,
    /* VADDPSZrb */
  },
  { /* 3076 */
    351,
    /* VADDPSZrbk */
  },
  { /* 3077 */
    352,
    /* VADDPSZrbkz */
  },
  { /* 3078 */
    325,
    /* VADDPSZrm */
  },
  { /* 3079 */
    353,
    /* VADDPSZrmb */
  },
  { /* 3080 */
    354,
    /* VADDPSZrmbk */
  },
  { /* 3081 */
    355,
    /* VADDPSZrmbkz */
  },
  { /* 3082 */
    356,
    /* VADDPSZrmk */
  },
  { /* 3083 */
    357,
    /* VADDPSZrmkz */
  },
  { /* 3084 */
    331,
    /* VADDPSZrr */
  },
  { /* 3085 */
    358,
    /* VADDPSZrrk */
  },
  { /* 3086 */
    359,
    /* VADDPSZrrkz */
  },
  { /* 3087 */
    334,
    /* VADDPSrm */
  },
  { /* 3088 */
    335,
    /* VADDPSrr */
  },
  { /* 3089 */
    0,
    /*  */
  },
  { /* 3090 */
    360,
    /* VADDSDZrm_Int */
  },
  { /* 3091 */
    361,
    /* VADDSDZrm_Intk */
  },
  { /* 3092 */
    362,
    /* VADDSDZrm_Intkz */
  },
  { /* 3093 */
    0,
    /*  */
  },
  { /* 3094 */
    363,
    /* VADDSDZrr_Int */
  },
  { /* 3095 */
    364,
    /* VADDSDZrr_Intk */
  },
  { /* 3096 */
    365,
    /* VADDSDZrr_Intkz */
  },
  { /* 3097 */
    366,
    /* VADDSDZrrb */
  },
  { /* 3098 */
    367,
    /* VADDSDZrrbk */
  },
  { /* 3099 */
    368,
    /* VADDSDZrrbkz */
  },
  { /* 3100 */
    369,
    /* VADDSDrm */
  },
  { /* 3101 */
    0,
    /*  */
  },
  { /* 3102 */
    370,
    /* VADDSDrr */
  },
  { /* 3103 */
    0,
    /*  */
  },
  { /* 3104 */
    0,
    /*  */
  },
  { /* 3105 */
    371,
    /* VADDSSZrm_Int */
  },
  { /* 3106 */
    372,
    /* VADDSSZrm_Intk */
  },
  { /* 3107 */
    373,
    /* VADDSSZrm_Intkz */
  },
  { /* 3108 */
    0,
    /*  */
  },
  { /* 3109 */
    374,
    /* VADDSSZrr_Int */
  },
  { /* 3110 */
    375,
    /* VADDSSZrr_Intk */
  },
  { /* 3111 */
    376,
    /* VADDSSZrr_Intkz */
  },
  { /* 3112 */
    377,
    /* VADDSSZrrb */
  },
  { /* 3113 */
    378,
    /* VADDSSZrrbk */
  },
  { /* 3114 */
    379,
    /* VADDSSZrrbkz */
  },
  { /* 3115 */
    380,
    /* VADDSSrm */
  },
  { /* 3116 */
    0,
    /*  */
  },
  { /* 3117 */
    381,
    /* VADDSSrr */
  },
  { /* 3118 */
    0,
    /*  */
  },
  { /* 3119 */
    302,
    /* VADDSUBPDYrm */
  },
  { /* 3120 */
    303,
    /* VADDSUBPDYrr */
  },
  { /* 3121 */
    334,
    /* VADDSUBPDrm */
  },
  { /* 3122 */
    335,
    /* VADDSUBPDrr */
  },
  { /* 3123 */
    302,
    /* VADDSUBPSYrm */
  },
  { /* 3124 */
    303,
    /* VADDSUBPSYrr */
  },
  { /* 3125 */
    334,
    /* VADDSUBPSrm */
  },
  { /* 3126 */
    335,
    /* VADDSUBPSrr */
  },
  { /* 3127 */
    334,
    /* VAESDECLASTrm */
  },
  { /* 3128 */
    335,
    /* VAESDECLASTrr */
  },
  { /* 3129 */
    334,
    /* VAESDECrm */
  },
  { /* 3130 */
    335,
    /* VAESDECrr */
  },
  { /* 3131 */
    334,
    /* VAESENCLASTrm */
  },
  { /* 3132 */
    335,
    /* VAESENCLASTrr */
  },
  { /* 3133 */
    334,
    /* VAESENCrm */
  },
  { /* 3134 */
    335,
    /* VAESENCrr */
  },
  { /* 3135 */
    44,
    /* VAESIMCrm */
  },
  { /* 3136 */
    45,
    /* VAESIMCrr */
  },
  { /* 3137 */
    46,
    /* VAESKEYGENASSIST128rm */
  },
  { /* 3138 */
    47,
    /* VAESKEYGENASSIST128rr */
  },
  { /* 3139 */
    382,
    /* VALIGNDrmi */
  },
  { /* 3140 */
    383,
    /* VALIGNDrri */
  },
  { /* 3141 */
    384,
    /* VALIGNDrrik */
  },
  { /* 3142 */
    385,
    /* VALIGNDrrikz */
  },
  { /* 3143 */
    382,
    /* VALIGNQrmi */
  },
  { /* 3144 */
    383,
    /* VALIGNQrri */
  },
  { /* 3145 */
    386,
    /* VALIGNQrrik */
  },
  { /* 3146 */
    387,
    /* VALIGNQrrikz */
  },
  { /* 3147 */
    302,
    /* VANDNPDYrm */
  },
  { /* 3148 */
    303,
    /* VANDNPDYrr */
  },
  { /* 3149 */
    334,
    /* VANDNPDrm */
  },
  { /* 3150 */
    335,
    /* VANDNPDrr */
  },
  { /* 3151 */
    302,
    /* VANDNPSYrm */
  },
  { /* 3152 */
    303,
    /* VANDNPSYrr */
  },
  { /* 3153 */
    334,
    /* VANDNPSrm */
  },
  { /* 3154 */
    335,
    /* VANDNPSrr */
  },
  { /* 3155 */
    302,
    /* VANDPDYrm */
  },
  { /* 3156 */
    303,
    /* VANDPDYrr */
  },
  { /* 3157 */
    334,
    /* VANDPDrm */
  },
  { /* 3158 */
    335,
    /* VANDPDrr */
  },
  { /* 3159 */
    302,
    /* VANDPSYrm */
  },
  { /* 3160 */
    303,
    /* VANDPSYrr */
  },
  { /* 3161 */
    334,
    /* VANDPSrm */
  },
  { /* 3162 */
    335,
    /* VANDPSrr */
  },
  { /* 3163 */
    0,
    /*  */
  },
  { /* 3164 */
    304,
    /* VBLENDMPDZ128rm */
  },
  { /* 3165 */
    305,
    /* VBLENDMPDZ128rmb */
  },
  { /* 3166 */
    307,
    /* VBLENDMPDZ128rmbk */
  },
  { /* 3167 */
    309,
    /* VBLENDMPDZ128rmk */
  },
  { /* 3168 */
    309,
    /* VBLENDMPDZ128rmkz */
  },
  { /* 3169 */
    310,
    /* VBLENDMPDZ128rr */
  },
  { /* 3170 */
    312,
    /* VBLENDMPDZ128rrk */
  },
  { /* 3171 */
    312,
    /* VBLENDMPDZ128rrkz */
  },
  { /* 3172 */
    313,
    /* VBLENDMPDZ256rm */
  },
  { /* 3173 */
    314,
    /* VBLENDMPDZ256rmb */
  },
  { /* 3174 */
    316,
    /* VBLENDMPDZ256rmbk */
  },
  { /* 3175 */
    318,
    /* VBLENDMPDZ256rmk */
  },
  { /* 3176 */
    318,
    /* VBLENDMPDZ256rmkz */
  },
  { /* 3177 */
    319,
    /* VBLENDMPDZ256rr */
  },
  { /* 3178 */
    321,
    /* VBLENDMPDZ256rrk */
  },
  { /* 3179 */
    321,
    /* VBLENDMPDZ256rrkz */
  },
  { /* 3180 */
    325,
    /* VBLENDMPDZrm */
  },
  { /* 3181 */
    326,
    /* VBLENDMPDZrmb */
  },
  { /* 3182 */
    328,
    /* VBLENDMPDZrmbk */
  },
  { /* 3183 */
    330,
    /* VBLENDMPDZrmk */
  },
  { /* 3184 */
    330,
    /* VBLENDMPDZrmkz */
  },
  { /* 3185 */
    331,
    /* VBLENDMPDZrr */
  },
  { /* 3186 */
    333,
    /* VBLENDMPDZrrk */
  },
  { /* 3187 */
    333,
    /* VBLENDMPDZrrkz */
  },
  { /* 3188 */
    304,
    /* VBLENDMPSZ128rm */
  },
  { /* 3189 */
    336,
    /* VBLENDMPSZ128rmb */
  },
  { /* 3190 */
    338,
    /* VBLENDMPSZ128rmbk */
  },
  { /* 3191 */
    340,
    /* VBLENDMPSZ128rmk */
  },
  { /* 3192 */
    340,
    /* VBLENDMPSZ128rmkz */
  },
  { /* 3193 */
    310,
    /* VBLENDMPSZ128rr */
  },
  { /* 3194 */
    342,
    /* VBLENDMPSZ128rrk */
  },
  { /* 3195 */
    342,
    /* VBLENDMPSZ128rrkz */
  },
  { /* 3196 */
    313,
    /* VBLENDMPSZ256rm */
  },
  { /* 3197 */
    343,
    /* VBLENDMPSZ256rmb */
  },
  { /* 3198 */
    345,
    /* VBLENDMPSZ256rmbk */
  },
  { /* 3199 */
    347,
    /* VBLENDMPSZ256rmk */
  },
  { /* 3200 */
    347,
    /* VBLENDMPSZ256rmkz */
  },
  { /* 3201 */
    319,
    /* VBLENDMPSZ256rr */
  },
  { /* 3202 */
    349,
    /* VBLENDMPSZ256rrk */
  },
  { /* 3203 */
    349,
    /* VBLENDMPSZ256rrkz */
  },
  { /* 3204 */
    325,
    /* VBLENDMPSZrm */
  },
  { /* 3205 */
    353,
    /* VBLENDMPSZrmb */
  },
  { /* 3206 */
    355,
    /* VBLENDMPSZrmbk */
  },
  { /* 3207 */
    357,
    /* VBLENDMPSZrmk */
  },
  { /* 3208 */
    357,
    /* VBLENDMPSZrmkz */
  },
  { /* 3209 */
    331,
    /* VBLENDMPSZrr */
  },
  { /* 3210 */
    359,
    /* VBLENDMPSZrrk */
  },
  { /* 3211 */
    359,
    /* VBLENDMPSZrrkz */
  },
  { /* 3212 */
    388,
    /* VBLENDPDYrmi */
  },
  { /* 3213 */
    389,
    /* VBLENDPDYrri */
  },
  { /* 3214 */
    390,
    /* VBLENDPDrmi */
  },
  { /* 3215 */
    391,
    /* VBLENDPDrri */
  },
  { /* 3216 */
    388,
    /* VBLENDPSYrmi */
  },
  { /* 3217 */
    389,
    /* VBLENDPSYrri */
  },
  { /* 3218 */
    390,
    /* VBLENDPSrmi */
  },
  { /* 3219 */
    391,
    /* VBLENDPSrri */
  },
  { /* 3220 */
    392,
    /* VBLENDVPDYrm */
  },
  { /* 3221 */
    393,
    /* VBLENDVPDYrr */
  },
  { /* 3222 */
    394,
    /* VBLENDVPDrm */
  },
  { /* 3223 */
    395,
    /* VBLENDVPDrr */
  },
  { /* 3224 */
    392,
    /* VBLENDVPSYrm */
  },
  { /* 3225 */
    393,
    /* VBLENDVPSYrr */
  },
  { /* 3226 */
    394,
    /* VBLENDVPSrm */
  },
  { /* 3227 */
    395,
    /* VBLENDVPSrr */
  },
  { /* 3228 */
    396,
    /* VBROADCASTF128 */
  },
  { /* 3229 */
    397,
    /* VBROADCASTI32X4krm */
  },
  { /* 3230 */
    398,
    /* VBROADCASTI32X4rm */
  },
  { /* 3231 */
    399,
    /* VBROADCASTI64X4krm */
  },
  { /* 3232 */
    400,
    /* VBROADCASTI64X4rm */
  },
  { /* 3233 */
    401,
    /* VBROADCASTSDYrm */
  },
  { /* 3234 */
    402,
    /* VBROADCASTSDYrr */
  },
  { /* 3235 */
    403,
    /* VBROADCASTSDZ256m */
  },
  { /* 3236 */
    404,
    /* VBROADCASTSDZ256mk */
  },
  { /* 3237 */
    405,
    /* VBROADCASTSDZ256mkz */
  },
  { /* 3238 */
    406,
    /* VBROADCASTSDZ256r */
  },
  { /* 3239 */
    407,
    /* VBROADCASTSDZ256rk */
  },
  { /* 3240 */
    408,
    /* VBROADCASTSDZ256rkz */
  },
  { /* 3241 */
    409,
    /* VBROADCASTSDZm */
  },
  { /* 3242 */
    410,
    /* VBROADCASTSDZmk */
  },
  { /* 3243 */
    411,
    /* VBROADCASTSDZmkz */
  },
  { /* 3244 */
    412,
    /* VBROADCASTSDZr */
  },
  { /* 3245 */
    413,
    /* VBROADCASTSDZrk */
  },
  { /* 3246 */
    414,
    /* VBROADCASTSDZrkz */
  },
  { /* 3247 */
    415,
    /* VBROADCASTSSYrm */
  },
  { /* 3248 */
    402,
    /* VBROADCASTSSYrr */
  },
  { /* 3249 */
    416,
    /* VBROADCASTSSZ128m */
  },
  { /* 3250 */
    417,
    /* VBROADCASTSSZ128mk */
  },
  { /* 3251 */
    418,
    /* VBROADCASTSSZ128mkz */
  },
  { /* 3252 */
    419,
    /* VBROADCASTSSZ128r */
  },
  { /* 3253 */
    420,
    /* VBROADCASTSSZ128rk */
  },
  { /* 3254 */
    421,
    /* VBROADCASTSSZ128rkz */
  },
  { /* 3255 */
    422,
    /* VBROADCASTSSZ256m */
  },
  { /* 3256 */
    423,
    /* VBROADCASTSSZ256mk */
  },
  { /* 3257 */
    424,
    /* VBROADCASTSSZ256mkz */
  },
  { /* 3258 */
    425,
    /* VBROADCASTSSZ256r */
  },
  { /* 3259 */
    426,
    /* VBROADCASTSSZ256rk */
  },
  { /* 3260 */
    427,
    /* VBROADCASTSSZ256rkz */
  },
  { /* 3261 */
    428,
    /* VBROADCASTSSZm */
  },
  { /* 3262 */
    429,
    /* VBROADCASTSSZmk */
  },
  { /* 3263 */
    430,
    /* VBROADCASTSSZmkz */
  },
  { /* 3264 */
    431,
    /* VBROADCASTSSZr */
  },
  { /* 3265 */
    432,
    /* VBROADCASTSSZrk */
  },
  { /* 3266 */
    433,
    /* VBROADCASTSSZrkz */
  },
  { /* 3267 */
    434,
    /* VBROADCASTSSrm */
  },
  { /* 3268 */
    45,
    /* VBROADCASTSSrr */
  },
  { /* 3269 */
    435,
    /* VCMPPDYrmi */
  },
  { /* 3270 */
    0,
    /*  */
  },
  { /* 3271 */
    436,
    /* VCMPPDYrri */
  },
  { /* 3272 */
    0,
    /*  */
  },
  { /* 3273 */
    437,
    /* VCMPPDZrmi */
  },
  { /* 3274 */
    0,
    /*  */
  },
  { /* 3275 */
    438,
    /* VCMPPDZrri */
  },
  { /* 3276 */
    0,
    /*  */
  },
  { /* 3277 */
    439,
    /* VCMPPDZrrib */
  },
  { /* 3278 */
    0,
    /*  */
  },
  { /* 3279 */
    440,
    /* VCMPPDrmi */
  },
  { /* 3280 */
    0,
    /*  */
  },
  { /* 3281 */
    441,
    /* VCMPPDrri */
  },
  { /* 3282 */
    0,
    /*  */
  },
  { /* 3283 */
    435,
    /* VCMPPSYrmi */
  },
  { /* 3284 */
    0,
    /*  */
  },
  { /* 3285 */
    436,
    /* VCMPPSYrri */
  },
  { /* 3286 */
    0,
    /*  */
  },
  { /* 3287 */
    442,
    /* VCMPPSZrmi */
  },
  { /* 3288 */
    0,
    /*  */
  },
  { /* 3289 */
    443,
    /* VCMPPSZrri */
  },
  { /* 3290 */
    0,
    /*  */
  },
  { /* 3291 */
    444,
    /* VCMPPSZrrib */
  },
  { /* 3292 */
    0,
    /*  */
  },
  { /* 3293 */
    440,
    /* VCMPPSrmi */
  },
  { /* 3294 */
    0,
    /*  */
  },
  { /* 3295 */
    441,
    /* VCMPPSrri */
  },
  { /* 3296 */
    0,
    /*  */
  },
  { /* 3297 */
    445,
    /* VCMPSDZrm */
  },
  { /* 3298 */
    0,
    /*  */
  },
  { /* 3299 */
    446,
    /* VCMPSDZrr */
  },
  { /* 3300 */
    0,
    /*  */
  },
  { /* 3301 */
    447,
    /* VCMPSDrm */
  },
  { /* 3302 */
    0,
    /*  */
  },
  { /* 3303 */
    448,
    /* VCMPSDrr */
  },
  { /* 3304 */
    0,
    /*  */
  },
  { /* 3305 */
    449,
    /* VCMPSSZrm */
  },
  { /* 3306 */
    0,
    /*  */
  },
  { /* 3307 */
    450,
    /* VCMPSSZrr */
  },
  { /* 3308 */
    0,
    /*  */
  },
  { /* 3309 */
    451,
    /* VCMPSSrm */
  },
  { /* 3310 */
    0,
    /*  */
  },
  { /* 3311 */
    452,
    /* VCMPSSrr */
  },
  { /* 3312 */
    0,
    /*  */
  },
  { /* 3313 */
    453,
    /* VCOMISDZrm */
  },
  { /* 3314 */
    454,
    /* VCOMISDZrr */
  },
  { /* 3315 */
    44,
    /* VCOMISDrm */
  },
  { /* 3316 */
    45,
    /* VCOMISDrr */
  },
  { /* 3317 */
    455,
    /* VCOMISSZrm */
  },
  { /* 3318 */
    419,
    /* VCOMISSZrr */
  },
  { /* 3319 */
    44,
    /* VCOMISSrm */
  },
  { /* 3320 */
    45,
    /* VCOMISSrr */
  },
  { /* 3321 */
    456,
    /* VCOMPRESSPDZ128mrk */
  },
  { /* 3322 */
    457,
    /* VCOMPRESSPDZ128rrk */
  },
  { /* 3323 */
    458,
    /* VCOMPRESSPDZ128rrkz */
  },
  { /* 3324 */
    459,
    /* VCOMPRESSPDZ256mrk */
  },
  { /* 3325 */
    460,
    /* VCOMPRESSPDZ256rrk */
  },
  { /* 3326 */
    461,
    /* VCOMPRESSPDZ256rrkz */
  },
  { /* 3327 */
    462,
    /* VCOMPRESSPDZmrk */
  },
  { /* 3328 */
    463,
    /* VCOMPRESSPDZrrk */
  },
  { /* 3329 */
    464,
    /* VCOMPRESSPDZrrkz */
  },
  { /* 3330 */
    465,
    /* VCOMPRESSPSZ128mrk */
  },
  { /* 3331 */
    466,
    /* VCOMPRESSPSZ128rrk */
  },
  { /* 3332 */
    467,
    /* VCOMPRESSPSZ128rrkz */
  },
  { /* 3333 */
    468,
    /* VCOMPRESSPSZ256mrk */
  },
  { /* 3334 */
    469,
    /* VCOMPRESSPSZ256rrk */
  },
  { /* 3335 */
    470,
    /* VCOMPRESSPSZ256rrkz */
  },
  { /* 3336 */
    471,
    /* VCOMPRESSPSZmrk */
  },
  { /* 3337 */
    472,
    /* VCOMPRESSPSZrrk */
  },
  { /* 3338 */
    473,
    /* VCOMPRESSPSZrrkz */
  },
  { /* 3339 */
    396,
    /* VCVTDQ2PDYrm */
  },
  { /* 3340 */
    402,
    /* VCVTDQ2PDYrr */
  },
  { /* 3341 */
    400,
    /* VCVTDQ2PDZrm */
  },
  { /* 3342 */
    474,
    /* VCVTDQ2PDZrr */
  },
  { /* 3343 */
    105,
    /* VCVTDQ2PDrm */
  },
  { /* 3344 */
    45,
    /* VCVTDQ2PDrr */
  },
  { /* 3345 */
    475,
    /* VCVTDQ2PSYrm */
  },
  { /* 3346 */
    476,
    /* VCVTDQ2PSYrr */
  },
  { /* 3347 */
    477,
    /* VCVTDQ2PSZrm */
  },
  { /* 3348 */
    478,
    /* VCVTDQ2PSZrr */
  },
  { /* 3349 */
    479,
    /* VCVTDQ2PSZrrb */
  },
  { /* 3350 */
    44,
    /* VCVTDQ2PSrm */
  },
  { /* 3351 */
    45,
    /* VCVTDQ2PSrr */
  },
  { /* 3352 */
    44,
    /* VCVTPD2DQXrm */
  },
  { /* 3353 */
    480,
    /* VCVTPD2DQYrm */
  },
  { /* 3354 */
    481,
    /* VCVTPD2DQYrr */
  },
  { /* 3355 */
    482,
    /* VCVTPD2DQZrm */
  },
  { /* 3356 */
    483,
    /* VCVTPD2DQZrr */
  },
  { /* 3357 */
    484,
    /* VCVTPD2DQZrrb */
  },
  { /* 3358 */
    45,
    /* VCVTPD2DQrr */
  },
  { /* 3359 */
    44,
    /* VCVTPD2PSXrm */
  },
  { /* 3360 */
    480,
    /* VCVTPD2PSYrm */
  },
  { /* 3361 */
    481,
    /* VCVTPD2PSYrr */
  },
  { /* 3362 */
    482,
    /* VCVTPD2PSZrm */
  },
  { /* 3363 */
    483,
    /* VCVTPD2PSZrr */
  },
  { /* 3364 */
    484,
    /* VCVTPD2PSZrrb */
  },
  { /* 3365 */
    45,
    /* VCVTPD2PSrr */
  },
  { /* 3366 */
    482,
    /* VCVTPD2UDQZrm */
  },
  { /* 3367 */
    483,
    /* VCVTPD2UDQZrr */
  },
  { /* 3368 */
    484,
    /* VCVTPD2UDQZrrb */
  },
  { /* 3369 */
    396,
    /* VCVTPH2PSYrm */
  },
  { /* 3370 */
    402,
    /* VCVTPH2PSYrr */
  },
  { /* 3371 */
    400,
    /* VCVTPH2PSZrm */
  },
  { /* 3372 */
    474,
    /* VCVTPH2PSZrr */
  },
  { /* 3373 */
    106,
    /* VCVTPH2PSrm */
  },
  { /* 3374 */
    45,
    /* VCVTPH2PSrr */
  },
  { /* 3375 */
    475,
    /* VCVTPS2DQYrm */
  },
  { /* 3376 */
    476,
    /* VCVTPS2DQYrr */
  },
  { /* 3377 */
    477,
    /* VCVTPS2DQZrm */
  },
  { /* 3378 */
    478,
    /* VCVTPS2DQZrr */
  },
  { /* 3379 */
    479,
    /* VCVTPS2DQZrrb */
  },
  { /* 3380 */
    44,
    /* VCVTPS2DQrm */
  },
  { /* 3381 */
    45,
    /* VCVTPS2DQrr */
  },
  { /* 3382 */
    396,
    /* VCVTPS2PDYrm */
  },
  { /* 3383 */
    402,
    /* VCVTPS2PDYrr */
  },
  { /* 3384 */
    400,
    /* VCVTPS2PDZrm */
  },
  { /* 3385 */
    474,
    /* VCVTPS2PDZrr */
  },
  { /* 3386 */
    106,
    /* VCVTPS2PDrm */
  },
  { /* 3387 */
    45,
    /* VCVTPS2PDrr */
  },
  { /* 3388 */
    485,
    /* VCVTPS2PHYmr */
  },
  { /* 3389 */
    486,
    /* VCVTPS2PHYrr */
  },
  { /* 3390 */
    487,
    /* VCVTPS2PHZmr */
  },
  { /* 3391 */
    488,
    /* VCVTPS2PHZrr */
  },
  { /* 3392 */
    489,
    /* VCVTPS2PHmr */
  },
  { /* 3393 */
    490,
    /* VCVTPS2PHrr */
  },
  { /* 3394 */
    477,
    /* VCVTPS2UDQZrm */
  },
  { /* 3395 */
    478,
    /* VCVTPS2UDQZrr */
  },
  { /* 3396 */
    479,
    /* VCVTPS2UDQZrrb */
  },
  { /* 3397 */
    491,
    /* VCVTSD2SI64Zrm */
  },
  { /* 3398 */
    492,
    /* VCVTSD2SI64Zrr */
  },
  { /* 3399 */
    107,
    /* VCVTSD2SI64rm */
  },
  { /* 3400 */
    108,
    /* VCVTSD2SI64rr */
  },
  { /* 3401 */
    493,
    /* VCVTSD2SIZrm */
  },
  { /* 3402 */
    494,
    /* VCVTSD2SIZrr */
  },
  { /* 3403 */
    109,
    /* VCVTSD2SIrm */
  },
  { /* 3404 */
    110,
    /* VCVTSD2SIrr */
  },
  { /* 3405 */
    495,
    /* VCVTSD2SSZrm */
  },
  { /* 3406 */
    496,
    /* VCVTSD2SSZrr */
  },
  { /* 3407 */
    497,
    /* VCVTSD2SSrm */
  },
  { /* 3408 */
    498,
    /* VCVTSD2SSrr */
  },
  { /* 3409 */
    491,
    /* VCVTSD2USI64Zrm */
  },
  { /* 3410 */
    492,
    /* VCVTSD2USI64Zrr */
  },
  { /* 3411 */
    493,
    /* VCVTSD2USIZrm */
  },
  { /* 3412 */
    494,
    /* VCVTSD2USIZrr */
  },
  { /* 3413 */
    499,
    /* VCVTSI2SD64rm */
  },
  { /* 3414 */
    500,
    /* VCVTSI2SD64rr */
  },
  { /* 3415 */
    501,
    /* VCVTSI2SDZrm */
  },
  { /* 3416 */
    502,
    /* VCVTSI2SDZrr */
  },
  { /* 3417 */
    499,
    /* VCVTSI2SDrm */
  },
  { /* 3418 */
    503,
    /* VCVTSI2SDrr */
  },
  { /* 3419 */
    504,
    /* VCVTSI2SS64rm */
  },
  { /* 3420 */
    505,
    /* VCVTSI2SS64rr */
  },
  { /* 3421 */
    506,
    /* VCVTSI2SSZrm */
  },
  { /* 3422 */
    507,
    /* VCVTSI2SSZrr */
  },
  { /* 3423 */
    504,
    /* VCVTSI2SSrm */
  },
  { /* 3424 */
    508,
    /* VCVTSI2SSrr */
  },
  { /* 3425 */
    509,
    /* VCVTSI642SDZrm */
  },
  { /* 3426 */
    510,
    /* VCVTSI642SDZrr */
  },
  { /* 3427 */
    511,
    /* VCVTSI642SSZrm */
  },
  { /* 3428 */
    512,
    /* VCVTSI642SSZrr */
  },
  { /* 3429 */
    513,
    /* VCVTSS2SDZrm */
  },
  { /* 3430 */
    514,
    /* VCVTSS2SDZrr */
  },
  { /* 3431 */
    515,
    /* VCVTSS2SDrm */
  },
  { /* 3432 */
    516,
    /* VCVTSS2SDrr */
  },
  { /* 3433 */
    517,
    /* VCVTSS2SI64Zrm */
  },
  { /* 3434 */
    518,
    /* VCVTSS2SI64Zrr */
  },
  { /* 3435 */
    121,
    /* VCVTSS2SI64rm */
  },
  { /* 3436 */
    108,
    /* VCVTSS2SI64rr */
  },
  { /* 3437 */
    519,
    /* VCVTSS2SIZrm */
  },
  { /* 3438 */
    520,
    /* VCVTSS2SIZrr */
  },
  { /* 3439 */
    122,
    /* VCVTSS2SIrm */
  },
  { /* 3440 */
    110,
    /* VCVTSS2SIrr */
  },
  { /* 3441 */
    517,
    /* VCVTSS2USI64Zrm */
  },
  { /* 3442 */
    518,
    /* VCVTSS2USI64Zrr */
  },
  { /* 3443 */
    519,
    /* VCVTSS2USIZrm */
  },
  { /* 3444 */
    520,
    /* VCVTSS2USIZrr */
  },
  { /* 3445 */
    44,
    /* VCVTTPD2DQXrm */
  },
  { /* 3446 */
    480,
    /* VCVTTPD2DQYrm */
  },
  { /* 3447 */
    481,
    /* VCVTTPD2DQYrr */
  },
  { /* 3448 */
    482,
    /* VCVTTPD2DQZrm */
  },
  { /* 3449 */
    483,
    /* VCVTTPD2DQZrr */
  },
  { /* 3450 */
    45,
    /* VCVTTPD2DQrr */
  },
  { /* 3451 */
    482,
    /* VCVTTPD2UDQZrm */
  },
  { /* 3452 */
    483,
    /* VCVTTPD2UDQZrr */
  },
  { /* 3453 */
    475,
    /* VCVTTPS2DQYrm */
  },
  { /* 3454 */
    476,
    /* VCVTTPS2DQYrr */
  },
  { /* 3455 */
    477,
    /* VCVTTPS2DQZrm */
  },
  { /* 3456 */
    478,
    /* VCVTTPS2DQZrr */
  },
  { /* 3457 */
    44,
    /* VCVTTPS2DQrm */
  },
  { /* 3458 */
    45,
    /* VCVTTPS2DQrr */
  },
  { /* 3459 */
    477,
    /* VCVTTPS2UDQZrm */
  },
  { /* 3460 */
    478,
    /* VCVTTPS2UDQZrr */
  },
  { /* 3461 */
    491,
    /* VCVTTSD2SI64Zrm */
  },
  { /* 3462 */
    521,
    /* VCVTTSD2SI64Zrr */
  },
  { /* 3463 */
    107,
    /* VCVTTSD2SI64rm */
  },
  { /* 3464 */
    123,
    /* VCVTTSD2SI64rr */
  },
  { /* 3465 */
    493,
    /* VCVTTSD2SIZrm */
  },
  { /* 3466 */
    522,
    /* VCVTTSD2SIZrr */
  },
  { /* 3467 */
    109,
    /* VCVTTSD2SIrm */
  },
  { /* 3468 */
    124,
    /* VCVTTSD2SIrr */
  },
  { /* 3469 */
    491,
    /* VCVTTSD2USI64Zrm */
  },
  { /* 3470 */
    521,
    /* VCVTTSD2USI64Zrr */
  },
  { /* 3471 */
    493,
    /* VCVTTSD2USIZrm */
  },
  { /* 3472 */
    522,
    /* VCVTTSD2USIZrr */
  },
  { /* 3473 */
    517,
    /* VCVTTSS2SI64Zrm */
  },
  { /* 3474 */
    523,
    /* VCVTTSS2SI64Zrr */
  },
  { /* 3475 */
    121,
    /* VCVTTSS2SI64rm */
  },
  { /* 3476 */
    125,
    /* VCVTTSS2SI64rr */
  },
  { /* 3477 */
    519,
    /* VCVTTSS2SIZrm */
  },
  { /* 3478 */
    524,
    /* VCVTTSS2SIZrr */
  },
  { /* 3479 */
    122,
    /* VCVTTSS2SIrm */
  },
  { /* 3480 */
    126,
    /* VCVTTSS2SIrr */
  },
  { /* 3481 */
    517,
    /* VCVTTSS2USI64Zrm */
  },
  { /* 3482 */
    523,
    /* VCVTTSS2USI64Zrr */
  },
  { /* 3483 */
    519,
    /* VCVTTSS2USIZrm */
  },
  { /* 3484 */
    524,
    /* VCVTTSS2USIZrr */
  },
  { /* 3485 */
    400,
    /* VCVTUDQ2PDZrm */
  },
  { /* 3486 */
    474,
    /* VCVTUDQ2PDZrr */
  },
  { /* 3487 */
    477,
    /* VCVTUDQ2PSZrm */
  },
  { /* 3488 */
    478,
    /* VCVTUDQ2PSZrr */
  },
  { /* 3489 */
    479,
    /* VCVTUDQ2PSZrrb */
  },
  { /* 3490 */
    501,
    /* VCVTUSI2SDZrm */
  },
  { /* 3491 */
    502,
    /* VCVTUSI2SDZrr */
  },
  { /* 3492 */
    506,
    /* VCVTUSI2SSZrm */
  },
  { /* 3493 */
    507,
    /* VCVTUSI2SSZrr */
  },
  { /* 3494 */
    509,
    /* VCVTUSI642SDZrm */
  },
  { /* 3495 */
    510,
    /* VCVTUSI642SDZrr */
  },
  { /* 3496 */
    511,
    /* VCVTUSI642SSZrm */
  },
  { /* 3497 */
    512,
    /* VCVTUSI642SSZrr */
  },
  { /* 3498 */
    302,
    /* VDIVPDYrm */
  },
  { /* 3499 */
    303,
    /* VDIVPDYrr */
  },
  { /* 3500 */
    304,
    /* VDIVPDZ128rm */
  },
  { /* 3501 */
    305,
    /* VDIVPDZ128rmb */
  },
  { /* 3502 */
    306,
    /* VDIVPDZ128rmbk */
  },
  { /* 3503 */
    307,
    /* VDIVPDZ128rmbkz */
  },
  { /* 3504 */
    308,
    /* VDIVPDZ128rmk */
  },
  { /* 3505 */
    309,
    /* VDIVPDZ128rmkz */
  },
  { /* 3506 */
    310,
    /* VDIVPDZ128rr */
  },
  { /* 3507 */
    311,
    /* VDIVPDZ128rrk */
  },
  { /* 3508 */
    312,
    /* VDIVPDZ128rrkz */
  },
  { /* 3509 */
    313,
    /* VDIVPDZ256rm */
  },
  { /* 3510 */
    314,
    /* VDIVPDZ256rmb */
  },
  { /* 3511 */
    315,
    /* VDIVPDZ256rmbk */
  },
  { /* 3512 */
    316,
    /* VDIVPDZ256rmbkz */
  },
  { /* 3513 */
    317,
    /* VDIVPDZ256rmk */
  },
  { /* 3514 */
    318,
    /* VDIVPDZ256rmkz */
  },
  { /* 3515 */
    319,
    /* VDIVPDZ256rr */
  },
  { /* 3516 */
    320,
    /* VDIVPDZ256rrk */
  },
  { /* 3517 */
    321,
    /* VDIVPDZ256rrkz */
  },
  { /* 3518 */
    322,
    /* VDIVPDZrb */
  },
  { /* 3519 */
    323,
    /* VDIVPDZrbk */
  },
  { /* 3520 */
    324,
    /* VDIVPDZrbkz */
  },
  { /* 3521 */
    325,
    /* VDIVPDZrm */
  },
  { /* 3522 */
    326,
    /* VDIVPDZrmb */
  },
  { /* 3523 */
    327,
    /* VDIVPDZrmbk */
  },
  { /* 3524 */
    328,
    /* VDIVPDZrmbkz */
  },
  { /* 3525 */
    329,
    /* VDIVPDZrmk */
  },
  { /* 3526 */
    330,
    /* VDIVPDZrmkz */
  },
  { /* 3527 */
    331,
    /* VDIVPDZrr */
  },
  { /* 3528 */
    332,
    /* VDIVPDZrrk */
  },
  { /* 3529 */
    333,
    /* VDIVPDZrrkz */
  },
  { /* 3530 */
    334,
    /* VDIVPDrm */
  },
  { /* 3531 */
    335,
    /* VDIVPDrr */
  },
  { /* 3532 */
    302,
    /* VDIVPSYrm */
  },
  { /* 3533 */
    303,
    /* VDIVPSYrr */
  },
  { /* 3534 */
    304,
    /* VDIVPSZ128rm */
  },
  { /* 3535 */
    336,
    /* VDIVPSZ128rmb */
  },
  { /* 3536 */
    337,
    /* VDIVPSZ128rmbk */
  },
  { /* 3537 */
    338,
    /* VDIVPSZ128rmbkz */
  },
  { /* 3538 */
    339,
    /* VDIVPSZ128rmk */
  },
  { /* 3539 */
    340,
    /* VDIVPSZ128rmkz */
  },
  { /* 3540 */
    310,
    /* VDIVPSZ128rr */
  },
  { /* 3541 */
    341,
    /* VDIVPSZ128rrk */
  },
  { /* 3542 */
    342,
    /* VDIVPSZ128rrkz */
  },
  { /* 3543 */
    313,
    /* VDIVPSZ256rm */
  },
  { /* 3544 */
    343,
    /* VDIVPSZ256rmb */
  },
  { /* 3545 */
    344,
    /* VDIVPSZ256rmbk */
  },
  { /* 3546 */
    345,
    /* VDIVPSZ256rmbkz */
  },
  { /* 3547 */
    346,
    /* VDIVPSZ256rmk */
  },
  { /* 3548 */
    347,
    /* VDIVPSZ256rmkz */
  },
  { /* 3549 */
    319,
    /* VDIVPSZ256rr */
  },
  { /* 3550 */
    348,
    /* VDIVPSZ256rrk */
  },
  { /* 3551 */
    349,
    /* VDIVPSZ256rrkz */
  },
  { /* 3552 */
    350,
    /* VDIVPSZrb */
  },
  { /* 3553 */
    351,
    /* VDIVPSZrbk */
  },
  { /* 3554 */
    352,
    /* VDIVPSZrbkz */
  },
  { /* 3555 */
    325,
    /* VDIVPSZrm */
  },
  { /* 3556 */
    353,
    /* VDIVPSZrmb */
  },
  { /* 3557 */
    354,
    /* VDIVPSZrmbk */
  },
  { /* 3558 */
    355,
    /* VDIVPSZrmbkz */
  },
  { /* 3559 */
    356,
    /* VDIVPSZrmk */
  },
  { /* 3560 */
    357,
    /* VDIVPSZrmkz */
  },
  { /* 3561 */
    331,
    /* VDIVPSZrr */
  },
  { /* 3562 */
    358,
    /* VDIVPSZrrk */
  },
  { /* 3563 */
    359,
    /* VDIVPSZrrkz */
  },
  { /* 3564 */
    334,
    /* VDIVPSrm */
  },
  { /* 3565 */
    335,
    /* VDIVPSrr */
  },
  { /* 3566 */
    0,
    /*  */
  },
  { /* 3567 */
    360,
    /* VDIVSDZrm_Int */
  },
  { /* 3568 */
    361,
    /* VDIVSDZrm_Intk */
  },
  { /* 3569 */
    362,
    /* VDIVSDZrm_Intkz */
  },
  { /* 3570 */
    0,
    /*  */
  },
  { /* 3571 */
    363,
    /* VDIVSDZrr_Int */
  },
  { /* 3572 */
    364,
    /* VDIVSDZrr_Intk */
  },
  { /* 3573 */
    365,
    /* VDIVSDZrr_Intkz */
  },
  { /* 3574 */
    366,
    /* VDIVSDZrrb */
  },
  { /* 3575 */
    367,
    /* VDIVSDZrrbk */
  },
  { /* 3576 */
    368,
    /* VDIVSDZrrbkz */
  },
  { /* 3577 */
    369,
    /* VDIVSDrm */
  },
  { /* 3578 */
    0,
    /*  */
  },
  { /* 3579 */
    370,
    /* VDIVSDrr */
  },
  { /* 3580 */
    0,
    /*  */
  },
  { /* 3581 */
    0,
    /*  */
  },
  { /* 3582 */
    371,
    /* VDIVSSZrm_Int */
  },
  { /* 3583 */
    372,
    /* VDIVSSZrm_Intk */
  },
  { /* 3584 */
    373,
    /* VDIVSSZrm_Intkz */
  },
  { /* 3585 */
    0,
    /*  */
  },
  { /* 3586 */
    374,
    /* VDIVSSZrr_Int */
  },
  { /* 3587 */
    375,
    /* VDIVSSZrr_Intk */
  },
  { /* 3588 */
    376,
    /* VDIVSSZrr_Intkz */
  },
  { /* 3589 */
    377,
    /* VDIVSSZrrb */
  },
  { /* 3590 */
    378,
    /* VDIVSSZrrbk */
  },
  { /* 3591 */
    379,
    /* VDIVSSZrrbkz */
  },
  { /* 3592 */
    380,
    /* VDIVSSrm */
  },
  { /* 3593 */
    0,
    /*  */
  },
  { /* 3594 */
    381,
    /* VDIVSSrr */
  },
  { /* 3595 */
    0,
    /*  */
  },
  { /* 3596 */
    390,
    /* VDPPDrmi */
  },
  { /* 3597 */
    391,
    /* VDPPDrri */
  },
  { /* 3598 */
    388,
    /* VDPPSYrmi */
  },
  { /* 3599 */
    389,
    /* VDPPSYrri */
  },
  { /* 3600 */
    390,
    /* VDPPSrmi */
  },
  { /* 3601 */
    391,
    /* VDPPSrri */
  },
  { /* 3602 */
    38,
    /* VERRm */
  },
  { /* 3603 */
    194,
    /* VERRr */
  },
  { /* 3604 */
    38,
    /* VERWm */
  },
  { /* 3605 */
    194,
    /* VERWr */
  },
  { /* 3606 */
    477,
    /* VEXP2PDm */
  },
  { /* 3607 */
    525,
    /* VEXP2PDmb */
  },
  { /* 3608 */
    526,
    /* VEXP2PDmbk */
  },
  { /* 3609 */
    527,
    /* VEXP2PDmbkz */
  },
  { /* 3610 */
    528,
    /* VEXP2PDmk */
  },
  { /* 3611 */
    529,
    /* VEXP2PDmkz */
  },
  { /* 3612 */
    478,
    /* VEXP2PDr */
  },
  { /* 3613 */
    530,
    /* VEXP2PDrb */
  },
  { /* 3614 */
    531,
    /* VEXP2PDrbk */
  },
  { /* 3615 */
    532,
    /* VEXP2PDrbkz */
  },
  { /* 3616 */
    533,
    /* VEXP2PDrk */
  },
  { /* 3617 */
    534,
    /* VEXP2PDrkz */
  },
  { /* 3618 */
    477,
    /* VEXP2PSm */
  },
  { /* 3619 */
    525,
    /* VEXP2PSmb */
  },
  { /* 3620 */
    535,
    /* VEXP2PSmbk */
  },
  { /* 3621 */
    536,
    /* VEXP2PSmbkz */
  },
  { /* 3622 */
    537,
    /* VEXP2PSmk */
  },
  { /* 3623 */
    538,
    /* VEXP2PSmkz */
  },
  { /* 3624 */
    478,
    /* VEXP2PSr */
  },
  { /* 3625 */
    530,
    /* VEXP2PSrb */
  },
  { /* 3626 */
    539,
    /* VEXP2PSrbk */
  },
  { /* 3627 */
    540,
    /* VEXP2PSrbkz */
  },
  { /* 3628 */
    541,
    /* VEXP2PSrk */
  },
  { /* 3629 */
    542,
    /* VEXP2PSrkz */
  },
  { /* 3630 */
    543,
    /* VEXPANDPDZ128rmk */
  },
  { /* 3631 */
    544,
    /* VEXPANDPDZ128rmkz */
  },
  { /* 3632 */
    545,
    /* VEXPANDPDZ128rrk */
  },
  { /* 3633 */
    546,
    /* VEXPANDPDZ128rrkz */
  },
  { /* 3634 */
    547,
    /* VEXPANDPDZ256rmk */
  },
  { /* 3635 */
    548,
    /* VEXPANDPDZ256rmkz */
  },
  { /* 3636 */
    549,
    /* VEXPANDPDZ256rrk */
  },
  { /* 3637 */
    550,
    /* VEXPANDPDZ256rrkz */
  },
  { /* 3638 */
    551,
    /* VEXPANDPDZrmk */
  },
  { /* 3639 */
    552,
    /* VEXPANDPDZrmkz */
  },
  { /* 3640 */
    533,
    /* VEXPANDPDZrrk */
  },
  { /* 3641 */
    534,
    /* VEXPANDPDZrrkz */
  },
  { /* 3642 */
    553,
    /* VEXPANDPSZ128rmk */
  },
  { /* 3643 */
    554,
    /* VEXPANDPSZ128rmkz */
  },
  { /* 3644 */
    555,
    /* VEXPANDPSZ128rrk */
  },
  { /* 3645 */
    556,
    /* VEXPANDPSZ128rrkz */
  },
  { /* 3646 */
    557,
    /* VEXPANDPSZ256rmk */
  },
  { /* 3647 */
    558,
    /* VEXPANDPSZ256rmkz */
  },
  { /* 3648 */
    559,
    /* VEXPANDPSZ256rrk */
  },
  { /* 3649 */
    560,
    /* VEXPANDPSZ256rrkz */
  },
  { /* 3650 */
    535,
    /* VEXPANDPSZrmk */
  },
  { /* 3651 */
    536,
    /* VEXPANDPSZrmkz */
  },
  { /* 3652 */
    541,
    /* VEXPANDPSZrrk */
  },
  { /* 3653 */
    542,
    /* VEXPANDPSZrrkz */
  },
  { /* 3654 */
    485,
    /* VEXTRACTF128mr */
  },
  { /* 3655 */
    486,
    /* VEXTRACTF128rr */
  },
  { /* 3656 */
    561,
    /* VEXTRACTF32x4rm */
  },
  { /* 3657 */
    562,
    /* VEXTRACTF32x4rr */
  },
  { /* 3658 */
    563,
    /* VEXTRACTF32x4rrk */
  },
  { /* 3659 */
    564,
    /* VEXTRACTF32x4rrkz */
  },
  { /* 3660 */
    487,
    /* VEXTRACTF64x4rm */
  },
  { /* 3661 */
    565,
    /* VEXTRACTF64x4rr */
  },
  { /* 3662 */
    566,
    /* VEXTRACTF64x4rrk */
  },
  { /* 3663 */
    567,
    /* VEXTRACTF64x4rrkz */
  },
  { /* 3664 */
    485,
    /* VEXTRACTI128mr */
  },
  { /* 3665 */
    486,
    /* VEXTRACTI128rr */
  },
  { /* 3666 */
    561,
    /* VEXTRACTI32x4rm */
  },
  { /* 3667 */
    562,
    /* VEXTRACTI32x4rr */
  },
  { /* 3668 */
    563,
    /* VEXTRACTI32x4rrk */
  },
  { /* 3669 */
    564,
    /* VEXTRACTI32x4rrkz */
  },
  { /* 3670 */
    487,
    /* VEXTRACTI64x4rm */
  },
  { /* 3671 */
    565,
    /* VEXTRACTI64x4rr */
  },
  { /* 3672 */
    566,
    /* VEXTRACTI64x4rrk */
  },
  { /* 3673 */
    567,
    /* VEXTRACTI64x4rrkz */
  },
  { /* 3674 */
    132,
    /* VEXTRACTPSmr */
  },
  { /* 3675 */
    133,
    /* VEXTRACTPSrr */
  },
  { /* 3676 */
    568,
    /* VEXTRACTPSzmr */
  },
  { /* 3677 */
    569,
    /* VEXTRACTPSzrr */
  },
  { /* 3678 */
    570,
    /* VFMADD132PDZ128m */
  },
  { /* 3679 */
    571,
    /* VFMADD132PDZ128mb */
  },
  { /* 3680 */
    572,
    /* VFMADD132PDZ256m */
  },
  { /* 3681 */
    573,
    /* VFMADD132PDZ256mb */
  },
  { /* 3682 */
    574,
    /* VFMADD132PDZm */
  },
  { /* 3683 */
    575,
    /* VFMADD132PDZmb */
  },
  { /* 3684 */
    570,
    /* VFMADD132PSZ128m */
  },
  { /* 3685 */
    576,
    /* VFMADD132PSZ128mb */
  },
  { /* 3686 */
    572,
    /* VFMADD132PSZ256m */
  },
  { /* 3687 */
    577,
    /* VFMADD132PSZ256mb */
  },
  { /* 3688 */
    574,
    /* VFMADD132PSZm */
  },
  { /* 3689 */
    578,
    /* VFMADD132PSZmb */
  },
  { /* 3690 */
    394,
    /* VFMADDPD4mr */
  },
  { /* 3691 */
    392,
    /* VFMADDPD4mrY */
  },
  { /* 3692 */
    579,
    /* VFMADDPD4rm */
  },
  { /* 3693 */
    580,
    /* VFMADDPD4rmY */
  },
  { /* 3694 */
    581,
    /* VFMADDPD4rr */
  },
  { /* 3695 */
    582,
    /* VFMADDPD4rrY */
  },
  { /* 3696 */
    393,
    /* VFMADDPD4rrY_REV */
  },
  { /* 3697 */
    395,
    /* VFMADDPD4rr_REV */
  },
  { /* 3698 */
    570,
    /* VFMADDPDZ128v213rm */
  },
  { /* 3699 */
    583,
    /* VFMADDPDZ128v213rmb */
  },
  { /* 3700 */
    306,
    /* VFMADDPDZ128v213rmbk */
  },
  { /* 3701 */
    306,
    /* VFMADDPDZ128v213rmbkz */
  },
  { /* 3702 */
    308,
    /* VFMADDPDZ128v213rmk */
  },
  { /* 3703 */
    308,
    /* VFMADDPDZ128v213rmkz */
  },
  { /* 3704 */
    584,
    /* VFMADDPDZ128v213rr */
  },
  { /* 3705 */
    311,
    /* VFMADDPDZ128v213rrk */
  },
  { /* 3706 */
    311,
    /* VFMADDPDZ128v213rrkz */
  },
  { /* 3707 */
    570,
    /* VFMADDPDZ128v231rm */
  },
  { /* 3708 */
    583,
    /* VFMADDPDZ128v231rmb */
  },
  { /* 3709 */
    306,
    /* VFMADDPDZ128v231rmbk */
  },
  { /* 3710 */
    306,
    /* VFMADDPDZ128v231rmbkz */
  },
  { /* 3711 */
    308,
    /* VFMADDPDZ128v231rmk */
  },
  { /* 3712 */
    308,
    /* VFMADDPDZ128v231rmkz */
  },
  { /* 3713 */
    584,
    /* VFMADDPDZ128v231rr */
  },
  { /* 3714 */
    311,
    /* VFMADDPDZ128v231rrk */
  },
  { /* 3715 */
    311,
    /* VFMADDPDZ128v231rrkz */
  },
  { /* 3716 */
    572,
    /* VFMADDPDZ256v213rm */
  },
  { /* 3717 */
    585,
    /* VFMADDPDZ256v213rmb */
  },
  { /* 3718 */
    315,
    /* VFMADDPDZ256v213rmbk */
  },
  { /* 3719 */
    315,
    /* VFMADDPDZ256v213rmbkz */
  },
  { /* 3720 */
    317,
    /* VFMADDPDZ256v213rmk */
  },
  { /* 3721 */
    317,
    /* VFMADDPDZ256v213rmkz */
  },
  { /* 3722 */
    586,
    /* VFMADDPDZ256v213rr */
  },
  { /* 3723 */
    320,
    /* VFMADDPDZ256v213rrk */
  },
  { /* 3724 */
    320,
    /* VFMADDPDZ256v213rrkz */
  },
  { /* 3725 */
    572,
    /* VFMADDPDZ256v231rm */
  },
  { /* 3726 */
    585,
    /* VFMADDPDZ256v231rmb */
  },
  { /* 3727 */
    315,
    /* VFMADDPDZ256v231rmbk */
  },
  { /* 3728 */
    315,
    /* VFMADDPDZ256v231rmbkz */
  },
  { /* 3729 */
    317,
    /* VFMADDPDZ256v231rmk */
  },
  { /* 3730 */
    317,
    /* VFMADDPDZ256v231rmkz */
  },
  { /* 3731 */
    586,
    /* VFMADDPDZ256v231rr */
  },
  { /* 3732 */
    320,
    /* VFMADDPDZ256v231rrk */
  },
  { /* 3733 */
    320,
    /* VFMADDPDZ256v231rrkz */
  },
  { /* 3734 */
    574,
    /* VFMADDPDZv213rm */
  },
  { /* 3735 */
    587,
    /* VFMADDPDZv213rmb */
  },
  { /* 3736 */
    327,
    /* VFMADDPDZv213rmbk */
  },
  { /* 3737 */
    327,
    /* VFMADDPDZv213rmbkz */
  },
  { /* 3738 */
    329,
    /* VFMADDPDZv213rmk */
  },
  { /* 3739 */
    329,
    /* VFMADDPDZv213rmkz */
  },
  { /* 3740 */
    588,
    /* VFMADDPDZv213rr */
  },
  { /* 3741 */
    589,
    /* VFMADDPDZv213rrb */
  },
  { /* 3742 */
    323,
    /* VFMADDPDZv213rrbk */
  },
  { /* 3743 */
    323,
    /* VFMADDPDZv213rrbkz */
  },
  { /* 3744 */
    332,
    /* VFMADDPDZv213rrk */
  },
  { /* 3745 */
    332,
    /* VFMADDPDZv213rrkz */
  },
  { /* 3746 */
    574,
    /* VFMADDPDZv231rm */
  },
  { /* 3747 */
    587,
    /* VFMADDPDZv231rmb */
  },
  { /* 3748 */
    327,
    /* VFMADDPDZv231rmbk */
  },
  { /* 3749 */
    327,
    /* VFMADDPDZv231rmbkz */
  },
  { /* 3750 */
    329,
    /* VFMADDPDZv231rmk */
  },
  { /* 3751 */
    329,
    /* VFMADDPDZv231rmkz */
  },
  { /* 3752 */
    588,
    /* VFMADDPDZv231rr */
  },
  { /* 3753 */
    332,
    /* VFMADDPDZv231rrk */
  },
  { /* 3754 */
    332,
    /* VFMADDPDZv231rrkz */
  },
  { /* 3755 */
    590,
    /* VFMADDPDr132m */
  },
  { /* 3756 */
    591,
    /* VFMADDPDr132mY */
  },
  { /* 3757 */
    592,
    /* VFMADDPDr132r */
  },
  { /* 3758 */
    593,
    /* VFMADDPDr132rY */
  },
  { /* 3759 */
    590,
    /* VFMADDPDr213m */
  },
  { /* 3760 */
    591,
    /* VFMADDPDr213mY */
  },
  { /* 3761 */
    592,
    /* VFMADDPDr213r */
  },
  { /* 3762 */
    593,
    /* VFMADDPDr213rY */
  },
  { /* 3763 */
    590,
    /* VFMADDPDr231m */
  },
  { /* 3764 */
    591,
    /* VFMADDPDr231mY */
  },
  { /* 3765 */
    592,
    /* VFMADDPDr231r */
  },
  { /* 3766 */
    593,
    /* VFMADDPDr231rY */
  },
  { /* 3767 */
    394,
    /* VFMADDPS4mr */
  },
  { /* 3768 */
    392,
    /* VFMADDPS4mrY */
  },
  { /* 3769 */
    579,
    /* VFMADDPS4rm */
  },
  { /* 3770 */
    580,
    /* VFMADDPS4rmY */
  },
  { /* 3771 */
    581,
    /* VFMADDPS4rr */
  },
  { /* 3772 */
    582,
    /* VFMADDPS4rrY */
  },
  { /* 3773 */
    393,
    /* VFMADDPS4rrY_REV */
  },
  { /* 3774 */
    395,
    /* VFMADDPS4rr_REV */
  },
  { /* 3775 */
    570,
    /* VFMADDPSZ128v213rm */
  },
  { /* 3776 */
    576,
    /* VFMADDPSZ128v213rmb */
  },
  { /* 3777 */
    337,
    /* VFMADDPSZ128v213rmbk */
  },
  { /* 3778 */
    337,
    /* VFMADDPSZ128v213rmbkz */
  },
  { /* 3779 */
    339,
    /* VFMADDPSZ128v213rmk */
  },
  { /* 3780 */
    339,
    /* VFMADDPSZ128v213rmkz */
  },
  { /* 3781 */
    584,
    /* VFMADDPSZ128v213rr */
  },
  { /* 3782 */
    341,
    /* VFMADDPSZ128v213rrk */
  },
  { /* 3783 */
    341,
    /* VFMADDPSZ128v213rrkz */
  },
  { /* 3784 */
    570,
    /* VFMADDPSZ128v231rm */
  },
  { /* 3785 */
    576,
    /* VFMADDPSZ128v231rmb */
  },
  { /* 3786 */
    337,
    /* VFMADDPSZ128v231rmbk */
  },
  { /* 3787 */
    337,
    /* VFMADDPSZ128v231rmbkz */
  },
  { /* 3788 */
    339,
    /* VFMADDPSZ128v231rmk */
  },
  { /* 3789 */
    339,
    /* VFMADDPSZ128v231rmkz */
  },
  { /* 3790 */
    584,
    /* VFMADDPSZ128v231rr */
  },
  { /* 3791 */
    341,
    /* VFMADDPSZ128v231rrk */
  },
  { /* 3792 */
    341,
    /* VFMADDPSZ128v231rrkz */
  },
  { /* 3793 */
    572,
    /* VFMADDPSZ256v213rm */
  },
  { /* 3794 */
    577,
    /* VFMADDPSZ256v213rmb */
  },
  { /* 3795 */
    344,
    /* VFMADDPSZ256v213rmbk */
  },
  { /* 3796 */
    344,
    /* VFMADDPSZ256v213rmbkz */
  },
  { /* 3797 */
    346,
    /* VFMADDPSZ256v213rmk */
  },
  { /* 3798 */
    346,
    /* VFMADDPSZ256v213rmkz */
  },
  { /* 3799 */
    586,
    /* VFMADDPSZ256v213rr */
  },
  { /* 3800 */
    348,
    /* VFMADDPSZ256v213rrk */
  },
  { /* 3801 */
    348,
    /* VFMADDPSZ256v213rrkz */
  },
  { /* 3802 */
    572,
    /* VFMADDPSZ256v231rm */
  },
  { /* 3803 */
    577,
    /* VFMADDPSZ256v231rmb */
  },
  { /* 3804 */
    344,
    /* VFMADDPSZ256v231rmbk */
  },
  { /* 3805 */
    344,
    /* VFMADDPSZ256v231rmbkz */
  },
  { /* 3806 */
    346,
    /* VFMADDPSZ256v231rmk */
  },
  { /* 3807 */
    346,
    /* VFMADDPSZ256v231rmkz */
  },
  { /* 3808 */
    586,
    /* VFMADDPSZ256v231rr */
  },
  { /* 3809 */
    348,
    /* VFMADDPSZ256v231rrk */
  },
  { /* 3810 */
    348,
    /* VFMADDPSZ256v231rrkz */
  },
  { /* 3811 */
    574,
    /* VFMADDPSZv213rm */
  },
  { /* 3812 */
    578,
    /* VFMADDPSZv213rmb */
  },
  { /* 3813 */
    354,
    /* VFMADDPSZv213rmbk */
  },
  { /* 3814 */
    354,
    /* VFMADDPSZv213rmbkz */
  },
  { /* 3815 */
    356,
    /* VFMADDPSZv213rmk */
  },
  { /* 3816 */
    356,
    /* VFMADDPSZv213rmkz */
  },
  { /* 3817 */
    588,
    /* VFMADDPSZv213rr */
  },
  { /* 3818 */
    594,
    /* VFMADDPSZv213rrb */
  },
  { /* 3819 */
    351,
    /* VFMADDPSZv213rrbk */
  },
  { /* 3820 */
    351,
    /* VFMADDPSZv213rrbkz */
  },
  { /* 3821 */
    358,
    /* VFMADDPSZv213rrk */
  },
  { /* 3822 */
    358,
    /* VFMADDPSZv213rrkz */
  },
  { /* 3823 */
    574,
    /* VFMADDPSZv231rm */
  },
  { /* 3824 */
    578,
    /* VFMADDPSZv231rmb */
  },
  { /* 3825 */
    354,
    /* VFMADDPSZv231rmbk */
  },
  { /* 3826 */
    354,
    /* VFMADDPSZv231rmbkz */
  },
  { /* 3827 */
    356,
    /* VFMADDPSZv231rmk */
  },
  { /* 3828 */
    356,
    /* VFMADDPSZv231rmkz */
  },
  { /* 3829 */
    588,
    /* VFMADDPSZv231rr */
  },
  { /* 3830 */
    358,
    /* VFMADDPSZv231rrk */
  },
  { /* 3831 */
    358,
    /* VFMADDPSZv231rrkz */
  },
  { /* 3832 */
    590,
    /* VFMADDPSr132m */
  },
  { /* 3833 */
    591,
    /* VFMADDPSr132mY */
  },
  { /* 3834 */
    592,
    /* VFMADDPSr132r */
  },
  { /* 3835 */
    593,
    /* VFMADDPSr132rY */
  },
  { /* 3836 */
    590,
    /* VFMADDPSr213m */
  },
  { /* 3837 */
    591,
    /* VFMADDPSr213mY */
  },
  { /* 3838 */
    592,
    /* VFMADDPSr213r */
  },
  { /* 3839 */
    593,
    /* VFMADDPSr213rY */
  },
  { /* 3840 */
    590,
    /* VFMADDPSr231m */
  },
  { /* 3841 */
    591,
    /* VFMADDPSr231mY */
  },
  { /* 3842 */
    592,
    /* VFMADDPSr231r */
  },
  { /* 3843 */
    593,
    /* VFMADDPSr231rY */
  },
  { /* 3844 */
    595,
    /* VFMADDSD4mr */
  },
  { /* 3845 */
    0,
    /*  */
  },
  { /* 3846 */
    596,
    /* VFMADDSD4rm */
  },
  { /* 3847 */
    0,
    /*  */
  },
  { /* 3848 */
    597,
    /* VFMADDSD4rr */
  },
  { /* 3849 */
    0,
    /*  */
  },
  { /* 3850 */
    598,
    /* VFMADDSD4rr_REV */
  },
  { /* 3851 */
    599,
    /* VFMADDSDZm */
  },
  { /* 3852 */
    600,
    /* VFMADDSDZr */
  },
  { /* 3853 */
    601,
    /* VFMADDSDr132m */
  },
  { /* 3854 */
    602,
    /* VFMADDSDr132r */
  },
  { /* 3855 */
    601,
    /* VFMADDSDr213m */
  },
  { /* 3856 */
    602,
    /* VFMADDSDr213r */
  },
  { /* 3857 */
    601,
    /* VFMADDSDr231m */
  },
  { /* 3858 */
    602,
    /* VFMADDSDr231r */
  },
  { /* 3859 */
    603,
    /* VFMADDSS4mr */
  },
  { /* 3860 */
    0,
    /*  */
  },
  { /* 3861 */
    604,
    /* VFMADDSS4rm */
  },
  { /* 3862 */
    0,
    /*  */
  },
  { /* 3863 */
    605,
    /* VFMADDSS4rr */
  },
  { /* 3864 */
    0,
    /*  */
  },
  { /* 3865 */
    606,
    /* VFMADDSS4rr_REV */
  },
  { /* 3866 */
    607,
    /* VFMADDSSZm */
  },
  { /* 3867 */
    608,
    /* VFMADDSSZr */
  },
  { /* 3868 */
    609,
    /* VFMADDSSr132m */
  },
  { /* 3869 */
    610,
    /* VFMADDSSr132r */
  },
  { /* 3870 */
    609,
    /* VFMADDSSr213m */
  },
  { /* 3871 */
    610,
    /* VFMADDSSr213r */
  },
  { /* 3872 */
    609,
    /* VFMADDSSr231m */
  },
  { /* 3873 */
    610,
    /* VFMADDSSr231r */
  },
  { /* 3874 */
    570,
    /* VFMADDSUB132PDZ128m */
  },
  { /* 3875 */
    571,
    /* VFMADDSUB132PDZ128mb */
  },
  { /* 3876 */
    572,
    /* VFMADDSUB132PDZ256m */
  },
  { /* 3877 */
    573,
    /* VFMADDSUB132PDZ256mb */
  },
  { /* 3878 */
    574,
    /* VFMADDSUB132PDZm */
  },
  { /* 3879 */
    575,
    /* VFMADDSUB132PDZmb */
  },
  { /* 3880 */
    570,
    /* VFMADDSUB132PSZ128m */
  },
  { /* 3881 */
    576,
    /* VFMADDSUB132PSZ128mb */
  },
  { /* 3882 */
    572,
    /* VFMADDSUB132PSZ256m */
  },
  { /* 3883 */
    577,
    /* VFMADDSUB132PSZ256mb */
  },
  { /* 3884 */
    574,
    /* VFMADDSUB132PSZm */
  },
  { /* 3885 */
    578,
    /* VFMADDSUB132PSZmb */
  },
  { /* 3886 */
    394,
    /* VFMADDSUBPD4mr */
  },
  { /* 3887 */
    392,
    /* VFMADDSUBPD4mrY */
  },
  { /* 3888 */
    579,
    /* VFMADDSUBPD4rm */
  },
  { /* 3889 */
    580,
    /* VFMADDSUBPD4rmY */
  },
  { /* 3890 */
    581,
    /* VFMADDSUBPD4rr */
  },
  { /* 3891 */
    582,
    /* VFMADDSUBPD4rrY */
  },
  { /* 3892 */
    393,
    /* VFMADDSUBPD4rrY_REV */
  },
  { /* 3893 */
    395,
    /* VFMADDSUBPD4rr_REV */
  },
  { /* 3894 */
    570,
    /* VFMADDSUBPDZ128v213rm */
  },
  { /* 3895 */
    583,
    /* VFMADDSUBPDZ128v213rmb */
  },
  { /* 3896 */
    306,
    /* VFMADDSUBPDZ128v213rmbk */
  },
  { /* 3897 */
    306,
    /* VFMADDSUBPDZ128v213rmbkz */
  },
  { /* 3898 */
    308,
    /* VFMADDSUBPDZ128v213rmk */
  },
  { /* 3899 */
    308,
    /* VFMADDSUBPDZ128v213rmkz */
  },
  { /* 3900 */
    584,
    /* VFMADDSUBPDZ128v213rr */
  },
  { /* 3901 */
    311,
    /* VFMADDSUBPDZ128v213rrk */
  },
  { /* 3902 */
    311,
    /* VFMADDSUBPDZ128v213rrkz */
  },
  { /* 3903 */
    570,
    /* VFMADDSUBPDZ128v231rm */
  },
  { /* 3904 */
    583,
    /* VFMADDSUBPDZ128v231rmb */
  },
  { /* 3905 */
    306,
    /* VFMADDSUBPDZ128v231rmbk */
  },
  { /* 3906 */
    306,
    /* VFMADDSUBPDZ128v231rmbkz */
  },
  { /* 3907 */
    308,
    /* VFMADDSUBPDZ128v231rmk */
  },
  { /* 3908 */
    308,
    /* VFMADDSUBPDZ128v231rmkz */
  },
  { /* 3909 */
    584,
    /* VFMADDSUBPDZ128v231rr */
  },
  { /* 3910 */
    311,
    /* VFMADDSUBPDZ128v231rrk */
  },
  { /* 3911 */
    311,
    /* VFMADDSUBPDZ128v231rrkz */
  },
  { /* 3912 */
    572,
    /* VFMADDSUBPDZ256v213rm */
  },
  { /* 3913 */
    585,
    /* VFMADDSUBPDZ256v213rmb */
  },
  { /* 3914 */
    315,
    /* VFMADDSUBPDZ256v213rmbk */
  },
  { /* 3915 */
    315,
    /* VFMADDSUBPDZ256v213rmbkz */
  },
  { /* 3916 */
    317,
    /* VFMADDSUBPDZ256v213rmk */
  },
  { /* 3917 */
    317,
    /* VFMADDSUBPDZ256v213rmkz */
  },
  { /* 3918 */
    586,
    /* VFMADDSUBPDZ256v213rr */
  },
  { /* 3919 */
    320,
    /* VFMADDSUBPDZ256v213rrk */
  },
  { /* 3920 */
    320,
    /* VFMADDSUBPDZ256v213rrkz */
  },
  { /* 3921 */
    572,
    /* VFMADDSUBPDZ256v231rm */
  },
  { /* 3922 */
    585,
    /* VFMADDSUBPDZ256v231rmb */
  },
  { /* 3923 */
    315,
    /* VFMADDSUBPDZ256v231rmbk */
  },
  { /* 3924 */
    315,
    /* VFMADDSUBPDZ256v231rmbkz */
  },
  { /* 3925 */
    317,
    /* VFMADDSUBPDZ256v231rmk */
  },
  { /* 3926 */
    317,
    /* VFMADDSUBPDZ256v231rmkz */
  },
  { /* 3927 */
    586,
    /* VFMADDSUBPDZ256v231rr */
  },
  { /* 3928 */
    320,
    /* VFMADDSUBPDZ256v231rrk */
  },
  { /* 3929 */
    320,
    /* VFMADDSUBPDZ256v231rrkz */
  },
  { /* 3930 */
    574,
    /* VFMADDSUBPDZv213rm */
  },
  { /* 3931 */
    587,
    /* VFMADDSUBPDZv213rmb */
  },
  { /* 3932 */
    327,
    /* VFMADDSUBPDZv213rmbk */
  },
  { /* 3933 */
    327,
    /* VFMADDSUBPDZv213rmbkz */
  },
  { /* 3934 */
    329,
    /* VFMADDSUBPDZv213rmk */
  },
  { /* 3935 */
    329,
    /* VFMADDSUBPDZv213rmkz */
  },
  { /* 3936 */
    588,
    /* VFMADDSUBPDZv213rr */
  },
  { /* 3937 */
    589,
    /* VFMADDSUBPDZv213rrb */
  },
  { /* 3938 */
    323,
    /* VFMADDSUBPDZv213rrbk */
  },
  { /* 3939 */
    323,
    /* VFMADDSUBPDZv213rrbkz */
  },
  { /* 3940 */
    332,
    /* VFMADDSUBPDZv213rrk */
  },
  { /* 3941 */
    332,
    /* VFMADDSUBPDZv213rrkz */
  },
  { /* 3942 */
    574,
    /* VFMADDSUBPDZv231rm */
  },
  { /* 3943 */
    587,
    /* VFMADDSUBPDZv231rmb */
  },
  { /* 3944 */
    327,
    /* VFMADDSUBPDZv231rmbk */
  },
  { /* 3945 */
    327,
    /* VFMADDSUBPDZv231rmbkz */
  },
  { /* 3946 */
    329,
    /* VFMADDSUBPDZv231rmk */
  },
  { /* 3947 */
    329,
    /* VFMADDSUBPDZv231rmkz */
  },
  { /* 3948 */
    588,
    /* VFMADDSUBPDZv231rr */
  },
  { /* 3949 */
    332,
    /* VFMADDSUBPDZv231rrk */
  },
  { /* 3950 */
    332,
    /* VFMADDSUBPDZv231rrkz */
  },
  { /* 3951 */
    590,
    /* VFMADDSUBPDr132m */
  },
  { /* 3952 */
    591,
    /* VFMADDSUBPDr132mY */
  },
  { /* 3953 */
    592,
    /* VFMADDSUBPDr132r */
  },
  { /* 3954 */
    593,
    /* VFMADDSUBPDr132rY */
  },
  { /* 3955 */
    590,
    /* VFMADDSUBPDr213m */
  },
  { /* 3956 */
    591,
    /* VFMADDSUBPDr213mY */
  },
  { /* 3957 */
    592,
    /* VFMADDSUBPDr213r */
  },
  { /* 3958 */
    593,
    /* VFMADDSUBPDr213rY */
  },
  { /* 3959 */
    590,
    /* VFMADDSUBPDr231m */
  },
  { /* 3960 */
    591,
    /* VFMADDSUBPDr231mY */
  },
  { /* 3961 */
    592,
    /* VFMADDSUBPDr231r */
  },
  { /* 3962 */
    593,
    /* VFMADDSUBPDr231rY */
  },
  { /* 3963 */
    394,
    /* VFMADDSUBPS4mr */
  },
  { /* 3964 */
    392,
    /* VFMADDSUBPS4mrY */
  },
  { /* 3965 */
    579,
    /* VFMADDSUBPS4rm */
  },
  { /* 3966 */
    580,
    /* VFMADDSUBPS4rmY */
  },
  { /* 3967 */
    581,
    /* VFMADDSUBPS4rr */
  },
  { /* 3968 */
    582,
    /* VFMADDSUBPS4rrY */
  },
  { /* 3969 */
    393,
    /* VFMADDSUBPS4rrY_REV */
  },
  { /* 3970 */
    395,
    /* VFMADDSUBPS4rr_REV */
  },
  { /* 3971 */
    570,
    /* VFMADDSUBPSZ128v213rm */
  },
  { /* 3972 */
    576,
    /* VFMADDSUBPSZ128v213rmb */
  },
  { /* 3973 */
    337,
    /* VFMADDSUBPSZ128v213rmbk */
  },
  { /* 3974 */
    337,
    /* VFMADDSUBPSZ128v213rmbkz */
  },
  { /* 3975 */
    339,
    /* VFMADDSUBPSZ128v213rmk */
  },
  { /* 3976 */
    339,
    /* VFMADDSUBPSZ128v213rmkz */
  },
  { /* 3977 */
    584,
    /* VFMADDSUBPSZ128v213rr */
  },
  { /* 3978 */
    341,
    /* VFMADDSUBPSZ128v213rrk */
  },
  { /* 3979 */
    341,
    /* VFMADDSUBPSZ128v213rrkz */
  },
  { /* 3980 */
    570,
    /* VFMADDSUBPSZ128v231rm */
  },
  { /* 3981 */
    576,
    /* VFMADDSUBPSZ128v231rmb */
  },
  { /* 3982 */
    337,
    /* VFMADDSUBPSZ128v231rmbk */
  },
  { /* 3983 */
    337,
    /* VFMADDSUBPSZ128v231rmbkz */
  },
  { /* 3984 */
    339,
    /* VFMADDSUBPSZ128v231rmk */
  },
  { /* 3985 */
    339,
    /* VFMADDSUBPSZ128v231rmkz */
  },
  { /* 3986 */
    584,
    /* VFMADDSUBPSZ128v231rr */
  },
  { /* 3987 */
    341,
    /* VFMADDSUBPSZ128v231rrk */
  },
  { /* 3988 */
    341,
    /* VFMADDSUBPSZ128v231rrkz */
  },
  { /* 3989 */
    572,
    /* VFMADDSUBPSZ256v213rm */
  },
  { /* 3990 */
    577,
    /* VFMADDSUBPSZ256v213rmb */
  },
  { /* 3991 */
    344,
    /* VFMADDSUBPSZ256v213rmbk */
  },
  { /* 3992 */
    344,
    /* VFMADDSUBPSZ256v213rmbkz */
  },
  { /* 3993 */
    346,
    /* VFMADDSUBPSZ256v213rmk */
  },
  { /* 3994 */
    346,
    /* VFMADDSUBPSZ256v213rmkz */
  },
  { /* 3995 */
    586,
    /* VFMADDSUBPSZ256v213rr */
  },
  { /* 3996 */
    348,
    /* VFMADDSUBPSZ256v213rrk */
  },
  { /* 3997 */
    348,
    /* VFMADDSUBPSZ256v213rrkz */
  },
  { /* 3998 */
    572,
    /* VFMADDSUBPSZ256v231rm */
  },
  { /* 3999 */
    577,
    /* VFMADDSUBPSZ256v231rmb */
  },
  { /* 4000 */
    344,
    /* VFMADDSUBPSZ256v231rmbk */
  },
  { /* 4001 */
    344,
    /* VFMADDSUBPSZ256v231rmbkz */
  },
  { /* 4002 */
    346,
    /* VFMADDSUBPSZ256v231rmk */
  },
  { /* 4003 */
    346,
    /* VFMADDSUBPSZ256v231rmkz */
  },
  { /* 4004 */
    586,
    /* VFMADDSUBPSZ256v231rr */
  },
  { /* 4005 */
    348,
    /* VFMADDSUBPSZ256v231rrk */
  },
  { /* 4006 */
    348,
    /* VFMADDSUBPSZ256v231rrkz */
  },
  { /* 4007 */
    574,
    /* VFMADDSUBPSZv213rm */
  },
  { /* 4008 */
    578,
    /* VFMADDSUBPSZv213rmb */
  },
  { /* 4009 */
    354,
    /* VFMADDSUBPSZv213rmbk */
  },
  { /* 4010 */
    354,
    /* VFMADDSUBPSZv213rmbkz */
  },
  { /* 4011 */
    356,
    /* VFMADDSUBPSZv213rmk */
  },
  { /* 4012 */
    356,
    /* VFMADDSUBPSZv213rmkz */
  },
  { /* 4013 */
    588,
    /* VFMADDSUBPSZv213rr */
  },
  { /* 4014 */
    594,
    /* VFMADDSUBPSZv213rrb */
  },
  { /* 4015 */
    351,
    /* VFMADDSUBPSZv213rrbk */
  },
  { /* 4016 */
    351,
    /* VFMADDSUBPSZv213rrbkz */
  },
  { /* 4017 */
    358,
    /* VFMADDSUBPSZv213rrk */
  },
  { /* 4018 */
    358,
    /* VFMADDSUBPSZv213rrkz */
  },
  { /* 4019 */
    574,
    /* VFMADDSUBPSZv231rm */
  },
  { /* 4020 */
    578,
    /* VFMADDSUBPSZv231rmb */
  },
  { /* 4021 */
    354,
    /* VFMADDSUBPSZv231rmbk */
  },
  { /* 4022 */
    354,
    /* VFMADDSUBPSZv231rmbkz */
  },
  { /* 4023 */
    356,
    /* VFMADDSUBPSZv231rmk */
  },
  { /* 4024 */
    356,
    /* VFMADDSUBPSZv231rmkz */
  },
  { /* 4025 */
    588,
    /* VFMADDSUBPSZv231rr */
  },
  { /* 4026 */
    358,
    /* VFMADDSUBPSZv231rrk */
  },
  { /* 4027 */
    358,
    /* VFMADDSUBPSZv231rrkz */
  },
  { /* 4028 */
    590,
    /* VFMADDSUBPSr132m */
  },
  { /* 4029 */
    591,
    /* VFMADDSUBPSr132mY */
  },
  { /* 4030 */
    592,
    /* VFMADDSUBPSr132r */
  },
  { /* 4031 */
    593,
    /* VFMADDSUBPSr132rY */
  },
  { /* 4032 */
    590,
    /* VFMADDSUBPSr213m */
  },
  { /* 4033 */
    591,
    /* VFMADDSUBPSr213mY */
  },
  { /* 4034 */
    592,
    /* VFMADDSUBPSr213r */
  },
  { /* 4035 */
    593,
    /* VFMADDSUBPSr213rY */
  },
  { /* 4036 */
    590,
    /* VFMADDSUBPSr231m */
  },
  { /* 4037 */
    591,
    /* VFMADDSUBPSr231mY */
  },
  { /* 4038 */
    592,
    /* VFMADDSUBPSr231r */
  },
  { /* 4039 */
    593,
    /* VFMADDSUBPSr231rY */
  },
  { /* 4040 */
    570,
    /* VFMSUB132PDZ128m */
  },
  { /* 4041 */
    571,
    /* VFMSUB132PDZ128mb */
  },
  { /* 4042 */
    572,
    /* VFMSUB132PDZ256m */
  },
  { /* 4043 */
    573,
    /* VFMSUB132PDZ256mb */
  },
  { /* 4044 */
    574,
    /* VFMSUB132PDZm */
  },
  { /* 4045 */
    575,
    /* VFMSUB132PDZmb */
  },
  { /* 4046 */
    570,
    /* VFMSUB132PSZ128m */
  },
  { /* 4047 */
    576,
    /* VFMSUB132PSZ128mb */
  },
  { /* 4048 */
    572,
    /* VFMSUB132PSZ256m */
  },
  { /* 4049 */
    577,
    /* VFMSUB132PSZ256mb */
  },
  { /* 4050 */
    574,
    /* VFMSUB132PSZm */
  },
  { /* 4051 */
    578,
    /* VFMSUB132PSZmb */
  },
  { /* 4052 */
    570,
    /* VFMSUBADD132PDZ128m */
  },
  { /* 4053 */
    571,
    /* VFMSUBADD132PDZ128mb */
  },
  { /* 4054 */
    572,
    /* VFMSUBADD132PDZ256m */
  },
  { /* 4055 */
    573,
    /* VFMSUBADD132PDZ256mb */
  },
  { /* 4056 */
    574,
    /* VFMSUBADD132PDZm */
  },
  { /* 4057 */
    575,
    /* VFMSUBADD132PDZmb */
  },
  { /* 4058 */
    570,
    /* VFMSUBADD132PSZ128m */
  },
  { /* 4059 */
    576,
    /* VFMSUBADD132PSZ128mb */
  },
  { /* 4060 */
    572,
    /* VFMSUBADD132PSZ256m */
  },
  { /* 4061 */
    577,
    /* VFMSUBADD132PSZ256mb */
  },
  { /* 4062 */
    574,
    /* VFMSUBADD132PSZm */
  },
  { /* 4063 */
    578,
    /* VFMSUBADD132PSZmb */
  },
  { /* 4064 */
    394,
    /* VFMSUBADDPD4mr */
  },
  { /* 4065 */
    392,
    /* VFMSUBADDPD4mrY */
  },
  { /* 4066 */
    579,
    /* VFMSUBADDPD4rm */
  },
  { /* 4067 */
    580,
    /* VFMSUBADDPD4rmY */
  },
  { /* 4068 */
    581,
    /* VFMSUBADDPD4rr */
  },
  { /* 4069 */
    582,
    /* VFMSUBADDPD4rrY */
  },
  { /* 4070 */
    393,
    /* VFMSUBADDPD4rrY_REV */
  },
  { /* 4071 */
    395,
    /* VFMSUBADDPD4rr_REV */
  },
  { /* 4072 */
    570,
    /* VFMSUBADDPDZ128v213rm */
  },
  { /* 4073 */
    583,
    /* VFMSUBADDPDZ128v213rmb */
  },
  { /* 4074 */
    306,
    /* VFMSUBADDPDZ128v213rmbk */
  },
  { /* 4075 */
    306,
    /* VFMSUBADDPDZ128v213rmbkz */
  },
  { /* 4076 */
    308,
    /* VFMSUBADDPDZ128v213rmk */
  },
  { /* 4077 */
    308,
    /* VFMSUBADDPDZ128v213rmkz */
  },
  { /* 4078 */
    584,
    /* VFMSUBADDPDZ128v213rr */
  },
  { /* 4079 */
    311,
    /* VFMSUBADDPDZ128v213rrk */
  },
  { /* 4080 */
    311,
    /* VFMSUBADDPDZ128v213rrkz */
  },
  { /* 4081 */
    570,
    /* VFMSUBADDPDZ128v231rm */
  },
  { /* 4082 */
    583,
    /* VFMSUBADDPDZ128v231rmb */
  },
  { /* 4083 */
    306,
    /* VFMSUBADDPDZ128v231rmbk */
  },
  { /* 4084 */
    306,
    /* VFMSUBADDPDZ128v231rmbkz */
  },
  { /* 4085 */
    308,
    /* VFMSUBADDPDZ128v231rmk */
  },
  { /* 4086 */
    308,
    /* VFMSUBADDPDZ128v231rmkz */
  },
  { /* 4087 */
    584,
    /* VFMSUBADDPDZ128v231rr */
  },
  { /* 4088 */
    311,
    /* VFMSUBADDPDZ128v231rrk */
  },
  { /* 4089 */
    311,
    /* VFMSUBADDPDZ128v231rrkz */
  },
  { /* 4090 */
    572,
    /* VFMSUBADDPDZ256v213rm */
  },
  { /* 4091 */
    585,
    /* VFMSUBADDPDZ256v213rmb */
  },
  { /* 4092 */
    315,
    /* VFMSUBADDPDZ256v213rmbk */
  },
  { /* 4093 */
    315,
    /* VFMSUBADDPDZ256v213rmbkz */
  },
  { /* 4094 */
    317,
    /* VFMSUBADDPDZ256v213rmk */
  },
  { /* 4095 */
    317,
    /* VFMSUBADDPDZ256v213rmkz */
  },
  { /* 4096 */
    586,
    /* VFMSUBADDPDZ256v213rr */
  },
  { /* 4097 */
    320,
    /* VFMSUBADDPDZ256v213rrk */
  },
  { /* 4098 */
    320,
    /* VFMSUBADDPDZ256v213rrkz */
  },
  { /* 4099 */
    572,
    /* VFMSUBADDPDZ256v231rm */
  },
  { /* 4100 */
    585,
    /* VFMSUBADDPDZ256v231rmb */
  },
  { /* 4101 */
    315,
    /* VFMSUBADDPDZ256v231rmbk */
  },
  { /* 4102 */
    315,
    /* VFMSUBADDPDZ256v231rmbkz */
  },
  { /* 4103 */
    317,
    /* VFMSUBADDPDZ256v231rmk */
  },
  { /* 4104 */
    317,
    /* VFMSUBADDPDZ256v231rmkz */
  },
  { /* 4105 */
    586,
    /* VFMSUBADDPDZ256v231rr */
  },
  { /* 4106 */
    320,
    /* VFMSUBADDPDZ256v231rrk */
  },
  { /* 4107 */
    320,
    /* VFMSUBADDPDZ256v231rrkz */
  },
  { /* 4108 */
    574,
    /* VFMSUBADDPDZv213rm */
  },
  { /* 4109 */
    587,
    /* VFMSUBADDPDZv213rmb */
  },
  { /* 4110 */
    327,
    /* VFMSUBADDPDZv213rmbk */
  },
  { /* 4111 */
    327,
    /* VFMSUBADDPDZv213rmbkz */
  },
  { /* 4112 */
    329,
    /* VFMSUBADDPDZv213rmk */
  },
  { /* 4113 */
    329,
    /* VFMSUBADDPDZv213rmkz */
  },
  { /* 4114 */
    588,
    /* VFMSUBADDPDZv213rr */
  },
  { /* 4115 */
    589,
    /* VFMSUBADDPDZv213rrb */
  },
  { /* 4116 */
    323,
    /* VFMSUBADDPDZv213rrbk */
  },
  { /* 4117 */
    323,
    /* VFMSUBADDPDZv213rrbkz */
  },
  { /* 4118 */
    332,
    /* VFMSUBADDPDZv213rrk */
  },
  { /* 4119 */
    332,
    /* VFMSUBADDPDZv213rrkz */
  },
  { /* 4120 */
    574,
    /* VFMSUBADDPDZv231rm */
  },
  { /* 4121 */
    587,
    /* VFMSUBADDPDZv231rmb */
  },
  { /* 4122 */
    327,
    /* VFMSUBADDPDZv231rmbk */
  },
  { /* 4123 */
    327,
    /* VFMSUBADDPDZv231rmbkz */
  },
  { /* 4124 */
    329,
    /* VFMSUBADDPDZv231rmk */
  },
  { /* 4125 */
    329,
    /* VFMSUBADDPDZv231rmkz */
  },
  { /* 4126 */
    588,
    /* VFMSUBADDPDZv231rr */
  },
  { /* 4127 */
    332,
    /* VFMSUBADDPDZv231rrk */
  },
  { /* 4128 */
    332,
    /* VFMSUBADDPDZv231rrkz */
  },
  { /* 4129 */
    590,
    /* VFMSUBADDPDr132m */
  },
  { /* 4130 */
    591,
    /* VFMSUBADDPDr132mY */
  },
  { /* 4131 */
    592,
    /* VFMSUBADDPDr132r */
  },
  { /* 4132 */
    593,
    /* VFMSUBADDPDr132rY */
  },
  { /* 4133 */
    590,
    /* VFMSUBADDPDr213m */
  },
  { /* 4134 */
    591,
    /* VFMSUBADDPDr213mY */
  },
  { /* 4135 */
    592,
    /* VFMSUBADDPDr213r */
  },
  { /* 4136 */
    593,
    /* VFMSUBADDPDr213rY */
  },
  { /* 4137 */
    590,
    /* VFMSUBADDPDr231m */
  },
  { /* 4138 */
    591,
    /* VFMSUBADDPDr231mY */
  },
  { /* 4139 */
    592,
    /* VFMSUBADDPDr231r */
  },
  { /* 4140 */
    593,
    /* VFMSUBADDPDr231rY */
  },
  { /* 4141 */
    394,
    /* VFMSUBADDPS4mr */
  },
  { /* 4142 */
    392,
    /* VFMSUBADDPS4mrY */
  },
  { /* 4143 */
    579,
    /* VFMSUBADDPS4rm */
  },
  { /* 4144 */
    580,
    /* VFMSUBADDPS4rmY */
  },
  { /* 4145 */
    581,
    /* VFMSUBADDPS4rr */
  },
  { /* 4146 */
    582,
    /* VFMSUBADDPS4rrY */
  },
  { /* 4147 */
    393,
    /* VFMSUBADDPS4rrY_REV */
  },
  { /* 4148 */
    395,
    /* VFMSUBADDPS4rr_REV */
  },
  { /* 4149 */
    570,
    /* VFMSUBADDPSZ128v213rm */
  },
  { /* 4150 */
    576,
    /* VFMSUBADDPSZ128v213rmb */
  },
  { /* 4151 */
    337,
    /* VFMSUBADDPSZ128v213rmbk */
  },
  { /* 4152 */
    337,
    /* VFMSUBADDPSZ128v213rmbkz */
  },
  { /* 4153 */
    339,
    /* VFMSUBADDPSZ128v213rmk */
  },
  { /* 4154 */
    339,
    /* VFMSUBADDPSZ128v213rmkz */
  },
  { /* 4155 */
    584,
    /* VFMSUBADDPSZ128v213rr */
  },
  { /* 4156 */
    341,
    /* VFMSUBADDPSZ128v213rrk */
  },
  { /* 4157 */
    341,
    /* VFMSUBADDPSZ128v213rrkz */
  },
  { /* 4158 */
    570,
    /* VFMSUBADDPSZ128v231rm */
  },
  { /* 4159 */
    576,
    /* VFMSUBADDPSZ128v231rmb */
  },
  { /* 4160 */
    337,
    /* VFMSUBADDPSZ128v231rmbk */
  },
  { /* 4161 */
    337,
    /* VFMSUBADDPSZ128v231rmbkz */
  },
  { /* 4162 */
    339,
    /* VFMSUBADDPSZ128v231rmk */
  },
  { /* 4163 */
    339,
    /* VFMSUBADDPSZ128v231rmkz */
  },
  { /* 4164 */
    584,
    /* VFMSUBADDPSZ128v231rr */
  },
  { /* 4165 */
    341,
    /* VFMSUBADDPSZ128v231rrk */
  },
  { /* 4166 */
    341,
    /* VFMSUBADDPSZ128v231rrkz */
  },
  { /* 4167 */
    572,
    /* VFMSUBADDPSZ256v213rm */
  },
  { /* 4168 */
    577,
    /* VFMSUBADDPSZ256v213rmb */
  },
  { /* 4169 */
    344,
    /* VFMSUBADDPSZ256v213rmbk */
  },
  { /* 4170 */
    344,
    /* VFMSUBADDPSZ256v213rmbkz */
  },
  { /* 4171 */
    346,
    /* VFMSUBADDPSZ256v213rmk */
  },
  { /* 4172 */
    346,
    /* VFMSUBADDPSZ256v213rmkz */
  },
  { /* 4173 */
    586,
    /* VFMSUBADDPSZ256v213rr */
  },
  { /* 4174 */
    348,
    /* VFMSUBADDPSZ256v213rrk */
  },
  { /* 4175 */
    348,
    /* VFMSUBADDPSZ256v213rrkz */
  },
  { /* 4176 */
    572,
    /* VFMSUBADDPSZ256v231rm */
  },
  { /* 4177 */
    577,
    /* VFMSUBADDPSZ256v231rmb */
  },
  { /* 4178 */
    344,
    /* VFMSUBADDPSZ256v231rmbk */
  },
  { /* 4179 */
    344,
    /* VFMSUBADDPSZ256v231rmbkz */
  },
  { /* 4180 */
    346,
    /* VFMSUBADDPSZ256v231rmk */
  },
  { /* 4181 */
    346,
    /* VFMSUBADDPSZ256v231rmkz */
  },
  { /* 4182 */
    586,
    /* VFMSUBADDPSZ256v231rr */
  },
  { /* 4183 */
    348,
    /* VFMSUBADDPSZ256v231rrk */
  },
  { /* 4184 */
    348,
    /* VFMSUBADDPSZ256v231rrkz */
  },
  { /* 4185 */
    574,
    /* VFMSUBADDPSZv213rm */
  },
  { /* 4186 */
    578,
    /* VFMSUBADDPSZv213rmb */
  },
  { /* 4187 */
    354,
    /* VFMSUBADDPSZv213rmbk */
  },
  { /* 4188 */
    354,
    /* VFMSUBADDPSZv213rmbkz */
  },
  { /* 4189 */
    356,
    /* VFMSUBADDPSZv213rmk */
  },
  { /* 4190 */
    356,
    /* VFMSUBADDPSZv213rmkz */
  },
  { /* 4191 */
    588,
    /* VFMSUBADDPSZv213rr */
  },
  { /* 4192 */
    594,
    /* VFMSUBADDPSZv213rrb */
  },
  { /* 4193 */
    351,
    /* VFMSUBADDPSZv213rrbk */
  },
  { /* 4194 */
    351,
    /* VFMSUBADDPSZv213rrbkz */
  },
  { /* 4195 */
    358,
    /* VFMSUBADDPSZv213rrk */
  },
  { /* 4196 */
    358,
    /* VFMSUBADDPSZv213rrkz */
  },
  { /* 4197 */
    574,
    /* VFMSUBADDPSZv231rm */
  },
  { /* 4198 */
    578,
    /* VFMSUBADDPSZv231rmb */
  },
  { /* 4199 */
    354,
    /* VFMSUBADDPSZv231rmbk */
  },
  { /* 4200 */
    354,
    /* VFMSUBADDPSZv231rmbkz */
  },
  { /* 4201 */
    356,
    /* VFMSUBADDPSZv231rmk */
  },
  { /* 4202 */
    356,
    /* VFMSUBADDPSZv231rmkz */
  },
  { /* 4203 */
    588,
    /* VFMSUBADDPSZv231rr */
  },
  { /* 4204 */
    358,
    /* VFMSUBADDPSZv231rrk */
  },
  { /* 4205 */
    358,
    /* VFMSUBADDPSZv231rrkz */
  },
  { /* 4206 */
    590,
    /* VFMSUBADDPSr132m */
  },
  { /* 4207 */
    591,
    /* VFMSUBADDPSr132mY */
  },
  { /* 4208 */
    592,
    /* VFMSUBADDPSr132r */
  },
  { /* 4209 */
    593,
    /* VFMSUBADDPSr132rY */
  },
  { /* 4210 */
    590,
    /* VFMSUBADDPSr213m */
  },
  { /* 4211 */
    591,
    /* VFMSUBADDPSr213mY */
  },
  { /* 4212 */
    592,
    /* VFMSUBADDPSr213r */
  },
  { /* 4213 */
    593,
    /* VFMSUBADDPSr213rY */
  },
  { /* 4214 */
    590,
    /* VFMSUBADDPSr231m */
  },
  { /* 4215 */
    591,
    /* VFMSUBADDPSr231mY */
  },
  { /* 4216 */
    592,
    /* VFMSUBADDPSr231r */
  },
  { /* 4217 */
    593,
    /* VFMSUBADDPSr231rY */
  },
  { /* 4218 */
    394,
    /* VFMSUBPD4mr */
  },
  { /* 4219 */
    392,
    /* VFMSUBPD4mrY */
  },
  { /* 4220 */
    579,
    /* VFMSUBPD4rm */
  },
  { /* 4221 */
    580,
    /* VFMSUBPD4rmY */
  },
  { /* 4222 */
    581,
    /* VFMSUBPD4rr */
  },
  { /* 4223 */
    582,
    /* VFMSUBPD4rrY */
  },
  { /* 4224 */
    393,
    /* VFMSUBPD4rrY_REV */
  },
  { /* 4225 */
    395,
    /* VFMSUBPD4rr_REV */
  },
  { /* 4226 */
    570,
    /* VFMSUBPDZ128v213rm */
  },
  { /* 4227 */
    583,
    /* VFMSUBPDZ128v213rmb */
  },
  { /* 4228 */
    306,
    /* VFMSUBPDZ128v213rmbk */
  },
  { /* 4229 */
    306,
    /* VFMSUBPDZ128v213rmbkz */
  },
  { /* 4230 */
    308,
    /* VFMSUBPDZ128v213rmk */
  },
  { /* 4231 */
    308,
    /* VFMSUBPDZ128v213rmkz */
  },
  { /* 4232 */
    584,
    /* VFMSUBPDZ128v213rr */
  },
  { /* 4233 */
    311,
    /* VFMSUBPDZ128v213rrk */
  },
  { /* 4234 */
    311,
    /* VFMSUBPDZ128v213rrkz */
  },
  { /* 4235 */
    570,
    /* VFMSUBPDZ128v231rm */
  },
  { /* 4236 */
    583,
    /* VFMSUBPDZ128v231rmb */
  },
  { /* 4237 */
    306,
    /* VFMSUBPDZ128v231rmbk */
  },
  { /* 4238 */
    306,
    /* VFMSUBPDZ128v231rmbkz */
  },
  { /* 4239 */
    308,
    /* VFMSUBPDZ128v231rmk */
  },
  { /* 4240 */
    308,
    /* VFMSUBPDZ128v231rmkz */
  },
  { /* 4241 */
    584,
    /* VFMSUBPDZ128v231rr */
  },
  { /* 4242 */
    311,
    /* VFMSUBPDZ128v231rrk */
  },
  { /* 4243 */
    311,
    /* VFMSUBPDZ128v231rrkz */
  },
  { /* 4244 */
    572,
    /* VFMSUBPDZ256v213rm */
  },
  { /* 4245 */
    585,
    /* VFMSUBPDZ256v213rmb */
  },
  { /* 4246 */
    315,
    /* VFMSUBPDZ256v213rmbk */
  },
  { /* 4247 */
    315,
    /* VFMSUBPDZ256v213rmbkz */
  },
  { /* 4248 */
    317,
    /* VFMSUBPDZ256v213rmk */
  },
  { /* 4249 */
    317,
    /* VFMSUBPDZ256v213rmkz */
  },
  { /* 4250 */
    586,
    /* VFMSUBPDZ256v213rr */
  },
  { /* 4251 */
    320,
    /* VFMSUBPDZ256v213rrk */
  },
  { /* 4252 */
    320,
    /* VFMSUBPDZ256v213rrkz */
  },
  { /* 4253 */
    572,
    /* VFMSUBPDZ256v231rm */
  },
  { /* 4254 */
    585,
    /* VFMSUBPDZ256v231rmb */
  },
  { /* 4255 */
    315,
    /* VFMSUBPDZ256v231rmbk */
  },
  { /* 4256 */
    315,
    /* VFMSUBPDZ256v231rmbkz */
  },
  { /* 4257 */
    317,
    /* VFMSUBPDZ256v231rmk */
  },
  { /* 4258 */
    317,
    /* VFMSUBPDZ256v231rmkz */
  },
  { /* 4259 */
    586,
    /* VFMSUBPDZ256v231rr */
  },
  { /* 4260 */
    320,
    /* VFMSUBPDZ256v231rrk */
  },
  { /* 4261 */
    320,
    /* VFMSUBPDZ256v231rrkz */
  },
  { /* 4262 */
    574,
    /* VFMSUBPDZv213rm */
  },
  { /* 4263 */
    587,
    /* VFMSUBPDZv213rmb */
  },
  { /* 4264 */
    327,
    /* VFMSUBPDZv213rmbk */
  },
  { /* 4265 */
    327,
    /* VFMSUBPDZv213rmbkz */
  },
  { /* 4266 */
    329,
    /* VFMSUBPDZv213rmk */
  },
  { /* 4267 */
    329,
    /* VFMSUBPDZv213rmkz */
  },
  { /* 4268 */
    588,
    /* VFMSUBPDZv213rr */
  },
  { /* 4269 */
    589,
    /* VFMSUBPDZv213rrb */
  },
  { /* 4270 */
    323,
    /* VFMSUBPDZv213rrbk */
  },
  { /* 4271 */
    323,
    /* VFMSUBPDZv213rrbkz */
  },
  { /* 4272 */
    332,
    /* VFMSUBPDZv213rrk */
  },
  { /* 4273 */
    332,
    /* VFMSUBPDZv213rrkz */
  },
  { /* 4274 */
    574,
    /* VFMSUBPDZv231rm */
  },
  { /* 4275 */
    587,
    /* VFMSUBPDZv231rmb */
  },
  { /* 4276 */
    327,
    /* VFMSUBPDZv231rmbk */
  },
  { /* 4277 */
    327,
    /* VFMSUBPDZv231rmbkz */
  },
  { /* 4278 */
    329,
    /* VFMSUBPDZv231rmk */
  },
  { /* 4279 */
    329,
    /* VFMSUBPDZv231rmkz */
  },
  { /* 4280 */
    588,
    /* VFMSUBPDZv231rr */
  },
  { /* 4281 */
    332,
    /* VFMSUBPDZv231rrk */
  },
  { /* 4282 */
    332,
    /* VFMSUBPDZv231rrkz */
  },
  { /* 4283 */
    590,
    /* VFMSUBPDr132m */
  },
  { /* 4284 */
    591,
    /* VFMSUBPDr132mY */
  },
  { /* 4285 */
    592,
    /* VFMSUBPDr132r */
  },
  { /* 4286 */
    593,
    /* VFMSUBPDr132rY */
  },
  { /* 4287 */
    590,
    /* VFMSUBPDr213m */
  },
  { /* 4288 */
    591,
    /* VFMSUBPDr213mY */
  },
  { /* 4289 */
    592,
    /* VFMSUBPDr213r */
  },
  { /* 4290 */
    593,
    /* VFMSUBPDr213rY */
  },
  { /* 4291 */
    590,
    /* VFMSUBPDr231m */
  },
  { /* 4292 */
    591,
    /* VFMSUBPDr231mY */
  },
  { /* 4293 */
    592,
    /* VFMSUBPDr231r */
  },
  { /* 4294 */
    593,
    /* VFMSUBPDr231rY */
  },
  { /* 4295 */
    394,
    /* VFMSUBPS4mr */
  },
  { /* 4296 */
    392,
    /* VFMSUBPS4mrY */
  },
  { /* 4297 */
    579,
    /* VFMSUBPS4rm */
  },
  { /* 4298 */
    580,
    /* VFMSUBPS4rmY */
  },
  { /* 4299 */
    581,
    /* VFMSUBPS4rr */
  },
  { /* 4300 */
    582,
    /* VFMSUBPS4rrY */
  },
  { /* 4301 */
    393,
    /* VFMSUBPS4rrY_REV */
  },
  { /* 4302 */
    395,
    /* VFMSUBPS4rr_REV */
  },
  { /* 4303 */
    570,
    /* VFMSUBPSZ128v213rm */
  },
  { /* 4304 */
    576,
    /* VFMSUBPSZ128v213rmb */
  },
  { /* 4305 */
    337,
    /* VFMSUBPSZ128v213rmbk */
  },
  { /* 4306 */
    337,
    /* VFMSUBPSZ128v213rmbkz */
  },
  { /* 4307 */
    339,
    /* VFMSUBPSZ128v213rmk */
  },
  { /* 4308 */
    339,
    /* VFMSUBPSZ128v213rmkz */
  },
  { /* 4309 */
    584,
    /* VFMSUBPSZ128v213rr */
  },
  { /* 4310 */
    341,
    /* VFMSUBPSZ128v213rrk */
  },
  { /* 4311 */
    341,
    /* VFMSUBPSZ128v213rrkz */
  },
  { /* 4312 */
    570,
    /* VFMSUBPSZ128v231rm */
  },
  { /* 4313 */
    576,
    /* VFMSUBPSZ128v231rmb */
  },
  { /* 4314 */
    337,
    /* VFMSUBPSZ128v231rmbk */
  },
  { /* 4315 */
    337,
    /* VFMSUBPSZ128v231rmbkz */
  },
  { /* 4316 */
    339,
    /* VFMSUBPSZ128v231rmk */
  },
  { /* 4317 */
    339,
    /* VFMSUBPSZ128v231rmkz */
  },
  { /* 4318 */
    584,
    /* VFMSUBPSZ128v231rr */
  },
  { /* 4319 */
    341,
    /* VFMSUBPSZ128v231rrk */
  },
  { /* 4320 */
    341,
    /* VFMSUBPSZ128v231rrkz */
  },
  { /* 4321 */
    572,
    /* VFMSUBPSZ256v213rm */
  },
  { /* 4322 */
    577,
    /* VFMSUBPSZ256v213rmb */
  },
  { /* 4323 */
    344,
    /* VFMSUBPSZ256v213rmbk */
  },
  { /* 4324 */
    344,
    /* VFMSUBPSZ256v213rmbkz */
  },
  { /* 4325 */
    346,
    /* VFMSUBPSZ256v213rmk */
  },
  { /* 4326 */
    346,
    /* VFMSUBPSZ256v213rmkz */
  },
  { /* 4327 */
    586,
    /* VFMSUBPSZ256v213rr */
  },
  { /* 4328 */
    348,
    /* VFMSUBPSZ256v213rrk */
  },
  { /* 4329 */
    348,
    /* VFMSUBPSZ256v213rrkz */
  },
  { /* 4330 */
    572,
    /* VFMSUBPSZ256v231rm */
  },
  { /* 4331 */
    577,
    /* VFMSUBPSZ256v231rmb */
  },
  { /* 4332 */
    344,
    /* VFMSUBPSZ256v231rmbk */
  },
  { /* 4333 */
    344,
    /* VFMSUBPSZ256v231rmbkz */
  },
  { /* 4334 */
    346,
    /* VFMSUBPSZ256v231rmk */
  },
  { /* 4335 */
    346,
    /* VFMSUBPSZ256v231rmkz */
  },
  { /* 4336 */
    586,
    /* VFMSUBPSZ256v231rr */
  },
  { /* 4337 */
    348,
    /* VFMSUBPSZ256v231rrk */
  },
  { /* 4338 */
    348,
    /* VFMSUBPSZ256v231rrkz */
  },
  { /* 4339 */
    574,
    /* VFMSUBPSZv213rm */
  },
  { /* 4340 */
    578,
    /* VFMSUBPSZv213rmb */
  },
  { /* 4341 */
    354,
    /* VFMSUBPSZv213rmbk */
  },
  { /* 4342 */
    354,
    /* VFMSUBPSZv213rmbkz */
  },
  { /* 4343 */
    356,
    /* VFMSUBPSZv213rmk */
  },
  { /* 4344 */
    356,
    /* VFMSUBPSZv213rmkz */
  },
  { /* 4345 */
    588,
    /* VFMSUBPSZv213rr */
  },
  { /* 4346 */
    594,
    /* VFMSUBPSZv213rrb */
  },
  { /* 4347 */
    351,
    /* VFMSUBPSZv213rrbk */
  },
  { /* 4348 */
    351,
    /* VFMSUBPSZv213rrbkz */
  },
  { /* 4349 */
    358,
    /* VFMSUBPSZv213rrk */
  },
  { /* 4350 */
    358,
    /* VFMSUBPSZv213rrkz */
  },
  { /* 4351 */
    574,
    /* VFMSUBPSZv231rm */
  },
  { /* 4352 */
    578,
    /* VFMSUBPSZv231rmb */
  },
  { /* 4353 */
    354,
    /* VFMSUBPSZv231rmbk */
  },
  { /* 4354 */
    354,
    /* VFMSUBPSZv231rmbkz */
  },
  { /* 4355 */
    356,
    /* VFMSUBPSZv231rmk */
  },
  { /* 4356 */
    356,
    /* VFMSUBPSZv231rmkz */
  },
  { /* 4357 */
    588,
    /* VFMSUBPSZv231rr */
  },
  { /* 4358 */
    358,
    /* VFMSUBPSZv231rrk */
  },
  { /* 4359 */
    358,
    /* VFMSUBPSZv231rrkz */
  },
  { /* 4360 */
    590,
    /* VFMSUBPSr132m */
  },
  { /* 4361 */
    591,
    /* VFMSUBPSr132mY */
  },
  { /* 4362 */
    592,
    /* VFMSUBPSr132r */
  },
  { /* 4363 */
    593,
    /* VFMSUBPSr132rY */
  },
  { /* 4364 */
    590,
    /* VFMSUBPSr213m */
  },
  { /* 4365 */
    591,
    /* VFMSUBPSr213mY */
  },
  { /* 4366 */
    592,
    /* VFMSUBPSr213r */
  },
  { /* 4367 */
    593,
    /* VFMSUBPSr213rY */
  },
  { /* 4368 */
    590,
    /* VFMSUBPSr231m */
  },
  { /* 4369 */
    591,
    /* VFMSUBPSr231mY */
  },
  { /* 4370 */
    592,
    /* VFMSUBPSr231r */
  },
  { /* 4371 */
    593,
    /* VFMSUBPSr231rY */
  },
  { /* 4372 */
    595,
    /* VFMSUBSD4mr */
  },
  { /* 4373 */
    0,
    /*  */
  },
  { /* 4374 */
    596,
    /* VFMSUBSD4rm */
  },
  { /* 4375 */
    0,
    /*  */
  },
  { /* 4376 */
    597,
    /* VFMSUBSD4rr */
  },
  { /* 4377 */
    0,
    /*  */
  },
  { /* 4378 */
    598,
    /* VFMSUBSD4rr_REV */
  },
  { /* 4379 */
    599,
    /* VFMSUBSDZm */
  },
  { /* 4380 */
    600,
    /* VFMSUBSDZr */
  },
  { /* 4381 */
    601,
    /* VFMSUBSDr132m */
  },
  { /* 4382 */
    602,
    /* VFMSUBSDr132r */
  },
  { /* 4383 */
    601,
    /* VFMSUBSDr213m */
  },
  { /* 4384 */
    602,
    /* VFMSUBSDr213r */
  },
  { /* 4385 */
    601,
    /* VFMSUBSDr231m */
  },
  { /* 4386 */
    602,
    /* VFMSUBSDr231r */
  },
  { /* 4387 */
    603,
    /* VFMSUBSS4mr */
  },
  { /* 4388 */
    0,
    /*  */
  },
  { /* 4389 */
    604,
    /* VFMSUBSS4rm */
  },
  { /* 4390 */
    0,
    /*  */
  },
  { /* 4391 */
    605,
    /* VFMSUBSS4rr */
  },
  { /* 4392 */
    0,
    /*  */
  },
  { /* 4393 */
    606,
    /* VFMSUBSS4rr_REV */
  },
  { /* 4394 */
    607,
    /* VFMSUBSSZm */
  },
  { /* 4395 */
    608,
    /* VFMSUBSSZr */
  },
  { /* 4396 */
    609,
    /* VFMSUBSSr132m */
  },
  { /* 4397 */
    610,
    /* VFMSUBSSr132r */
  },
  { /* 4398 */
    609,
    /* VFMSUBSSr213m */
  },
  { /* 4399 */
    610,
    /* VFMSUBSSr213r */
  },
  { /* 4400 */
    609,
    /* VFMSUBSSr231m */
  },
  { /* 4401 */
    610,
    /* VFMSUBSSr231r */
  },
  { /* 4402 */
    570,
    /* VFNMADD132PDZ128m */
  },
  { /* 4403 */
    571,
    /* VFNMADD132PDZ128mb */
  },
  { /* 4404 */
    572,
    /* VFNMADD132PDZ256m */
  },
  { /* 4405 */
    573,
    /* VFNMADD132PDZ256mb */
  },
  { /* 4406 */
    574,
    /* VFNMADD132PDZm */
  },
  { /* 4407 */
    575,
    /* VFNMADD132PDZmb */
  },
  { /* 4408 */
    570,
    /* VFNMADD132PSZ128m */
  },
  { /* 4409 */
    576,
    /* VFNMADD132PSZ128mb */
  },
  { /* 4410 */
    572,
    /* VFNMADD132PSZ256m */
  },
  { /* 4411 */
    577,
    /* VFNMADD132PSZ256mb */
  },
  { /* 4412 */
    574,
    /* VFNMADD132PSZm */
  },
  { /* 4413 */
    578,
    /* VFNMADD132PSZmb */
  },
  { /* 4414 */
    394,
    /* VFNMADDPD4mr */
  },
  { /* 4415 */
    392,
    /* VFNMADDPD4mrY */
  },
  { /* 4416 */
    579,
    /* VFNMADDPD4rm */
  },
  { /* 4417 */
    580,
    /* VFNMADDPD4rmY */
  },
  { /* 4418 */
    581,
    /* VFNMADDPD4rr */
  },
  { /* 4419 */
    582,
    /* VFNMADDPD4rrY */
  },
  { /* 4420 */
    393,
    /* VFNMADDPD4rrY_REV */
  },
  { /* 4421 */
    395,
    /* VFNMADDPD4rr_REV */
  },
  { /* 4422 */
    570,
    /* VFNMADDPDZ128v213rm */
  },
  { /* 4423 */
    583,
    /* VFNMADDPDZ128v213rmb */
  },
  { /* 4424 */
    306,
    /* VFNMADDPDZ128v213rmbk */
  },
  { /* 4425 */
    306,
    /* VFNMADDPDZ128v213rmbkz */
  },
  { /* 4426 */
    308,
    /* VFNMADDPDZ128v213rmk */
  },
  { /* 4427 */
    308,
    /* VFNMADDPDZ128v213rmkz */
  },
  { /* 4428 */
    584,
    /* VFNMADDPDZ128v213rr */
  },
  { /* 4429 */
    311,
    /* VFNMADDPDZ128v213rrk */
  },
  { /* 4430 */
    311,
    /* VFNMADDPDZ128v213rrkz */
  },
  { /* 4431 */
    570,
    /* VFNMADDPDZ128v231rm */
  },
  { /* 4432 */
    583,
    /* VFNMADDPDZ128v231rmb */
  },
  { /* 4433 */
    306,
    /* VFNMADDPDZ128v231rmbk */
  },
  { /* 4434 */
    306,
    /* VFNMADDPDZ128v231rmbkz */
  },
  { /* 4435 */
    308,
    /* VFNMADDPDZ128v231rmk */
  },
  { /* 4436 */
    308,
    /* VFNMADDPDZ128v231rmkz */
  },
  { /* 4437 */
    584,
    /* VFNMADDPDZ128v231rr */
  },
  { /* 4438 */
    311,
    /* VFNMADDPDZ128v231rrk */
  },
  { /* 4439 */
    311,
    /* VFNMADDPDZ128v231rrkz */
  },
  { /* 4440 */
    572,
    /* VFNMADDPDZ256v213rm */
  },
  { /* 4441 */
    585,
    /* VFNMADDPDZ256v213rmb */
  },
  { /* 4442 */
    315,
    /* VFNMADDPDZ256v213rmbk */
  },
  { /* 4443 */
    315,
    /* VFNMADDPDZ256v213rmbkz */
  },
  { /* 4444 */
    317,
    /* VFNMADDPDZ256v213rmk */
  },
  { /* 4445 */
    317,
    /* VFNMADDPDZ256v213rmkz */
  },
  { /* 4446 */
    586,
    /* VFNMADDPDZ256v213rr */
  },
  { /* 4447 */
    320,
    /* VFNMADDPDZ256v213rrk */
  },
  { /* 4448 */
    320,
    /* VFNMADDPDZ256v213rrkz */
  },
  { /* 4449 */
    572,
    /* VFNMADDPDZ256v231rm */
  },
  { /* 4450 */
    585,
    /* VFNMADDPDZ256v231rmb */
  },
  { /* 4451 */
    315,
    /* VFNMADDPDZ256v231rmbk */
  },
  { /* 4452 */
    315,
    /* VFNMADDPDZ256v231rmbkz */
  },
  { /* 4453 */
    317,
    /* VFNMADDPDZ256v231rmk */
  },
  { /* 4454 */
    317,
    /* VFNMADDPDZ256v231rmkz */
  },
  { /* 4455 */
    586,
    /* VFNMADDPDZ256v231rr */
  },
  { /* 4456 */
    320,
    /* VFNMADDPDZ256v231rrk */
  },
  { /* 4457 */
    320,
    /* VFNMADDPDZ256v231rrkz */
  },
  { /* 4458 */
    574,
    /* VFNMADDPDZv213rm */
  },
  { /* 4459 */
    587,
    /* VFNMADDPDZv213rmb */
  },
  { /* 4460 */
    327,
    /* VFNMADDPDZv213rmbk */
  },
  { /* 4461 */
    327,
    /* VFNMADDPDZv213rmbkz */
  },
  { /* 4462 */
    329,
    /* VFNMADDPDZv213rmk */
  },
  { /* 4463 */
    329,
    /* VFNMADDPDZv213rmkz */
  },
  { /* 4464 */
    588,
    /* VFNMADDPDZv213rr */
  },
  { /* 4465 */
    589,
    /* VFNMADDPDZv213rrb */
  },
  { /* 4466 */
    323,
    /* VFNMADDPDZv213rrbk */
  },
  { /* 4467 */
    323,
    /* VFNMADDPDZv213rrbkz */
  },
  { /* 4468 */
    332,
    /* VFNMADDPDZv213rrk */
  },
  { /* 4469 */
    332,
    /* VFNMADDPDZv213rrkz */
  },
  { /* 4470 */
    574,
    /* VFNMADDPDZv231rm */
  },
  { /* 4471 */
    587,
    /* VFNMADDPDZv231rmb */
  },
  { /* 4472 */
    327,
    /* VFNMADDPDZv231rmbk */
  },
  { /* 4473 */
    327,
    /* VFNMADDPDZv231rmbkz */
  },
  { /* 4474 */
    329,
    /* VFNMADDPDZv231rmk */
  },
  { /* 4475 */
    329,
    /* VFNMADDPDZv231rmkz */
  },
  { /* 4476 */
    588,
    /* VFNMADDPDZv231rr */
  },
  { /* 4477 */
    332,
    /* VFNMADDPDZv231rrk */
  },
  { /* 4478 */
    332,
    /* VFNMADDPDZv231rrkz */
  },
  { /* 4479 */
    590,
    /* VFNMADDPDr132m */
  },
  { /* 4480 */
    591,
    /* VFNMADDPDr132mY */
  },
  { /* 4481 */
    592,
    /* VFNMADDPDr132r */
  },
  { /* 4482 */
    593,
    /* VFNMADDPDr132rY */
  },
  { /* 4483 */
    590,
    /* VFNMADDPDr213m */
  },
  { /* 4484 */
    591,
    /* VFNMADDPDr213mY */
  },
  { /* 4485 */
    592,
    /* VFNMADDPDr213r */
  },
  { /* 4486 */
    593,
    /* VFNMADDPDr213rY */
  },
  { /* 4487 */
    590,
    /* VFNMADDPDr231m */
  },
  { /* 4488 */
    591,
    /* VFNMADDPDr231mY */
  },
  { /* 4489 */
    592,
    /* VFNMADDPDr231r */
  },
  { /* 4490 */
    593,
    /* VFNMADDPDr231rY */
  },
  { /* 4491 */
    394,
    /* VFNMADDPS4mr */
  },
  { /* 4492 */
    392,
    /* VFNMADDPS4mrY */
  },
  { /* 4493 */
    579,
    /* VFNMADDPS4rm */
  },
  { /* 4494 */
    580,
    /* VFNMADDPS4rmY */
  },
  { /* 4495 */
    581,
    /* VFNMADDPS4rr */
  },
  { /* 4496 */
    582,
    /* VFNMADDPS4rrY */
  },
  { /* 4497 */
    393,
    /* VFNMADDPS4rrY_REV */
  },
  { /* 4498 */
    395,
    /* VFNMADDPS4rr_REV */
  },
  { /* 4499 */
    570,
    /* VFNMADDPSZ128v213rm */
  },
  { /* 4500 */
    576,
    /* VFNMADDPSZ128v213rmb */
  },
  { /* 4501 */
    337,
    /* VFNMADDPSZ128v213rmbk */
  },
  { /* 4502 */
    337,
    /* VFNMADDPSZ128v213rmbkz */
  },
  { /* 4503 */
    339,
    /* VFNMADDPSZ128v213rmk */
  },
  { /* 4504 */
    339,
    /* VFNMADDPSZ128v213rmkz */
  },
  { /* 4505 */
    584,
    /* VFNMADDPSZ128v213rr */
  },
  { /* 4506 */
    341,
    /* VFNMADDPSZ128v213rrk */
  },
  { /* 4507 */
    341,
    /* VFNMADDPSZ128v213rrkz */
  },
  { /* 4508 */
    570,
    /* VFNMADDPSZ128v231rm */
  },
  { /* 4509 */
    576,
    /* VFNMADDPSZ128v231rmb */
  },
  { /* 4510 */
    337,
    /* VFNMADDPSZ128v231rmbk */
  },
  { /* 4511 */
    337,
    /* VFNMADDPSZ128v231rmbkz */
  },
  { /* 4512 */
    339,
    /* VFNMADDPSZ128v231rmk */
  },
  { /* 4513 */
    339,
    /* VFNMADDPSZ128v231rmkz */
  },
  { /* 4514 */
    584,
    /* VFNMADDPSZ128v231rr */
  },
  { /* 4515 */
    341,
    /* VFNMADDPSZ128v231rrk */
  },
  { /* 4516 */
    341,
    /* VFNMADDPSZ128v231rrkz */
  },
  { /* 4517 */
    572,
    /* VFNMADDPSZ256v213rm */
  },
  { /* 4518 */
    577,
    /* VFNMADDPSZ256v213rmb */
  },
  { /* 4519 */
    344,
    /* VFNMADDPSZ256v213rmbk */
  },
  { /* 4520 */
    344,
    /* VFNMADDPSZ256v213rmbkz */
  },
  { /* 4521 */
    346,
    /* VFNMADDPSZ256v213rmk */
  },
  { /* 4522 */
    346,
    /* VFNMADDPSZ256v213rmkz */
  },
  { /* 4523 */
    586,
    /* VFNMADDPSZ256v213rr */
  },
  { /* 4524 */
    348,
    /* VFNMADDPSZ256v213rrk */
  },
  { /* 4525 */
    348,
    /* VFNMADDPSZ256v213rrkz */
  },
  { /* 4526 */
    572,
    /* VFNMADDPSZ256v231rm */
  },
  { /* 4527 */
    577,
    /* VFNMADDPSZ256v231rmb */
  },
  { /* 4528 */
    344,
    /* VFNMADDPSZ256v231rmbk */
  },
  { /* 4529 */
    344,
    /* VFNMADDPSZ256v231rmbkz */
  },
  { /* 4530 */
    346,
    /* VFNMADDPSZ256v231rmk */
  },
  { /* 4531 */
    346,
    /* VFNMADDPSZ256v231rmkz */
  },
  { /* 4532 */
    586,
    /* VFNMADDPSZ256v231rr */
  },
  { /* 4533 */
    348,
    /* VFNMADDPSZ256v231rrk */
  },
  { /* 4534 */
    348,
    /* VFNMADDPSZ256v231rrkz */
  },
  { /* 4535 */
    574,
    /* VFNMADDPSZv213rm */
  },
  { /* 4536 */
    578,
    /* VFNMADDPSZv213rmb */
  },
  { /* 4537 */
    354,
    /* VFNMADDPSZv213rmbk */
  },
  { /* 4538 */
    354,
    /* VFNMADDPSZv213rmbkz */
  },
  { /* 4539 */
    356,
    /* VFNMADDPSZv213rmk */
  },
  { /* 4540 */
    356,
    /* VFNMADDPSZv213rmkz */
  },
  { /* 4541 */
    588,
    /* VFNMADDPSZv213rr */
  },
  { /* 4542 */
    594,
    /* VFNMADDPSZv213rrb */
  },
  { /* 4543 */
    351,
    /* VFNMADDPSZv213rrbk */
  },
  { /* 4544 */
    351,
    /* VFNMADDPSZv213rrbkz */
  },
  { /* 4545 */
    358,
    /* VFNMADDPSZv213rrk */
  },
  { /* 4546 */
    358,
    /* VFNMADDPSZv213rrkz */
  },
  { /* 4547 */
    574,
    /* VFNMADDPSZv231rm */
  },
  { /* 4548 */
    578,
    /* VFNMADDPSZv231rmb */
  },
  { /* 4549 */
    354,
    /* VFNMADDPSZv231rmbk */
  },
  { /* 4550 */
    354,
    /* VFNMADDPSZv231rmbkz */
  },
  { /* 4551 */
    356,
    /* VFNMADDPSZv231rmk */
  },
  { /* 4552 */
    356,
    /* VFNMADDPSZv231rmkz */
  },
  { /* 4553 */
    588,
    /* VFNMADDPSZv231rr */
  },
  { /* 4554 */
    358,
    /* VFNMADDPSZv231rrk */
  },
  { /* 4555 */
    358,
    /* VFNMADDPSZv231rrkz */
  },
  { /* 4556 */
    590,
    /* VFNMADDPSr132m */
  },
  { /* 4557 */
    591,
    /* VFNMADDPSr132mY */
  },
  { /* 4558 */
    592,
    /* VFNMADDPSr132r */
  },
  { /* 4559 */
    593,
    /* VFNMADDPSr132rY */
  },
  { /* 4560 */
    590,
    /* VFNMADDPSr213m */
  },
  { /* 4561 */
    591,
    /* VFNMADDPSr213mY */
  },
  { /* 4562 */
    592,
    /* VFNMADDPSr213r */
  },
  { /* 4563 */
    593,
    /* VFNMADDPSr213rY */
  },
  { /* 4564 */
    590,
    /* VFNMADDPSr231m */
  },
  { /* 4565 */
    591,
    /* VFNMADDPSr231mY */
  },
  { /* 4566 */
    592,
    /* VFNMADDPSr231r */
  },
  { /* 4567 */
    593,
    /* VFNMADDPSr231rY */
  },
  { /* 4568 */
    595,
    /* VFNMADDSD4mr */
  },
  { /* 4569 */
    0,
    /*  */
  },
  { /* 4570 */
    596,
    /* VFNMADDSD4rm */
  },
  { /* 4571 */
    0,
    /*  */
  },
  { /* 4572 */
    597,
    /* VFNMADDSD4rr */
  },
  { /* 4573 */
    0,
    /*  */
  },
  { /* 4574 */
    598,
    /* VFNMADDSD4rr_REV */
  },
  { /* 4575 */
    599,
    /* VFNMADDSDZm */
  },
  { /* 4576 */
    600,
    /* VFNMADDSDZr */
  },
  { /* 4577 */
    601,
    /* VFNMADDSDr132m */
  },
  { /* 4578 */
    602,
    /* VFNMADDSDr132r */
  },
  { /* 4579 */
    601,
    /* VFNMADDSDr213m */
  },
  { /* 4580 */
    602,
    /* VFNMADDSDr213r */
  },
  { /* 4581 */
    601,
    /* VFNMADDSDr231m */
  },
  { /* 4582 */
    602,
    /* VFNMADDSDr231r */
  },
  { /* 4583 */
    603,
    /* VFNMADDSS4mr */
  },
  { /* 4584 */
    0,
    /*  */
  },
  { /* 4585 */
    604,
    /* VFNMADDSS4rm */
  },
  { /* 4586 */
    0,
    /*  */
  },
  { /* 4587 */
    605,
    /* VFNMADDSS4rr */
  },
  { /* 4588 */
    0,
    /*  */
  },
  { /* 4589 */
    606,
    /* VFNMADDSS4rr_REV */
  },
  { /* 4590 */
    607,
    /* VFNMADDSSZm */
  },
  { /* 4591 */
    608,
    /* VFNMADDSSZr */
  },
  { /* 4592 */
    609,
    /* VFNMADDSSr132m */
  },
  { /* 4593 */
    610,
    /* VFNMADDSSr132r */
  },
  { /* 4594 */
    609,
    /* VFNMADDSSr213m */
  },
  { /* 4595 */
    610,
    /* VFNMADDSSr213r */
  },
  { /* 4596 */
    609,
    /* VFNMADDSSr231m */
  },
  { /* 4597 */
    610,
    /* VFNMADDSSr231r */
  },
  { /* 4598 */
    570,
    /* VFNMSUB132PDZ128m */
  },
  { /* 4599 */
    571,
    /* VFNMSUB132PDZ128mb */
  },
  { /* 4600 */
    572,
    /* VFNMSUB132PDZ256m */
  },
  { /* 4601 */
    573,
    /* VFNMSUB132PDZ256mb */
  },
  { /* 4602 */
    574,
    /* VFNMSUB132PDZm */
  },
  { /* 4603 */
    575,
    /* VFNMSUB132PDZmb */
  },
  { /* 4604 */
    570,
    /* VFNMSUB132PSZ128m */
  },
  { /* 4605 */
    576,
    /* VFNMSUB132PSZ128mb */
  },
  { /* 4606 */
    572,
    /* VFNMSUB132PSZ256m */
  },
  { /* 4607 */
    577,
    /* VFNMSUB132PSZ256mb */
  },
  { /* 4608 */
    574,
    /* VFNMSUB132PSZm */
  },
  { /* 4609 */
    578,
    /* VFNMSUB132PSZmb */
  },
  { /* 4610 */
    394,
    /* VFNMSUBPD4mr */
  },
  { /* 4611 */
    392,
    /* VFNMSUBPD4mrY */
  },
  { /* 4612 */
    579,
    /* VFNMSUBPD4rm */
  },
  { /* 4613 */
    580,
    /* VFNMSUBPD4rmY */
  },
  { /* 4614 */
    581,
    /* VFNMSUBPD4rr */
  },
  { /* 4615 */
    582,
    /* VFNMSUBPD4rrY */
  },
  { /* 4616 */
    393,
    /* VFNMSUBPD4rrY_REV */
  },
  { /* 4617 */
    395,
    /* VFNMSUBPD4rr_REV */
  },
  { /* 4618 */
    570,
    /* VFNMSUBPDZ128v213rm */
  },
  { /* 4619 */
    583,
    /* VFNMSUBPDZ128v213rmb */
  },
  { /* 4620 */
    306,
    /* VFNMSUBPDZ128v213rmbk */
  },
  { /* 4621 */
    306,
    /* VFNMSUBPDZ128v213rmbkz */
  },
  { /* 4622 */
    308,
    /* VFNMSUBPDZ128v213rmk */
  },
  { /* 4623 */
    308,
    /* VFNMSUBPDZ128v213rmkz */
  },
  { /* 4624 */
    584,
    /* VFNMSUBPDZ128v213rr */
  },
  { /* 4625 */
    311,
    /* VFNMSUBPDZ128v213rrk */
  },
  { /* 4626 */
    311,
    /* VFNMSUBPDZ128v213rrkz */
  },
  { /* 4627 */
    570,
    /* VFNMSUBPDZ128v231rm */
  },
  { /* 4628 */
    583,
    /* VFNMSUBPDZ128v231rmb */
  },
  { /* 4629 */
    306,
    /* VFNMSUBPDZ128v231rmbk */
  },
  { /* 4630 */
    306,
    /* VFNMSUBPDZ128v231rmbkz */
  },
  { /* 4631 */
    308,
    /* VFNMSUBPDZ128v231rmk */
  },
  { /* 4632 */
    308,
    /* VFNMSUBPDZ128v231rmkz */
  },
  { /* 4633 */
    584,
    /* VFNMSUBPDZ128v231rr */
  },
  { /* 4634 */
    311,
    /* VFNMSUBPDZ128v231rrk */
  },
  { /* 4635 */
    311,
    /* VFNMSUBPDZ128v231rrkz */
  },
  { /* 4636 */
    572,
    /* VFNMSUBPDZ256v213rm */
  },
  { /* 4637 */
    585,
    /* VFNMSUBPDZ256v213rmb */
  },
  { /* 4638 */
    315,
    /* VFNMSUBPDZ256v213rmbk */
  },
  { /* 4639 */
    315,
    /* VFNMSUBPDZ256v213rmbkz */
  },
  { /* 4640 */
    317,
    /* VFNMSUBPDZ256v213rmk */
  },
  { /* 4641 */
    317,
    /* VFNMSUBPDZ256v213rmkz */
  },
  { /* 4642 */
    586,
    /* VFNMSUBPDZ256v213rr */
  },
  { /* 4643 */
    320,
    /* VFNMSUBPDZ256v213rrk */
  },
  { /* 4644 */
    320,
    /* VFNMSUBPDZ256v213rrkz */
  },
  { /* 4645 */
    572,
    /* VFNMSUBPDZ256v231rm */
  },
  { /* 4646 */
    585,
    /* VFNMSUBPDZ256v231rmb */
  },
  { /* 4647 */
    315,
    /* VFNMSUBPDZ256v231rmbk */
  },
  { /* 4648 */
    315,
    /* VFNMSUBPDZ256v231rmbkz */
  },
  { /* 4649 */
    317,
    /* VFNMSUBPDZ256v231rmk */
  },
  { /* 4650 */
    317,
    /* VFNMSUBPDZ256v231rmkz */
  },
  { /* 4651 */
    586,
    /* VFNMSUBPDZ256v231rr */
  },
  { /* 4652 */
    320,
    /* VFNMSUBPDZ256v231rrk */
  },
  { /* 4653 */
    320,
    /* VFNMSUBPDZ256v231rrkz */
  },
  { /* 4654 */
    574,
    /* VFNMSUBPDZv213rm */
  },
  { /* 4655 */
    587,
    /* VFNMSUBPDZv213rmb */
  },
  { /* 4656 */
    327,
    /* VFNMSUBPDZv213rmbk */
  },
  { /* 4657 */
    327,
    /* VFNMSUBPDZv213rmbkz */
  },
  { /* 4658 */
    329,
    /* VFNMSUBPDZv213rmk */
  },
  { /* 4659 */
    329,
    /* VFNMSUBPDZv213rmkz */
  },
  { /* 4660 */
    588,
    /* VFNMSUBPDZv213rr */
  },
  { /* 4661 */
    589,
    /* VFNMSUBPDZv213rrb */
  },
  { /* 4662 */
    323,
    /* VFNMSUBPDZv213rrbk */
  },
  { /* 4663 */
    323,
    /* VFNMSUBPDZv213rrbkz */
  },
  { /* 4664 */
    332,
    /* VFNMSUBPDZv213rrk */
  },
  { /* 4665 */
    332,
    /* VFNMSUBPDZv213rrkz */
  },
  { /* 4666 */
    574,
    /* VFNMSUBPDZv231rm */
  },
  { /* 4667 */
    587,
    /* VFNMSUBPDZv231rmb */
  },
  { /* 4668 */
    327,
    /* VFNMSUBPDZv231rmbk */
  },
  { /* 4669 */
    327,
    /* VFNMSUBPDZv231rmbkz */
  },
  { /* 4670 */
    329,
    /* VFNMSUBPDZv231rmk */
  },
  { /* 4671 */
    329,
    /* VFNMSUBPDZv231rmkz */
  },
  { /* 4672 */
    588,
    /* VFNMSUBPDZv231rr */
  },
  { /* 4673 */
    332,
    /* VFNMSUBPDZv231rrk */
  },
  { /* 4674 */
    332,
    /* VFNMSUBPDZv231rrkz */
  },
  { /* 4675 */
    590,
    /* VFNMSUBPDr132m */
  },
  { /* 4676 */
    591,
    /* VFNMSUBPDr132mY */
  },
  { /* 4677 */
    592,
    /* VFNMSUBPDr132r */
  },
  { /* 4678 */
    593,
    /* VFNMSUBPDr132rY */
  },
  { /* 4679 */
    590,
    /* VFNMSUBPDr213m */
  },
  { /* 4680 */
    591,
    /* VFNMSUBPDr213mY */
  },
  { /* 4681 */
    592,
    /* VFNMSUBPDr213r */
  },
  { /* 4682 */
    593,
    /* VFNMSUBPDr213rY */
  },
  { /* 4683 */
    590,
    /* VFNMSUBPDr231m */
  },
  { /* 4684 */
    591,
    /* VFNMSUBPDr231mY */
  },
  { /* 4685 */
    592,
    /* VFNMSUBPDr231r */
  },
  { /* 4686 */
    593,
    /* VFNMSUBPDr231rY */
  },
  { /* 4687 */
    394,
    /* VFNMSUBPS4mr */
  },
  { /* 4688 */
    392,
    /* VFNMSUBPS4mrY */
  },
  { /* 4689 */
    579,
    /* VFNMSUBPS4rm */
  },
  { /* 4690 */
    580,
    /* VFNMSUBPS4rmY */
  },
  { /* 4691 */
    581,
    /* VFNMSUBPS4rr */
  },
  { /* 4692 */
    582,
    /* VFNMSUBPS4rrY */
  },
  { /* 4693 */
    393,
    /* VFNMSUBPS4rrY_REV */
  },
  { /* 4694 */
    395,
    /* VFNMSUBPS4rr_REV */
  },
  { /* 4695 */
    570,
    /* VFNMSUBPSZ128v213rm */
  },
  { /* 4696 */
    576,
    /* VFNMSUBPSZ128v213rmb */
  },
  { /* 4697 */
    337,
    /* VFNMSUBPSZ128v213rmbk */
  },
  { /* 4698 */
    337,
    /* VFNMSUBPSZ128v213rmbkz */
  },
  { /* 4699 */
    339,
    /* VFNMSUBPSZ128v213rmk */
  },
  { /* 4700 */
    339,
    /* VFNMSUBPSZ128v213rmkz */
  },
  { /* 4701 */
    584,
    /* VFNMSUBPSZ128v213rr */
  },
  { /* 4702 */
    341,
    /* VFNMSUBPSZ128v213rrk */
  },
  { /* 4703 */
    341,
    /* VFNMSUBPSZ128v213rrkz */
  },
  { /* 4704 */
    570,
    /* VFNMSUBPSZ128v231rm */
  },
  { /* 4705 */
    576,
    /* VFNMSUBPSZ128v231rmb */
  },
  { /* 4706 */
    337,
    /* VFNMSUBPSZ128v231rmbk */
  },
  { /* 4707 */
    337,
    /* VFNMSUBPSZ128v231rmbkz */
  },
  { /* 4708 */
    339,
    /* VFNMSUBPSZ128v231rmk */
  },
  { /* 4709 */
    339,
    /* VFNMSUBPSZ128v231rmkz */
  },
  { /* 4710 */
    584,
    /* VFNMSUBPSZ128v231rr */
  },
  { /* 4711 */
    341,
    /* VFNMSUBPSZ128v231rrk */
  },
  { /* 4712 */
    341,
    /* VFNMSUBPSZ128v231rrkz */
  },
  { /* 4713 */
    572,
    /* VFNMSUBPSZ256v213rm */
  },
  { /* 4714 */
    577,
    /* VFNMSUBPSZ256v213rmb */
  },
  { /* 4715 */
    344,
    /* VFNMSUBPSZ256v213rmbk */
  },
  { /* 4716 */
    344,
    /* VFNMSUBPSZ256v213rmbkz */
  },
  { /* 4717 */
    346,
    /* VFNMSUBPSZ256v213rmk */
  },
  { /* 4718 */
    346,
    /* VFNMSUBPSZ256v213rmkz */
  },
  { /* 4719 */
    586,
    /* VFNMSUBPSZ256v213rr */
  },
  { /* 4720 */
    348,
    /* VFNMSUBPSZ256v213rrk */
  },
  { /* 4721 */
    348,
    /* VFNMSUBPSZ256v213rrkz */
  },
  { /* 4722 */
    572,
    /* VFNMSUBPSZ256v231rm */
  },
  { /* 4723 */
    577,
    /* VFNMSUBPSZ256v231rmb */
  },
  { /* 4724 */
    344,
    /* VFNMSUBPSZ256v231rmbk */
  },
  { /* 4725 */
    344,
    /* VFNMSUBPSZ256v231rmbkz */
  },
  { /* 4726 */
    346,
    /* VFNMSUBPSZ256v231rmk */
  },
  { /* 4727 */
    346,
    /* VFNMSUBPSZ256v231rmkz */
  },
  { /* 4728 */
    586,
    /* VFNMSUBPSZ256v231rr */
  },
  { /* 4729 */
    348,
    /* VFNMSUBPSZ256v231rrk */
  },
  { /* 4730 */
    348,
    /* VFNMSUBPSZ256v231rrkz */
  },
  { /* 4731 */
    574,
    /* VFNMSUBPSZv213rm */
  },
  { /* 4732 */
    578,
    /* VFNMSUBPSZv213rmb */
  },
  { /* 4733 */
    354,
    /* VFNMSUBPSZv213rmbk */
  },
  { /* 4734 */
    354,
    /* VFNMSUBPSZv213rmbkz */
  },
  { /* 4735 */
    356,
    /* VFNMSUBPSZv213rmk */
  },
  { /* 4736 */
    356,
    /* VFNMSUBPSZv213rmkz */
  },
  { /* 4737 */
    588,
    /* VFNMSUBPSZv213rr */
  },
  { /* 4738 */
    594,
    /* VFNMSUBPSZv213rrb */
  },
  { /* 4739 */
    351,
    /* VFNMSUBPSZv213rrbk */
  },
  { /* 4740 */
    351,
    /* VFNMSUBPSZv213rrbkz */
  },
  { /* 4741 */
    358,
    /* VFNMSUBPSZv213rrk */
  },
  { /* 4742 */
    358,
    /* VFNMSUBPSZv213rrkz */
  },
  { /* 4743 */
    574,
    /* VFNMSUBPSZv231rm */
  },
  { /* 4744 */
    578,
    /* VFNMSUBPSZv231rmb */
  },
  { /* 4745 */
    354,
    /* VFNMSUBPSZv231rmbk */
  },
  { /* 4746 */
    354,
    /* VFNMSUBPSZv231rmbkz */
  },
  { /* 4747 */
    356,
    /* VFNMSUBPSZv231rmk */
  },
  { /* 4748 */
    356,
    /* VFNMSUBPSZv231rmkz */
  },
  { /* 4749 */
    588,
    /* VFNMSUBPSZv231rr */
  },
  { /* 4750 */
    358,
    /* VFNMSUBPSZv231rrk */
  },
  { /* 4751 */
    358,
    /* VFNMSUBPSZv231rrkz */
  },
  { /* 4752 */
    590,
    /* VFNMSUBPSr132m */
  },
  { /* 4753 */
    591,
    /* VFNMSUBPSr132mY */
  },
  { /* 4754 */
    592,
    /* VFNMSUBPSr132r */
  },
  { /* 4755 */
    593,
    /* VFNMSUBPSr132rY */
  },
  { /* 4756 */
    590,
    /* VFNMSUBPSr213m */
  },
  { /* 4757 */
    591,
    /* VFNMSUBPSr213mY */
  },
  { /* 4758 */
    592,
    /* VFNMSUBPSr213r */
  },
  { /* 4759 */
    593,
    /* VFNMSUBPSr213rY */
  },
  { /* 4760 */
    590,
    /* VFNMSUBPSr231m */
  },
  { /* 4761 */
    591,
    /* VFNMSUBPSr231mY */
  },
  { /* 4762 */
    592,
    /* VFNMSUBPSr231r */
  },
  { /* 4763 */
    593,
    /* VFNMSUBPSr231rY */
  },
  { /* 4764 */
    595,
    /* VFNMSUBSD4mr */
  },
  { /* 4765 */
    0,
    /*  */
  },
  { /* 4766 */
    596,
    /* VFNMSUBSD4rm */
  },
  { /* 4767 */
    0,
    /*  */
  },
  { /* 4768 */
    597,
    /* VFNMSUBSD4rr */
  },
  { /* 4769 */
    0,
    /*  */
  },
  { /* 4770 */
    598,
    /* VFNMSUBSD4rr_REV */
  },
  { /* 4771 */
    599,
    /* VFNMSUBSDZm */
  },
  { /* 4772 */
    600,
    /* VFNMSUBSDZr */
  },
  { /* 4773 */
    601,
    /* VFNMSUBSDr132m */
  },
  { /* 4774 */
    602,
    /* VFNMSUBSDr132r */
  },
  { /* 4775 */
    601,
    /* VFNMSUBSDr213m */
  },
  { /* 4776 */
    602,
    /* VFNMSUBSDr213r */
  },
  { /* 4777 */
    601,
    /* VFNMSUBSDr231m */
  },
  { /* 4778 */
    602,
    /* VFNMSUBSDr231r */
  },
  { /* 4779 */
    603,
    /* VFNMSUBSS4mr */
  },
  { /* 4780 */
    0,
    /*  */
  },
  { /* 4781 */
    604,
    /* VFNMSUBSS4rm */
  },
  { /* 4782 */
    0,
    /*  */
  },
  { /* 4783 */
    605,
    /* VFNMSUBSS4rr */
  },
  { /* 4784 */
    0,
    /*  */
  },
  { /* 4785 */
    606,
    /* VFNMSUBSS4rr_REV */
  },
  { /* 4786 */
    607,
    /* VFNMSUBSSZm */
  },
  { /* 4787 */
    608,
    /* VFNMSUBSSZr */
  },
  { /* 4788 */
    609,
    /* VFNMSUBSSr132m */
  },
  { /* 4789 */
    610,
    /* VFNMSUBSSr132r */
  },
  { /* 4790 */
    609,
    /* VFNMSUBSSr213m */
  },
  { /* 4791 */
    610,
    /* VFNMSUBSSr213r */
  },
  { /* 4792 */
    609,
    /* VFNMSUBSSr231m */
  },
  { /* 4793 */
    610,
    /* VFNMSUBSSr231r */
  },
  { /* 4794 */
    44,
    /* VFRCZPDrm */
  },
  { /* 4795 */
    475,
    /* VFRCZPDrmY */
  },
  { /* 4796 */
    45,
    /* VFRCZPDrr */
  },
  { /* 4797 */
    476,
    /* VFRCZPDrrY */
  },
  { /* 4798 */
    44,
    /* VFRCZPSrm */
  },
  { /* 4799 */
    475,
    /* VFRCZPSrmY */
  },
  { /* 4800 */
    45,
    /* VFRCZPSrr */
  },
  { /* 4801 */
    476,
    /* VFRCZPSrrY */
  },
  { /* 4802 */
    106,
    /* VFRCZSDrm */
  },
  { /* 4803 */
    45,
    /* VFRCZSDrr */
  },
  { /* 4804 */
    434,
    /* VFRCZSSrm */
  },
  { /* 4805 */
    45,
    /* VFRCZSSrr */
  },
  { /* 4806 */
    0,
    /*  */
  },
  { /* 4807 */
    0,
    /*  */
  },
  { /* 4808 */
    0,
    /*  */
  },
  { /* 4809 */
    0,
    /*  */
  },
  { /* 4810 */
    0,
    /*  */
  },
  { /* 4811 */
    0,
    /*  */
  },
  { /* 4812 */
    0,
    /*  */
  },
  { /* 4813 */
    0,
    /*  */
  },
  { /* 4814 */
    0,
    /*  */
  },
  { /* 4815 */
    0,
    /*  */
  },
  { /* 4816 */
    0,
    /*  */
  },
  { /* 4817 */
    0,
    /*  */
  },
  { /* 4818 */
    0,
    /*  */
  },
  { /* 4819 */
    0,
    /*  */
  },
  { /* 4820 */
    0,
    /*  */
  },
  { /* 4821 */
    0,
    /*  */
  },
  { /* 4822 */
    0,
    /*  */
  },
  { /* 4823 */
    0,
    /*  */
  },
  { /* 4824 */
    0,
    /*  */
  },
  { /* 4825 */
    0,
    /*  */
  },
  { /* 4826 */
    0,
    /*  */
  },
  { /* 4827 */
    0,
    /*  */
  },
  { /* 4828 */
    0,
    /*  */
  },
  { /* 4829 */
    0,
    /*  */
  },
  { /* 4830 */
    0,
    /*  */
  },
  { /* 4831 */
    0,
    /*  */
  },
  { /* 4832 */
    0,
    /*  */
  },
  { /* 4833 */
    0,
    /*  */
  },
  { /* 4834 */
    0,
    /*  */
  },
  { /* 4835 */
    0,
    /*  */
  },
  { /* 4836 */
    0,
    /*  */
  },
  { /* 4837 */
    0,
    /*  */
  },
  { /* 4838 */
    611,
    /* VGATHERDPDYrm */
  },
  { /* 4839 */
    612,
    /* VGATHERDPDZrm */
  },
  { /* 4840 */
    613,
    /* VGATHERDPDrm */
  },
  { /* 4841 */
    614,
    /* VGATHERDPSYrm */
  },
  { /* 4842 */
    615,
    /* VGATHERDPSZrm */
  },
  { /* 4843 */
    616,
    /* VGATHERDPSrm */
  },
  { /* 4844 */
    617,
    /* VGATHERPF0DPDm */
  },
  { /* 4845 */
    618,
    /* VGATHERPF0DPSm */
  },
  { /* 4846 */
    619,
    /* VGATHERPF0QPDm */
  },
  { /* 4847 */
    619,
    /* VGATHERPF0QPSm */
  },
  { /* 4848 */
    617,
    /* VGATHERPF1DPDm */
  },
  { /* 4849 */
    618,
    /* VGATHERPF1DPSm */
  },
  { /* 4850 */
    619,
    /* VGATHERPF1QPDm */
  },
  { /* 4851 */
    619,
    /* VGATHERPF1QPSm */
  },
  { /* 4852 */
    611,
    /* VGATHERQPDYrm */
  },
  { /* 4853 */
    612,
    /* VGATHERQPDZrm */
  },
  { /* 4854 */
    613,
    /* VGATHERQPDrm */
  },
  { /* 4855 */
    616,
    /* VGATHERQPSYrm */
  },
  { /* 4856 */
    620,
    /* VGATHERQPSZrm */
  },
  { /* 4857 */
    616,
    /* VGATHERQPSrm */
  },
  { /* 4858 */
    302,
    /* VHADDPDYrm */
  },
  { /* 4859 */
    303,
    /* VHADDPDYrr */
  },
  { /* 4860 */
    334,
    /* VHADDPDrm */
  },
  { /* 4861 */
    335,
    /* VHADDPDrr */
  },
  { /* 4862 */
    302,
    /* VHADDPSYrm */
  },
  { /* 4863 */
    303,
    /* VHADDPSYrr */
  },
  { /* 4864 */
    334,
    /* VHADDPSrm */
  },
  { /* 4865 */
    335,
    /* VHADDPSrr */
  },
  { /* 4866 */
    302,
    /* VHSUBPDYrm */
  },
  { /* 4867 */
    303,
    /* VHSUBPDYrr */
  },
  { /* 4868 */
    334,
    /* VHSUBPDrm */
  },
  { /* 4869 */
    335,
    /* VHSUBPDrr */
  },
  { /* 4870 */
    302,
    /* VHSUBPSYrm */
  },
  { /* 4871 */
    303,
    /* VHSUBPSYrr */
  },
  { /* 4872 */
    334,
    /* VHSUBPSrm */
  },
  { /* 4873 */
    335,
    /* VHSUBPSrr */
  },
  { /* 4874 */
    621,
    /* VINSERTF128rm */
  },
  { /* 4875 */
    622,
    /* VINSERTF128rr */
  },
  { /* 4876 */
    623,
    /* VINSERTF32x4rm */
  },
  { /* 4877 */
    624,
    /* VINSERTF32x4rr */
  },
  { /* 4878 */
    625,
    /* VINSERTF32x8rm */
  },
  { /* 4879 */
    626,
    /* VINSERTF32x8rr */
  },
  { /* 4880 */
    623,
    /* VINSERTF64x2rm */
  },
  { /* 4881 */
    624,
    /* VINSERTF64x2rr */
  },
  { /* 4882 */
    625,
    /* VINSERTF64x4rm */
  },
  { /* 4883 */
    626,
    /* VINSERTF64x4rr */
  },
  { /* 4884 */
    621,
    /* VINSERTI128rm */
  },
  { /* 4885 */
    622,
    /* VINSERTI128rr */
  },
  { /* 4886 */
    623,
    /* VINSERTI32x4rm */
  },
  { /* 4887 */
    624,
    /* VINSERTI32x4rr */
  },
  { /* 4888 */
    625,
    /* VINSERTI32x8rm */
  },
  { /* 4889 */
    626,
    /* VINSERTI32x8rr */
  },
  { /* 4890 */
    623,
    /* VINSERTI64x2rm */
  },
  { /* 4891 */
    624,
    /* VINSERTI64x2rr */
  },
  { /* 4892 */
    625,
    /* VINSERTI64x4rm */
  },
  { /* 4893 */
    626,
    /* VINSERTI64x4rr */
  },
  { /* 4894 */
    627,
    /* VINSERTPSrm */
  },
  { /* 4895 */
    391,
    /* VINSERTPSrr */
  },
  { /* 4896 */
    628,
    /* VINSERTPSzrm */
  },
  { /* 4897 */
    629,
    /* VINSERTPSzrr */
  },
  { /* 4898 */
    475,
    /* VLDDQUYrm */
  },
  { /* 4899 */
    44,
    /* VLDDQUrm */
  },
  { /* 4900 */
    38,
    /* VLDMXCSR */
  },
  { /* 4901 */
    45,
    /* VMASKMOVDQU */
  },
  { /* 4902 */
    0,
    /*  */
  },
  { /* 4903 */
    630,
    /* VMASKMOVPDYmr */
  },
  { /* 4904 */
    302,
    /* VMASKMOVPDYrm */
  },
  { /* 4905 */
    631,
    /* VMASKMOVPDmr */
  },
  { /* 4906 */
    334,
    /* VMASKMOVPDrm */
  },
  { /* 4907 */
    630,
    /* VMASKMOVPSYmr */
  },
  { /* 4908 */
    302,
    /* VMASKMOVPSYrm */
  },
  { /* 4909 */
    631,
    /* VMASKMOVPSmr */
  },
  { /* 4910 */
    334,
    /* VMASKMOVPSrm */
  },
  { /* 4911 */
    0,
    /*  */
  },
  { /* 4912 */
    0,
    /*  */
  },
  { /* 4913 */
    0,
    /*  */
  },
  { /* 4914 */
    0,
    /*  */
  },
  { /* 4915 */
    0,
    /*  */
  },
  { /* 4916 */
    0,
    /*  */
  },
  { /* 4917 */
    0,
    /*  */
  },
  { /* 4918 */
    0,
    /*  */
  },
  { /* 4919 */
    0,
    /*  */
  },
  { /* 4920 */
    0,
    /*  */
  },
  { /* 4921 */
    0,
    /*  */
  },
  { /* 4922 */
    0,
    /*  */
  },
  { /* 4923 */
    302,
    /* VMAXPDYrm */
  },
  { /* 4924 */
    303,
    /* VMAXPDYrr */
  },
  { /* 4925 */
    304,
    /* VMAXPDZ128rm */
  },
  { /* 4926 */
    305,
    /* VMAXPDZ128rmb */
  },
  { /* 4927 */
    306,
    /* VMAXPDZ128rmbk */
  },
  { /* 4928 */
    307,
    /* VMAXPDZ128rmbkz */
  },
  { /* 4929 */
    308,
    /* VMAXPDZ128rmk */
  },
  { /* 4930 */
    309,
    /* VMAXPDZ128rmkz */
  },
  { /* 4931 */
    310,
    /* VMAXPDZ128rr */
  },
  { /* 4932 */
    311,
    /* VMAXPDZ128rrk */
  },
  { /* 4933 */
    312,
    /* VMAXPDZ128rrkz */
  },
  { /* 4934 */
    313,
    /* VMAXPDZ256rm */
  },
  { /* 4935 */
    314,
    /* VMAXPDZ256rmb */
  },
  { /* 4936 */
    315,
    /* VMAXPDZ256rmbk */
  },
  { /* 4937 */
    316,
    /* VMAXPDZ256rmbkz */
  },
  { /* 4938 */
    317,
    /* VMAXPDZ256rmk */
  },
  { /* 4939 */
    318,
    /* VMAXPDZ256rmkz */
  },
  { /* 4940 */
    319,
    /* VMAXPDZ256rr */
  },
  { /* 4941 */
    320,
    /* VMAXPDZ256rrk */
  },
  { /* 4942 */
    321,
    /* VMAXPDZ256rrkz */
  },
  { /* 4943 */
    325,
    /* VMAXPDZrm */
  },
  { /* 4944 */
    326,
    /* VMAXPDZrmb */
  },
  { /* 4945 */
    327,
    /* VMAXPDZrmbk */
  },
  { /* 4946 */
    328,
    /* VMAXPDZrmbkz */
  },
  { /* 4947 */
    329,
    /* VMAXPDZrmk */
  },
  { /* 4948 */
    330,
    /* VMAXPDZrmkz */
  },
  { /* 4949 */
    331,
    /* VMAXPDZrr */
  },
  { /* 4950 */
    332,
    /* VMAXPDZrrk */
  },
  { /* 4951 */
    333,
    /* VMAXPDZrrkz */
  },
  { /* 4952 */
    334,
    /* VMAXPDrm */
  },
  { /* 4953 */
    335,
    /* VMAXPDrr */
  },
  { /* 4954 */
    302,
    /* VMAXPSYrm */
  },
  { /* 4955 */
    303,
    /* VMAXPSYrr */
  },
  { /* 4956 */
    304,
    /* VMAXPSZ128rm */
  },
  { /* 4957 */
    336,
    /* VMAXPSZ128rmb */
  },
  { /* 4958 */
    337,
    /* VMAXPSZ128rmbk */
  },
  { /* 4959 */
    338,
    /* VMAXPSZ128rmbkz */
  },
  { /* 4960 */
    339,
    /* VMAXPSZ128rmk */
  },
  { /* 4961 */
    340,
    /* VMAXPSZ128rmkz */
  },
  { /* 4962 */
    310,
    /* VMAXPSZ128rr */
  },
  { /* 4963 */
    341,
    /* VMAXPSZ128rrk */
  },
  { /* 4964 */
    342,
    /* VMAXPSZ128rrkz */
  },
  { /* 4965 */
    313,
    /* VMAXPSZ256rm */
  },
  { /* 4966 */
    343,
    /* VMAXPSZ256rmb */
  },
  { /* 4967 */
    344,
    /* VMAXPSZ256rmbk */
  },
  { /* 4968 */
    345,
    /* VMAXPSZ256rmbkz */
  },
  { /* 4969 */
    346,
    /* VMAXPSZ256rmk */
  },
  { /* 4970 */
    347,
    /* VMAXPSZ256rmkz */
  },
  { /* 4971 */
    319,
    /* VMAXPSZ256rr */
  },
  { /* 4972 */
    348,
    /* VMAXPSZ256rrk */
  },
  { /* 4973 */
    349,
    /* VMAXPSZ256rrkz */
  },
  { /* 4974 */
    325,
    /* VMAXPSZrm */
  },
  { /* 4975 */
    353,
    /* VMAXPSZrmb */
  },
  { /* 4976 */
    354,
    /* VMAXPSZrmbk */
  },
  { /* 4977 */
    355,
    /* VMAXPSZrmbkz */
  },
  { /* 4978 */
    356,
    /* VMAXPSZrmk */
  },
  { /* 4979 */
    357,
    /* VMAXPSZrmkz */
  },
  { /* 4980 */
    331,
    /* VMAXPSZrr */
  },
  { /* 4981 */
    358,
    /* VMAXPSZrrk */
  },
  { /* 4982 */
    359,
    /* VMAXPSZrrkz */
  },
  { /* 4983 */
    334,
    /* VMAXPSrm */
  },
  { /* 4984 */
    335,
    /* VMAXPSrr */
  },
  { /* 4985 */
    0,
    /*  */
  },
  { /* 4986 */
    360,
    /* VMAXSDZrm_Int */
  },
  { /* 4987 */
    361,
    /* VMAXSDZrm_Intk */
  },
  { /* 4988 */
    362,
    /* VMAXSDZrm_Intkz */
  },
  { /* 4989 */
    0,
    /*  */
  },
  { /* 4990 */
    363,
    /* VMAXSDZrr_Int */
  },
  { /* 4991 */
    364,
    /* VMAXSDZrr_Intk */
  },
  { /* 4992 */
    365,
    /* VMAXSDZrr_Intkz */
  },
  { /* 4993 */
    363,
    /* VMAXSDZrrb */
  },
  { /* 4994 */
    364,
    /* VMAXSDZrrbk */
  },
  { /* 4995 */
    365,
    /* VMAXSDZrrbkz */
  },
  { /* 4996 */
    369,
    /* VMAXSDrm */
  },
  { /* 4997 */
    0,
    /*  */
  },
  { /* 4998 */
    370,
    /* VMAXSDrr */
  },
  { /* 4999 */
    0,
    /*  */
  },
  { /* 5000 */
    0,
    /*  */
  },
  { /* 5001 */
    371,
    /* VMAXSSZrm_Int */
  },
  { /* 5002 */
    372,
    /* VMAXSSZrm_Intk */
  },
  { /* 5003 */
    373,
    /* VMAXSSZrm_Intkz */
  },
  { /* 5004 */
    0,
    /*  */
  },
  { /* 5005 */
    374,
    /* VMAXSSZrr_Int */
  },
  { /* 5006 */
    375,
    /* VMAXSSZrr_Intk */
  },
  { /* 5007 */
    376,
    /* VMAXSSZrr_Intkz */
  },
  { /* 5008 */
    374,
    /* VMAXSSZrrb */
  },
  { /* 5009 */
    375,
    /* VMAXSSZrrbk */
  },
  { /* 5010 */
    376,
    /* VMAXSSZrrbkz */
  },
  { /* 5011 */
    380,
    /* VMAXSSrm */
  },
  { /* 5012 */
    0,
    /*  */
  },
  { /* 5013 */
    381,
    /* VMAXSSrr */
  },
  { /* 5014 */
    0,
    /*  */
  },
  { /* 5015 */
    0,
    /* VMCALL */
  },
  { /* 5016 */
    38,
    /* VMCLEARm */
  },
  { /* 5017 */
    0,
    /* VMFUNC */
  },
  { /* 5018 */
    0,
    /*  */
  },
  { /* 5019 */
    0,
    /*  */
  },
  { /* 5020 */
    0,
    /*  */
  },
  { /* 5021 */
    0,
    /*  */
  },
  { /* 5022 */
    0,
    /*  */
  },
  { /* 5023 */
    0,
    /*  */
  },
  { /* 5024 */
    0,
    /*  */
  },
  { /* 5025 */
    0,
    /*  */
  },
  { /* 5026 */
    0,
    /*  */
  },
  { /* 5027 */
    0,
    /*  */
  },
  { /* 5028 */
    0,
    /*  */
  },
  { /* 5029 */
    0,
    /*  */
  },
  { /* 5030 */
    302,
    /* VMINPDYrm */
  },
  { /* 5031 */
    303,
    /* VMINPDYrr */
  },
  { /* 5032 */
    304,
    /* VMINPDZ128rm */
  },
  { /* 5033 */
    305,
    /* VMINPDZ128rmb */
  },
  { /* 5034 */
    306,
    /* VMINPDZ128rmbk */
  },
  { /* 5035 */
    307,
    /* VMINPDZ128rmbkz */
  },
  { /* 5036 */
    308,
    /* VMINPDZ128rmk */
  },
  { /* 5037 */
    309,
    /* VMINPDZ128rmkz */
  },
  { /* 5038 */
    310,
    /* VMINPDZ128rr */
  },
  { /* 5039 */
    311,
    /* VMINPDZ128rrk */
  },
  { /* 5040 */
    312,
    /* VMINPDZ128rrkz */
  },
  { /* 5041 */
    313,
    /* VMINPDZ256rm */
  },
  { /* 5042 */
    314,
    /* VMINPDZ256rmb */
  },
  { /* 5043 */
    315,
    /* VMINPDZ256rmbk */
  },
  { /* 5044 */
    316,
    /* VMINPDZ256rmbkz */
  },
  { /* 5045 */
    317,
    /* VMINPDZ256rmk */
  },
  { /* 5046 */
    318,
    /* VMINPDZ256rmkz */
  },
  { /* 5047 */
    319,
    /* VMINPDZ256rr */
  },
  { /* 5048 */
    320,
    /* VMINPDZ256rrk */
  },
  { /* 5049 */
    321,
    /* VMINPDZ256rrkz */
  },
  { /* 5050 */
    325,
    /* VMINPDZrm */
  },
  { /* 5051 */
    326,
    /* VMINPDZrmb */
  },
  { /* 5052 */
    327,
    /* VMINPDZrmbk */
  },
  { /* 5053 */
    328,
    /* VMINPDZrmbkz */
  },
  { /* 5054 */
    329,
    /* VMINPDZrmk */
  },
  { /* 5055 */
    330,
    /* VMINPDZrmkz */
  },
  { /* 5056 */
    331,
    /* VMINPDZrr */
  },
  { /* 5057 */
    332,
    /* VMINPDZrrk */
  },
  { /* 5058 */
    333,
    /* VMINPDZrrkz */
  },
  { /* 5059 */
    334,
    /* VMINPDrm */
  },
  { /* 5060 */
    335,
    /* VMINPDrr */
  },
  { /* 5061 */
    302,
    /* VMINPSYrm */
  },
  { /* 5062 */
    303,
    /* VMINPSYrr */
  },
  { /* 5063 */
    304,
    /* VMINPSZ128rm */
  },
  { /* 5064 */
    336,
    /* VMINPSZ128rmb */
  },
  { /* 5065 */
    337,
    /* VMINPSZ128rmbk */
  },
  { /* 5066 */
    338,
    /* VMINPSZ128rmbkz */
  },
  { /* 5067 */
    339,
    /* VMINPSZ128rmk */
  },
  { /* 5068 */
    340,
    /* VMINPSZ128rmkz */
  },
  { /* 5069 */
    310,
    /* VMINPSZ128rr */
  },
  { /* 5070 */
    341,
    /* VMINPSZ128rrk */
  },
  { /* 5071 */
    342,
    /* VMINPSZ128rrkz */
  },
  { /* 5072 */
    313,
    /* VMINPSZ256rm */
  },
  { /* 5073 */
    343,
    /* VMINPSZ256rmb */
  },
  { /* 5074 */
    344,
    /* VMINPSZ256rmbk */
  },
  { /* 5075 */
    345,
    /* VMINPSZ256rmbkz */
  },
  { /* 5076 */
    346,
    /* VMINPSZ256rmk */
  },
  { /* 5077 */
    347,
    /* VMINPSZ256rmkz */
  },
  { /* 5078 */
    319,
    /* VMINPSZ256rr */
  },
  { /* 5079 */
    348,
    /* VMINPSZ256rrk */
  },
  { /* 5080 */
    349,
    /* VMINPSZ256rrkz */
  },
  { /* 5081 */
    325,
    /* VMINPSZrm */
  },
  { /* 5082 */
    353,
    /* VMINPSZrmb */
  },
  { /* 5083 */
    354,
    /* VMINPSZrmbk */
  },
  { /* 5084 */
    355,
    /* VMINPSZrmbkz */
  },
  { /* 5085 */
    356,
    /* VMINPSZrmk */
  },
  { /* 5086 */
    357,
    /* VMINPSZrmkz */
  },
  { /* 5087 */
    331,
    /* VMINPSZrr */
  },
  { /* 5088 */
    358,
    /* VMINPSZrrk */
  },
  { /* 5089 */
    359,
    /* VMINPSZrrkz */
  },
  { /* 5090 */
    334,
    /* VMINPSrm */
  },
  { /* 5091 */
    335,
    /* VMINPSrr */
  },
  { /* 5092 */
    0,
    /*  */
  },
  { /* 5093 */
    360,
    /* VMINSDZrm_Int */
  },
  { /* 5094 */
    361,
    /* VMINSDZrm_Intk */
  },
  { /* 5095 */
    362,
    /* VMINSDZrm_Intkz */
  },
  { /* 5096 */
    0,
    /*  */
  },
  { /* 5097 */
    363,
    /* VMINSDZrr_Int */
  },
  { /* 5098 */
    364,
    /* VMINSDZrr_Intk */
  },
  { /* 5099 */
    365,
    /* VMINSDZrr_Intkz */
  },
  { /* 5100 */
    363,
    /* VMINSDZrrb */
  },
  { /* 5101 */
    364,
    /* VMINSDZrrbk */
  },
  { /* 5102 */
    365,
    /* VMINSDZrrbkz */
  },
  { /* 5103 */
    369,
    /* VMINSDrm */
  },
  { /* 5104 */
    0,
    /*  */
  },
  { /* 5105 */
    370,
    /* VMINSDrr */
  },
  { /* 5106 */
    0,
    /*  */
  },
  { /* 5107 */
    0,
    /*  */
  },
  { /* 5108 */
    371,
    /* VMINSSZrm_Int */
  },
  { /* 5109 */
    372,
    /* VMINSSZrm_Intk */
  },
  { /* 5110 */
    373,
    /* VMINSSZrm_Intkz */
  },
  { /* 5111 */
    0,
    /*  */
  },
  { /* 5112 */
    374,
    /* VMINSSZrr_Int */
  },
  { /* 5113 */
    375,
    /* VMINSSZrr_Intk */
  },
  { /* 5114 */
    376,
    /* VMINSSZrr_Intkz */
  },
  { /* 5115 */
    374,
    /* VMINSSZrrb */
  },
  { /* 5116 */
    375,
    /* VMINSSZrrbk */
  },
  { /* 5117 */
    376,
    /* VMINSSZrrbkz */
  },
  { /* 5118 */
    380,
    /* VMINSSrm */
  },
  { /* 5119 */
    0,
    /*  */
  },
  { /* 5120 */
    381,
    /* VMINSSrr */
  },
  { /* 5121 */
    0,
    /*  */
  },
  { /* 5122 */
    0,
    /* VMLAUNCH */
  },
  { /* 5123 */
    0,
    /* VMLOAD32 */
  },
  { /* 5124 */
    0,
    /* VMLOAD64 */
  },
  { /* 5125 */
    0,
    /* VMMCALL */
  },
  { /* 5126 */
    632,
    /* VMOV64toPQIZrr */
  },
  { /* 5127 */
    105,
    /* VMOV64toPQIrm */
  },
  { /* 5128 */
    243,
    /* VMOV64toPQIrr */
  },
  { /* 5129 */
    0,
    /*  */
  },
  { /* 5130 */
    0,
    /*  */
  },
  { /* 5131 */
    0,
    /*  */
  },
  { /* 5132 */
    633,
    /* VMOVAPDYmr */
  },
  { /* 5133 */
    475,
    /* VMOVAPDYrm */
  },
  { /* 5134 */
    476,
    /* VMOVAPDYrr */
  },
  { /* 5135 */
    634,
    /* VMOVAPDYrr_REV */
  },
  { /* 5136 */
    635,
    /* VMOVAPDZ128mr */
  },
  { /* 5137 */
    636,
    /* VMOVAPDZ128mrk */
  },
  { /* 5138 */
    637,
    /* VMOVAPDZ128rm */
  },
  { /* 5139 */
    638,
    /* VMOVAPDZ128rmk */
  },
  { /* 5140 */
    639,
    /* VMOVAPDZ128rmkz */
  },
  { /* 5141 */
    640,
    /* VMOVAPDZ128rr */
  },
  { /* 5142 */
    641,
    /* VMOVAPDZ128rr_alt */
  },
  { /* 5143 */
    545,
    /* VMOVAPDZ128rrk */
  },
  { /* 5144 */
    457,
    /* VMOVAPDZ128rrk_alt */
  },
  { /* 5145 */
    546,
    /* VMOVAPDZ128rrkz */
  },
  { /* 5146 */
    458,
    /* VMOVAPDZ128rrkz_alt */
  },
  { /* 5147 */
    642,
    /* VMOVAPDZ256mr */
  },
  { /* 5148 */
    643,
    /* VMOVAPDZ256mrk */
  },
  { /* 5149 */
    644,
    /* VMOVAPDZ256rm */
  },
  { /* 5150 */
    645,
    /* VMOVAPDZ256rmk */
  },
  { /* 5151 */
    646,
    /* VMOVAPDZ256rmkz */
  },
  { /* 5152 */
    647,
    /* VMOVAPDZ256rr */
  },
  { /* 5153 */
    648,
    /* VMOVAPDZ256rr_alt */
  },
  { /* 5154 */
    549,
    /* VMOVAPDZ256rrk */
  },
  { /* 5155 */
    460,
    /* VMOVAPDZ256rrk_alt */
  },
  { /* 5156 */
    550,
    /* VMOVAPDZ256rrkz */
  },
  { /* 5157 */
    461,
    /* VMOVAPDZ256rrkz_alt */
  },
  { /* 5158 */
    649,
    /* VMOVAPDZmr */
  },
  { /* 5159 */
    650,
    /* VMOVAPDZmrk */
  },
  { /* 5160 */
    477,
    /* VMOVAPDZrm */
  },
  { /* 5161 */
    528,
    /* VMOVAPDZrmk */
  },
  { /* 5162 */
    529,
    /* VMOVAPDZrmkz */
  },
  { /* 5163 */
    478,
    /* VMOVAPDZrr */
  },
  { /* 5164 */
    651,
    /* VMOVAPDZrr_alt */
  },
  { /* 5165 */
    533,
    /* VMOVAPDZrrk */
  },
  { /* 5166 */
    463,
    /* VMOVAPDZrrk_alt */
  },
  { /* 5167 */
    534,
    /* VMOVAPDZrrkz */
  },
  { /* 5168 */
    464,
    /* VMOVAPDZrrkz_alt */
  },
  { /* 5169 */
    246,
    /* VMOVAPDmr */
  },
  { /* 5170 */
    44,
    /* VMOVAPDrm */
  },
  { /* 5171 */
    45,
    /* VMOVAPDrr */
  },
  { /* 5172 */
    247,
    /* VMOVAPDrr_REV */
  },
  { /* 5173 */
    633,
    /* VMOVAPSYmr */
  },
  { /* 5174 */
    475,
    /* VMOVAPSYrm */
  },
  { /* 5175 */
    476,
    /* VMOVAPSYrr */
  },
  { /* 5176 */
    634,
    /* VMOVAPSYrr_REV */
  },
  { /* 5177 */
    635,
    /* VMOVAPSZ128mr */
  },
  { /* 5178 */
    652,
    /* VMOVAPSZ128mrk */
  },
  { /* 5179 */
    637,
    /* VMOVAPSZ128rm */
  },
  { /* 5180 */
    653,
    /* VMOVAPSZ128rmk */
  },
  { /* 5181 */
    654,
    /* VMOVAPSZ128rmkz */
  },
  { /* 5182 */
    640,
    /* VMOVAPSZ128rr */
  },
  { /* 5183 */
    641,
    /* VMOVAPSZ128rr_alt */
  },
  { /* 5184 */
    555,
    /* VMOVAPSZ128rrk */
  },
  { /* 5185 */
    466,
    /* VMOVAPSZ128rrk_alt */
  },
  { /* 5186 */
    556,
    /* VMOVAPSZ128rrkz */
  },
  { /* 5187 */
    467,
    /* VMOVAPSZ128rrkz_alt */
  },
  { /* 5188 */
    642,
    /* VMOVAPSZ256mr */
  },
  { /* 5189 */
    655,
    /* VMOVAPSZ256mrk */
  },
  { /* 5190 */
    644,
    /* VMOVAPSZ256rm */
  },
  { /* 5191 */
    656,
    /* VMOVAPSZ256rmk */
  },
  { /* 5192 */
    657,
    /* VMOVAPSZ256rmkz */
  },
  { /* 5193 */
    647,
    /* VMOVAPSZ256rr */
  },
  { /* 5194 */
    648,
    /* VMOVAPSZ256rr_alt */
  },
  { /* 5195 */
    559,
    /* VMOVAPSZ256rrk */
  },
  { /* 5196 */
    469,
    /* VMOVAPSZ256rrk_alt */
  },
  { /* 5197 */
    560,
    /* VMOVAPSZ256rrkz */
  },
  { /* 5198 */
    470,
    /* VMOVAPSZ256rrkz_alt */
  },
  { /* 5199 */
    649,
    /* VMOVAPSZmr */
  },
  { /* 5200 */
    658,
    /* VMOVAPSZmrk */
  },
  { /* 5201 */
    477,
    /* VMOVAPSZrm */
  },
  { /* 5202 */
    537,
    /* VMOVAPSZrmk */
  },
  { /* 5203 */
    538,
    /* VMOVAPSZrmkz */
  },
  { /* 5204 */
    478,
    /* VMOVAPSZrr */
  },
  { /* 5205 */
    651,
    /* VMOVAPSZrr_alt */
  },
  { /* 5206 */
    541,
    /* VMOVAPSZrrk */
  },
  { /* 5207 */
    472,
    /* VMOVAPSZrrk_alt */
  },
  { /* 5208 */
    542,
    /* VMOVAPSZrrkz */
  },
  { /* 5209 */
    473,
    /* VMOVAPSZrrkz_alt */
  },
  { /* 5210 */
    246,
    /* VMOVAPSmr */
  },
  { /* 5211 */
    44,
    /* VMOVAPSrm */
  },
  { /* 5212 */
    45,
    /* VMOVAPSrr */
  },
  { /* 5213 */
    247,
    /* VMOVAPSrr_REV */
  },
  { /* 5214 */
    475,
    /* VMOVDDUPYrm */
  },
  { /* 5215 */
    476,
    /* VMOVDDUPYrr */
  },
  { /* 5216 */
    477,
    /* VMOVDDUPZrm */
  },
  { /* 5217 */
    478,
    /* VMOVDDUPZrr */
  },
  { /* 5218 */
    106,
    /* VMOVDDUPrm */
  },
  { /* 5219 */
    45,
    /* VMOVDDUPrr */
  },
  { /* 5220 */
    659,
    /* VMOVDI2PDIZrm */
  },
  { /* 5221 */
    660,
    /* VMOVDI2PDIZrr */
  },
  { /* 5222 */
    105,
    /* VMOVDI2PDIrm */
  },
  { /* 5223 */
    248,
    /* VMOVDI2PDIrr */
  },
  { /* 5224 */
    0,
    /*  */
  },
  { /* 5225 */
    0,
    /*  */
  },
  { /* 5226 */
    0,
    /*  */
  },
  { /* 5227 */
    0,
    /*  */
  },
  { /* 5228 */
    635,
    /* VMOVDQA32Z128mr */
  },
  { /* 5229 */
    652,
    /* VMOVDQA32Z128mrk */
  },
  { /* 5230 */
    637,
    /* VMOVDQA32Z128rm */
  },
  { /* 5231 */
    653,
    /* VMOVDQA32Z128rmk */
  },
  { /* 5232 */
    654,
    /* VMOVDQA32Z128rmkz */
  },
  { /* 5233 */
    640,
    /* VMOVDQA32Z128rr */
  },
  { /* 5234 */
    641,
    /* VMOVDQA32Z128rr_alt */
  },
  { /* 5235 */
    555,
    /* VMOVDQA32Z128rrk */
  },
  { /* 5236 */
    466,
    /* VMOVDQA32Z128rrk_alt */
  },
  { /* 5237 */
    556,
    /* VMOVDQA32Z128rrkz */
  },
  { /* 5238 */
    467,
    /* VMOVDQA32Z128rrkz_alt */
  },
  { /* 5239 */
    642,
    /* VMOVDQA32Z256mr */
  },
  { /* 5240 */
    655,
    /* VMOVDQA32Z256mrk */
  },
  { /* 5241 */
    644,
    /* VMOVDQA32Z256rm */
  },
  { /* 5242 */
    656,
    /* VMOVDQA32Z256rmk */
  },
  { /* 5243 */
    657,
    /* VMOVDQA32Z256rmkz */
  },
  { /* 5244 */
    647,
    /* VMOVDQA32Z256rr */
  },
  { /* 5245 */
    648,
    /* VMOVDQA32Z256rr_alt */
  },
  { /* 5246 */
    559,
    /* VMOVDQA32Z256rrk */
  },
  { /* 5247 */
    469,
    /* VMOVDQA32Z256rrk_alt */
  },
  { /* 5248 */
    560,
    /* VMOVDQA32Z256rrkz */
  },
  { /* 5249 */
    470,
    /* VMOVDQA32Z256rrkz_alt */
  },
  { /* 5250 */
    649,
    /* VMOVDQA32Zmr */
  },
  { /* 5251 */
    658,
    /* VMOVDQA32Zmrk */
  },
  { /* 5252 */
    477,
    /* VMOVDQA32Zrm */
  },
  { /* 5253 */
    537,
    /* VMOVDQA32Zrmk */
  },
  { /* 5254 */
    538,
    /* VMOVDQA32Zrmkz */
  },
  { /* 5255 */
    478,
    /* VMOVDQA32Zrr */
  },
  { /* 5256 */
    651,
    /* VMOVDQA32Zrr_alt */
  },
  { /* 5257 */
    541,
    /* VMOVDQA32Zrrk */
  },
  { /* 5258 */
    472,
    /* VMOVDQA32Zrrk_alt */
  },
  { /* 5259 */
    542,
    /* VMOVDQA32Zrrkz */
  },
  { /* 5260 */
    473,
    /* VMOVDQA32Zrrkz_alt */
  },
  { /* 5261 */
    635,
    /* VMOVDQA64Z128mr */
  },
  { /* 5262 */
    636,
    /* VMOVDQA64Z128mrk */
  },
  { /* 5263 */
    637,
    /* VMOVDQA64Z128rm */
  },
  { /* 5264 */
    638,
    /* VMOVDQA64Z128rmk */
  },
  { /* 5265 */
    639,
    /* VMOVDQA64Z128rmkz */
  },
  { /* 5266 */
    640,
    /* VMOVDQA64Z128rr */
  },
  { /* 5267 */
    641,
    /* VMOVDQA64Z128rr_alt */
  },
  { /* 5268 */
    545,
    /* VMOVDQA64Z128rrk */
  },
  { /* 5269 */
    457,
    /* VMOVDQA64Z128rrk_alt */
  },
  { /* 5270 */
    546,
    /* VMOVDQA64Z128rrkz */
  },
  { /* 5271 */
    458,
    /* VMOVDQA64Z128rrkz_alt */
  },
  { /* 5272 */
    642,
    /* VMOVDQA64Z256mr */
  },
  { /* 5273 */
    643,
    /* VMOVDQA64Z256mrk */
  },
  { /* 5274 */
    644,
    /* VMOVDQA64Z256rm */
  },
  { /* 5275 */
    645,
    /* VMOVDQA64Z256rmk */
  },
  { /* 5276 */
    646,
    /* VMOVDQA64Z256rmkz */
  },
  { /* 5277 */
    647,
    /* VMOVDQA64Z256rr */
  },
  { /* 5278 */
    648,
    /* VMOVDQA64Z256rr_alt */
  },
  { /* 5279 */
    549,
    /* VMOVDQA64Z256rrk */
  },
  { /* 5280 */
    460,
    /* VMOVDQA64Z256rrk_alt */
  },
  { /* 5281 */
    550,
    /* VMOVDQA64Z256rrkz */
  },
  { /* 5282 */
    461,
    /* VMOVDQA64Z256rrkz_alt */
  },
  { /* 5283 */
    649,
    /* VMOVDQA64Zmr */
  },
  { /* 5284 */
    650,
    /* VMOVDQA64Zmrk */
  },
  { /* 5285 */
    477,
    /* VMOVDQA64Zrm */
  },
  { /* 5286 */
    528,
    /* VMOVDQA64Zrmk */
  },
  { /* 5287 */
    529,
    /* VMOVDQA64Zrmkz */
  },
  { /* 5288 */
    478,
    /* VMOVDQA64Zrr */
  },
  { /* 5289 */
    651,
    /* VMOVDQA64Zrr_alt */
  },
  { /* 5290 */
    533,
    /* VMOVDQA64Zrrk */
  },
  { /* 5291 */
    463,
    /* VMOVDQA64Zrrk_alt */
  },
  { /* 5292 */
    534,
    /* VMOVDQA64Zrrkz */
  },
  { /* 5293 */
    464,
    /* VMOVDQA64Zrrkz_alt */
  },
  { /* 5294 */
    633,
    /* VMOVDQAYmr */
  },
  { /* 5295 */
    475,
    /* VMOVDQAYrm */
  },
  { /* 5296 */
    476,
    /* VMOVDQAYrr */
  },
  { /* 5297 */
    634,
    /* VMOVDQAYrr_REV */
  },
  { /* 5298 */
    246,
    /* VMOVDQAmr */
  },
  { /* 5299 */
    44,
    /* VMOVDQArm */
  },
  { /* 5300 */
    45,
    /* VMOVDQArr */
  },
  { /* 5301 */
    247,
    /* VMOVDQArr_REV */
  },
  { /* 5302 */
    635,
    /* VMOVDQU16Z128mr */
  },
  { /* 5303 */
    661,
    /* VMOVDQU16Z128mrk */
  },
  { /* 5304 */
    637,
    /* VMOVDQU16Z128rm */
  },
  { /* 5305 */
    662,
    /* VMOVDQU16Z128rmk */
  },
  { /* 5306 */
    663,
    /* VMOVDQU16Z128rmkz */
  },
  { /* 5307 */
    640,
    /* VMOVDQU16Z128rr */
  },
  { /* 5308 */
    641,
    /* VMOVDQU16Z128rr_alt */
  },
  { /* 5309 */
    664,
    /* VMOVDQU16Z128rrk */
  },
  { /* 5310 */
    665,
    /* VMOVDQU16Z128rrk_alt */
  },
  { /* 5311 */
    666,
    /* VMOVDQU16Z128rrkz */
  },
  { /* 5312 */
    667,
    /* VMOVDQU16Z128rrkz_alt */
  },
  { /* 5313 */
    642,
    /* VMOVDQU16Z256mr */
  },
  { /* 5314 */
    668,
    /* VMOVDQU16Z256mrk */
  },
  { /* 5315 */
    644,
    /* VMOVDQU16Z256rm */
  },
  { /* 5316 */
    669,
    /* VMOVDQU16Z256rmk */
  },
  { /* 5317 */
    670,
    /* VMOVDQU16Z256rmkz */
  },
  { /* 5318 */
    647,
    /* VMOVDQU16Z256rr */
  },
  { /* 5319 */
    648,
    /* VMOVDQU16Z256rr_alt */
  },
  { /* 5320 */
    671,
    /* VMOVDQU16Z256rrk */
  },
  { /* 5321 */
    672,
    /* VMOVDQU16Z256rrk_alt */
  },
  { /* 5322 */
    673,
    /* VMOVDQU16Z256rrkz */
  },
  { /* 5323 */
    674,
    /* VMOVDQU16Z256rrkz_alt */
  },
  { /* 5324 */
    649,
    /* VMOVDQU16Zmr */
  },
  { /* 5325 */
    675,
    /* VMOVDQU16Zmrk */
  },
  { /* 5326 */
    477,
    /* VMOVDQU16Zrm */
  },
  { /* 5327 */
    676,
    /* VMOVDQU16Zrmk */
  },
  { /* 5328 */
    677,
    /* VMOVDQU16Zrmkz */
  },
  { /* 5329 */
    478,
    /* VMOVDQU16Zrr */
  },
  { /* 5330 */
    651,
    /* VMOVDQU16Zrr_alt */
  },
  { /* 5331 */
    678,
    /* VMOVDQU16Zrrk */
  },
  { /* 5332 */
    679,
    /* VMOVDQU16Zrrk_alt */
  },
  { /* 5333 */
    680,
    /* VMOVDQU16Zrrkz */
  },
  { /* 5334 */
    681,
    /* VMOVDQU16Zrrkz_alt */
  },
  { /* 5335 */
    635,
    /* VMOVDQU32Z128mr */
  },
  { /* 5336 */
    652,
    /* VMOVDQU32Z128mrk */
  },
  { /* 5337 */
    637,
    /* VMOVDQU32Z128rm */
  },
  { /* 5338 */
    653,
    /* VMOVDQU32Z128rmk */
  },
  { /* 5339 */
    654,
    /* VMOVDQU32Z128rmkz */
  },
  { /* 5340 */
    640,
    /* VMOVDQU32Z128rr */
  },
  { /* 5341 */
    641,
    /* VMOVDQU32Z128rr_alt */
  },
  { /* 5342 */
    555,
    /* VMOVDQU32Z128rrk */
  },
  { /* 5343 */
    466,
    /* VMOVDQU32Z128rrk_alt */
  },
  { /* 5344 */
    556,
    /* VMOVDQU32Z128rrkz */
  },
  { /* 5345 */
    467,
    /* VMOVDQU32Z128rrkz_alt */
  },
  { /* 5346 */
    642,
    /* VMOVDQU32Z256mr */
  },
  { /* 5347 */
    655,
    /* VMOVDQU32Z256mrk */
  },
  { /* 5348 */
    644,
    /* VMOVDQU32Z256rm */
  },
  { /* 5349 */
    656,
    /* VMOVDQU32Z256rmk */
  },
  { /* 5350 */
    657,
    /* VMOVDQU32Z256rmkz */
  },
  { /* 5351 */
    647,
    /* VMOVDQU32Z256rr */
  },
  { /* 5352 */
    648,
    /* VMOVDQU32Z256rr_alt */
  },
  { /* 5353 */
    559,
    /* VMOVDQU32Z256rrk */
  },
  { /* 5354 */
    469,
    /* VMOVDQU32Z256rrk_alt */
  },
  { /* 5355 */
    560,
    /* VMOVDQU32Z256rrkz */
  },
  { /* 5356 */
    470,
    /* VMOVDQU32Z256rrkz_alt */
  },
  { /* 5357 */
    649,
    /* VMOVDQU32Zmr */
  },
  { /* 5358 */
    658,
    /* VMOVDQU32Zmrk */
  },
  { /* 5359 */
    477,
    /* VMOVDQU32Zrm */
  },
  { /* 5360 */
    537,
    /* VMOVDQU32Zrmk */
  },
  { /* 5361 */
    538,
    /* VMOVDQU32Zrmkz */
  },
  { /* 5362 */
    478,
    /* VMOVDQU32Zrr */
  },
  { /* 5363 */
    651,
    /* VMOVDQU32Zrr_alt */
  },
  { /* 5364 */
    541,
    /* VMOVDQU32Zrrk */
  },
  { /* 5365 */
    472,
    /* VMOVDQU32Zrrk_alt */
  },
  { /* 5366 */
    542,
    /* VMOVDQU32Zrrkz */
  },
  { /* 5367 */
    473,
    /* VMOVDQU32Zrrkz_alt */
  },
  { /* 5368 */
    635,
    /* VMOVDQU64Z128mr */
  },
  { /* 5369 */
    636,
    /* VMOVDQU64Z128mrk */
  },
  { /* 5370 */
    637,
    /* VMOVDQU64Z128rm */
  },
  { /* 5371 */
    638,
    /* VMOVDQU64Z128rmk */
  },
  { /* 5372 */
    639,
    /* VMOVDQU64Z128rmkz */
  },
  { /* 5373 */
    640,
    /* VMOVDQU64Z128rr */
  },
  { /* 5374 */
    641,
    /* VMOVDQU64Z128rr_alt */
  },
  { /* 5375 */
    545,
    /* VMOVDQU64Z128rrk */
  },
  { /* 5376 */
    457,
    /* VMOVDQU64Z128rrk_alt */
  },
  { /* 5377 */
    546,
    /* VMOVDQU64Z128rrkz */
  },
  { /* 5378 */
    458,
    /* VMOVDQU64Z128rrkz_alt */
  },
  { /* 5379 */
    642,
    /* VMOVDQU64Z256mr */
  },
  { /* 5380 */
    643,
    /* VMOVDQU64Z256mrk */
  },
  { /* 5381 */
    644,
    /* VMOVDQU64Z256rm */
  },
  { /* 5382 */
    645,
    /* VMOVDQU64Z256rmk */
  },
  { /* 5383 */
    646,
    /* VMOVDQU64Z256rmkz */
  },
  { /* 5384 */
    647,
    /* VMOVDQU64Z256rr */
  },
  { /* 5385 */
    648,
    /* VMOVDQU64Z256rr_alt */
  },
  { /* 5386 */
    549,
    /* VMOVDQU64Z256rrk */
  },
  { /* 5387 */
    460,
    /* VMOVDQU64Z256rrk_alt */
  },
  { /* 5388 */
    550,
    /* VMOVDQU64Z256rrkz */
  },
  { /* 5389 */
    461,
    /* VMOVDQU64Z256rrkz_alt */
  },
  { /* 5390 */
    649,
    /* VMOVDQU64Zmr */
  },
  { /* 5391 */
    650,
    /* VMOVDQU64Zmrk */
  },
  { /* 5392 */
    477,
    /* VMOVDQU64Zrm */
  },
  { /* 5393 */
    528,
    /* VMOVDQU64Zrmk */
  },
  { /* 5394 */
    529,
    /* VMOVDQU64Zrmkz */
  },
  { /* 5395 */
    478,
    /* VMOVDQU64Zrr */
  },
  { /* 5396 */
    651,
    /* VMOVDQU64Zrr_alt */
  },
  { /* 5397 */
    533,
    /* VMOVDQU64Zrrk */
  },
  { /* 5398 */
    463,
    /* VMOVDQU64Zrrk_alt */
  },
  { /* 5399 */
    534,
    /* VMOVDQU64Zrrkz */
  },
  { /* 5400 */
    464,
    /* VMOVDQU64Zrrkz_alt */
  },
  { /* 5401 */
    635,
    /* VMOVDQU8Z128mr */
  },
  { /* 5402 */
    682,
    /* VMOVDQU8Z128mrk */
  },
  { /* 5403 */
    637,
    /* VMOVDQU8Z128rm */
  },
  { /* 5404 */
    683,
    /* VMOVDQU8Z128rmk */
  },
  { /* 5405 */
    684,
    /* VMOVDQU8Z128rmkz */
  },
  { /* 5406 */
    640,
    /* VMOVDQU8Z128rr */
  },
  { /* 5407 */
    641,
    /* VMOVDQU8Z128rr_alt */
  },
  { /* 5408 */
    685,
    /* VMOVDQU8Z128rrk */
  },
  { /* 5409 */
    686,
    /* VMOVDQU8Z128rrk_alt */
  },
  { /* 5410 */
    687,
    /* VMOVDQU8Z128rrkz */
  },
  { /* 5411 */
    688,
    /* VMOVDQU8Z128rrkz_alt */
  },
  { /* 5412 */
    642,
    /* VMOVDQU8Z256mr */
  },
  { /* 5413 */
    689,
    /* VMOVDQU8Z256mrk */
  },
  { /* 5414 */
    644,
    /* VMOVDQU8Z256rm */
  },
  { /* 5415 */
    690,
    /* VMOVDQU8Z256rmk */
  },
  { /* 5416 */
    691,
    /* VMOVDQU8Z256rmkz */
  },
  { /* 5417 */
    647,
    /* VMOVDQU8Z256rr */
  },
  { /* 5418 */
    648,
    /* VMOVDQU8Z256rr_alt */
  },
  { /* 5419 */
    692,
    /* VMOVDQU8Z256rrk */
  },
  { /* 5420 */
    693,
    /* VMOVDQU8Z256rrk_alt */
  },
  { /* 5421 */
    694,
    /* VMOVDQU8Z256rrkz */
  },
  { /* 5422 */
    695,
    /* VMOVDQU8Z256rrkz_alt */
  },
  { /* 5423 */
    649,
    /* VMOVDQU8Zmr */
  },
  { /* 5424 */
    696,
    /* VMOVDQU8Zmrk */
  },
  { /* 5425 */
    477,
    /* VMOVDQU8Zrm */
  },
  { /* 5426 */
    697,
    /* VMOVDQU8Zrmk */
  },
  { /* 5427 */
    698,
    /* VMOVDQU8Zrmkz */
  },
  { /* 5428 */
    478,
    /* VMOVDQU8Zrr */
  },
  { /* 5429 */
    651,
    /* VMOVDQU8Zrr_alt */
  },
  { /* 5430 */
    699,
    /* VMOVDQU8Zrrk */
  },
  { /* 5431 */
    700,
    /* VMOVDQU8Zrrk_alt */
  },
  { /* 5432 */
    701,
    /* VMOVDQU8Zrrkz */
  },
  { /* 5433 */
    702,
    /* VMOVDQU8Zrrkz_alt */
  },
  { /* 5434 */
    633,
    /* VMOVDQUYmr */
  },
  { /* 5435 */
    475,
    /* VMOVDQUYrm */
  },
  { /* 5436 */
    476,
    /* VMOVDQUYrr */
  },
  { /* 5437 */
    634,
    /* VMOVDQUYrr_REV */
  },
  { /* 5438 */
    246,
    /* VMOVDQUmr */
  },
  { /* 5439 */
    44,
    /* VMOVDQUrm */
  },
  { /* 5440 */
    45,
    /* VMOVDQUrr */
  },
  { /* 5441 */
    247,
    /* VMOVDQUrr_REV */
  },
  { /* 5442 */
    310,
    /* VMOVHLPSZrr */
  },
  { /* 5443 */
    335,
    /* VMOVHLPSrr */
  },
  { /* 5444 */
    249,
    /* VMOVHPDmr */
  },
  { /* 5445 */
    703,
    /* VMOVHPDrm */
  },
  { /* 5446 */
    249,
    /* VMOVHPSmr */
  },
  { /* 5447 */
    703,
    /* VMOVHPSrm */
  },
  { /* 5448 */
    310,
    /* VMOVLHPSZrr */
  },
  { /* 5449 */
    335,
    /* VMOVLHPSrr */
  },
  { /* 5450 */
    249,
    /* VMOVLPDmr */
  },
  { /* 5451 */
    703,
    /* VMOVLPDrm */
  },
  { /* 5452 */
    249,
    /* VMOVLPSmr */
  },
  { /* 5453 */
    703,
    /* VMOVLPSrm */
  },
  { /* 5454 */
    704,
    /* VMOVMSKPDYrr */
  },
  { /* 5455 */
    110,
    /* VMOVMSKPDrr */
  },
  { /* 5456 */
    704,
    /* VMOVMSKPSYrr */
  },
  { /* 5457 */
    110,
    /* VMOVMSKPSrr */
  },
  { /* 5458 */
    475,
    /* VMOVNTDQAYrm */
  },
  { /* 5459 */
    637,
    /* VMOVNTDQAZ128rm */
  },
  { /* 5460 */
    644,
    /* VMOVNTDQAZ256rm */
  },
  { /* 5461 */
    477,
    /* VMOVNTDQAZrm */
  },
  { /* 5462 */
    44,
    /* VMOVNTDQArm */
  },
  { /* 5463 */
    633,
    /* VMOVNTDQYmr */
  },
  { /* 5464 */
    635,
    /* VMOVNTDQZ128mr */
  },
  { /* 5465 */
    642,
    /* VMOVNTDQZ256mr */
  },
  { /* 5466 */
    649,
    /* VMOVNTDQZmr */
  },
  { /* 5467 */
    246,
    /* VMOVNTDQmr */
  },
  { /* 5468 */
    633,
    /* VMOVNTPDYmr */
  },
  { /* 5469 */
    635,
    /* VMOVNTPDZ128mr */
  },
  { /* 5470 */
    642,
    /* VMOVNTPDZ256mr */
  },
  { /* 5471 */
    649,
    /* VMOVNTPDZmr */
  },
  { /* 5472 */
    246,
    /* VMOVNTPDmr */
  },
  { /* 5473 */
    633,
    /* VMOVNTPSYmr */
  },
  { /* 5474 */
    635,
    /* VMOVNTPSZ128mr */
  },
  { /* 5475 */
    642,
    /* VMOVNTPSZ256mr */
  },
  { /* 5476 */
    649,
    /* VMOVNTPSZmr */
  },
  { /* 5477 */
    246,
    /* VMOVNTPSmr */
  },
  { /* 5478 */
    705,
    /* VMOVPDI2DIZmr */
  },
  { /* 5479 */
    706,
    /* VMOVPDI2DIZrr */
  },
  { /* 5480 */
    253,
    /* VMOVPDI2DImr */
  },
  { /* 5481 */
    254,
    /* VMOVPDI2DIrr */
  },
  { /* 5482 */
    253,
    /* VMOVPQI2QImr */
  },
  { /* 5483 */
    247,
    /* VMOVPQI2QIrr */
  },
  { /* 5484 */
    707,
    /* VMOVPQIto64Zmr */
  },
  { /* 5485 */
    708,
    /* VMOVPQIto64Zrr */
  },
  { /* 5486 */
    253,
    /* VMOVPQIto64rm */
  },
  { /* 5487 */
    255,
    /* VMOVPQIto64rr */
  },
  { /* 5488 */
    709,
    /* VMOVQI2PQIZrm */
  },
  { /* 5489 */
    105,
    /* VMOVQI2PQIrm */
  },
  { /* 5490 */
    710,
    /* VMOVSDZmr */
  },
  { /* 5491 */
    711,
    /* VMOVSDZmrk */
  },
  { /* 5492 */
    712,
    /* VMOVSDZrm */
  },
  { /* 5493 */
    713,
    /* VMOVSDZrr */
  },
  { /* 5494 */
    714,
    /* VMOVSDZrr_REV */
  },
  { /* 5495 */
    715,
    /* VMOVSDZrrk */
  },
  { /* 5496 */
    256,
    /* VMOVSDmr */
  },
  { /* 5497 */
    257,
    /* VMOVSDrm */
  },
  { /* 5498 */
    716,
    /* VMOVSDrr */
  },
  { /* 5499 */
    717,
    /* VMOVSDrr_REV */
  },
  { /* 5500 */
    718,
    /* VMOVSDto64Zmr */
  },
  { /* 5501 */
    0,
    /*  */
  },
  { /* 5502 */
    0,
    /*  */
  },
  { /* 5503 */
    0,
    /*  */
  },
  { /* 5504 */
    475,
    /* VMOVSHDUPYrm */
  },
  { /* 5505 */
    476,
    /* VMOVSHDUPYrr */
  },
  { /* 5506 */
    477,
    /* VMOVSHDUPZrm */
  },
  { /* 5507 */
    478,
    /* VMOVSHDUPZrr */
  },
  { /* 5508 */
    44,
    /* VMOVSHDUPrm */
  },
  { /* 5509 */
    45,
    /* VMOVSHDUPrr */
  },
  { /* 5510 */
    475,
    /* VMOVSLDUPYrm */
  },
  { /* 5511 */
    476,
    /* VMOVSLDUPYrr */
  },
  { /* 5512 */
    477,
    /* VMOVSLDUPZrm */
  },
  { /* 5513 */
    478,
    /* VMOVSLDUPZrr */
  },
  { /* 5514 */
    44,
    /* VMOVSLDUPrm */
  },
  { /* 5515 */
    45,
    /* VMOVSLDUPrr */
  },
  { /* 5516 */
    0,
    /*  */
  },
  { /* 5517 */
    0,
    /*  */
  },
  { /* 5518 */
    0,
    /*  */
  },
  { /* 5519 */
    0,
    /*  */
  },
  { /* 5520 */
    719,
    /* VMOVSSZmr */
  },
  { /* 5521 */
    720,
    /* VMOVSSZmrk */
  },
  { /* 5522 */
    721,
    /* VMOVSSZrm */
  },
  { /* 5523 */
    722,
    /* VMOVSSZrr */
  },
  { /* 5524 */
    723,
    /* VMOVSSZrr_REV */
  },
  { /* 5525 */
    724,
    /* VMOVSSZrrk */
  },
  { /* 5526 */
    260,
    /* VMOVSSmr */
  },
  { /* 5527 */
    261,
    /* VMOVSSrm */
  },
  { /* 5528 */
    725,
    /* VMOVSSrr */
  },
  { /* 5529 */
    726,
    /* VMOVSSrr_REV */
  },
  { /* 5530 */
    633,
    /* VMOVUPDYmr */
  },
  { /* 5531 */
    475,
    /* VMOVUPDYrm */
  },
  { /* 5532 */
    476,
    /* VMOVUPDYrr */
  },
  { /* 5533 */
    634,
    /* VMOVUPDYrr_REV */
  },
  { /* 5534 */
    635,
    /* VMOVUPDZ128mr */
  },
  { /* 5535 */
    636,
    /* VMOVUPDZ128mrk */
  },
  { /* 5536 */
    637,
    /* VMOVUPDZ128rm */
  },
  { /* 5537 */
    638,
    /* VMOVUPDZ128rmk */
  },
  { /* 5538 */
    639,
    /* VMOVUPDZ128rmkz */
  },
  { /* 5539 */
    640,
    /* VMOVUPDZ128rr */
  },
  { /* 5540 */
    641,
    /* VMOVUPDZ128rr_alt */
  },
  { /* 5541 */
    545,
    /* VMOVUPDZ128rrk */
  },
  { /* 5542 */
    457,
    /* VMOVUPDZ128rrk_alt */
  },
  { /* 5543 */
    546,
    /* VMOVUPDZ128rrkz */
  },
  { /* 5544 */
    458,
    /* VMOVUPDZ128rrkz_alt */
  },
  { /* 5545 */
    642,
    /* VMOVUPDZ256mr */
  },
  { /* 5546 */
    643,
    /* VMOVUPDZ256mrk */
  },
  { /* 5547 */
    644,
    /* VMOVUPDZ256rm */
  },
  { /* 5548 */
    645,
    /* VMOVUPDZ256rmk */
  },
  { /* 5549 */
    646,
    /* VMOVUPDZ256rmkz */
  },
  { /* 5550 */
    647,
    /* VMOVUPDZ256rr */
  },
  { /* 5551 */
    648,
    /* VMOVUPDZ256rr_alt */
  },
  { /* 5552 */
    549,
    /* VMOVUPDZ256rrk */
  },
  { /* 5553 */
    460,
    /* VMOVUPDZ256rrk_alt */
  },
  { /* 5554 */
    550,
    /* VMOVUPDZ256rrkz */
  },
  { /* 5555 */
    461,
    /* VMOVUPDZ256rrkz_alt */
  },
  { /* 5556 */
    649,
    /* VMOVUPDZmr */
  },
  { /* 5557 */
    650,
    /* VMOVUPDZmrk */
  },
  { /* 5558 */
    477,
    /* VMOVUPDZrm */
  },
  { /* 5559 */
    528,
    /* VMOVUPDZrmk */
  },
  { /* 5560 */
    529,
    /* VMOVUPDZrmkz */
  },
  { /* 5561 */
    478,
    /* VMOVUPDZrr */
  },
  { /* 5562 */
    651,
    /* VMOVUPDZrr_alt */
  },
  { /* 5563 */
    533,
    /* VMOVUPDZrrk */
  },
  { /* 5564 */
    463,
    /* VMOVUPDZrrk_alt */
  },
  { /* 5565 */
    534,
    /* VMOVUPDZrrkz */
  },
  { /* 5566 */
    464,
    /* VMOVUPDZrrkz_alt */
  },
  { /* 5567 */
    246,
    /* VMOVUPDmr */
  },
  { /* 5568 */
    44,
    /* VMOVUPDrm */
  },
  { /* 5569 */
    45,
    /* VMOVUPDrr */
  },
  { /* 5570 */
    247,
    /* VMOVUPDrr_REV */
  },
  { /* 5571 */
    633,
    /* VMOVUPSYmr */
  },
  { /* 5572 */
    475,
    /* VMOVUPSYrm */
  },
  { /* 5573 */
    476,
    /* VMOVUPSYrr */
  },
  { /* 5574 */
    634,
    /* VMOVUPSYrr_REV */
  },
  { /* 5575 */
    635,
    /* VMOVUPSZ128mr */
  },
  { /* 5576 */
    652,
    /* VMOVUPSZ128mrk */
  },
  { /* 5577 */
    637,
    /* VMOVUPSZ128rm */
  },
  { /* 5578 */
    653,
    /* VMOVUPSZ128rmk */
  },
  { /* 5579 */
    654,
    /* VMOVUPSZ128rmkz */
  },
  { /* 5580 */
    640,
    /* VMOVUPSZ128rr */
  },
  { /* 5581 */
    641,
    /* VMOVUPSZ128rr_alt */
  },
  { /* 5582 */
    555,
    /* VMOVUPSZ128rrk */
  },
  { /* 5583 */
    466,
    /* VMOVUPSZ128rrk_alt */
  },
  { /* 5584 */
    556,
    /* VMOVUPSZ128rrkz */
  },
  { /* 5585 */
    467,
    /* VMOVUPSZ128rrkz_alt */
  },
  { /* 5586 */
    642,
    /* VMOVUPSZ256mr */
  },
  { /* 5587 */
    655,
    /* VMOVUPSZ256mrk */
  },
  { /* 5588 */
    644,
    /* VMOVUPSZ256rm */
  },
  { /* 5589 */
    656,
    /* VMOVUPSZ256rmk */
  },
  { /* 5590 */
    657,
    /* VMOVUPSZ256rmkz */
  },
  { /* 5591 */
    647,
    /* VMOVUPSZ256rr */
  },
  { /* 5592 */
    648,
    /* VMOVUPSZ256rr_alt */
  },
  { /* 5593 */
    559,
    /* VMOVUPSZ256rrk */
  },
  { /* 5594 */
    469,
    /* VMOVUPSZ256rrk_alt */
  },
  { /* 5595 */
    560,
    /* VMOVUPSZ256rrkz */
  },
  { /* 5596 */
    470,
    /* VMOVUPSZ256rrkz_alt */
  },
  { /* 5597 */
    649,
    /* VMOVUPSZmr */
  },
  { /* 5598 */
    658,
    /* VMOVUPSZmrk */
  },
  { /* 5599 */
    477,
    /* VMOVUPSZrm */
  },
  { /* 5600 */
    537,
    /* VMOVUPSZrmk */
  },
  { /* 5601 */
    538,
    /* VMOVUPSZrmkz */
  },
  { /* 5602 */
    478,
    /* VMOVUPSZrr */
  },
  { /* 5603 */
    651,
    /* VMOVUPSZrr_alt */
  },
  { /* 5604 */
    541,
    /* VMOVUPSZrrk */
  },
  { /* 5605 */
    472,
    /* VMOVUPSZrrk_alt */
  },
  { /* 5606 */
    542,
    /* VMOVUPSZrrkz */
  },
  { /* 5607 */
    473,
    /* VMOVUPSZrrkz_alt */
  },
  { /* 5608 */
    246,
    /* VMOVUPSmr */
  },
  { /* 5609 */
    44,
    /* VMOVUPSrm */
  },
  { /* 5610 */
    45,
    /* VMOVUPSrr */
  },
  { /* 5611 */
    247,
    /* VMOVUPSrr_REV */
  },
  { /* 5612 */
    453,
    /* VMOVZPQILo2PQIZrm */
  },
  { /* 5613 */
    640,
    /* VMOVZPQILo2PQIZrr */
  },
  { /* 5614 */
    0,
    /*  */
  },
  { /* 5615 */
    45,
    /* VMOVZPQILo2PQIrr */
  },
  { /* 5616 */
    0,
    /*  */
  },
  { /* 5617 */
    0,
    /*  */
  },
  { /* 5618 */
    388,
    /* VMPSADBWYrmi */
  },
  { /* 5619 */
    389,
    /* VMPSADBWYrri */
  },
  { /* 5620 */
    390,
    /* VMPSADBWrmi */
  },
  { /* 5621 */
    391,
    /* VMPSADBWrri */
  },
  { /* 5622 */
    38,
    /* VMPTRLDm */
  },
  { /* 5623 */
    38,
    /* VMPTRSTm */
  },
  { /* 5624 */
    251,
    /* VMREAD32rm */
  },
  { /* 5625 */
    727,
    /* VMREAD32rr */
  },
  { /* 5626 */
    16,
    /* VMREAD64rm */
  },
  { /* 5627 */
    76,
    /* VMREAD64rr */
  },
  { /* 5628 */
    0,
    /* VMRESUME */
  },
  { /* 5629 */
    0,
    /* VMRUN32 */
  },
  { /* 5630 */
    0,
    /* VMRUN64 */
  },
  { /* 5631 */
    0,
    /* VMSAVE32 */
  },
  { /* 5632 */
    0,
    /* VMSAVE64 */
  },
  { /* 5633 */
    302,
    /* VMULPDYrm */
  },
  { /* 5634 */
    303,
    /* VMULPDYrr */
  },
  { /* 5635 */
    304,
    /* VMULPDZ128rm */
  },
  { /* 5636 */
    305,
    /* VMULPDZ128rmb */
  },
  { /* 5637 */
    306,
    /* VMULPDZ128rmbk */
  },
  { /* 5638 */
    307,
    /* VMULPDZ128rmbkz */
  },
  { /* 5639 */
    308,
    /* VMULPDZ128rmk */
  },
  { /* 5640 */
    309,
    /* VMULPDZ128rmkz */
  },
  { /* 5641 */
    310,
    /* VMULPDZ128rr */
  },
  { /* 5642 */
    311,
    /* VMULPDZ128rrk */
  },
  { /* 5643 */
    312,
    /* VMULPDZ128rrkz */
  },
  { /* 5644 */
    313,
    /* VMULPDZ256rm */
  },
  { /* 5645 */
    314,
    /* VMULPDZ256rmb */
  },
  { /* 5646 */
    315,
    /* VMULPDZ256rmbk */
  },
  { /* 5647 */
    316,
    /* VMULPDZ256rmbkz */
  },
  { /* 5648 */
    317,
    /* VMULPDZ256rmk */
  },
  { /* 5649 */
    318,
    /* VMULPDZ256rmkz */
  },
  { /* 5650 */
    319,
    /* VMULPDZ256rr */
  },
  { /* 5651 */
    320,
    /* VMULPDZ256rrk */
  },
  { /* 5652 */
    321,
    /* VMULPDZ256rrkz */
  },
  { /* 5653 */
    322,
    /* VMULPDZrb */
  },
  { /* 5654 */
    323,
    /* VMULPDZrbk */
  },
  { /* 5655 */
    324,
    /* VMULPDZrbkz */
  },
  { /* 5656 */
    325,
    /* VMULPDZrm */
  },
  { /* 5657 */
    326,
    /* VMULPDZrmb */
  },
  { /* 5658 */
    327,
    /* VMULPDZrmbk */
  },
  { /* 5659 */
    328,
    /* VMULPDZrmbkz */
  },
  { /* 5660 */
    329,
    /* VMULPDZrmk */
  },
  { /* 5661 */
    330,
    /* VMULPDZrmkz */
  },
  { /* 5662 */
    331,
    /* VMULPDZrr */
  },
  { /* 5663 */
    332,
    /* VMULPDZrrk */
  },
  { /* 5664 */
    333,
    /* VMULPDZrrkz */
  },
  { /* 5665 */
    334,
    /* VMULPDrm */
  },
  { /* 5666 */
    335,
    /* VMULPDrr */
  },
  { /* 5667 */
    302,
    /* VMULPSYrm */
  },
  { /* 5668 */
    303,
    /* VMULPSYrr */
  },
  { /* 5669 */
    304,
    /* VMULPSZ128rm */
  },
  { /* 5670 */
    336,
    /* VMULPSZ128rmb */
  },
  { /* 5671 */
    337,
    /* VMULPSZ128rmbk */
  },
  { /* 5672 */
    338,
    /* VMULPSZ128rmbkz */
  },
  { /* 5673 */
    339,
    /* VMULPSZ128rmk */
  },
  { /* 5674 */
    340,
    /* VMULPSZ128rmkz */
  },
  { /* 5675 */
    310,
    /* VMULPSZ128rr */
  },
  { /* 5676 */
    341,
    /* VMULPSZ128rrk */
  },
  { /* 5677 */
    342,
    /* VMULPSZ128rrkz */
  },
  { /* 5678 */
    313,
    /* VMULPSZ256rm */
  },
  { /* 5679 */
    343,
    /* VMULPSZ256rmb */
  },
  { /* 5680 */
    344,
    /* VMULPSZ256rmbk */
  },
  { /* 5681 */
    345,
    /* VMULPSZ256rmbkz */
  },
  { /* 5682 */
    346,
    /* VMULPSZ256rmk */
  },
  { /* 5683 */
    347,
    /* VMULPSZ256rmkz */
  },
  { /* 5684 */
    319,
    /* VMULPSZ256rr */
  },
  { /* 5685 */
    348,
    /* VMULPSZ256rrk */
  },
  { /* 5686 */
    349,
    /* VMULPSZ256rrkz */
  },
  { /* 5687 */
    350,
    /* VMULPSZrb */
  },
  { /* 5688 */
    351,
    /* VMULPSZrbk */
  },
  { /* 5689 */
    352,
    /* VMULPSZrbkz */
  },
  { /* 5690 */
    325,
    /* VMULPSZrm */
  },
  { /* 5691 */
    353,
    /* VMULPSZrmb */
  },
  { /* 5692 */
    354,
    /* VMULPSZrmbk */
  },
  { /* 5693 */
    355,
    /* VMULPSZrmbkz */
  },
  { /* 5694 */
    356,
    /* VMULPSZrmk */
  },
  { /* 5695 */
    357,
    /* VMULPSZrmkz */
  },
  { /* 5696 */
    331,
    /* VMULPSZrr */
  },
  { /* 5697 */
    358,
    /* VMULPSZrrk */
  },
  { /* 5698 */
    359,
    /* VMULPSZrrkz */
  },
  { /* 5699 */
    334,
    /* VMULPSrm */
  },
  { /* 5700 */
    335,
    /* VMULPSrr */
  },
  { /* 5701 */
    0,
    /*  */
  },
  { /* 5702 */
    360,
    /* VMULSDZrm_Int */
  },
  { /* 5703 */
    361,
    /* VMULSDZrm_Intk */
  },
  { /* 5704 */
    362,
    /* VMULSDZrm_Intkz */
  },
  { /* 5705 */
    0,
    /*  */
  },
  { /* 5706 */
    363,
    /* VMULSDZrr_Int */
  },
  { /* 5707 */
    364,
    /* VMULSDZrr_Intk */
  },
  { /* 5708 */
    365,
    /* VMULSDZrr_Intkz */
  },
  { /* 5709 */
    366,
    /* VMULSDZrrb */
  },
  { /* 5710 */
    367,
    /* VMULSDZrrbk */
  },
  { /* 5711 */
    368,
    /* VMULSDZrrbkz */
  },
  { /* 5712 */
    369,
    /* VMULSDrm */
  },
  { /* 5713 */
    0,
    /*  */
  },
  { /* 5714 */
    370,
    /* VMULSDrr */
  },
  { /* 5715 */
    0,
    /*  */
  },
  { /* 5716 */
    0,
    /*  */
  },
  { /* 5717 */
    371,
    /* VMULSSZrm_Int */
  },
  { /* 5718 */
    372,
    /* VMULSSZrm_Intk */
  },
  { /* 5719 */
    373,
    /* VMULSSZrm_Intkz */
  },
  { /* 5720 */
    0,
    /*  */
  },
  { /* 5721 */
    374,
    /* VMULSSZrr_Int */
  },
  { /* 5722 */
    375,
    /* VMULSSZrr_Intk */
  },
  { /* 5723 */
    376,
    /* VMULSSZrr_Intkz */
  },
  { /* 5724 */
    377,
    /* VMULSSZrrb */
  },
  { /* 5725 */
    378,
    /* VMULSSZrrbk */
  },
  { /* 5726 */
    379,
    /* VMULSSZrrbkz */
  },
  { /* 5727 */
    380,
    /* VMULSSrm */
  },
  { /* 5728 */
    0,
    /*  */
  },
  { /* 5729 */
    381,
    /* VMULSSrr */
  },
  { /* 5730 */
    0,
    /*  */
  },
  { /* 5731 */
    40,
    /* VMWRITE32rm */
  },
  { /* 5732 */
    41,
    /* VMWRITE32rr */
  },
  { /* 5733 */
    42,
    /* VMWRITE64rm */
  },
  { /* 5734 */
    43,
    /* VMWRITE64rr */
  },
  { /* 5735 */
    0,
    /* VMXOFF */
  },
  { /* 5736 */
    38,
    /* VMXON */
  },
  { /* 5737 */
    302,
    /* VORPDYrm */
  },
  { /* 5738 */
    303,
    /* VORPDYrr */
  },
  { /* 5739 */
    334,
    /* VORPDrm */
  },
  { /* 5740 */
    335,
    /* VORPDrr */
  },
  { /* 5741 */
    302,
    /* VORPSYrm */
  },
  { /* 5742 */
    303,
    /* VORPSYrr */
  },
  { /* 5743 */
    334,
    /* VORPSrm */
  },
  { /* 5744 */
    335,
    /* VORPSrr */
  },
  { /* 5745 */
    44,
    /* VPABSBrm128 */
  },
  { /* 5746 */
    475,
    /* VPABSBrm256 */
  },
  { /* 5747 */
    45,
    /* VPABSBrr128 */
  },
  { /* 5748 */
    476,
    /* VPABSBrr256 */
  },
  { /* 5749 */
    477,
    /* VPABSDZrm */
  },
  { /* 5750 */
    728,
    /* VPABSDZrmb */
  },
  { /* 5751 */
    729,
    /* VPABSDZrmbk */
  },
  { /* 5752 */
    729,
    /* VPABSDZrmbkz */
  },
  { /* 5753 */
    538,
    /* VPABSDZrmk */
  },
  { /* 5754 */
    538,
    /* VPABSDZrmkz */
  },
  { /* 5755 */
    478,
    /* VPABSDZrr */
  },
  { /* 5756 */
    542,
    /* VPABSDZrrk */
  },
  { /* 5757 */
    542,
    /* VPABSDZrrkz */
  },
  { /* 5758 */
    44,
    /* VPABSDrm128 */
  },
  { /* 5759 */
    475,
    /* VPABSDrm256 */
  },
  { /* 5760 */
    45,
    /* VPABSDrr128 */
  },
  { /* 5761 */
    476,
    /* VPABSDrr256 */
  },
  { /* 5762 */
    477,
    /* VPABSQZrm */
  },
  { /* 5763 */
    730,
    /* VPABSQZrmb */
  },
  { /* 5764 */
    731,
    /* VPABSQZrmbk */
  },
  { /* 5765 */
    731,
    /* VPABSQZrmbkz */
  },
  { /* 5766 */
    529,
    /* VPABSQZrmk */
  },
  { /* 5767 */
    529,
    /* VPABSQZrmkz */
  },
  { /* 5768 */
    478,
    /* VPABSQZrr */
  },
  { /* 5769 */
    534,
    /* VPABSQZrrk */
  },
  { /* 5770 */
    534,
    /* VPABSQZrrkz */
  },
  { /* 5771 */
    44,
    /* VPABSWrm128 */
  },
  { /* 5772 */
    475,
    /* VPABSWrm256 */
  },
  { /* 5773 */
    45,
    /* VPABSWrr128 */
  },
  { /* 5774 */
    476,
    /* VPABSWrr256 */
  },
  { /* 5775 */
    302,
    /* VPACKSSDWYrm */
  },
  { /* 5776 */
    303,
    /* VPACKSSDWYrr */
  },
  { /* 5777 */
    334,
    /* VPACKSSDWrm */
  },
  { /* 5778 */
    335,
    /* VPACKSSDWrr */
  },
  { /* 5779 */
    302,
    /* VPACKSSWBYrm */
  },
  { /* 5780 */
    303,
    /* VPACKSSWBYrr */
  },
  { /* 5781 */
    334,
    /* VPACKSSWBrm */
  },
  { /* 5782 */
    335,
    /* VPACKSSWBrr */
  },
  { /* 5783 */
    302,
    /* VPACKUSDWYrm */
  },
  { /* 5784 */
    303,
    /* VPACKUSDWYrr */
  },
  { /* 5785 */
    334,
    /* VPACKUSDWrm */
  },
  { /* 5786 */
    335,
    /* VPACKUSDWrr */
  },
  { /* 5787 */
    302,
    /* VPACKUSWBYrm */
  },
  { /* 5788 */
    303,
    /* VPACKUSWBYrr */
  },
  { /* 5789 */
    334,
    /* VPACKUSWBrm */
  },
  { /* 5790 */
    335,
    /* VPACKUSWBrr */
  },
  { /* 5791 */
    302,
    /* VPADDBYrm */
  },
  { /* 5792 */
    303,
    /* VPADDBYrr */
  },
  { /* 5793 */
    304,
    /* VPADDBZ128rm */
  },
  { /* 5794 */
    732,
    /* VPADDBZ128rmk */
  },
  { /* 5795 */
    733,
    /* VPADDBZ128rmkz */
  },
  { /* 5796 */
    310,
    /* VPADDBZ128rr */
  },
  { /* 5797 */
    734,
    /* VPADDBZ128rrk */
  },
  { /* 5798 */
    735,
    /* VPADDBZ128rrkz */
  },
  { /* 5799 */
    313,
    /* VPADDBZ256rm */
  },
  { /* 5800 */
    736,
    /* VPADDBZ256rmk */
  },
  { /* 5801 */
    737,
    /* VPADDBZ256rmkz */
  },
  { /* 5802 */
    319,
    /* VPADDBZ256rr */
  },
  { /* 5803 */
    738,
    /* VPADDBZ256rrk */
  },
  { /* 5804 */
    739,
    /* VPADDBZ256rrkz */
  },
  { /* 5805 */
    325,
    /* VPADDBZrm */
  },
  { /* 5806 */
    740,
    /* VPADDBZrmk */
  },
  { /* 5807 */
    741,
    /* VPADDBZrmkz */
  },
  { /* 5808 */
    331,
    /* VPADDBZrr */
  },
  { /* 5809 */
    742,
    /* VPADDBZrrk */
  },
  { /* 5810 */
    743,
    /* VPADDBZrrkz */
  },
  { /* 5811 */
    334,
    /* VPADDBrm */
  },
  { /* 5812 */
    335,
    /* VPADDBrr */
  },
  { /* 5813 */
    302,
    /* VPADDDYrm */
  },
  { /* 5814 */
    303,
    /* VPADDDYrr */
  },
  { /* 5815 */
    304,
    /* VPADDDZ128rm */
  },
  { /* 5816 */
    744,
    /* VPADDDZ128rmb */
  },
  { /* 5817 */
    745,
    /* VPADDDZ128rmbk */
  },
  { /* 5818 */
    746,
    /* VPADDDZ128rmbkz */
  },
  { /* 5819 */
    339,
    /* VPADDDZ128rmk */
  },
  { /* 5820 */
    340,
    /* VPADDDZ128rmkz */
  },
  { /* 5821 */
    310,
    /* VPADDDZ128rr */
  },
  { /* 5822 */
    341,
    /* VPADDDZ128rrk */
  },
  { /* 5823 */
    342,
    /* VPADDDZ128rrkz */
  },
  { /* 5824 */
    313,
    /* VPADDDZ256rm */
  },
  { /* 5825 */
    747,
    /* VPADDDZ256rmb */
  },
  { /* 5826 */
    748,
    /* VPADDDZ256rmbk */
  },
  { /* 5827 */
    749,
    /* VPADDDZ256rmbkz */
  },
  { /* 5828 */
    346,
    /* VPADDDZ256rmk */
  },
  { /* 5829 */
    347,
    /* VPADDDZ256rmkz */
  },
  { /* 5830 */
    319,
    /* VPADDDZ256rr */
  },
  { /* 5831 */
    348,
    /* VPADDDZ256rrk */
  },
  { /* 5832 */
    349,
    /* VPADDDZ256rrkz */
  },
  { /* 5833 */
    325,
    /* VPADDDZrm */
  },
  { /* 5834 */
    750,
    /* VPADDDZrmb */
  },
  { /* 5835 */
    751,
    /* VPADDDZrmbk */
  },
  { /* 5836 */
    752,
    /* VPADDDZrmbkz */
  },
  { /* 5837 */
    356,
    /* VPADDDZrmk */
  },
  { /* 5838 */
    357,
    /* VPADDDZrmkz */
  },
  { /* 5839 */
    331,
    /* VPADDDZrr */
  },
  { /* 5840 */
    358,
    /* VPADDDZrrk */
  },
  { /* 5841 */
    359,
    /* VPADDDZrrkz */
  },
  { /* 5842 */
    334,
    /* VPADDDrm */
  },
  { /* 5843 */
    335,
    /* VPADDDrr */
  },
  { /* 5844 */
    302,
    /* VPADDQYrm */
  },
  { /* 5845 */
    303,
    /* VPADDQYrr */
  },
  { /* 5846 */
    304,
    /* VPADDQZ128rm */
  },
  { /* 5847 */
    753,
    /* VPADDQZ128rmb */
  },
  { /* 5848 */
    754,
    /* VPADDQZ128rmbk */
  },
  { /* 5849 */
    755,
    /* VPADDQZ128rmbkz */
  },
  { /* 5850 */
    308,
    /* VPADDQZ128rmk */
  },
  { /* 5851 */
    309,
    /* VPADDQZ128rmkz */
  },
  { /* 5852 */
    310,
    /* VPADDQZ128rr */
  },
  { /* 5853 */
    311,
    /* VPADDQZ128rrk */
  },
  { /* 5854 */
    312,
    /* VPADDQZ128rrkz */
  },
  { /* 5855 */
    313,
    /* VPADDQZ256rm */
  },
  { /* 5856 */
    756,
    /* VPADDQZ256rmb */
  },
  { /* 5857 */
    757,
    /* VPADDQZ256rmbk */
  },
  { /* 5858 */
    758,
    /* VPADDQZ256rmbkz */
  },
  { /* 5859 */
    317,
    /* VPADDQZ256rmk */
  },
  { /* 5860 */
    318,
    /* VPADDQZ256rmkz */
  },
  { /* 5861 */
    319,
    /* VPADDQZ256rr */
  },
  { /* 5862 */
    320,
    /* VPADDQZ256rrk */
  },
  { /* 5863 */
    321,
    /* VPADDQZ256rrkz */
  },
  { /* 5864 */
    325,
    /* VPADDQZrm */
  },
  { /* 5865 */
    759,
    /* VPADDQZrmb */
  },
  { /* 5866 */
    760,
    /* VPADDQZrmbk */
  },
  { /* 5867 */
    761,
    /* VPADDQZrmbkz */
  },
  { /* 5868 */
    329,
    /* VPADDQZrmk */
  },
  { /* 5869 */
    330,
    /* VPADDQZrmkz */
  },
  { /* 5870 */
    331,
    /* VPADDQZrr */
  },
  { /* 5871 */
    332,
    /* VPADDQZrrk */
  },
  { /* 5872 */
    333,
    /* VPADDQZrrkz */
  },
  { /* 5873 */
    334,
    /* VPADDQrm */
  },
  { /* 5874 */
    335,
    /* VPADDQrr */
  },
  { /* 5875 */
    302,
    /* VPADDSBYrm */
  },
  { /* 5876 */
    303,
    /* VPADDSBYrr */
  },
  { /* 5877 */
    334,
    /* VPADDSBrm */
  },
  { /* 5878 */
    335,
    /* VPADDSBrr */
  },
  { /* 5879 */
    302,
    /* VPADDSWYrm */
  },
  { /* 5880 */
    303,
    /* VPADDSWYrr */
  },
  { /* 5881 */
    334,
    /* VPADDSWrm */
  },
  { /* 5882 */
    335,
    /* VPADDSWrr */
  },
  { /* 5883 */
    302,
    /* VPADDUSBYrm */
  },
  { /* 5884 */
    303,
    /* VPADDUSBYrr */
  },
  { /* 5885 */
    334,
    /* VPADDUSBrm */
  },
  { /* 5886 */
    335,
    /* VPADDUSBrr */
  },
  { /* 5887 */
    302,
    /* VPADDUSWYrm */
  },
  { /* 5888 */
    303,
    /* VPADDUSWYrr */
  },
  { /* 5889 */
    334,
    /* VPADDUSWrm */
  },
  { /* 5890 */
    335,
    /* VPADDUSWrr */
  },
  { /* 5891 */
    302,
    /* VPADDWYrm */
  },
  { /* 5892 */
    303,
    /* VPADDWYrr */
  },
  { /* 5893 */
    304,
    /* VPADDWZ128rm */
  },
  { /* 5894 */
    762,
    /* VPADDWZ128rmk */
  },
  { /* 5895 */
    763,
    /* VPADDWZ128rmkz */
  },
  { /* 5896 */
    310,
    /* VPADDWZ128rr */
  },
  { /* 5897 */
    764,
    /* VPADDWZ128rrk */
  },
  { /* 5898 */
    765,
    /* VPADDWZ128rrkz */
  },
  { /* 5899 */
    313,
    /* VPADDWZ256rm */
  },
  { /* 5900 */
    766,
    /* VPADDWZ256rmk */
  },
  { /* 5901 */
    767,
    /* VPADDWZ256rmkz */
  },
  { /* 5902 */
    319,
    /* VPADDWZ256rr */
  },
  { /* 5903 */
    768,
    /* VPADDWZ256rrk */
  },
  { /* 5904 */
    769,
    /* VPADDWZ256rrkz */
  },
  { /* 5905 */
    325,
    /* VPADDWZrm */
  },
  { /* 5906 */
    770,
    /* VPADDWZrmk */
  },
  { /* 5907 */
    771,
    /* VPADDWZrmkz */
  },
  { /* 5908 */
    331,
    /* VPADDWZrr */
  },
  { /* 5909 */
    772,
    /* VPADDWZrrk */
  },
  { /* 5910 */
    773,
    /* VPADDWZrrkz */
  },
  { /* 5911 */
    334,
    /* VPADDWrm */
  },
  { /* 5912 */
    335,
    /* VPADDWrr */
  },
  { /* 5913 */
    390,
    /* VPALIGNR128rm */
  },
  { /* 5914 */
    391,
    /* VPALIGNR128rr */
  },
  { /* 5915 */
    388,
    /* VPALIGNR256rm */
  },
  { /* 5916 */
    389,
    /* VPALIGNR256rr */
  },
  { /* 5917 */
    304,
    /* VPANDDZ128rm */
  },
  { /* 5918 */
    744,
    /* VPANDDZ128rmb */
  },
  { /* 5919 */
    745,
    /* VPANDDZ128rmbk */
  },
  { /* 5920 */
    746,
    /* VPANDDZ128rmbkz */
  },
  { /* 5921 */
    339,
    /* VPANDDZ128rmk */
  },
  { /* 5922 */
    340,
    /* VPANDDZ128rmkz */
  },
  { /* 5923 */
    310,
    /* VPANDDZ128rr */
  },
  { /* 5924 */
    341,
    /* VPANDDZ128rrk */
  },
  { /* 5925 */
    342,
    /* VPANDDZ128rrkz */
  },
  { /* 5926 */
    313,
    /* VPANDDZ256rm */
  },
  { /* 5927 */
    747,
    /* VPANDDZ256rmb */
  },
  { /* 5928 */
    748,
    /* VPANDDZ256rmbk */
  },
  { /* 5929 */
    749,
    /* VPANDDZ256rmbkz */
  },
  { /* 5930 */
    346,
    /* VPANDDZ256rmk */
  },
  { /* 5931 */
    347,
    /* VPANDDZ256rmkz */
  },
  { /* 5932 */
    319,
    /* VPANDDZ256rr */
  },
  { /* 5933 */
    348,
    /* VPANDDZ256rrk */
  },
  { /* 5934 */
    349,
    /* VPANDDZ256rrkz */
  },
  { /* 5935 */
    325,
    /* VPANDDZrm */
  },
  { /* 5936 */
    750,
    /* VPANDDZrmb */
  },
  { /* 5937 */
    751,
    /* VPANDDZrmbk */
  },
  { /* 5938 */
    752,
    /* VPANDDZrmbkz */
  },
  { /* 5939 */
    356,
    /* VPANDDZrmk */
  },
  { /* 5940 */
    357,
    /* VPANDDZrmkz */
  },
  { /* 5941 */
    331,
    /* VPANDDZrr */
  },
  { /* 5942 */
    358,
    /* VPANDDZrrk */
  },
  { /* 5943 */
    359,
    /* VPANDDZrrkz */
  },
  { /* 5944 */
    304,
    /* VPANDNDZ128rm */
  },
  { /* 5945 */
    744,
    /* VPANDNDZ128rmb */
  },
  { /* 5946 */
    745,
    /* VPANDNDZ128rmbk */
  },
  { /* 5947 */
    746,
    /* VPANDNDZ128rmbkz */
  },
  { /* 5948 */
    339,
    /* VPANDNDZ128rmk */
  },
  { /* 5949 */
    340,
    /* VPANDNDZ128rmkz */
  },
  { /* 5950 */
    310,
    /* VPANDNDZ128rr */
  },
  { /* 5951 */
    341,
    /* VPANDNDZ128rrk */
  },
  { /* 5952 */
    342,
    /* VPANDNDZ128rrkz */
  },
  { /* 5953 */
    313,
    /* VPANDNDZ256rm */
  },
  { /* 5954 */
    747,
    /* VPANDNDZ256rmb */
  },
  { /* 5955 */
    748,
    /* VPANDNDZ256rmbk */
  },
  { /* 5956 */
    749,
    /* VPANDNDZ256rmbkz */
  },
  { /* 5957 */
    346,
    /* VPANDNDZ256rmk */
  },
  { /* 5958 */
    347,
    /* VPANDNDZ256rmkz */
  },
  { /* 5959 */
    319,
    /* VPANDNDZ256rr */
  },
  { /* 5960 */
    348,
    /* VPANDNDZ256rrk */
  },
  { /* 5961 */
    349,
    /* VPANDNDZ256rrkz */
  },
  { /* 5962 */
    325,
    /* VPANDNDZrm */
  },
  { /* 5963 */
    750,
    /* VPANDNDZrmb */
  },
  { /* 5964 */
    751,
    /* VPANDNDZrmbk */
  },
  { /* 5965 */
    752,
    /* VPANDNDZrmbkz */
  },
  { /* 5966 */
    356,
    /* VPANDNDZrmk */
  },
  { /* 5967 */
    357,
    /* VPANDNDZrmkz */
  },
  { /* 5968 */
    331,
    /* VPANDNDZrr */
  },
  { /* 5969 */
    358,
    /* VPANDNDZrrk */
  },
  { /* 5970 */
    359,
    /* VPANDNDZrrkz */
  },
  { /* 5971 */
    304,
    /* VPANDNQZ128rm */
  },
  { /* 5972 */
    753,
    /* VPANDNQZ128rmb */
  },
  { /* 5973 */
    754,
    /* VPANDNQZ128rmbk */
  },
  { /* 5974 */
    755,
    /* VPANDNQZ128rmbkz */
  },
  { /* 5975 */
    308,
    /* VPANDNQZ128rmk */
  },
  { /* 5976 */
    309,
    /* VPANDNQZ128rmkz */
  },
  { /* 5977 */
    310,
    /* VPANDNQZ128rr */
  },
  { /* 5978 */
    311,
    /* VPANDNQZ128rrk */
  },
  { /* 5979 */
    312,
    /* VPANDNQZ128rrkz */
  },
  { /* 5980 */
    313,
    /* VPANDNQZ256rm */
  },
  { /* 5981 */
    756,
    /* VPANDNQZ256rmb */
  },
  { /* 5982 */
    757,
    /* VPANDNQZ256rmbk */
  },
  { /* 5983 */
    758,
    /* VPANDNQZ256rmbkz */
  },
  { /* 5984 */
    317,
    /* VPANDNQZ256rmk */
  },
  { /* 5985 */
    318,
    /* VPANDNQZ256rmkz */
  },
  { /* 5986 */
    319,
    /* VPANDNQZ256rr */
  },
  { /* 5987 */
    320,
    /* VPANDNQZ256rrk */
  },
  { /* 5988 */
    321,
    /* VPANDNQZ256rrkz */
  },
  { /* 5989 */
    325,
    /* VPANDNQZrm */
  },
  { /* 5990 */
    759,
    /* VPANDNQZrmb */
  },
  { /* 5991 */
    760,
    /* VPANDNQZrmbk */
  },
  { /* 5992 */
    761,
    /* VPANDNQZrmbkz */
  },
  { /* 5993 */
    329,
    /* VPANDNQZrmk */
  },
  { /* 5994 */
    330,
    /* VPANDNQZrmkz */
  },
  { /* 5995 */
    331,
    /* VPANDNQZrr */
  },
  { /* 5996 */
    332,
    /* VPANDNQZrrk */
  },
  { /* 5997 */
    333,
    /* VPANDNQZrrkz */
  },
  { /* 5998 */
    302,
    /* VPANDNYrm */
  },
  { /* 5999 */
    303,
    /* VPANDNYrr */
  },
  { /* 6000 */
    334,
    /* VPANDNrm */
  },
  { /* 6001 */
    335,
    /* VPANDNrr */
  },
  { /* 6002 */
    304,
    /* VPANDQZ128rm */
  },
  { /* 6003 */
    753,
    /* VPANDQZ128rmb */
  },
  { /* 6004 */
    754,
    /* VPANDQZ128rmbk */
  },
  { /* 6005 */
    755,
    /* VPANDQZ128rmbkz */
  },
  { /* 6006 */
    308,
    /* VPANDQZ128rmk */
  },
  { /* 6007 */
    309,
    /* VPANDQZ128rmkz */
  },
  { /* 6008 */
    310,
    /* VPANDQZ128rr */
  },
  { /* 6009 */
    311,
    /* VPANDQZ128rrk */
  },
  { /* 6010 */
    312,
    /* VPANDQZ128rrkz */
  },
  { /* 6011 */
    313,
    /* VPANDQZ256rm */
  },
  { /* 6012 */
    756,
    /* VPANDQZ256rmb */
  },
  { /* 6013 */
    757,
    /* VPANDQZ256rmbk */
  },
  { /* 6014 */
    758,
    /* VPANDQZ256rmbkz */
  },
  { /* 6015 */
    317,
    /* VPANDQZ256rmk */
  },
  { /* 6016 */
    318,
    /* VPANDQZ256rmkz */
  },
  { /* 6017 */
    319,
    /* VPANDQZ256rr */
  },
  { /* 6018 */
    320,
    /* VPANDQZ256rrk */
  },
  { /* 6019 */
    321,
    /* VPANDQZ256rrkz */
  },
  { /* 6020 */
    325,
    /* VPANDQZrm */
  },
  { /* 6021 */
    759,
    /* VPANDQZrmb */
  },
  { /* 6022 */
    760,
    /* VPANDQZrmbk */
  },
  { /* 6023 */
    761,
    /* VPANDQZrmbkz */
  },
  { /* 6024 */
    329,
    /* VPANDQZrmk */
  },
  { /* 6025 */
    330,
    /* VPANDQZrmkz */
  },
  { /* 6026 */
    331,
    /* VPANDQZrr */
  },
  { /* 6027 */
    332,
    /* VPANDQZrrk */
  },
  { /* 6028 */
    333,
    /* VPANDQZrrkz */
  },
  { /* 6029 */
    302,
    /* VPANDYrm */
  },
  { /* 6030 */
    303,
    /* VPANDYrr */
  },
  { /* 6031 */
    334,
    /* VPANDrm */
  },
  { /* 6032 */
    335,
    /* VPANDrr */
  },
  { /* 6033 */
    302,
    /* VPAVGBYrm */
  },
  { /* 6034 */
    303,
    /* VPAVGBYrr */
  },
  { /* 6035 */
    334,
    /* VPAVGBrm */
  },
  { /* 6036 */
    335,
    /* VPAVGBrr */
  },
  { /* 6037 */
    302,
    /* VPAVGWYrm */
  },
  { /* 6038 */
    303,
    /* VPAVGWYrr */
  },
  { /* 6039 */
    334,
    /* VPAVGWrm */
  },
  { /* 6040 */
    335,
    /* VPAVGWrr */
  },
  { /* 6041 */
    388,
    /* VPBLENDDYrmi */
  },
  { /* 6042 */
    389,
    /* VPBLENDDYrri */
  },
  { /* 6043 */
    390,
    /* VPBLENDDrmi */
  },
  { /* 6044 */
    391,
    /* VPBLENDDrri */
  },
  { /* 6045 */
    304,
    /* VPBLENDMBZ128rm */
  },
  { /* 6046 */
    733,
    /* VPBLENDMBZ128rmk */
  },
  { /* 6047 */
    733,
    /* VPBLENDMBZ128rmkz */
  },
  { /* 6048 */
    310,
    /* VPBLENDMBZ128rr */
  },
  { /* 6049 */
    735,
    /* VPBLENDMBZ128rrk */
  },
  { /* 6050 */
    735,
    /* VPBLENDMBZ128rrkz */
  },
  { /* 6051 */
    313,
    /* VPBLENDMBZ256rm */
  },
  { /* 6052 */
    737,
    /* VPBLENDMBZ256rmk */
  },
  { /* 6053 */
    737,
    /* VPBLENDMBZ256rmkz */
  },
  { /* 6054 */
    319,
    /* VPBLENDMBZ256rr */
  },
  { /* 6055 */
    739,
    /* VPBLENDMBZ256rrk */
  },
  { /* 6056 */
    739,
    /* VPBLENDMBZ256rrkz */
  },
  { /* 6057 */
    325,
    /* VPBLENDMBZrm */
  },
  { /* 6058 */
    741,
    /* VPBLENDMBZrmk */
  },
  { /* 6059 */
    741,
    /* VPBLENDMBZrmkz */
  },
  { /* 6060 */
    331,
    /* VPBLENDMBZrr */
  },
  { /* 6061 */
    743,
    /* VPBLENDMBZrrk */
  },
  { /* 6062 */
    743,
    /* VPBLENDMBZrrkz */
  },
  { /* 6063 */
    304,
    /* VPBLENDMDZ128rm */
  },
  { /* 6064 */
    744,
    /* VPBLENDMDZ128rmb */
  },
  { /* 6065 */
    746,
    /* VPBLENDMDZ128rmbk */
  },
  { /* 6066 */
    340,
    /* VPBLENDMDZ128rmk */
  },
  { /* 6067 */
    340,
    /* VPBLENDMDZ128rmkz */
  },
  { /* 6068 */
    310,
    /* VPBLENDMDZ128rr */
  },
  { /* 6069 */
    342,
    /* VPBLENDMDZ128rrk */
  },
  { /* 6070 */
    342,
    /* VPBLENDMDZ128rrkz */
  },
  { /* 6071 */
    313,
    /* VPBLENDMDZ256rm */
  },
  { /* 6072 */
    747,
    /* VPBLENDMDZ256rmb */
  },
  { /* 6073 */
    749,
    /* VPBLENDMDZ256rmbk */
  },
  { /* 6074 */
    347,
    /* VPBLENDMDZ256rmk */
  },
  { /* 6075 */
    347,
    /* VPBLENDMDZ256rmkz */
  },
  { /* 6076 */
    319,
    /* VPBLENDMDZ256rr */
  },
  { /* 6077 */
    349,
    /* VPBLENDMDZ256rrk */
  },
  { /* 6078 */
    349,
    /* VPBLENDMDZ256rrkz */
  },
  { /* 6079 */
    325,
    /* VPBLENDMDZrm */
  },
  { /* 6080 */
    750,
    /* VPBLENDMDZrmb */
  },
  { /* 6081 */
    752,
    /* VPBLENDMDZrmbk */
  },
  { /* 6082 */
    357,
    /* VPBLENDMDZrmk */
  },
  { /* 6083 */
    357,
    /* VPBLENDMDZrmkz */
  },
  { /* 6084 */
    331,
    /* VPBLENDMDZrr */
  },
  { /* 6085 */
    359,
    /* VPBLENDMDZrrk */
  },
  { /* 6086 */
    359,
    /* VPBLENDMDZrrkz */
  },
  { /* 6087 */
    304,
    /* VPBLENDMQZ128rm */
  },
  { /* 6088 */
    753,
    /* VPBLENDMQZ128rmb */
  },
  { /* 6089 */
    755,
    /* VPBLENDMQZ128rmbk */
  },
  { /* 6090 */
    309,
    /* VPBLENDMQZ128rmk */
  },
  { /* 6091 */
    309,
    /* VPBLENDMQZ128rmkz */
  },
  { /* 6092 */
    310,
    /* VPBLENDMQZ128rr */
  },
  { /* 6093 */
    312,
    /* VPBLENDMQZ128rrk */
  },
  { /* 6094 */
    312,
    /* VPBLENDMQZ128rrkz */
  },
  { /* 6095 */
    313,
    /* VPBLENDMQZ256rm */
  },
  { /* 6096 */
    756,
    /* VPBLENDMQZ256rmb */
  },
  { /* 6097 */
    758,
    /* VPBLENDMQZ256rmbk */
  },
  { /* 6098 */
    318,
    /* VPBLENDMQZ256rmk */
  },
  { /* 6099 */
    318,
    /* VPBLENDMQZ256rmkz */
  },
  { /* 6100 */
    319,
    /* VPBLENDMQZ256rr */
  },
  { /* 6101 */
    321,
    /* VPBLENDMQZ256rrk */
  },
  { /* 6102 */
    321,
    /* VPBLENDMQZ256rrkz */
  },
  { /* 6103 */
    325,
    /* VPBLENDMQZrm */
  },
  { /* 6104 */
    759,
    /* VPBLENDMQZrmb */
  },
  { /* 6105 */
    761,
    /* VPBLENDMQZrmbk */
  },
  { /* 6106 */
    330,
    /* VPBLENDMQZrmk */
  },
  { /* 6107 */
    330,
    /* VPBLENDMQZrmkz */
  },
  { /* 6108 */
    331,
    /* VPBLENDMQZrr */
  },
  { /* 6109 */
    333,
    /* VPBLENDMQZrrk */
  },
  { /* 6110 */
    333,
    /* VPBLENDMQZrrkz */
  },
  { /* 6111 */
    304,
    /* VPBLENDMWZ128rm */
  },
  { /* 6112 */
    763,
    /* VPBLENDMWZ128rmk */
  },
  { /* 6113 */
    763,
    /* VPBLENDMWZ128rmkz */
  },
  { /* 6114 */
    310,
    /* VPBLENDMWZ128rr */
  },
  { /* 6115 */
    765,
    /* VPBLENDMWZ128rrk */
  },
  { /* 6116 */
    765,
    /* VPBLENDMWZ128rrkz */
  },
  { /* 6117 */
    313,
    /* VPBLENDMWZ256rm */
  },
  { /* 6118 */
    767,
    /* VPBLENDMWZ256rmk */
  },
  { /* 6119 */
    767,
    /* VPBLENDMWZ256rmkz */
  },
  { /* 6120 */
    319,
    /* VPBLENDMWZ256rr */
  },
  { /* 6121 */
    769,
    /* VPBLENDMWZ256rrk */
  },
  { /* 6122 */
    769,
    /* VPBLENDMWZ256rrkz */
  },
  { /* 6123 */
    325,
    /* VPBLENDMWZrm */
  },
  { /* 6124 */
    771,
    /* VPBLENDMWZrmk */
  },
  { /* 6125 */
    771,
    /* VPBLENDMWZrmkz */
  },
  { /* 6126 */
    331,
    /* VPBLENDMWZrr */
  },
  { /* 6127 */
    773,
    /* VPBLENDMWZrrk */
  },
  { /* 6128 */
    773,
    /* VPBLENDMWZrrkz */
  },
  { /* 6129 */
    392,
    /* VPBLENDVBYrm */
  },
  { /* 6130 */
    393,
    /* VPBLENDVBYrr */
  },
  { /* 6131 */
    394,
    /* VPBLENDVBrm */
  },
  { /* 6132 */
    395,
    /* VPBLENDVBrr */
  },
  { /* 6133 */
    388,
    /* VPBLENDWYrmi */
  },
  { /* 6134 */
    389,
    /* VPBLENDWYrri */
  },
  { /* 6135 */
    390,
    /* VPBLENDWrmi */
  },
  { /* 6136 */
    391,
    /* VPBLENDWrri */
  },
  { /* 6137 */
    774,
    /* VPBROADCASTBYrm */
  },
  { /* 6138 */
    402,
    /* VPBROADCASTBYrr */
  },
  { /* 6139 */
    660,
    /* VPBROADCASTBrZ128r */
  },
  { /* 6140 */
    775,
    /* VPBROADCASTBrZ128rk */
  },
  { /* 6141 */
    776,
    /* VPBROADCASTBrZ128rkz */
  },
  { /* 6142 */
    777,
    /* VPBROADCASTBrZ256r */
  },
  { /* 6143 */
    778,
    /* VPBROADCASTBrZ256rk */
  },
  { /* 6144 */
    779,
    /* VPBROADCASTBrZ256rkz */
  },
  { /* 6145 */
    780,
    /* VPBROADCASTBrZr */
  },
  { /* 6146 */
    781,
    /* VPBROADCASTBrZrk */
  },
  { /* 6147 */
    782,
    /* VPBROADCASTBrZrkz */
  },
  { /* 6148 */
    783,
    /* VPBROADCASTBrm */
  },
  { /* 6149 */
    45,
    /* VPBROADCASTBrr */
  },
  { /* 6150 */
    784,
    /* VPBROADCASTDYrm */
  },
  { /* 6151 */
    402,
    /* VPBROADCASTDYrr */
  },
  { /* 6152 */
    729,
    /* VPBROADCASTDZkrm */
  },
  { /* 6153 */
    433,
    /* VPBROADCASTDZkrr */
  },
  { /* 6154 */
    728,
    /* VPBROADCASTDZrm */
  },
  { /* 6155 */
    431,
    /* VPBROADCASTDZrr */
  },
  { /* 6156 */
    660,
    /* VPBROADCASTDrZ128r */
  },
  { /* 6157 */
    785,
    /* VPBROADCASTDrZ128rk */
  },
  { /* 6158 */
    786,
    /* VPBROADCASTDrZ128rkz */
  },
  { /* 6159 */
    777,
    /* VPBROADCASTDrZ256r */
  },
  { /* 6160 */
    787,
    /* VPBROADCASTDrZ256rk */
  },
  { /* 6161 */
    788,
    /* VPBROADCASTDrZ256rkz */
  },
  { /* 6162 */
    780,
    /* VPBROADCASTDrZr */
  },
  { /* 6163 */
    789,
    /* VPBROADCASTDrZrk */
  },
  { /* 6164 */
    790,
    /* VPBROADCASTDrZrkz */
  },
  { /* 6165 */
    105,
    /* VPBROADCASTDrm */
  },
  { /* 6166 */
    45,
    /* VPBROADCASTDrr */
  },
  { /* 6167 */
    791,
    /* VPBROADCASTMB2QZ128rr */
  },
  { /* 6168 */
    792,
    /* VPBROADCASTMB2QZ256rr */
  },
  { /* 6169 */
    793,
    /* VPBROADCASTMB2QZrr */
  },
  { /* 6170 */
    794,
    /* VPBROADCASTMW2DZ128rr */
  },
  { /* 6171 */
    795,
    /* VPBROADCASTMW2DZ256rr */
  },
  { /* 6172 */
    796,
    /* VPBROADCASTMW2DZrr */
  },
  { /* 6173 */
    784,
    /* VPBROADCASTQYrm */
  },
  { /* 6174 */
    402,
    /* VPBROADCASTQYrr */
  },
  { /* 6175 */
    731,
    /* VPBROADCASTQZkrm */
  },
  { /* 6176 */
    414,
    /* VPBROADCASTQZkrr */
  },
  { /* 6177 */
    730,
    /* VPBROADCASTQZrm */
  },
  { /* 6178 */
    412,
    /* VPBROADCASTQZrr */
  },
  { /* 6179 */
    632,
    /* VPBROADCASTQrZ128r */
  },
  { /* 6180 */
    797,
    /* VPBROADCASTQrZ128rk */
  },
  { /* 6181 */
    798,
    /* VPBROADCASTQrZ128rkz */
  },
  { /* 6182 */
    799,
    /* VPBROADCASTQrZ256r */
  },
  { /* 6183 */
    800,
    /* VPBROADCASTQrZ256rk */
  },
  { /* 6184 */
    801,
    /* VPBROADCASTQrZ256rkz */
  },
  { /* 6185 */
    802,
    /* VPBROADCASTQrZr */
  },
  { /* 6186 */
    803,
    /* VPBROADCASTQrZrk */
  },
  { /* 6187 */
    804,
    /* VPBROADCASTQrZrkz */
  },
  { /* 6188 */
    105,
    /* VPBROADCASTQrm */
  },
  { /* 6189 */
    45,
    /* VPBROADCASTQrr */
  },
  { /* 6190 */
    784,
    /* VPBROADCASTWYrm */
  },
  { /* 6191 */
    402,
    /* VPBROADCASTWYrr */
  },
  { /* 6192 */
    660,
    /* VPBROADCASTWrZ128r */
  },
  { /* 6193 */
    805,
    /* VPBROADCASTWrZ128rk */
  },
  { /* 6194 */
    806,
    /* VPBROADCASTWrZ128rkz */
  },
  { /* 6195 */
    777,
    /* VPBROADCASTWrZ256r */
  },
  { /* 6196 */
    807,
    /* VPBROADCASTWrZ256rk */
  },
  { /* 6197 */
    808,
    /* VPBROADCASTWrZ256rkz */
  },
  { /* 6198 */
    780,
    /* VPBROADCASTWrZr */
  },
  { /* 6199 */
    809,
    /* VPBROADCASTWrZrk */
  },
  { /* 6200 */
    810,
    /* VPBROADCASTWrZrkz */
  },
  { /* 6201 */
    105,
    /* VPBROADCASTWrm */
  },
  { /* 6202 */
    45,
    /* VPBROADCASTWrr */
  },
  { /* 6203 */
    390,
    /* VPCLMULQDQrm */
  },
  { /* 6204 */
    391,
    /* VPCLMULQDQrr */
  },
  { /* 6205 */
    394,
    /* VPCMOVmr */
  },
  { /* 6206 */
    392,
    /* VPCMOVmrY */
  },
  { /* 6207 */
    579,
    /* VPCMOVrm */
  },
  { /* 6208 */
    580,
    /* VPCMOVrmY */
  },
  { /* 6209 */
    395,
    /* VPCMOVrr */
  },
  { /* 6210 */
    393,
    /* VPCMOVrrY */
  },
  { /* 6211 */
    811,
    /* VPCMPBZ128rmi */
  },
  { /* 6212 */
    0,
    /*  */
  },
  { /* 6213 */
    812,
    /* VPCMPBZ128rmik */
  },
  { /* 6214 */
    0,
    /*  */
  },
  { /* 6215 */
    813,
    /* VPCMPBZ128rri */
  },
  { /* 6216 */
    0,
    /*  */
  },
  { /* 6217 */
    814,
    /* VPCMPBZ128rrik */
  },
  { /* 6218 */
    0,
    /*  */
  },
  { /* 6219 */
    815,
    /* VPCMPBZ256rmi */
  },
  { /* 6220 */
    0,
    /*  */
  },
  { /* 6221 */
    816,
    /* VPCMPBZ256rmik */
  },
  { /* 6222 */
    0,
    /*  */
  },
  { /* 6223 */
    817,
    /* VPCMPBZ256rri */
  },
  { /* 6224 */
    0,
    /*  */
  },
  { /* 6225 */
    818,
    /* VPCMPBZ256rrik */
  },
  { /* 6226 */
    0,
    /*  */
  },
  { /* 6227 */
    819,
    /* VPCMPBZrmi */
  },
  { /* 6228 */
    0,
    /*  */
  },
  { /* 6229 */
    820,
    /* VPCMPBZrmik */
  },
  { /* 6230 */
    0,
    /*  */
  },
  { /* 6231 */
    821,
    /* VPCMPBZrri */
  },
  { /* 6232 */
    0,
    /*  */
  },
  { /* 6233 */
    822,
    /* VPCMPBZrrik */
  },
  { /* 6234 */
    0,
    /*  */
  },
  { /* 6235 */
    823,
    /* VPCMPDZ128rmi */
  },
  { /* 6236 */
    0,
    /*  */
  },
  { /* 6237 */
    824,
    /* VPCMPDZ128rmib */
  },
  { /* 6238 */
    0,
    /*  */
  },
  { /* 6239 */
    825,
    /* VPCMPDZ128rmibk */
  },
  { /* 6240 */
    0,
    /*  */
  },
  { /* 6241 */
    826,
    /* VPCMPDZ128rmik */
  },
  { /* 6242 */
    0,
    /*  */
  },
  { /* 6243 */
    827,
    /* VPCMPDZ128rri */
  },
  { /* 6244 */
    0,
    /*  */
  },
  { /* 6245 */
    828,
    /* VPCMPDZ128rrik */
  },
  { /* 6246 */
    0,
    /*  */
  },
  { /* 6247 */
    829,
    /* VPCMPDZ256rmi */
  },
  { /* 6248 */
    0,
    /*  */
  },
  { /* 6249 */
    830,
    /* VPCMPDZ256rmib */
  },
  { /* 6250 */
    0,
    /*  */
  },
  { /* 6251 */
    831,
    /* VPCMPDZ256rmibk */
  },
  { /* 6252 */
    0,
    /*  */
  },
  { /* 6253 */
    832,
    /* VPCMPDZ256rmik */
  },
  { /* 6254 */
    0,
    /*  */
  },
  { /* 6255 */
    833,
    /* VPCMPDZ256rri */
  },
  { /* 6256 */
    0,
    /*  */
  },
  { /* 6257 */
    834,
    /* VPCMPDZ256rrik */
  },
  { /* 6258 */
    0,
    /*  */
  },
  { /* 6259 */
    835,
    /* VPCMPDZrmi */
  },
  { /* 6260 */
    0,
    /*  */
  },
  { /* 6261 */
    836,
    /* VPCMPDZrmib */
  },
  { /* 6262 */
    0,
    /*  */
  },
  { /* 6263 */
    837,
    /* VPCMPDZrmibk */
  },
  { /* 6264 */
    0,
    /*  */
  },
  { /* 6265 */
    838,
    /* VPCMPDZrmik */
  },
  { /* 6266 */
    0,
    /*  */
  },
  { /* 6267 */
    839,
    /* VPCMPDZrri */
  },
  { /* 6268 */
    0,
    /*  */
  },
  { /* 6269 */
    840,
    /* VPCMPDZrrik */
  },
  { /* 6270 */
    0,
    /*  */
  },
  { /* 6271 */
    302,
    /* VPCMPEQBYrm */
  },
  { /* 6272 */
    303,
    /* VPCMPEQBYrr */
  },
  { /* 6273 */
    841,
    /* VPCMPEQBZ128rm */
  },
  { /* 6274 */
    842,
    /* VPCMPEQBZ128rmk */
  },
  { /* 6275 */
    843,
    /* VPCMPEQBZ128rr */
  },
  { /* 6276 */
    844,
    /* VPCMPEQBZ128rrk */
  },
  { /* 6277 */
    845,
    /* VPCMPEQBZ256rm */
  },
  { /* 6278 */
    846,
    /* VPCMPEQBZ256rmk */
  },
  { /* 6279 */
    847,
    /* VPCMPEQBZ256rr */
  },
  { /* 6280 */
    848,
    /* VPCMPEQBZ256rrk */
  },
  { /* 6281 */
    849,
    /* VPCMPEQBZrm */
  },
  { /* 6282 */
    850,
    /* VPCMPEQBZrmk */
  },
  { /* 6283 */
    851,
    /* VPCMPEQBZrr */
  },
  { /* 6284 */
    852,
    /* VPCMPEQBZrrk */
  },
  { /* 6285 */
    334,
    /* VPCMPEQBrm */
  },
  { /* 6286 */
    335,
    /* VPCMPEQBrr */
  },
  { /* 6287 */
    302,
    /* VPCMPEQDYrm */
  },
  { /* 6288 */
    303,
    /* VPCMPEQDYrr */
  },
  { /* 6289 */
    853,
    /* VPCMPEQDZ128rm */
  },
  { /* 6290 */
    854,
    /* VPCMPEQDZ128rmb */
  },
  { /* 6291 */
    855,
    /* VPCMPEQDZ128rmbk */
  },
  { /* 6292 */
    856,
    /* VPCMPEQDZ128rmk */
  },
  { /* 6293 */
    857,
    /* VPCMPEQDZ128rr */
  },
  { /* 6294 */
    858,
    /* VPCMPEQDZ128rrk */
  },
  { /* 6295 */
    859,
    /* VPCMPEQDZ256rm */
  },
  { /* 6296 */
    860,
    /* VPCMPEQDZ256rmb */
  },
  { /* 6297 */
    861,
    /* VPCMPEQDZ256rmbk */
  },
  { /* 6298 */
    862,
    /* VPCMPEQDZ256rmk */
  },
  { /* 6299 */
    863,
    /* VPCMPEQDZ256rr */
  },
  { /* 6300 */
    864,
    /* VPCMPEQDZ256rrk */
  },
  { /* 6301 */
    865,
    /* VPCMPEQDZrm */
  },
  { /* 6302 */
    866,
    /* VPCMPEQDZrmb */
  },
  { /* 6303 */
    867,
    /* VPCMPEQDZrmbk */
  },
  { /* 6304 */
    868,
    /* VPCMPEQDZrmk */
  },
  { /* 6305 */
    869,
    /* VPCMPEQDZrr */
  },
  { /* 6306 */
    870,
    /* VPCMPEQDZrrk */
  },
  { /* 6307 */
    334,
    /* VPCMPEQDrm */
  },
  { /* 6308 */
    335,
    /* VPCMPEQDrr */
  },
  { /* 6309 */
    302,
    /* VPCMPEQQYrm */
  },
  { /* 6310 */
    303,
    /* VPCMPEQQYrr */
  },
  { /* 6311 */
    871,
    /* VPCMPEQQZ128rm */
  },
  { /* 6312 */
    872,
    /* VPCMPEQQZ128rmb */
  },
  { /* 6313 */
    873,
    /* VPCMPEQQZ128rmbk */
  },
  { /* 6314 */
    874,
    /* VPCMPEQQZ128rmk */
  },
  { /* 6315 */
    875,
    /* VPCMPEQQZ128rr */
  },
  { /* 6316 */
    876,
    /* VPCMPEQQZ128rrk */
  },
  { /* 6317 */
    877,
    /* VPCMPEQQZ256rm */
  },
  { /* 6318 */
    878,
    /* VPCMPEQQZ256rmb */
  },
  { /* 6319 */
    879,
    /* VPCMPEQQZ256rmbk */
  },
  { /* 6320 */
    880,
    /* VPCMPEQQZ256rmk */
  },
  { /* 6321 */
    881,
    /* VPCMPEQQZ256rr */
  },
  { /* 6322 */
    882,
    /* VPCMPEQQZ256rrk */
  },
  { /* 6323 */
    883,
    /* VPCMPEQQZrm */
  },
  { /* 6324 */
    884,
    /* VPCMPEQQZrmb */
  },
  { /* 6325 */
    885,
    /* VPCMPEQQZrmbk */
  },
  { /* 6326 */
    886,
    /* VPCMPEQQZrmk */
  },
  { /* 6327 */
    887,
    /* VPCMPEQQZrr */
  },
  { /* 6328 */
    888,
    /* VPCMPEQQZrrk */
  },
  { /* 6329 */
    334,
    /* VPCMPEQQrm */
  },
  { /* 6330 */
    335,
    /* VPCMPEQQrr */
  },
  { /* 6331 */
    302,
    /* VPCMPEQWYrm */
  },
  { /* 6332 */
    303,
    /* VPCMPEQWYrr */
  },
  { /* 6333 */
    889,
    /* VPCMPEQWZ128rm */
  },
  { /* 6334 */
    890,
    /* VPCMPEQWZ128rmk */
  },
  { /* 6335 */
    891,
    /* VPCMPEQWZ128rr */
  },
  { /* 6336 */
    892,
    /* VPCMPEQWZ128rrk */
  },
  { /* 6337 */
    893,
    /* VPCMPEQWZ256rm */
  },
  { /* 6338 */
    894,
    /* VPCMPEQWZ256rmk */
  },
  { /* 6339 */
    895,
    /* VPCMPEQWZ256rr */
  },
  { /* 6340 */
    896,
    /* VPCMPEQWZ256rrk */
  },
  { /* 6341 */
    897,
    /* VPCMPEQWZrm */
  },
  { /* 6342 */
    898,
    /* VPCMPEQWZrmk */
  },
  { /* 6343 */
    899,
    /* VPCMPEQWZrr */
  },
  { /* 6344 */
    900,
    /* VPCMPEQWZrrk */
  },
  { /* 6345 */
    334,
    /* VPCMPEQWrm */
  },
  { /* 6346 */
    335,
    /* VPCMPEQWrr */
  },
  { /* 6347 */
    0,
    /*  */
  },
  { /* 6348 */
    0,
    /*  */
  },
  { /* 6349 */
    46,
    /* VPCMPESTRIrm */
  },
  { /* 6350 */
    47,
    /* VPCMPESTRIrr */
  },
  { /* 6351 */
    0,
    /*  */
  },
  { /* 6352 */
    0,
    /*  */
  },
  { /* 6353 */
    46,
    /* VPCMPESTRM128rm */
  },
  { /* 6354 */
    47,
    /* VPCMPESTRM128rr */
  },
  { /* 6355 */
    302,
    /* VPCMPGTBYrm */
  },
  { /* 6356 */
    303,
    /* VPCMPGTBYrr */
  },
  { /* 6357 */
    841,
    /* VPCMPGTBZ128rm */
  },
  { /* 6358 */
    842,
    /* VPCMPGTBZ128rmk */
  },
  { /* 6359 */
    843,
    /* VPCMPGTBZ128rr */
  },
  { /* 6360 */
    844,
    /* VPCMPGTBZ128rrk */
  },
  { /* 6361 */
    845,
    /* VPCMPGTBZ256rm */
  },
  { /* 6362 */
    846,
    /* VPCMPGTBZ256rmk */
  },
  { /* 6363 */
    847,
    /* VPCMPGTBZ256rr */
  },
  { /* 6364 */
    848,
    /* VPCMPGTBZ256rrk */
  },
  { /* 6365 */
    849,
    /* VPCMPGTBZrm */
  },
  { /* 6366 */
    850,
    /* VPCMPGTBZrmk */
  },
  { /* 6367 */
    851,
    /* VPCMPGTBZrr */
  },
  { /* 6368 */
    852,
    /* VPCMPGTBZrrk */
  },
  { /* 6369 */
    334,
    /* VPCMPGTBrm */
  },
  { /* 6370 */
    335,
    /* VPCMPGTBrr */
  },
  { /* 6371 */
    302,
    /* VPCMPGTDYrm */
  },
  { /* 6372 */
    303,
    /* VPCMPGTDYrr */
  },
  { /* 6373 */
    853,
    /* VPCMPGTDZ128rm */
  },
  { /* 6374 */
    854,
    /* VPCMPGTDZ128rmb */
  },
  { /* 6375 */
    855,
    /* VPCMPGTDZ128rmbk */
  },
  { /* 6376 */
    856,
    /* VPCMPGTDZ128rmk */
  },
  { /* 6377 */
    857,
    /* VPCMPGTDZ128rr */
  },
  { /* 6378 */
    858,
    /* VPCMPGTDZ128rrk */
  },
  { /* 6379 */
    859,
    /* VPCMPGTDZ256rm */
  },
  { /* 6380 */
    860,
    /* VPCMPGTDZ256rmb */
  },
  { /* 6381 */
    861,
    /* VPCMPGTDZ256rmbk */
  },
  { /* 6382 */
    862,
    /* VPCMPGTDZ256rmk */
  },
  { /* 6383 */
    863,
    /* VPCMPGTDZ256rr */
  },
  { /* 6384 */
    864,
    /* VPCMPGTDZ256rrk */
  },
  { /* 6385 */
    865,
    /* VPCMPGTDZrm */
  },
  { /* 6386 */
    866,
    /* VPCMPGTDZrmb */
  },
  { /* 6387 */
    867,
    /* VPCMPGTDZrmbk */
  },
  { /* 6388 */
    868,
    /* VPCMPGTDZrmk */
  },
  { /* 6389 */
    869,
    /* VPCMPGTDZrr */
  },
  { /* 6390 */
    870,
    /* VPCMPGTDZrrk */
  },
  { /* 6391 */
    334,
    /* VPCMPGTDrm */
  },
  { /* 6392 */
    335,
    /* VPCMPGTDrr */
  },
  { /* 6393 */
    302,
    /* VPCMPGTQYrm */
  },
  { /* 6394 */
    303,
    /* VPCMPGTQYrr */
  },
  { /* 6395 */
    871,
    /* VPCMPGTQZ128rm */
  },
  { /* 6396 */
    872,
    /* VPCMPGTQZ128rmb */
  },
  { /* 6397 */
    873,
    /* VPCMPGTQZ128rmbk */
  },
  { /* 6398 */
    874,
    /* VPCMPGTQZ128rmk */
  },
  { /* 6399 */
    875,
    /* VPCMPGTQZ128rr */
  },
  { /* 6400 */
    876,
    /* VPCMPGTQZ128rrk */
  },
  { /* 6401 */
    877,
    /* VPCMPGTQZ256rm */
  },
  { /* 6402 */
    878,
    /* VPCMPGTQZ256rmb */
  },
  { /* 6403 */
    879,
    /* VPCMPGTQZ256rmbk */
  },
  { /* 6404 */
    880,
    /* VPCMPGTQZ256rmk */
  },
  { /* 6405 */
    881,
    /* VPCMPGTQZ256rr */
  },
  { /* 6406 */
    882,
    /* VPCMPGTQZ256rrk */
  },
  { /* 6407 */
    883,
    /* VPCMPGTQZrm */
  },
  { /* 6408 */
    884,
    /* VPCMPGTQZrmb */
  },
  { /* 6409 */
    885,
    /* VPCMPGTQZrmbk */
  },
  { /* 6410 */
    886,
    /* VPCMPGTQZrmk */
  },
  { /* 6411 */
    887,
    /* VPCMPGTQZrr */
  },
  { /* 6412 */
    888,
    /* VPCMPGTQZrrk */
  },
  { /* 6413 */
    334,
    /* VPCMPGTQrm */
  },
  { /* 6414 */
    335,
    /* VPCMPGTQrr */
  },
  { /* 6415 */
    302,
    /* VPCMPGTWYrm */
  },
  { /* 6416 */
    303,
    /* VPCMPGTWYrr */
  },
  { /* 6417 */
    889,
    /* VPCMPGTWZ128rm */
  },
  { /* 6418 */
    890,
    /* VPCMPGTWZ128rmk */
  },
  { /* 6419 */
    891,
    /* VPCMPGTWZ128rr */
  },
  { /* 6420 */
    892,
    /* VPCMPGTWZ128rrk */
  },
  { /* 6421 */
    893,
    /* VPCMPGTWZ256rm */
  },
  { /* 6422 */
    894,
    /* VPCMPGTWZ256rmk */
  },
  { /* 6423 */
    895,
    /* VPCMPGTWZ256rr */
  },
  { /* 6424 */
    896,
    /* VPCMPGTWZ256rrk */
  },
  { /* 6425 */
    897,
    /* VPCMPGTWZrm */
  },
  { /* 6426 */
    898,
    /* VPCMPGTWZrmk */
  },
  { /* 6427 */
    899,
    /* VPCMPGTWZrr */
  },
  { /* 6428 */
    900,
    /* VPCMPGTWZrrk */
  },
  { /* 6429 */
    334,
    /* VPCMPGTWrm */
  },
  { /* 6430 */
    335,
    /* VPCMPGTWrr */
  },
  { /* 6431 */
    0,
    /*  */
  },
  { /* 6432 */
    0,
    /*  */
  },
  { /* 6433 */
    46,
    /* VPCMPISTRIrm */
  },
  { /* 6434 */
    47,
    /* VPCMPISTRIrr */
  },
  { /* 6435 */
    0,
    /*  */
  },
  { /* 6436 */
    0,
    /*  */
  },
  { /* 6437 */
    46,
    /* VPCMPISTRM128rm */
  },
  { /* 6438 */
    47,
    /* VPCMPISTRM128rr */
  },
  { /* 6439 */
    901,
    /* VPCMPQZ128rmi */
  },
  { /* 6440 */
    0,
    /*  */
  },
  { /* 6441 */
    902,
    /* VPCMPQZ128rmib */
  },
  { /* 6442 */
    0,
    /*  */
  },
  { /* 6443 */
    903,
    /* VPCMPQZ128rmibk */
  },
  { /* 6444 */
    0,
    /*  */
  },
  { /* 6445 */
    904,
    /* VPCMPQZ128rmik */
  },
  { /* 6446 */
    0,
    /*  */
  },
  { /* 6447 */
    905,
    /* VPCMPQZ128rri */
  },
  { /* 6448 */
    0,
    /*  */
  },
  { /* 6449 */
    906,
    /* VPCMPQZ128rrik */
  },
  { /* 6450 */
    0,
    /*  */
  },
  { /* 6451 */
    907,
    /* VPCMPQZ256rmi */
  },
  { /* 6452 */
    0,
    /*  */
  },
  { /* 6453 */
    908,
    /* VPCMPQZ256rmib */
  },
  { /* 6454 */
    0,
    /*  */
  },
  { /* 6455 */
    909,
    /* VPCMPQZ256rmibk */
  },
  { /* 6456 */
    0,
    /*  */
  },
  { /* 6457 */
    910,
    /* VPCMPQZ256rmik */
  },
  { /* 6458 */
    0,
    /*  */
  },
  { /* 6459 */
    911,
    /* VPCMPQZ256rri */
  },
  { /* 6460 */
    0,
    /*  */
  },
  { /* 6461 */
    912,
    /* VPCMPQZ256rrik */
  },
  { /* 6462 */
    0,
    /*  */
  },
  { /* 6463 */
    913,
    /* VPCMPQZrmi */
  },
  { /* 6464 */
    0,
    /*  */
  },
  { /* 6465 */
    914,
    /* VPCMPQZrmib */
  },
  { /* 6466 */
    0,
    /*  */
  },
  { /* 6467 */
    915,
    /* VPCMPQZrmibk */
  },
  { /* 6468 */
    0,
    /*  */
  },
  { /* 6469 */
    916,
    /* VPCMPQZrmik */
  },
  { /* 6470 */
    0,
    /*  */
  },
  { /* 6471 */
    917,
    /* VPCMPQZrri */
  },
  { /* 6472 */
    0,
    /*  */
  },
  { /* 6473 */
    918,
    /* VPCMPQZrrik */
  },
  { /* 6474 */
    0,
    /*  */
  },
  { /* 6475 */
    811,
    /* VPCMPUBZ128rmi */
  },
  { /* 6476 */
    0,
    /*  */
  },
  { /* 6477 */
    812,
    /* VPCMPUBZ128rmik */
  },
  { /* 6478 */
    0,
    /*  */
  },
  { /* 6479 */
    813,
    /* VPCMPUBZ128rri */
  },
  { /* 6480 */
    0,
    /*  */
  },
  { /* 6481 */
    814,
    /* VPCMPUBZ128rrik */
  },
  { /* 6482 */
    0,
    /*  */
  },
  { /* 6483 */
    815,
    /* VPCMPUBZ256rmi */
  },
  { /* 6484 */
    0,
    /*  */
  },
  { /* 6485 */
    816,
    /* VPCMPUBZ256rmik */
  },
  { /* 6486 */
    0,
    /*  */
  },
  { /* 6487 */
    817,
    /* VPCMPUBZ256rri */
  },
  { /* 6488 */
    0,
    /*  */
  },
  { /* 6489 */
    818,
    /* VPCMPUBZ256rrik */
  },
  { /* 6490 */
    0,
    /*  */
  },
  { /* 6491 */
    819,
    /* VPCMPUBZrmi */
  },
  { /* 6492 */
    0,
    /*  */
  },
  { /* 6493 */
    820,
    /* VPCMPUBZrmik */
  },
  { /* 6494 */
    0,
    /*  */
  },
  { /* 6495 */
    821,
    /* VPCMPUBZrri */
  },
  { /* 6496 */
    0,
    /*  */
  },
  { /* 6497 */
    822,
    /* VPCMPUBZrrik */
  },
  { /* 6498 */
    0,
    /*  */
  },
  { /* 6499 */
    823,
    /* VPCMPUDZ128rmi */
  },
  { /* 6500 */
    0,
    /*  */
  },
  { /* 6501 */
    824,
    /* VPCMPUDZ128rmib */
  },
  { /* 6502 */
    0,
    /*  */
  },
  { /* 6503 */
    825,
    /* VPCMPUDZ128rmibk */
  },
  { /* 6504 */
    0,
    /*  */
  },
  { /* 6505 */
    826,
    /* VPCMPUDZ128rmik */
  },
  { /* 6506 */
    0,
    /*  */
  },
  { /* 6507 */
    827,
    /* VPCMPUDZ128rri */
  },
  { /* 6508 */
    0,
    /*  */
  },
  { /* 6509 */
    828,
    /* VPCMPUDZ128rrik */
  },
  { /* 6510 */
    0,
    /*  */
  },
  { /* 6511 */
    829,
    /* VPCMPUDZ256rmi */
  },
  { /* 6512 */
    0,
    /*  */
  },
  { /* 6513 */
    830,
    /* VPCMPUDZ256rmib */
  },
  { /* 6514 */
    0,
    /*  */
  },
  { /* 6515 */
    831,
    /* VPCMPUDZ256rmibk */
  },
  { /* 6516 */
    0,
    /*  */
  },
  { /* 6517 */
    832,
    /* VPCMPUDZ256rmik */
  },
  { /* 6518 */
    0,
    /*  */
  },
  { /* 6519 */
    833,
    /* VPCMPUDZ256rri */
  },
  { /* 6520 */
    0,
    /*  */
  },
  { /* 6521 */
    834,
    /* VPCMPUDZ256rrik */
  },
  { /* 6522 */
    0,
    /*  */
  },
  { /* 6523 */
    835,
    /* VPCMPUDZrmi */
  },
  { /* 6524 */
    0,
    /*  */
  },
  { /* 6525 */
    836,
    /* VPCMPUDZrmib */
  },
  { /* 6526 */
    0,
    /*  */
  },
  { /* 6527 */
    837,
    /* VPCMPUDZrmibk */
  },
  { /* 6528 */
    0,
    /*  */
  },
  { /* 6529 */
    838,
    /* VPCMPUDZrmik */
  },
  { /* 6530 */
    0,
    /*  */
  },
  { /* 6531 */
    839,
    /* VPCMPUDZrri */
  },
  { /* 6532 */
    0,
    /*  */
  },
  { /* 6533 */
    840,
    /* VPCMPUDZrrik */
  },
  { /* 6534 */
    0,
    /*  */
  },
  { /* 6535 */
    901,
    /* VPCMPUQZ128rmi */
  },
  { /* 6536 */
    0,
    /*  */
  },
  { /* 6537 */
    902,
    /* VPCMPUQZ128rmib */
  },
  { /* 6538 */
    0,
    /*  */
  },
  { /* 6539 */
    903,
    /* VPCMPUQZ128rmibk */
  },
  { /* 6540 */
    0,
    /*  */
  },
  { /* 6541 */
    904,
    /* VPCMPUQZ128rmik */
  },
  { /* 6542 */
    0,
    /*  */
  },
  { /* 6543 */
    905,
    /* VPCMPUQZ128rri */
  },
  { /* 6544 */
    0,
    /*  */
  },
  { /* 6545 */
    906,
    /* VPCMPUQZ128rrik */
  },
  { /* 6546 */
    0,
    /*  */
  },
  { /* 6547 */
    907,
    /* VPCMPUQZ256rmi */
  },
  { /* 6548 */
    0,
    /*  */
  },
  { /* 6549 */
    908,
    /* VPCMPUQZ256rmib */
  },
  { /* 6550 */
    0,
    /*  */
  },
  { /* 6551 */
    909,
    /* VPCMPUQZ256rmibk */
  },
  { /* 6552 */
    0,
    /*  */
  },
  { /* 6553 */
    910,
    /* VPCMPUQZ256rmik */
  },
  { /* 6554 */
    0,
    /*  */
  },
  { /* 6555 */
    911,
    /* VPCMPUQZ256rri */
  },
  { /* 6556 */
    0,
    /*  */
  },
  { /* 6557 */
    912,
    /* VPCMPUQZ256rrik */
  },
  { /* 6558 */
    0,
    /*  */
  },
  { /* 6559 */
    913,
    /* VPCMPUQZrmi */
  },
  { /* 6560 */
    0,
    /*  */
  },
  { /* 6561 */
    914,
    /* VPCMPUQZrmib */
  },
  { /* 6562 */
    0,
    /*  */
  },
  { /* 6563 */
    915,
    /* VPCMPUQZrmibk */
  },
  { /* 6564 */
    0,
    /*  */
  },
  { /* 6565 */
    916,
    /* VPCMPUQZrmik */
  },
  { /* 6566 */
    0,
    /*  */
  },
  { /* 6567 */
    917,
    /* VPCMPUQZrri */
  },
  { /* 6568 */
    0,
    /*  */
  },
  { /* 6569 */
    918,
    /* VPCMPUQZrrik */
  },
  { /* 6570 */
    0,
    /*  */
  },
  { /* 6571 */
    919,
    /* VPCMPUWZ128rmi */
  },
  { /* 6572 */
    0,
    /*  */
  },
  { /* 6573 */
    920,
    /* VPCMPUWZ128rmik */
  },
  { /* 6574 */
    0,
    /*  */
  },
  { /* 6575 */
    921,
    /* VPCMPUWZ128rri */
  },
  { /* 6576 */
    0,
    /*  */
  },
  { /* 6577 */
    922,
    /* VPCMPUWZ128rrik */
  },
  { /* 6578 */
    0,
    /*  */
  },
  { /* 6579 */
    923,
    /* VPCMPUWZ256rmi */
  },
  { /* 6580 */
    0,
    /*  */
  },
  { /* 6581 */
    924,
    /* VPCMPUWZ256rmik */
  },
  { /* 6582 */
    0,
    /*  */
  },
  { /* 6583 */
    925,
    /* VPCMPUWZ256rri */
  },
  { /* 6584 */
    0,
    /*  */
  },
  { /* 6585 */
    926,
    /* VPCMPUWZ256rrik */
  },
  { /* 6586 */
    0,
    /*  */
  },
  { /* 6587 */
    927,
    /* VPCMPUWZrmi */
  },
  { /* 6588 */
    0,
    /*  */
  },
  { /* 6589 */
    928,
    /* VPCMPUWZrmik */
  },
  { /* 6590 */
    0,
    /*  */
  },
  { /* 6591 */
    929,
    /* VPCMPUWZrri */
  },
  { /* 6592 */
    0,
    /*  */
  },
  { /* 6593 */
    930,
    /* VPCMPUWZrrik */
  },
  { /* 6594 */
    0,
    /*  */
  },
  { /* 6595 */
    919,
    /* VPCMPWZ128rmi */
  },
  { /* 6596 */
    0,
    /*  */
  },
  { /* 6597 */
    920,
    /* VPCMPWZ128rmik */
  },
  { /* 6598 */
    0,
    /*  */
  },
  { /* 6599 */
    921,
    /* VPCMPWZ128rri */
  },
  { /* 6600 */
    0,
    /*  */
  },
  { /* 6601 */
    922,
    /* VPCMPWZ128rrik */
  },
  { /* 6602 */
    0,
    /*  */
  },
  { /* 6603 */
    923,
    /* VPCMPWZ256rmi */
  },
  { /* 6604 */
    0,
    /*  */
  },
  { /* 6605 */
    924,
    /* VPCMPWZ256rmik */
  },
  { /* 6606 */
    0,
    /*  */
  },
  { /* 6607 */
    925,
    /* VPCMPWZ256rri */
  },
  { /* 6608 */
    0,
    /*  */
  },
  { /* 6609 */
    926,
    /* VPCMPWZ256rrik */
  },
  { /* 6610 */
    0,
    /*  */
  },
  { /* 6611 */
    927,
    /* VPCMPWZrmi */
  },
  { /* 6612 */
    0,
    /*  */
  },
  { /* 6613 */
    928,
    /* VPCMPWZrmik */
  },
  { /* 6614 */
    0,
    /*  */
  },
  { /* 6615 */
    929,
    /* VPCMPWZrri */
  },
  { /* 6616 */
    0,
    /*  */
  },
  { /* 6617 */
    930,
    /* VPCMPWZrrik */
  },
  { /* 6618 */
    0,
    /*  */
  },
  { /* 6619 */
    931,
    /* VPCOMBmi */
  },
  { /* 6620 */
    0,
    /*  */
  },
  { /* 6621 */
    932,
    /* VPCOMBri */
  },
  { /* 6622 */
    0,
    /*  */
  },
  { /* 6623 */
    931,
    /* VPCOMDmi */
  },
  { /* 6624 */
    0,
    /*  */
  },
  { /* 6625 */
    932,
    /* VPCOMDri */
  },
  { /* 6626 */
    0,
    /*  */
  },
  { /* 6627 */
    465,
    /* VPCOMPRESSDZ128mrk */
  },
  { /* 6628 */
    466,
    /* VPCOMPRESSDZ128rrk */
  },
  { /* 6629 */
    467,
    /* VPCOMPRESSDZ128rrkz */
  },
  { /* 6630 */
    468,
    /* VPCOMPRESSDZ256mrk */
  },
  { /* 6631 */
    469,
    /* VPCOMPRESSDZ256rrk */
  },
  { /* 6632 */
    470,
    /* VPCOMPRESSDZ256rrkz */
  },
  { /* 6633 */
    471,
    /* VPCOMPRESSDZmrk */
  },
  { /* 6634 */
    472,
    /* VPCOMPRESSDZrrk */
  },
  { /* 6635 */
    473,
    /* VPCOMPRESSDZrrkz */
  },
  { /* 6636 */
    456,
    /* VPCOMPRESSQZ128mrk */
  },
  { /* 6637 */
    457,
    /* VPCOMPRESSQZ128rrk */
  },
  { /* 6638 */
    458,
    /* VPCOMPRESSQZ128rrkz */
  },
  { /* 6639 */
    459,
    /* VPCOMPRESSQZ256mrk */
  },
  { /* 6640 */
    460,
    /* VPCOMPRESSQZ256rrk */
  },
  { /* 6641 */
    461,
    /* VPCOMPRESSQZ256rrkz */
  },
  { /* 6642 */
    462,
    /* VPCOMPRESSQZmrk */
  },
  { /* 6643 */
    463,
    /* VPCOMPRESSQZrrk */
  },
  { /* 6644 */
    464,
    /* VPCOMPRESSQZrrkz */
  },
  { /* 6645 */
    931,
    /* VPCOMQmi */
  },
  { /* 6646 */
    0,
    /*  */
  },
  { /* 6647 */
    932,
    /* VPCOMQri */
  },
  { /* 6648 */
    0,
    /*  */
  },
  { /* 6649 */
    931,
    /* VPCOMUBmi */
  },
  { /* 6650 */
    0,
    /*  */
  },
  { /* 6651 */
    932,
    /* VPCOMUBri */
  },
  { /* 6652 */
    0,
    /*  */
  },
  { /* 6653 */
    931,
    /* VPCOMUDmi */
  },
  { /* 6654 */
    0,
    /*  */
  },
  { /* 6655 */
    932,
    /* VPCOMUDri */
  },
  { /* 6656 */
    0,
    /*  */
  },
  { /* 6657 */
    931,
    /* VPCOMUQmi */
  },
  { /* 6658 */
    0,
    /*  */
  },
  { /* 6659 */
    932,
    /* VPCOMUQri */
  },
  { /* 6660 */
    0,
    /*  */
  },
  { /* 6661 */
    931,
    /* VPCOMUWmi */
  },
  { /* 6662 */
    0,
    /*  */
  },
  { /* 6663 */
    932,
    /* VPCOMUWri */
  },
  { /* 6664 */
    0,
    /*  */
  },
  { /* 6665 */
    931,
    /* VPCOMWmi */
  },
  { /* 6666 */
    0,
    /*  */
  },
  { /* 6667 */
    932,
    /* VPCOMWri */
  },
  { /* 6668 */
    0,
    /*  */
  },
  { /* 6669 */
    477,
    /* VPCONFLICTDrm */
  },
  { /* 6670 */
    728,
    /* VPCONFLICTDrmb */
  },
  { /* 6671 */
    933,
    /* VPCONFLICTDrmbk */
  },
  { /* 6672 */
    729,
    /* VPCONFLICTDrmbkz */
  },
  { /* 6673 */
    537,
    /* VPCONFLICTDrmk */
  },
  { /* 6674 */
    538,
    /* VPCONFLICTDrmkz */
  },
  { /* 6675 */
    478,
    /* VPCONFLICTDrr */
  },
  { /* 6676 */
    541,
    /* VPCONFLICTDrrk */
  },
  { /* 6677 */
    542,
    /* VPCONFLICTDrrkz */
  },
  { /* 6678 */
    477,
    /* VPCONFLICTQrm */
  },
  { /* 6679 */
    730,
    /* VPCONFLICTQrmb */
  },
  { /* 6680 */
    934,
    /* VPCONFLICTQrmbk */
  },
  { /* 6681 */
    731,
    /* VPCONFLICTQrmbkz */
  },
  { /* 6682 */
    528,
    /* VPCONFLICTQrmk */
  },
  { /* 6683 */
    529,
    /* VPCONFLICTQrmkz */
  },
  { /* 6684 */
    478,
    /* VPCONFLICTQrr */
  },
  { /* 6685 */
    533,
    /* VPCONFLICTQrrk */
  },
  { /* 6686 */
    534,
    /* VPCONFLICTQrrkz */
  },
  { /* 6687 */
    388,
    /* VPERM2F128rm */
  },
  { /* 6688 */
    389,
    /* VPERM2F128rr */
  },
  { /* 6689 */
    388,
    /* VPERM2I128rm */
  },
  { /* 6690 */
    389,
    /* VPERM2I128rr */
  },
  { /* 6691 */
    302,
    /* VPERMDYrm */
  },
  { /* 6692 */
    303,
    /* VPERMDYrr */
  },
  { /* 6693 */
    325,
    /* VPERMDZrm */
  },
  { /* 6694 */
    331,
    /* VPERMDZrr */
  },
  { /* 6695 */
    574,
    /* VPERMI2Drm */
  },
  { /* 6696 */
    356,
    /* VPERMI2Drmk */
  },
  { /* 6697 */
    356,
    /* VPERMI2Drmkz */
  },
  { /* 6698 */
    588,
    /* VPERMI2Drr */
  },
  { /* 6699 */
    358,
    /* VPERMI2Drrk */
  },
  { /* 6700 */
    358,
    /* VPERMI2Drrkz */
  },
  { /* 6701 */
    574,
    /* VPERMI2PDrm */
  },
  { /* 6702 */
    329,
    /* VPERMI2PDrmk */
  },
  { /* 6703 */
    329,
    /* VPERMI2PDrmkz */
  },
  { /* 6704 */
    588,
    /* VPERMI2PDrr */
  },
  { /* 6705 */
    332,
    /* VPERMI2PDrrk */
  },
  { /* 6706 */
    332,
    /* VPERMI2PDrrkz */
  },
  { /* 6707 */
    574,
    /* VPERMI2PSrm */
  },
  { /* 6708 */
    356,
    /* VPERMI2PSrmk */
  },
  { /* 6709 */
    356,
    /* VPERMI2PSrmkz */
  },
  { /* 6710 */
    588,
    /* VPERMI2PSrr */
  },
  { /* 6711 */
    358,
    /* VPERMI2PSrrk */
  },
  { /* 6712 */
    358,
    /* VPERMI2PSrrkz */
  },
  { /* 6713 */
    574,
    /* VPERMI2Qrm */
  },
  { /* 6714 */
    329,
    /* VPERMI2Qrmk */
  },
  { /* 6715 */
    329,
    /* VPERMI2Qrmkz */
  },
  { /* 6716 */
    588,
    /* VPERMI2Qrr */
  },
  { /* 6717 */
    332,
    /* VPERMI2Qrrk */
  },
  { /* 6718 */
    332,
    /* VPERMI2Qrrkz */
  },
  { /* 6719 */
    935,
    /* VPERMIL2PDmr */
  },
  { /* 6720 */
    936,
    /* VPERMIL2PDmrY */
  },
  { /* 6721 */
    937,
    /* VPERMIL2PDrm */
  },
  { /* 6722 */
    938,
    /* VPERMIL2PDrmY */
  },
  { /* 6723 */
    939,
    /* VPERMIL2PDrr */
  },
  { /* 6724 */
    940,
    /* VPERMIL2PDrrY */
  },
  { /* 6725 */
    935,
    /* VPERMIL2PSmr */
  },
  { /* 6726 */
    936,
    /* VPERMIL2PSmrY */
  },
  { /* 6727 */
    937,
    /* VPERMIL2PSrm */
  },
  { /* 6728 */
    938,
    /* VPERMIL2PSrmY */
  },
  { /* 6729 */
    939,
    /* VPERMIL2PSrr */
  },
  { /* 6730 */
    940,
    /* VPERMIL2PSrrY */
  },
  { /* 6731 */
    941,
    /* VPERMILPDYmi */
  },
  { /* 6732 */
    942,
    /* VPERMILPDYri */
  },
  { /* 6733 */
    302,
    /* VPERMILPDYrm */
  },
  { /* 6734 */
    303,
    /* VPERMILPDYrr */
  },
  { /* 6735 */
    943,
    /* VPERMILPDZmi */
  },
  { /* 6736 */
    944,
    /* VPERMILPDZri */
  },
  { /* 6737 */
    325,
    /* VPERMILPDZrm */
  },
  { /* 6738 */
    331,
    /* VPERMILPDZrr */
  },
  { /* 6739 */
    46,
    /* VPERMILPDmi */
  },
  { /* 6740 */
    47,
    /* VPERMILPDri */
  },
  { /* 6741 */
    334,
    /* VPERMILPDrm */
  },
  { /* 6742 */
    335,
    /* VPERMILPDrr */
  },
  { /* 6743 */
    941,
    /* VPERMILPSYmi */
  },
  { /* 6744 */
    942,
    /* VPERMILPSYri */
  },
  { /* 6745 */
    302,
    /* VPERMILPSYrm */
  },
  { /* 6746 */
    303,
    /* VPERMILPSYrr */
  },
  { /* 6747 */
    943,
    /* VPERMILPSZmi */
  },
  { /* 6748 */
    944,
    /* VPERMILPSZri */
  },
  { /* 6749 */
    325,
    /* VPERMILPSZrm */
  },
  { /* 6750 */
    331,
    /* VPERMILPSZrr */
  },
  { /* 6751 */
    46,
    /* VPERMILPSmi */
  },
  { /* 6752 */
    47,
    /* VPERMILPSri */
  },
  { /* 6753 */
    334,
    /* VPERMILPSrm */
  },
  { /* 6754 */
    335,
    /* VPERMILPSrr */
  },
  { /* 6755 */
    941,
    /* VPERMPDYmi */
  },
  { /* 6756 */
    942,
    /* VPERMPDYri */
  },
  { /* 6757 */
    943,
    /* VPERMPDZmi */
  },
  { /* 6758 */
    944,
    /* VPERMPDZri */
  },
  { /* 6759 */
    325,
    /* VPERMPDZrm */
  },
  { /* 6760 */
    331,
    /* VPERMPDZrr */
  },
  { /* 6761 */
    302,
    /* VPERMPSYrm */
  },
  { /* 6762 */
    303,
    /* VPERMPSYrr */
  },
  { /* 6763 */
    325,
    /* VPERMPSZrm */
  },
  { /* 6764 */
    331,
    /* VPERMPSZrr */
  },
  { /* 6765 */
    941,
    /* VPERMQYmi */
  },
  { /* 6766 */
    942,
    /* VPERMQYri */
  },
  { /* 6767 */
    943,
    /* VPERMQZmi */
  },
  { /* 6768 */
    944,
    /* VPERMQZri */
  },
  { /* 6769 */
    325,
    /* VPERMQZrm */
  },
  { /* 6770 */
    331,
    /* VPERMQZrr */
  },
  { /* 6771 */
    574,
    /* VPERMT2Drm */
  },
  { /* 6772 */
    356,
    /* VPERMT2Drmk */
  },
  { /* 6773 */
    356,
    /* VPERMT2Drmkz */
  },
  { /* 6774 */
    588,
    /* VPERMT2Drr */
  },
  { /* 6775 */
    358,
    /* VPERMT2Drrk */
  },
  { /* 6776 */
    358,
    /* VPERMT2Drrkz */
  },
  { /* 6777 */
    574,
    /* VPERMT2PDrm */
  },
  { /* 6778 */
    329,
    /* VPERMT2PDrmk */
  },
  { /* 6779 */
    329,
    /* VPERMT2PDrmkz */
  },
  { /* 6780 */
    588,
    /* VPERMT2PDrr */
  },
  { /* 6781 */
    332,
    /* VPERMT2PDrrk */
  },
  { /* 6782 */
    332,
    /* VPERMT2PDrrkz */
  },
  { /* 6783 */
    574,
    /* VPERMT2PSrm */
  },
  { /* 6784 */
    356,
    /* VPERMT2PSrmk */
  },
  { /* 6785 */
    356,
    /* VPERMT2PSrmkz */
  },
  { /* 6786 */
    588,
    /* VPERMT2PSrr */
  },
  { /* 6787 */
    358,
    /* VPERMT2PSrrk */
  },
  { /* 6788 */
    358,
    /* VPERMT2PSrrkz */
  },
  { /* 6789 */
    574,
    /* VPERMT2Qrm */
  },
  { /* 6790 */
    329,
    /* VPERMT2Qrmk */
  },
  { /* 6791 */
    329,
    /* VPERMT2Qrmkz */
  },
  { /* 6792 */
    588,
    /* VPERMT2Qrr */
  },
  { /* 6793 */
    332,
    /* VPERMT2Qrrk */
  },
  { /* 6794 */
    332,
    /* VPERMT2Qrrkz */
  },
  { /* 6795 */
    553,
    /* VPEXPANDDZ128rmk */
  },
  { /* 6796 */
    554,
    /* VPEXPANDDZ128rmkz */
  },
  { /* 6797 */
    555,
    /* VPEXPANDDZ128rrk */
  },
  { /* 6798 */
    556,
    /* VPEXPANDDZ128rrkz */
  },
  { /* 6799 */
    557,
    /* VPEXPANDDZ256rmk */
  },
  { /* 6800 */
    558,
    /* VPEXPANDDZ256rmkz */
  },
  { /* 6801 */
    559,
    /* VPEXPANDDZ256rrk */
  },
  { /* 6802 */
    560,
    /* VPEXPANDDZ256rrkz */
  },
  { /* 6803 */
    535,
    /* VPEXPANDDZrmk */
  },
  { /* 6804 */
    536,
    /* VPEXPANDDZrmkz */
  },
  { /* 6805 */
    541,
    /* VPEXPANDDZrrk */
  },
  { /* 6806 */
    542,
    /* VPEXPANDDZrrkz */
  },
  { /* 6807 */
    543,
    /* VPEXPANDQZ128rmk */
  },
  { /* 6808 */
    544,
    /* VPEXPANDQZ128rmkz */
  },
  { /* 6809 */
    545,
    /* VPEXPANDQZ128rrk */
  },
  { /* 6810 */
    546,
    /* VPEXPANDQZ128rrkz */
  },
  { /* 6811 */
    547,
    /* VPEXPANDQZ256rmk */
  },
  { /* 6812 */
    548,
    /* VPEXPANDQZ256rmkz */
  },
  { /* 6813 */
    549,
    /* VPEXPANDQZ256rrk */
  },
  { /* 6814 */
    550,
    /* VPEXPANDQZ256rrkz */
  },
  { /* 6815 */
    551,
    /* VPEXPANDQZrmk */
  },
  { /* 6816 */
    552,
    /* VPEXPANDQZrmkz */
  },
  { /* 6817 */
    533,
    /* VPEXPANDQZrrk */
  },
  { /* 6818 */
    534,
    /* VPEXPANDQZrrkz */
  },
  { /* 6819 */
    270,
    /* VPEXTRBmr */
  },
  { /* 6820 */
    133,
    /* VPEXTRBrr */
  },
  { /* 6821 */
    271,
    /* VPEXTRDmr */
  },
  { /* 6822 */
    133,
    /* VPEXTRDrr */
  },
  { /* 6823 */
    271,
    /* VPEXTRQmr */
  },
  { /* 6824 */
    272,
    /* VPEXTRQrr */
  },
  { /* 6825 */
    271,
    /* VPEXTRWmr */
  },
  { /* 6826 */
    273,
    /* VPEXTRWri */
  },
  { /* 6827 */
    133,
    /* VPEXTRWrr_REV */
  },
  { /* 6828 */
    614,
    /* VPGATHERDDYrm */
  },
  { /* 6829 */
    615,
    /* VPGATHERDDZrm */
  },
  { /* 6830 */
    616,
    /* VPGATHERDDrm */
  },
  { /* 6831 */
    611,
    /* VPGATHERDQYrm */
  },
  { /* 6832 */
    612,
    /* VPGATHERDQZrm */
  },
  { /* 6833 */
    613,
    /* VPGATHERDQrm */
  },
  { /* 6834 */
    616,
    /* VPGATHERQDYrm */
  },
  { /* 6835 */
    620,
    /* VPGATHERQDZrm */
  },
  { /* 6836 */
    616,
    /* VPGATHERQDrm */
  },
  { /* 6837 */
    611,
    /* VPGATHERQQYrm */
  },
  { /* 6838 */
    612,
    /* VPGATHERQQZrm */
  },
  { /* 6839 */
    613,
    /* VPGATHERQQrm */
  },
  { /* 6840 */
    44,
    /* VPHADDBDrm */
  },
  { /* 6841 */
    45,
    /* VPHADDBDrr */
  },
  { /* 6842 */
    44,
    /* VPHADDBQrm */
  },
  { /* 6843 */
    45,
    /* VPHADDBQrr */
  },
  { /* 6844 */
    44,
    /* VPHADDBWrm */
  },
  { /* 6845 */
    45,
    /* VPHADDBWrr */
  },
  { /* 6846 */
    44,
    /* VPHADDDQrm */
  },
  { /* 6847 */
    45,
    /* VPHADDDQrr */
  },
  { /* 6848 */
    302,
    /* VPHADDDYrm */
  },
  { /* 6849 */
    303,
    /* VPHADDDYrr */
  },
  { /* 6850 */
    334,
    /* VPHADDDrm */
  },
  { /* 6851 */
    335,
    /* VPHADDDrr */
  },
  { /* 6852 */
    334,
    /* VPHADDSWrm128 */
  },
  { /* 6853 */
    302,
    /* VPHADDSWrm256 */
  },
  { /* 6854 */
    335,
    /* VPHADDSWrr128 */
  },
  { /* 6855 */
    303,
    /* VPHADDSWrr256 */
  },
  { /* 6856 */
    44,
    /* VPHADDUBDrm */
  },
  { /* 6857 */
    45,
    /* VPHADDUBDrr */
  },
  { /* 6858 */
    44,
    /* VPHADDUBQrm */
  },
  { /* 6859 */
    45,
    /* VPHADDUBQrr */
  },
  { /* 6860 */
    44,
    /* VPHADDUBWrm */
  },
  { /* 6861 */
    45,
    /* VPHADDUBWrr */
  },
  { /* 6862 */
    44,
    /* VPHADDUDQrm */
  },
  { /* 6863 */
    45,
    /* VPHADDUDQrr */
  },
  { /* 6864 */
    44,
    /* VPHADDUWDrm */
  },
  { /* 6865 */
    45,
    /* VPHADDUWDrr */
  },
  { /* 6866 */
    44,
    /* VPHADDUWQrm */
  },
  { /* 6867 */
    45,
    /* VPHADDUWQrr */
  },
  { /* 6868 */
    44,
    /* VPHADDWDrm */
  },
  { /* 6869 */
    45,
    /* VPHADDWDrr */
  },
  { /* 6870 */
    44,
    /* VPHADDWQrm */
  },
  { /* 6871 */
    45,
    /* VPHADDWQrr */
  },
  { /* 6872 */
    302,
    /* VPHADDWYrm */
  },
  { /* 6873 */
    303,
    /* VPHADDWYrr */
  },
  { /* 6874 */
    334,
    /* VPHADDWrm */
  },
  { /* 6875 */
    335,
    /* VPHADDWrr */
  },
  { /* 6876 */
    44,
    /* VPHMINPOSUWrm128 */
  },
  { /* 6877 */
    45,
    /* VPHMINPOSUWrr128 */
  },
  { /* 6878 */
    44,
    /* VPHSUBBWrm */
  },
  { /* 6879 */
    45,
    /* VPHSUBBWrr */
  },
  { /* 6880 */
    44,
    /* VPHSUBDQrm */
  },
  { /* 6881 */
    45,
    /* VPHSUBDQrr */
  },
  { /* 6882 */
    302,
    /* VPHSUBDYrm */
  },
  { /* 6883 */
    303,
    /* VPHSUBDYrr */
  },
  { /* 6884 */
    334,
    /* VPHSUBDrm */
  },
  { /* 6885 */
    335,
    /* VPHSUBDrr */
  },
  { /* 6886 */
    334,
    /* VPHSUBSWrm128 */
  },
  { /* 6887 */
    302,
    /* VPHSUBSWrm256 */
  },
  { /* 6888 */
    335,
    /* VPHSUBSWrr128 */
  },
  { /* 6889 */
    303,
    /* VPHSUBSWrr256 */
  },
  { /* 6890 */
    44,
    /* VPHSUBWDrm */
  },
  { /* 6891 */
    45,
    /* VPHSUBWDrr */
  },
  { /* 6892 */
    302,
    /* VPHSUBWYrm */
  },
  { /* 6893 */
    303,
    /* VPHSUBWYrr */
  },
  { /* 6894 */
    334,
    /* VPHSUBWrm */
  },
  { /* 6895 */
    335,
    /* VPHSUBWrr */
  },
  { /* 6896 */
    945,
    /* VPINSRBrm */
  },
  { /* 6897 */
    946,
    /* VPINSRBrr */
  },
  { /* 6898 */
    947,
    /* VPINSRDrm */
  },
  { /* 6899 */
    946,
    /* VPINSRDrr */
  },
  { /* 6900 */
    947,
    /* VPINSRQrm */
  },
  { /* 6901 */
    948,
    /* VPINSRQrr */
  },
  { /* 6902 */
    947,
    /* VPINSRWrmi */
  },
  { /* 6903 */
    946,
    /* VPINSRWrri */
  },
  { /* 6904 */
    477,
    /* VPLZCNTDrm */
  },
  { /* 6905 */
    728,
    /* VPLZCNTDrmb */
  },
  { /* 6906 */
    933,
    /* VPLZCNTDrmbk */
  },
  { /* 6907 */
    729,
    /* VPLZCNTDrmbkz */
  },
  { /* 6908 */
    537,
    /* VPLZCNTDrmk */
  },
  { /* 6909 */
    538,
    /* VPLZCNTDrmkz */
  },
  { /* 6910 */
    478,
    /* VPLZCNTDrr */
  },
  { /* 6911 */
    541,
    /* VPLZCNTDrrk */
  },
  { /* 6912 */
    542,
    /* VPLZCNTDrrkz */
  },
  { /* 6913 */
    477,
    /* VPLZCNTQrm */
  },
  { /* 6914 */
    730,
    /* VPLZCNTQrmb */
  },
  { /* 6915 */
    934,
    /* VPLZCNTQrmbk */
  },
  { /* 6916 */
    731,
    /* VPLZCNTQrmbkz */
  },
  { /* 6917 */
    528,
    /* VPLZCNTQrmk */
  },
  { /* 6918 */
    529,
    /* VPLZCNTQrmkz */
  },
  { /* 6919 */
    478,
    /* VPLZCNTQrr */
  },
  { /* 6920 */
    533,
    /* VPLZCNTQrrk */
  },
  { /* 6921 */
    534,
    /* VPLZCNTQrrkz */
  },
  { /* 6922 */
    394,
    /* VPMACSDDrm */
  },
  { /* 6923 */
    395,
    /* VPMACSDDrr */
  },
  { /* 6924 */
    394,
    /* VPMACSDQHrm */
  },
  { /* 6925 */
    395,
    /* VPMACSDQHrr */
  },
  { /* 6926 */
    394,
    /* VPMACSDQLrm */
  },
  { /* 6927 */
    395,
    /* VPMACSDQLrr */
  },
  { /* 6928 */
    394,
    /* VPMACSSDDrm */
  },
  { /* 6929 */
    395,
    /* VPMACSSDDrr */
  },
  { /* 6930 */
    394,
    /* VPMACSSDQHrm */
  },
  { /* 6931 */
    395,
    /* VPMACSSDQHrr */
  },
  { /* 6932 */
    394,
    /* VPMACSSDQLrm */
  },
  { /* 6933 */
    395,
    /* VPMACSSDQLrr */
  },
  { /* 6934 */
    394,
    /* VPMACSSWDrm */
  },
  { /* 6935 */
    395,
    /* VPMACSSWDrr */
  },
  { /* 6936 */
    394,
    /* VPMACSSWWrm */
  },
  { /* 6937 */
    395,
    /* VPMACSSWWrr */
  },
  { /* 6938 */
    394,
    /* VPMACSWDrm */
  },
  { /* 6939 */
    395,
    /* VPMACSWDrr */
  },
  { /* 6940 */
    394,
    /* VPMACSWWrm */
  },
  { /* 6941 */
    395,
    /* VPMACSWWrr */
  },
  { /* 6942 */
    394,
    /* VPMADCSSWDrm */
  },
  { /* 6943 */
    395,
    /* VPMADCSSWDrr */
  },
  { /* 6944 */
    394,
    /* VPMADCSWDrm */
  },
  { /* 6945 */
    395,
    /* VPMADCSWDrr */
  },
  { /* 6946 */
    334,
    /* VPMADDUBSWrm128 */
  },
  { /* 6947 */
    302,
    /* VPMADDUBSWrm256 */
  },
  { /* 6948 */
    335,
    /* VPMADDUBSWrr128 */
  },
  { /* 6949 */
    303,
    /* VPMADDUBSWrr256 */
  },
  { /* 6950 */
    302,
    /* VPMADDWDYrm */
  },
  { /* 6951 */
    303,
    /* VPMADDWDYrr */
  },
  { /* 6952 */
    334,
    /* VPMADDWDrm */
  },
  { /* 6953 */
    335,
    /* VPMADDWDrr */
  },
  { /* 6954 */
    630,
    /* VPMASKMOVDYmr */
  },
  { /* 6955 */
    302,
    /* VPMASKMOVDYrm */
  },
  { /* 6956 */
    631,
    /* VPMASKMOVDmr */
  },
  { /* 6957 */
    334,
    /* VPMASKMOVDrm */
  },
  { /* 6958 */
    630,
    /* VPMASKMOVQYmr */
  },
  { /* 6959 */
    302,
    /* VPMASKMOVQYrm */
  },
  { /* 6960 */
    631,
    /* VPMASKMOVQmr */
  },
  { /* 6961 */
    334,
    /* VPMASKMOVQrm */
  },
  { /* 6962 */
    302,
    /* VPMAXSBYrm */
  },
  { /* 6963 */
    303,
    /* VPMAXSBYrr */
  },
  { /* 6964 */
    304,
    /* VPMAXSBZ128rm */
  },
  { /* 6965 */
    732,
    /* VPMAXSBZ128rmk */
  },
  { /* 6966 */
    733,
    /* VPMAXSBZ128rmkz */
  },
  { /* 6967 */
    310,
    /* VPMAXSBZ128rr */
  },
  { /* 6968 */
    734,
    /* VPMAXSBZ128rrk */
  },
  { /* 6969 */
    735,
    /* VPMAXSBZ128rrkz */
  },
  { /* 6970 */
    313,
    /* VPMAXSBZ256rm */
  },
  { /* 6971 */
    736,
    /* VPMAXSBZ256rmk */
  },
  { /* 6972 */
    737,
    /* VPMAXSBZ256rmkz */
  },
  { /* 6973 */
    319,
    /* VPMAXSBZ256rr */
  },
  { /* 6974 */
    738,
    /* VPMAXSBZ256rrk */
  },
  { /* 6975 */
    739,
    /* VPMAXSBZ256rrkz */
  },
  { /* 6976 */
    325,
    /* VPMAXSBZrm */
  },
  { /* 6977 */
    740,
    /* VPMAXSBZrmk */
  },
  { /* 6978 */
    741,
    /* VPMAXSBZrmkz */
  },
  { /* 6979 */
    331,
    /* VPMAXSBZrr */
  },
  { /* 6980 */
    742,
    /* VPMAXSBZrrk */
  },
  { /* 6981 */
    743,
    /* VPMAXSBZrrkz */
  },
  { /* 6982 */
    334,
    /* VPMAXSBrm */
  },
  { /* 6983 */
    335,
    /* VPMAXSBrr */
  },
  { /* 6984 */
    302,
    /* VPMAXSDYrm */
  },
  { /* 6985 */
    303,
    /* VPMAXSDYrr */
  },
  { /* 6986 */
    304,
    /* VPMAXSDZ128rm */
  },
  { /* 6987 */
    744,
    /* VPMAXSDZ128rmb */
  },
  { /* 6988 */
    745,
    /* VPMAXSDZ128rmbk */
  },
  { /* 6989 */
    746,
    /* VPMAXSDZ128rmbkz */
  },
  { /* 6990 */
    339,
    /* VPMAXSDZ128rmk */
  },
  { /* 6991 */
    340,
    /* VPMAXSDZ128rmkz */
  },
  { /* 6992 */
    310,
    /* VPMAXSDZ128rr */
  },
  { /* 6993 */
    341,
    /* VPMAXSDZ128rrk */
  },
  { /* 6994 */
    342,
    /* VPMAXSDZ128rrkz */
  },
  { /* 6995 */
    313,
    /* VPMAXSDZ256rm */
  },
  { /* 6996 */
    747,
    /* VPMAXSDZ256rmb */
  },
  { /* 6997 */
    748,
    /* VPMAXSDZ256rmbk */
  },
  { /* 6998 */
    749,
    /* VPMAXSDZ256rmbkz */
  },
  { /* 6999 */
    346,
    /* VPMAXSDZ256rmk */
  },
  { /* 7000 */
    347,
    /* VPMAXSDZ256rmkz */
  },
  { /* 7001 */
    319,
    /* VPMAXSDZ256rr */
  },
  { /* 7002 */
    348,
    /* VPMAXSDZ256rrk */
  },
  { /* 7003 */
    349,
    /* VPMAXSDZ256rrkz */
  },
  { /* 7004 */
    325,
    /* VPMAXSDZrm */
  },
  { /* 7005 */
    750,
    /* VPMAXSDZrmb */
  },
  { /* 7006 */
    751,
    /* VPMAXSDZrmbk */
  },
  { /* 7007 */
    752,
    /* VPMAXSDZrmbkz */
  },
  { /* 7008 */
    356,
    /* VPMAXSDZrmk */
  },
  { /* 7009 */
    357,
    /* VPMAXSDZrmkz */
  },
  { /* 7010 */
    331,
    /* VPMAXSDZrr */
  },
  { /* 7011 */
    358,
    /* VPMAXSDZrrk */
  },
  { /* 7012 */
    359,
    /* VPMAXSDZrrkz */
  },
  { /* 7013 */
    334,
    /* VPMAXSDrm */
  },
  { /* 7014 */
    335,
    /* VPMAXSDrr */
  },
  { /* 7015 */
    304,
    /* VPMAXSQZ128rm */
  },
  { /* 7016 */
    753,
    /* VPMAXSQZ128rmb */
  },
  { /* 7017 */
    754,
    /* VPMAXSQZ128rmbk */
  },
  { /* 7018 */
    755,
    /* VPMAXSQZ128rmbkz */
  },
  { /* 7019 */
    308,
    /* VPMAXSQZ128rmk */
  },
  { /* 7020 */
    309,
    /* VPMAXSQZ128rmkz */
  },
  { /* 7021 */
    310,
    /* VPMAXSQZ128rr */
  },
  { /* 7022 */
    311,
    /* VPMAXSQZ128rrk */
  },
  { /* 7023 */
    312,
    /* VPMAXSQZ128rrkz */
  },
  { /* 7024 */
    313,
    /* VPMAXSQZ256rm */
  },
  { /* 7025 */
    756,
    /* VPMAXSQZ256rmb */
  },
  { /* 7026 */
    757,
    /* VPMAXSQZ256rmbk */
  },
  { /* 7027 */
    758,
    /* VPMAXSQZ256rmbkz */
  },
  { /* 7028 */
    317,
    /* VPMAXSQZ256rmk */
  },
  { /* 7029 */
    318,
    /* VPMAXSQZ256rmkz */
  },
  { /* 7030 */
    319,
    /* VPMAXSQZ256rr */
  },
  { /* 7031 */
    320,
    /* VPMAXSQZ256rrk */
  },
  { /* 7032 */
    321,
    /* VPMAXSQZ256rrkz */
  },
  { /* 7033 */
    325,
    /* VPMAXSQZrm */
  },
  { /* 7034 */
    759,
    /* VPMAXSQZrmb */
  },
  { /* 7035 */
    760,
    /* VPMAXSQZrmbk */
  },
  { /* 7036 */
    761,
    /* VPMAXSQZrmbkz */
  },
  { /* 7037 */
    329,
    /* VPMAXSQZrmk */
  },
  { /* 7038 */
    330,
    /* VPMAXSQZrmkz */
  },
  { /* 7039 */
    331,
    /* VPMAXSQZrr */
  },
  { /* 7040 */
    332,
    /* VPMAXSQZrrk */
  },
  { /* 7041 */
    333,
    /* VPMAXSQZrrkz */
  },
  { /* 7042 */
    302,
    /* VPMAXSWYrm */
  },
  { /* 7043 */
    303,
    /* VPMAXSWYrr */
  },
  { /* 7044 */
    304,
    /* VPMAXSWZ128rm */
  },
  { /* 7045 */
    762,
    /* VPMAXSWZ128rmk */
  },
  { /* 7046 */
    763,
    /* VPMAXSWZ128rmkz */
  },
  { /* 7047 */
    310,
    /* VPMAXSWZ128rr */
  },
  { /* 7048 */
    764,
    /* VPMAXSWZ128rrk */
  },
  { /* 7049 */
    765,
    /* VPMAXSWZ128rrkz */
  },
  { /* 7050 */
    313,
    /* VPMAXSWZ256rm */
  },
  { /* 7051 */
    766,
    /* VPMAXSWZ256rmk */
  },
  { /* 7052 */
    767,
    /* VPMAXSWZ256rmkz */
  },
  { /* 7053 */
    319,
    /* VPMAXSWZ256rr */
  },
  { /* 7054 */
    768,
    /* VPMAXSWZ256rrk */
  },
  { /* 7055 */
    769,
    /* VPMAXSWZ256rrkz */
  },
  { /* 7056 */
    325,
    /* VPMAXSWZrm */
  },
  { /* 7057 */
    770,
    /* VPMAXSWZrmk */
  },
  { /* 7058 */
    771,
    /* VPMAXSWZrmkz */
  },
  { /* 7059 */
    331,
    /* VPMAXSWZrr */
  },
  { /* 7060 */
    772,
    /* VPMAXSWZrrk */
  },
  { /* 7061 */
    773,
    /* VPMAXSWZrrkz */
  },
  { /* 7062 */
    334,
    /* VPMAXSWrm */
  },
  { /* 7063 */
    335,
    /* VPMAXSWrr */
  },
  { /* 7064 */
    302,
    /* VPMAXUBYrm */
  },
  { /* 7065 */
    303,
    /* VPMAXUBYrr */
  },
  { /* 7066 */
    304,
    /* VPMAXUBZ128rm */
  },
  { /* 7067 */
    732,
    /* VPMAXUBZ128rmk */
  },
  { /* 7068 */
    733,
    /* VPMAXUBZ128rmkz */
  },
  { /* 7069 */
    310,
    /* VPMAXUBZ128rr */
  },
  { /* 7070 */
    734,
    /* VPMAXUBZ128rrk */
  },
  { /* 7071 */
    735,
    /* VPMAXUBZ128rrkz */
  },
  { /* 7072 */
    313,
    /* VPMAXUBZ256rm */
  },
  { /* 7073 */
    736,
    /* VPMAXUBZ256rmk */
  },
  { /* 7074 */
    737,
    /* VPMAXUBZ256rmkz */
  },
  { /* 7075 */
    319,
    /* VPMAXUBZ256rr */
  },
  { /* 7076 */
    738,
    /* VPMAXUBZ256rrk */
  },
  { /* 7077 */
    739,
    /* VPMAXUBZ256rrkz */
  },
  { /* 7078 */
    325,
    /* VPMAXUBZrm */
  },
  { /* 7079 */
    740,
    /* VPMAXUBZrmk */
  },
  { /* 7080 */
    741,
    /* VPMAXUBZrmkz */
  },
  { /* 7081 */
    331,
    /* VPMAXUBZrr */
  },
  { /* 7082 */
    742,
    /* VPMAXUBZrrk */
  },
  { /* 7083 */
    743,
    /* VPMAXUBZrrkz */
  },
  { /* 7084 */
    334,
    /* VPMAXUBrm */
  },
  { /* 7085 */
    335,
    /* VPMAXUBrr */
  },
  { /* 7086 */
    302,
    /* VPMAXUDYrm */
  },
  { /* 7087 */
    303,
    /* VPMAXUDYrr */
  },
  { /* 7088 */
    304,
    /* VPMAXUDZ128rm */
  },
  { /* 7089 */
    744,
    /* VPMAXUDZ128rmb */
  },
  { /* 7090 */
    745,
    /* VPMAXUDZ128rmbk */
  },
  { /* 7091 */
    746,
    /* VPMAXUDZ128rmbkz */
  },
  { /* 7092 */
    339,
    /* VPMAXUDZ128rmk */
  },
  { /* 7093 */
    340,
    /* VPMAXUDZ128rmkz */
  },
  { /* 7094 */
    310,
    /* VPMAXUDZ128rr */
  },
  { /* 7095 */
    341,
    /* VPMAXUDZ128rrk */
  },
  { /* 7096 */
    342,
    /* VPMAXUDZ128rrkz */
  },
  { /* 7097 */
    313,
    /* VPMAXUDZ256rm */
  },
  { /* 7098 */
    747,
    /* VPMAXUDZ256rmb */
  },
  { /* 7099 */
    748,
    /* VPMAXUDZ256rmbk */
  },
  { /* 7100 */
    749,
    /* VPMAXUDZ256rmbkz */
  },
  { /* 7101 */
    346,
    /* VPMAXUDZ256rmk */
  },
  { /* 7102 */
    347,
    /* VPMAXUDZ256rmkz */
  },
  { /* 7103 */
    319,
    /* VPMAXUDZ256rr */
  },
  { /* 7104 */
    348,
    /* VPMAXUDZ256rrk */
  },
  { /* 7105 */
    349,
    /* VPMAXUDZ256rrkz */
  },
  { /* 7106 */
    325,
    /* VPMAXUDZrm */
  },
  { /* 7107 */
    750,
    /* VPMAXUDZrmb */
  },
  { /* 7108 */
    751,
    /* VPMAXUDZrmbk */
  },
  { /* 7109 */
    752,
    /* VPMAXUDZrmbkz */
  },
  { /* 7110 */
    356,
    /* VPMAXUDZrmk */
  },
  { /* 7111 */
    357,
    /* VPMAXUDZrmkz */
  },
  { /* 7112 */
    331,
    /* VPMAXUDZrr */
  },
  { /* 7113 */
    358,
    /* VPMAXUDZrrk */
  },
  { /* 7114 */
    359,
    /* VPMAXUDZrrkz */
  },
  { /* 7115 */
    334,
    /* VPMAXUDrm */
  },
  { /* 7116 */
    335,
    /* VPMAXUDrr */
  },
  { /* 7117 */
    304,
    /* VPMAXUQZ128rm */
  },
  { /* 7118 */
    753,
    /* VPMAXUQZ128rmb */
  },
  { /* 7119 */
    754,
    /* VPMAXUQZ128rmbk */
  },
  { /* 7120 */
    755,
    /* VPMAXUQZ128rmbkz */
  },
  { /* 7121 */
    308,
    /* VPMAXUQZ128rmk */
  },
  { /* 7122 */
    309,
    /* VPMAXUQZ128rmkz */
  },
  { /* 7123 */
    310,
    /* VPMAXUQZ128rr */
  },
  { /* 7124 */
    311,
    /* VPMAXUQZ128rrk */
  },
  { /* 7125 */
    312,
    /* VPMAXUQZ128rrkz */
  },
  { /* 7126 */
    313,
    /* VPMAXUQZ256rm */
  },
  { /* 7127 */
    756,
    /* VPMAXUQZ256rmb */
  },
  { /* 7128 */
    757,
    /* VPMAXUQZ256rmbk */
  },
  { /* 7129 */
    758,
    /* VPMAXUQZ256rmbkz */
  },
  { /* 7130 */
    317,
    /* VPMAXUQZ256rmk */
  },
  { /* 7131 */
    318,
    /* VPMAXUQZ256rmkz */
  },
  { /* 7132 */
    319,
    /* VPMAXUQZ256rr */
  },
  { /* 7133 */
    320,
    /* VPMAXUQZ256rrk */
  },
  { /* 7134 */
    321,
    /* VPMAXUQZ256rrkz */
  },
  { /* 7135 */
    325,
    /* VPMAXUQZrm */
  },
  { /* 7136 */
    759,
    /* VPMAXUQZrmb */
  },
  { /* 7137 */
    760,
    /* VPMAXUQZrmbk */
  },
  { /* 7138 */
    761,
    /* VPMAXUQZrmbkz */
  },
  { /* 7139 */
    329,
    /* VPMAXUQZrmk */
  },
  { /* 7140 */
    330,
    /* VPMAXUQZrmkz */
  },
  { /* 7141 */
    331,
    /* VPMAXUQZrr */
  },
  { /* 7142 */
    332,
    /* VPMAXUQZrrk */
  },
  { /* 7143 */
    333,
    /* VPMAXUQZrrkz */
  },
  { /* 7144 */
    302,
    /* VPMAXUWYrm */
  },
  { /* 7145 */
    303,
    /* VPMAXUWYrr */
  },
  { /* 7146 */
    304,
    /* VPMAXUWZ128rm */
  },
  { /* 7147 */
    762,
    /* VPMAXUWZ128rmk */
  },
  { /* 7148 */
    763,
    /* VPMAXUWZ128rmkz */
  },
  { /* 7149 */
    310,
    /* VPMAXUWZ128rr */
  },
  { /* 7150 */
    764,
    /* VPMAXUWZ128rrk */
  },
  { /* 7151 */
    765,
    /* VPMAXUWZ128rrkz */
  },
  { /* 7152 */
    313,
    /* VPMAXUWZ256rm */
  },
  { /* 7153 */
    766,
    /* VPMAXUWZ256rmk */
  },
  { /* 7154 */
    767,
    /* VPMAXUWZ256rmkz */
  },
  { /* 7155 */
    319,
    /* VPMAXUWZ256rr */
  },
  { /* 7156 */
    768,
    /* VPMAXUWZ256rrk */
  },
  { /* 7157 */
    769,
    /* VPMAXUWZ256rrkz */
  },
  { /* 7158 */
    325,
    /* VPMAXUWZrm */
  },
  { /* 7159 */
    770,
    /* VPMAXUWZrmk */
  },
  { /* 7160 */
    771,
    /* VPMAXUWZrmkz */
  },
  { /* 7161 */
    331,
    /* VPMAXUWZrr */
  },
  { /* 7162 */
    772,
    /* VPMAXUWZrrk */
  },
  { /* 7163 */
    773,
    /* VPMAXUWZrrkz */
  },
  { /* 7164 */
    334,
    /* VPMAXUWrm */
  },
  { /* 7165 */
    335,
    /* VPMAXUWrr */
  },
  { /* 7166 */
    302,
    /* VPMINSBYrm */
  },
  { /* 7167 */
    303,
    /* VPMINSBYrr */
  },
  { /* 7168 */
    304,
    /* VPMINSBZ128rm */
  },
  { /* 7169 */
    732,
    /* VPMINSBZ128rmk */
  },
  { /* 7170 */
    733,
    /* VPMINSBZ128rmkz */
  },
  { /* 7171 */
    310,
    /* VPMINSBZ128rr */
  },
  { /* 7172 */
    734,
    /* VPMINSBZ128rrk */
  },
  { /* 7173 */
    735,
    /* VPMINSBZ128rrkz */
  },
  { /* 7174 */
    313,
    /* VPMINSBZ256rm */
  },
  { /* 7175 */
    736,
    /* VPMINSBZ256rmk */
  },
  { /* 7176 */
    737,
    /* VPMINSBZ256rmkz */
  },
  { /* 7177 */
    319,
    /* VPMINSBZ256rr */
  },
  { /* 7178 */
    738,
    /* VPMINSBZ256rrk */
  },
  { /* 7179 */
    739,
    /* VPMINSBZ256rrkz */
  },
  { /* 7180 */
    325,
    /* VPMINSBZrm */
  },
  { /* 7181 */
    740,
    /* VPMINSBZrmk */
  },
  { /* 7182 */
    741,
    /* VPMINSBZrmkz */
  },
  { /* 7183 */
    331,
    /* VPMINSBZrr */
  },
  { /* 7184 */
    742,
    /* VPMINSBZrrk */
  },
  { /* 7185 */
    743,
    /* VPMINSBZrrkz */
  },
  { /* 7186 */
    334,
    /* VPMINSBrm */
  },
  { /* 7187 */
    335,
    /* VPMINSBrr */
  },
  { /* 7188 */
    302,
    /* VPMINSDYrm */
  },
  { /* 7189 */
    303,
    /* VPMINSDYrr */
  },
  { /* 7190 */
    304,
    /* VPMINSDZ128rm */
  },
  { /* 7191 */
    744,
    /* VPMINSDZ128rmb */
  },
  { /* 7192 */
    745,
    /* VPMINSDZ128rmbk */
  },
  { /* 7193 */
    746,
    /* VPMINSDZ128rmbkz */
  },
  { /* 7194 */
    339,
    /* VPMINSDZ128rmk */
  },
  { /* 7195 */
    340,
    /* VPMINSDZ128rmkz */
  },
  { /* 7196 */
    310,
    /* VPMINSDZ128rr */
  },
  { /* 7197 */
    341,
    /* VPMINSDZ128rrk */
  },
  { /* 7198 */
    342,
    /* VPMINSDZ128rrkz */
  },
  { /* 7199 */
    313,
    /* VPMINSDZ256rm */
  },
  { /* 7200 */
    747,
    /* VPMINSDZ256rmb */
  },
  { /* 7201 */
    748,
    /* VPMINSDZ256rmbk */
  },
  { /* 7202 */
    749,
    /* VPMINSDZ256rmbkz */
  },
  { /* 7203 */
    346,
    /* VPMINSDZ256rmk */
  },
  { /* 7204 */
    347,
    /* VPMINSDZ256rmkz */
  },
  { /* 7205 */
    319,
    /* VPMINSDZ256rr */
  },
  { /* 7206 */
    348,
    /* VPMINSDZ256rrk */
  },
  { /* 7207 */
    349,
    /* VPMINSDZ256rrkz */
  },
  { /* 7208 */
    325,
    /* VPMINSDZrm */
  },
  { /* 7209 */
    750,
    /* VPMINSDZrmb */
  },
  { /* 7210 */
    751,
    /* VPMINSDZrmbk */
  },
  { /* 7211 */
    752,
    /* VPMINSDZrmbkz */
  },
  { /* 7212 */
    356,
    /* VPMINSDZrmk */
  },
  { /* 7213 */
    357,
    /* VPMINSDZrmkz */
  },
  { /* 7214 */
    331,
    /* VPMINSDZrr */
  },
  { /* 7215 */
    358,
    /* VPMINSDZrrk */
  },
  { /* 7216 */
    359,
    /* VPMINSDZrrkz */
  },
  { /* 7217 */
    334,
    /* VPMINSDrm */
  },
  { /* 7218 */
    335,
    /* VPMINSDrr */
  },
  { /* 7219 */
    304,
    /* VPMINSQZ128rm */
  },
  { /* 7220 */
    753,
    /* VPMINSQZ128rmb */
  },
  { /* 7221 */
    754,
    /* VPMINSQZ128rmbk */
  },
  { /* 7222 */
    755,
    /* VPMINSQZ128rmbkz */
  },
  { /* 7223 */
    308,
    /* VPMINSQZ128rmk */
  },
  { /* 7224 */
    309,
    /* VPMINSQZ128rmkz */
  },
  { /* 7225 */
    310,
    /* VPMINSQZ128rr */
  },
  { /* 7226 */
    311,
    /* VPMINSQZ128rrk */
  },
  { /* 7227 */
    312,
    /* VPMINSQZ128rrkz */
  },
  { /* 7228 */
    313,
    /* VPMINSQZ256rm */
  },
  { /* 7229 */
    756,
    /* VPMINSQZ256rmb */
  },
  { /* 7230 */
    757,
    /* VPMINSQZ256rmbk */
  },
  { /* 7231 */
    758,
    /* VPMINSQZ256rmbkz */
  },
  { /* 7232 */
    317,
    /* VPMINSQZ256rmk */
  },
  { /* 7233 */
    318,
    /* VPMINSQZ256rmkz */
  },
  { /* 7234 */
    319,
    /* VPMINSQZ256rr */
  },
  { /* 7235 */
    320,
    /* VPMINSQZ256rrk */
  },
  { /* 7236 */
    321,
    /* VPMINSQZ256rrkz */
  },
  { /* 7237 */
    325,
    /* VPMINSQZrm */
  },
  { /* 7238 */
    759,
    /* VPMINSQZrmb */
  },
  { /* 7239 */
    760,
    /* VPMINSQZrmbk */
  },
  { /* 7240 */
    761,
    /* VPMINSQZrmbkz */
  },
  { /* 7241 */
    329,
    /* VPMINSQZrmk */
  },
  { /* 7242 */
    330,
    /* VPMINSQZrmkz */
  },
  { /* 7243 */
    331,
    /* VPMINSQZrr */
  },
  { /* 7244 */
    332,
    /* VPMINSQZrrk */
  },
  { /* 7245 */
    333,
    /* VPMINSQZrrkz */
  },
  { /* 7246 */
    302,
    /* VPMINSWYrm */
  },
  { /* 7247 */
    303,
    /* VPMINSWYrr */
  },
  { /* 7248 */
    304,
    /* VPMINSWZ128rm */
  },
  { /* 7249 */
    762,
    /* VPMINSWZ128rmk */
  },
  { /* 7250 */
    763,
    /* VPMINSWZ128rmkz */
  },
  { /* 7251 */
    310,
    /* VPMINSWZ128rr */
  },
  { /* 7252 */
    764,
    /* VPMINSWZ128rrk */
  },
  { /* 7253 */
    765,
    /* VPMINSWZ128rrkz */
  },
  { /* 7254 */
    313,
    /* VPMINSWZ256rm */
  },
  { /* 7255 */
    766,
    /* VPMINSWZ256rmk */
  },
  { /* 7256 */
    767,
    /* VPMINSWZ256rmkz */
  },
  { /* 7257 */
    319,
    /* VPMINSWZ256rr */
  },
  { /* 7258 */
    768,
    /* VPMINSWZ256rrk */
  },
  { /* 7259 */
    769,
    /* VPMINSWZ256rrkz */
  },
  { /* 7260 */
    325,
    /* VPMINSWZrm */
  },
  { /* 7261 */
    770,
    /* VPMINSWZrmk */
  },
  { /* 7262 */
    771,
    /* VPMINSWZrmkz */
  },
  { /* 7263 */
    331,
    /* VPMINSWZrr */
  },
  { /* 7264 */
    772,
    /* VPMINSWZrrk */
  },
  { /* 7265 */
    773,
    /* VPMINSWZrrkz */
  },
  { /* 7266 */
    334,
    /* VPMINSWrm */
  },
  { /* 7267 */
    335,
    /* VPMINSWrr */
  },
  { /* 7268 */
    302,
    /* VPMINUBYrm */
  },
  { /* 7269 */
    303,
    /* VPMINUBYrr */
  },
  { /* 7270 */
    304,
    /* VPMINUBZ128rm */
  },
  { /* 7271 */
    732,
    /* VPMINUBZ128rmk */
  },
  { /* 7272 */
    733,
    /* VPMINUBZ128rmkz */
  },
  { /* 7273 */
    310,
    /* VPMINUBZ128rr */
  },
  { /* 7274 */
    734,
    /* VPMINUBZ128rrk */
  },
  { /* 7275 */
    735,
    /* VPMINUBZ128rrkz */
  },
  { /* 7276 */
    313,
    /* VPMINUBZ256rm */
  },
  { /* 7277 */
    736,
    /* VPMINUBZ256rmk */
  },
  { /* 7278 */
    737,
    /* VPMINUBZ256rmkz */
  },
  { /* 7279 */
    319,
    /* VPMINUBZ256rr */
  },
  { /* 7280 */
    738,
    /* VPMINUBZ256rrk */
  },
  { /* 7281 */
    739,
    /* VPMINUBZ256rrkz */
  },
  { /* 7282 */
    325,
    /* VPMINUBZrm */
  },
  { /* 7283 */
    740,
    /* VPMINUBZrmk */
  },
  { /* 7284 */
    741,
    /* VPMINUBZrmkz */
  },
  { /* 7285 */
    331,
    /* VPMINUBZrr */
  },
  { /* 7286 */
    742,
    /* VPMINUBZrrk */
  },
  { /* 7287 */
    743,
    /* VPMINUBZrrkz */
  },
  { /* 7288 */
    334,
    /* VPMINUBrm */
  },
  { /* 7289 */
    335,
    /* VPMINUBrr */
  },
  { /* 7290 */
    302,
    /* VPMINUDYrm */
  },
  { /* 7291 */
    303,
    /* VPMINUDYrr */
  },
  { /* 7292 */
    304,
    /* VPMINUDZ128rm */
  },
  { /* 7293 */
    744,
    /* VPMINUDZ128rmb */
  },
  { /* 7294 */
    745,
    /* VPMINUDZ128rmbk */
  },
  { /* 7295 */
    746,
    /* VPMINUDZ128rmbkz */
  },
  { /* 7296 */
    339,
    /* VPMINUDZ128rmk */
  },
  { /* 7297 */
    340,
    /* VPMINUDZ128rmkz */
  },
  { /* 7298 */
    310,
    /* VPMINUDZ128rr */
  },
  { /* 7299 */
    341,
    /* VPMINUDZ128rrk */
  },
  { /* 7300 */
    342,
    /* VPMINUDZ128rrkz */
  },
  { /* 7301 */
    313,
    /* VPMINUDZ256rm */
  },
  { /* 7302 */
    747,
    /* VPMINUDZ256rmb */
  },
  { /* 7303 */
    748,
    /* VPMINUDZ256rmbk */
  },
  { /* 7304 */
    749,
    /* VPMINUDZ256rmbkz */
  },
  { /* 7305 */
    346,
    /* VPMINUDZ256rmk */
  },
  { /* 7306 */
    347,
    /* VPMINUDZ256rmkz */
  },
  { /* 7307 */
    319,
    /* VPMINUDZ256rr */
  },
  { /* 7308 */
    348,
    /* VPMINUDZ256rrk */
  },
  { /* 7309 */
    349,
    /* VPMINUDZ256rrkz */
  },
  { /* 7310 */
    325,
    /* VPMINUDZrm */
  },
  { /* 7311 */
    750,
    /* VPMINUDZrmb */
  },
  { /* 7312 */
    751,
    /* VPMINUDZrmbk */
  },
  { /* 7313 */
    752,
    /* VPMINUDZrmbkz */
  },
  { /* 7314 */
    356,
    /* VPMINUDZrmk */
  },
  { /* 7315 */
    357,
    /* VPMINUDZrmkz */
  },
  { /* 7316 */
    331,
    /* VPMINUDZrr */
  },
  { /* 7317 */
    358,
    /* VPMINUDZrrk */
  },
  { /* 7318 */
    359,
    /* VPMINUDZrrkz */
  },
  { /* 7319 */
    334,
    /* VPMINUDrm */
  },
  { /* 7320 */
    335,
    /* VPMINUDrr */
  },
  { /* 7321 */
    304,
    /* VPMINUQZ128rm */
  },
  { /* 7322 */
    753,
    /* VPMINUQZ128rmb */
  },
  { /* 7323 */
    754,
    /* VPMINUQZ128rmbk */
  },
  { /* 7324 */
    755,
    /* VPMINUQZ128rmbkz */
  },
  { /* 7325 */
    308,
    /* VPMINUQZ128rmk */
  },
  { /* 7326 */
    309,
    /* VPMINUQZ128rmkz */
  },
  { /* 7327 */
    310,
    /* VPMINUQZ128rr */
  },
  { /* 7328 */
    311,
    /* VPMINUQZ128rrk */
  },
  { /* 7329 */
    312,
    /* VPMINUQZ128rrkz */
  },
  { /* 7330 */
    313,
    /* VPMINUQZ256rm */
  },
  { /* 7331 */
    756,
    /* VPMINUQZ256rmb */
  },
  { /* 7332 */
    757,
    /* VPMINUQZ256rmbk */
  },
  { /* 7333 */
    758,
    /* VPMINUQZ256rmbkz */
  },
  { /* 7334 */
    317,
    /* VPMINUQZ256rmk */
  },
  { /* 7335 */
    318,
    /* VPMINUQZ256rmkz */
  },
  { /* 7336 */
    319,
    /* VPMINUQZ256rr */
  },
  { /* 7337 */
    320,
    /* VPMINUQZ256rrk */
  },
  { /* 7338 */
    321,
    /* VPMINUQZ256rrkz */
  },
  { /* 7339 */
    325,
    /* VPMINUQZrm */
  },
  { /* 7340 */
    759,
    /* VPMINUQZrmb */
  },
  { /* 7341 */
    760,
    /* VPMINUQZrmbk */
  },
  { /* 7342 */
    761,
    /* VPMINUQZrmbkz */
  },
  { /* 7343 */
    329,
    /* VPMINUQZrmk */
  },
  { /* 7344 */
    330,
    /* VPMINUQZrmkz */
  },
  { /* 7345 */
    331,
    /* VPMINUQZrr */
  },
  { /* 7346 */
    332,
    /* VPMINUQZrrk */
  },
  { /* 7347 */
    333,
    /* VPMINUQZrrkz */
  },
  { /* 7348 */
    302,
    /* VPMINUWYrm */
  },
  { /* 7349 */
    303,
    /* VPMINUWYrr */
  },
  { /* 7350 */
    304,
    /* VPMINUWZ128rm */
  },
  { /* 7351 */
    762,
    /* VPMINUWZ128rmk */
  },
  { /* 7352 */
    763,
    /* VPMINUWZ128rmkz */
  },
  { /* 7353 */
    310,
    /* VPMINUWZ128rr */
  },
  { /* 7354 */
    764,
    /* VPMINUWZ128rrk */
  },
  { /* 7355 */
    765,
    /* VPMINUWZ128rrkz */
  },
  { /* 7356 */
    313,
    /* VPMINUWZ256rm */
  },
  { /* 7357 */
    766,
    /* VPMINUWZ256rmk */
  },
  { /* 7358 */
    767,
    /* VPMINUWZ256rmkz */
  },
  { /* 7359 */
    319,
    /* VPMINUWZ256rr */
  },
  { /* 7360 */
    768,
    /* VPMINUWZ256rrk */
  },
  { /* 7361 */
    769,
    /* VPMINUWZ256rrkz */
  },
  { /* 7362 */
    325,
    /* VPMINUWZrm */
  },
  { /* 7363 */
    770,
    /* VPMINUWZrmk */
  },
  { /* 7364 */
    771,
    /* VPMINUWZrmkz */
  },
  { /* 7365 */
    331,
    /* VPMINUWZrr */
  },
  { /* 7366 */
    772,
    /* VPMINUWZrrk */
  },
  { /* 7367 */
    773,
    /* VPMINUWZrrkz */
  },
  { /* 7368 */
    334,
    /* VPMINUWrm */
  },
  { /* 7369 */
    335,
    /* VPMINUWrr */
  },
  { /* 7370 */
    949,
    /* VPMOVDBmr */
  },
  { /* 7371 */
    950,
    /* VPMOVDBmrk */
  },
  { /* 7372 */
    951,
    /* VPMOVDBrr */
  },
  { /* 7373 */
    952,
    /* VPMOVDBrrk */
  },
  { /* 7374 */
    952,
    /* VPMOVDBrrkz */
  },
  { /* 7375 */
    953,
    /* VPMOVDWmr */
  },
  { /* 7376 */
    954,
    /* VPMOVDWmrk */
  },
  { /* 7377 */
    955,
    /* VPMOVDWrr */
  },
  { /* 7378 */
    956,
    /* VPMOVDWrrk */
  },
  { /* 7379 */
    956,
    /* VPMOVDWrrkz */
  },
  { /* 7380 */
    957,
    /* VPMOVM2BZ128rr */
  },
  { /* 7381 */
    958,
    /* VPMOVM2BZ256rr */
  },
  { /* 7382 */
    959,
    /* VPMOVM2BZrr */
  },
  { /* 7383 */
    960,
    /* VPMOVM2DZ128rr */
  },
  { /* 7384 */
    961,
    /* VPMOVM2DZ256rr */
  },
  { /* 7385 */
    962,
    /* VPMOVM2DZrr */
  },
  { /* 7386 */
    963,
    /* VPMOVM2QZ128rr */
  },
  { /* 7387 */
    964,
    /* VPMOVM2QZ256rr */
  },
  { /* 7388 */
    965,
    /* VPMOVM2QZrr */
  },
  { /* 7389 */
    966,
    /* VPMOVM2WZ128rr */
  },
  { /* 7390 */
    967,
    /* VPMOVM2WZ256rr */
  },
  { /* 7391 */
    968,
    /* VPMOVM2WZrr */
  },
  { /* 7392 */
    704,
    /* VPMOVMSKBYrr */
  },
  { /* 7393 */
    110,
    /* VPMOVMSKBrr */
  },
  { /* 7394 */
    969,
    /* VPMOVQBmr */
  },
  { /* 7395 */
    970,
    /* VPMOVQBmrk */
  },
  { /* 7396 */
    971,
    /* VPMOVQBrr */
  },
  { /* 7397 */
    972,
    /* VPMOVQBrrk */
  },
  { /* 7398 */
    972,
    /* VPMOVQBrrkz */
  },
  { /* 7399 */
    953,
    /* VPMOVQDmr */
  },
  { /* 7400 */
    973,
    /* VPMOVQDmrk */
  },
  { /* 7401 */
    955,
    /* VPMOVQDrr */
  },
  { /* 7402 */
    974,
    /* VPMOVQDrrk */
  },
  { /* 7403 */
    974,
    /* VPMOVQDrrkz */
  },
  { /* 7404 */
    949,
    /* VPMOVQWmr */
  },
  { /* 7405 */
    975,
    /* VPMOVQWmrk */
  },
  { /* 7406 */
    951,
    /* VPMOVQWrr */
  },
  { /* 7407 */
    976,
    /* VPMOVQWrrk */
  },
  { /* 7408 */
    976,
    /* VPMOVQWrrkz */
  },
  { /* 7409 */
    949,
    /* VPMOVSDBmr */
  },
  { /* 7410 */
    950,
    /* VPMOVSDBmrk */
  },
  { /* 7411 */
    951,
    /* VPMOVSDBrr */
  },
  { /* 7412 */
    952,
    /* VPMOVSDBrrk */
  },
  { /* 7413 */
    952,
    /* VPMOVSDBrrkz */
  },
  { /* 7414 */
    953,
    /* VPMOVSDWmr */
  },
  { /* 7415 */
    954,
    /* VPMOVSDWmrk */
  },
  { /* 7416 */
    955,
    /* VPMOVSDWrr */
  },
  { /* 7417 */
    956,
    /* VPMOVSDWrrk */
  },
  { /* 7418 */
    956,
    /* VPMOVSDWrrkz */
  },
  { /* 7419 */
    969,
    /* VPMOVSQBmr */
  },
  { /* 7420 */
    970,
    /* VPMOVSQBmrk */
  },
  { /* 7421 */
    971,
    /* VPMOVSQBrr */
  },
  { /* 7422 */
    972,
    /* VPMOVSQBrrk */
  },
  { /* 7423 */
    972,
    /* VPMOVSQBrrkz */
  },
  { /* 7424 */
    953,
    /* VPMOVSQDmr */
  },
  { /* 7425 */
    973,
    /* VPMOVSQDmrk */
  },
  { /* 7426 */
    955,
    /* VPMOVSQDrr */
  },
  { /* 7427 */
    974,
    /* VPMOVSQDrrk */
  },
  { /* 7428 */
    974,
    /* VPMOVSQDrrkz */
  },
  { /* 7429 */
    949,
    /* VPMOVSQWmr */
  },
  { /* 7430 */
    975,
    /* VPMOVSQWmrk */
  },
  { /* 7431 */
    951,
    /* VPMOVSQWrr */
  },
  { /* 7432 */
    976,
    /* VPMOVSQWrrk */
  },
  { /* 7433 */
    976,
    /* VPMOVSQWrrkz */
  },
  { /* 7434 */
    784,
    /* VPMOVSXBDYrm */
  },
  { /* 7435 */
    402,
    /* VPMOVSXBDYrr */
  },
  { /* 7436 */
    398,
    /* VPMOVSXBDZrm */
  },
  { /* 7437 */
    397,
    /* VPMOVSXBDZrmk */
  },
  { /* 7438 */
    397,
    /* VPMOVSXBDZrmkz */
  },
  { /* 7439 */
    977,
    /* VPMOVSXBDZrr */
  },
  { /* 7440 */
    978,
    /* VPMOVSXBDZrrk */
  },
  { /* 7441 */
    978,
    /* VPMOVSXBDZrrkz */
  },
  { /* 7442 */
    105,
    /* VPMOVSXBDrm */
  },
  { /* 7443 */
    45,
    /* VPMOVSXBDrr */
  },
  { /* 7444 */
    784,
    /* VPMOVSXBQYrm */
  },
  { /* 7445 */
    402,
    /* VPMOVSXBQYrr */
  },
  { /* 7446 */
    979,
    /* VPMOVSXBQZrm */
  },
  { /* 7447 */
    980,
    /* VPMOVSXBQZrmk */
  },
  { /* 7448 */
    980,
    /* VPMOVSXBQZrmkz */
  },
  { /* 7449 */
    412,
    /* VPMOVSXBQZrr */
  },
  { /* 7450 */
    414,
    /* VPMOVSXBQZrrk */
  },
  { /* 7451 */
    414,
    /* VPMOVSXBQZrrkz */
  },
  { /* 7452 */
    105,
    /* VPMOVSXBQrm */
  },
  { /* 7453 */
    45,
    /* VPMOVSXBQrr */
  },
  { /* 7454 */
    396,
    /* VPMOVSXBWYrm */
  },
  { /* 7455 */
    402,
    /* VPMOVSXBWYrr */
  },
  { /* 7456 */
    105,
    /* VPMOVSXBWrm */
  },
  { /* 7457 */
    45,
    /* VPMOVSXBWrr */
  },
  { /* 7458 */
    396,
    /* VPMOVSXDQYrm */
  },
  { /* 7459 */
    402,
    /* VPMOVSXDQYrr */
  },
  { /* 7460 */
    400,
    /* VPMOVSXDQZrm */
  },
  { /* 7461 */
    981,
    /* VPMOVSXDQZrmk */
  },
  { /* 7462 */
    981,
    /* VPMOVSXDQZrmkz */
  },
  { /* 7463 */
    474,
    /* VPMOVSXDQZrr */
  },
  { /* 7464 */
    982,
    /* VPMOVSXDQZrrk */
  },
  { /* 7465 */
    982,
    /* VPMOVSXDQZrrkz */
  },
  { /* 7466 */
    105,
    /* VPMOVSXDQrm */
  },
  { /* 7467 */
    45,
    /* VPMOVSXDQrr */
  },
  { /* 7468 */
    396,
    /* VPMOVSXWDYrm */
  },
  { /* 7469 */
    402,
    /* VPMOVSXWDYrr */
  },
  { /* 7470 */
    400,
    /* VPMOVSXWDZrm */
  },
  { /* 7471 */
    399,
    /* VPMOVSXWDZrmk */
  },
  { /* 7472 */
    399,
    /* VPMOVSXWDZrmkz */
  },
  { /* 7473 */
    474,
    /* VPMOVSXWDZrr */
  },
  { /* 7474 */
    983,
    /* VPMOVSXWDZrrk */
  },
  { /* 7475 */
    983,
    /* VPMOVSXWDZrrkz */
  },
  { /* 7476 */
    105,
    /* VPMOVSXWDrm */
  },
  { /* 7477 */
    45,
    /* VPMOVSXWDrr */
  },
  { /* 7478 */
    784,
    /* VPMOVSXWQYrm */
  },
  { /* 7479 */
    402,
    /* VPMOVSXWQYrr */
  },
  { /* 7480 */
    398,
    /* VPMOVSXWQZrm */
  },
  { /* 7481 */
    984,
    /* VPMOVSXWQZrmk */
  },
  { /* 7482 */
    984,
    /* VPMOVSXWQZrmkz */
  },
  { /* 7483 */
    977,
    /* VPMOVSXWQZrr */
  },
  { /* 7484 */
    985,
    /* VPMOVSXWQZrrk */
  },
  { /* 7485 */
    985,
    /* VPMOVSXWQZrrkz */
  },
  { /* 7486 */
    105,
    /* VPMOVSXWQrm */
  },
  { /* 7487 */
    45,
    /* VPMOVSXWQrr */
  },
  { /* 7488 */
    949,
    /* VPMOVUSDBmr */
  },
  { /* 7489 */
    950,
    /* VPMOVUSDBmrk */
  },
  { /* 7490 */
    951,
    /* VPMOVUSDBrr */
  },
  { /* 7491 */
    952,
    /* VPMOVUSDBrrk */
  },
  { /* 7492 */
    952,
    /* VPMOVUSDBrrkz */
  },
  { /* 7493 */
    953,
    /* VPMOVUSDWmr */
  },
  { /* 7494 */
    954,
    /* VPMOVUSDWmrk */
  },
  { /* 7495 */
    955,
    /* VPMOVUSDWrr */
  },
  { /* 7496 */
    956,
    /* VPMOVUSDWrrk */
  },
  { /* 7497 */
    956,
    /* VPMOVUSDWrrkz */
  },
  { /* 7498 */
    969,
    /* VPMOVUSQBmr */
  },
  { /* 7499 */
    970,
    /* VPMOVUSQBmrk */
  },
  { /* 7500 */
    971,
    /* VPMOVUSQBrr */
  },
  { /* 7501 */
    972,
    /* VPMOVUSQBrrk */
  },
  { /* 7502 */
    972,
    /* VPMOVUSQBrrkz */
  },
  { /* 7503 */
    953,
    /* VPMOVUSQDmr */
  },
  { /* 7504 */
    973,
    /* VPMOVUSQDmrk */
  },
  { /* 7505 */
    955,
    /* VPMOVUSQDrr */
  },
  { /* 7506 */
    974,
    /* VPMOVUSQDrrk */
  },
  { /* 7507 */
    974,
    /* VPMOVUSQDrrkz */
  },
  { /* 7508 */
    949,
    /* VPMOVUSQWmr */
  },
  { /* 7509 */
    975,
    /* VPMOVUSQWmrk */
  },
  { /* 7510 */
    951,
    /* VPMOVUSQWrr */
  },
  { /* 7511 */
    976,
    /* VPMOVUSQWrrk */
  },
  { /* 7512 */
    976,
    /* VPMOVUSQWrrkz */
  },
  { /* 7513 */
    784,
    /* VPMOVZXBDYrm */
  },
  { /* 7514 */
    402,
    /* VPMOVZXBDYrr */
  },
  { /* 7515 */
    398,
    /* VPMOVZXBDZrm */
  },
  { /* 7516 */
    397,
    /* VPMOVZXBDZrmk */
  },
  { /* 7517 */
    397,
    /* VPMOVZXBDZrmkz */
  },
  { /* 7518 */
    977,
    /* VPMOVZXBDZrr */
  },
  { /* 7519 */
    978,
    /* VPMOVZXBDZrrk */
  },
  { /* 7520 */
    978,
    /* VPMOVZXBDZrrkz */
  },
  { /* 7521 */
    105,
    /* VPMOVZXBDrm */
  },
  { /* 7522 */
    45,
    /* VPMOVZXBDrr */
  },
  { /* 7523 */
    784,
    /* VPMOVZXBQYrm */
  },
  { /* 7524 */
    402,
    /* VPMOVZXBQYrr */
  },
  { /* 7525 */
    979,
    /* VPMOVZXBQZrm */
  },
  { /* 7526 */
    980,
    /* VPMOVZXBQZrmk */
  },
  { /* 7527 */
    980,
    /* VPMOVZXBQZrmkz */
  },
  { /* 7528 */
    412,
    /* VPMOVZXBQZrr */
  },
  { /* 7529 */
    414,
    /* VPMOVZXBQZrrk */
  },
  { /* 7530 */
    414,
    /* VPMOVZXBQZrrkz */
  },
  { /* 7531 */
    105,
    /* VPMOVZXBQrm */
  },
  { /* 7532 */
    45,
    /* VPMOVZXBQrr */
  },
  { /* 7533 */
    396,
    /* VPMOVZXBWYrm */
  },
  { /* 7534 */
    402,
    /* VPMOVZXBWYrr */
  },
  { /* 7535 */
    105,
    /* VPMOVZXBWrm */
  },
  { /* 7536 */
    45,
    /* VPMOVZXBWrr */
  },
  { /* 7537 */
    396,
    /* VPMOVZXDQYrm */
  },
  { /* 7538 */
    402,
    /* VPMOVZXDQYrr */
  },
  { /* 7539 */
    400,
    /* VPMOVZXDQZrm */
  },
  { /* 7540 */
    981,
    /* VPMOVZXDQZrmk */
  },
  { /* 7541 */
    981,
    /* VPMOVZXDQZrmkz */
  },
  { /* 7542 */
    474,
    /* VPMOVZXDQZrr */
  },
  { /* 7543 */
    982,
    /* VPMOVZXDQZrrk */
  },
  { /* 7544 */
    982,
    /* VPMOVZXDQZrrkz */
  },
  { /* 7545 */
    105,
    /* VPMOVZXDQrm */
  },
  { /* 7546 */
    45,
    /* VPMOVZXDQrr */
  },
  { /* 7547 */
    396,
    /* VPMOVZXWDYrm */
  },
  { /* 7548 */
    402,
    /* VPMOVZXWDYrr */
  },
  { /* 7549 */
    400,
    /* VPMOVZXWDZrm */
  },
  { /* 7550 */
    399,
    /* VPMOVZXWDZrmk */
  },
  { /* 7551 */
    399,
    /* VPMOVZXWDZrmkz */
  },
  { /* 7552 */
    474,
    /* VPMOVZXWDZrr */
  },
  { /* 7553 */
    983,
    /* VPMOVZXWDZrrk */
  },
  { /* 7554 */
    983,
    /* VPMOVZXWDZrrkz */
  },
  { /* 7555 */
    105,
    /* VPMOVZXWDrm */
  },
  { /* 7556 */
    45,
    /* VPMOVZXWDrr */
  },
  { /* 7557 */
    784,
    /* VPMOVZXWQYrm */
  },
  { /* 7558 */
    402,
    /* VPMOVZXWQYrr */
  },
  { /* 7559 */
    398,
    /* VPMOVZXWQZrm */
  },
  { /* 7560 */
    984,
    /* VPMOVZXWQZrmk */
  },
  { /* 7561 */
    984,
    /* VPMOVZXWQZrmkz */
  },
  { /* 7562 */
    977,
    /* VPMOVZXWQZrr */
  },
  { /* 7563 */
    985,
    /* VPMOVZXWQZrrk */
  },
  { /* 7564 */
    985,
    /* VPMOVZXWQZrrkz */
  },
  { /* 7565 */
    105,
    /* VPMOVZXWQrm */
  },
  { /* 7566 */
    45,
    /* VPMOVZXWQrr */
  },
  { /* 7567 */
    302,
    /* VPMULDQYrm */
  },
  { /* 7568 */
    303,
    /* VPMULDQYrr */
  },
  { /* 7569 */
    325,
    /* VPMULDQZrm */
  },
  { /* 7570 */
    759,
    /* VPMULDQZrmb */
  },
  { /* 7571 */
    761,
    /* VPMULDQZrmbk */
  },
  { /* 7572 */
    761,
    /* VPMULDQZrmbkz */
  },
  { /* 7573 */
    330,
    /* VPMULDQZrmk */
  },
  { /* 7574 */
    330,
    /* VPMULDQZrmkz */
  },
  { /* 7575 */
    331,
    /* VPMULDQZrr */
  },
  { /* 7576 */
    333,
    /* VPMULDQZrrk */
  },
  { /* 7577 */
    333,
    /* VPMULDQZrrkz */
  },
  { /* 7578 */
    334,
    /* VPMULDQrm */
  },
  { /* 7579 */
    335,
    /* VPMULDQrr */
  },
  { /* 7580 */
    334,
    /* VPMULHRSWrm128 */
  },
  { /* 7581 */
    302,
    /* VPMULHRSWrm256 */
  },
  { /* 7582 */
    335,
    /* VPMULHRSWrr128 */
  },
  { /* 7583 */
    303,
    /* VPMULHRSWrr256 */
  },
  { /* 7584 */
    302,
    /* VPMULHUWYrm */
  },
  { /* 7585 */
    303,
    /* VPMULHUWYrr */
  },
  { /* 7586 */
    334,
    /* VPMULHUWrm */
  },
  { /* 7587 */
    335,
    /* VPMULHUWrr */
  },
  { /* 7588 */
    302,
    /* VPMULHWYrm */
  },
  { /* 7589 */
    303,
    /* VPMULHWYrr */
  },
  { /* 7590 */
    334,
    /* VPMULHWrm */
  },
  { /* 7591 */
    335,
    /* VPMULHWrr */
  },
  { /* 7592 */
    302,
    /* VPMULLDYrm */
  },
  { /* 7593 */
    303,
    /* VPMULLDYrr */
  },
  { /* 7594 */
    304,
    /* VPMULLDZ128rm */
  },
  { /* 7595 */
    744,
    /* VPMULLDZ128rmb */
  },
  { /* 7596 */
    745,
    /* VPMULLDZ128rmbk */
  },
  { /* 7597 */
    746,
    /* VPMULLDZ128rmbkz */
  },
  { /* 7598 */
    339,
    /* VPMULLDZ128rmk */
  },
  { /* 7599 */
    340,
    /* VPMULLDZ128rmkz */
  },
  { /* 7600 */
    310,
    /* VPMULLDZ128rr */
  },
  { /* 7601 */
    341,
    /* VPMULLDZ128rrk */
  },
  { /* 7602 */
    342,
    /* VPMULLDZ128rrkz */
  },
  { /* 7603 */
    313,
    /* VPMULLDZ256rm */
  },
  { /* 7604 */
    747,
    /* VPMULLDZ256rmb */
  },
  { /* 7605 */
    748,
    /* VPMULLDZ256rmbk */
  },
  { /* 7606 */
    749,
    /* VPMULLDZ256rmbkz */
  },
  { /* 7607 */
    346,
    /* VPMULLDZ256rmk */
  },
  { /* 7608 */
    347,
    /* VPMULLDZ256rmkz */
  },
  { /* 7609 */
    319,
    /* VPMULLDZ256rr */
  },
  { /* 7610 */
    348,
    /* VPMULLDZ256rrk */
  },
  { /* 7611 */
    349,
    /* VPMULLDZ256rrkz */
  },
  { /* 7612 */
    325,
    /* VPMULLDZrm */
  },
  { /* 7613 */
    750,
    /* VPMULLDZrmb */
  },
  { /* 7614 */
    751,
    /* VPMULLDZrmbk */
  },
  { /* 7615 */
    752,
    /* VPMULLDZrmbkz */
  },
  { /* 7616 */
    356,
    /* VPMULLDZrmk */
  },
  { /* 7617 */
    357,
    /* VPMULLDZrmkz */
  },
  { /* 7618 */
    331,
    /* VPMULLDZrr */
  },
  { /* 7619 */
    358,
    /* VPMULLDZrrk */
  },
  { /* 7620 */
    359,
    /* VPMULLDZrrkz */
  },
  { /* 7621 */
    334,
    /* VPMULLDrm */
  },
  { /* 7622 */
    335,
    /* VPMULLDrr */
  },
  { /* 7623 */
    304,
    /* VPMULLQZ128rm */
  },
  { /* 7624 */
    753,
    /* VPMULLQZ128rmb */
  },
  { /* 7625 */
    754,
    /* VPMULLQZ128rmbk */
  },
  { /* 7626 */
    755,
    /* VPMULLQZ128rmbkz */
  },
  { /* 7627 */
    308,
    /* VPMULLQZ128rmk */
  },
  { /* 7628 */
    309,
    /* VPMULLQZ128rmkz */
  },
  { /* 7629 */
    310,
    /* VPMULLQZ128rr */
  },
  { /* 7630 */
    311,
    /* VPMULLQZ128rrk */
  },
  { /* 7631 */
    312,
    /* VPMULLQZ128rrkz */
  },
  { /* 7632 */
    313,
    /* VPMULLQZ256rm */
  },
  { /* 7633 */
    756,
    /* VPMULLQZ256rmb */
  },
  { /* 7634 */
    757,
    /* VPMULLQZ256rmbk */
  },
  { /* 7635 */
    758,
    /* VPMULLQZ256rmbkz */
  },
  { /* 7636 */
    317,
    /* VPMULLQZ256rmk */
  },
  { /* 7637 */
    318,
    /* VPMULLQZ256rmkz */
  },
  { /* 7638 */
    319,
    /* VPMULLQZ256rr */
  },
  { /* 7639 */
    320,
    /* VPMULLQZ256rrk */
  },
  { /* 7640 */
    321,
    /* VPMULLQZ256rrkz */
  },
  { /* 7641 */
    325,
    /* VPMULLQZrm */
  },
  { /* 7642 */
    759,
    /* VPMULLQZrmb */
  },
  { /* 7643 */
    760,
    /* VPMULLQZrmbk */
  },
  { /* 7644 */
    761,
    /* VPMULLQZrmbkz */
  },
  { /* 7645 */
    329,
    /* VPMULLQZrmk */
  },
  { /* 7646 */
    330,
    /* VPMULLQZrmkz */
  },
  { /* 7647 */
    331,
    /* VPMULLQZrr */
  },
  { /* 7648 */
    332,
    /* VPMULLQZrrk */
  },
  { /* 7649 */
    333,
    /* VPMULLQZrrkz */
  },
  { /* 7650 */
    302,
    /* VPMULLWYrm */
  },
  { /* 7651 */
    303,
    /* VPMULLWYrr */
  },
  { /* 7652 */
    304,
    /* VPMULLWZ128rm */
  },
  { /* 7653 */
    762,
    /* VPMULLWZ128rmk */
  },
  { /* 7654 */
    763,
    /* VPMULLWZ128rmkz */
  },
  { /* 7655 */
    310,
    /* VPMULLWZ128rr */
  },
  { /* 7656 */
    764,
    /* VPMULLWZ128rrk */
  },
  { /* 7657 */
    765,
    /* VPMULLWZ128rrkz */
  },
  { /* 7658 */
    313,
    /* VPMULLWZ256rm */
  },
  { /* 7659 */
    766,
    /* VPMULLWZ256rmk */
  },
  { /* 7660 */
    767,
    /* VPMULLWZ256rmkz */
  },
  { /* 7661 */
    319,
    /* VPMULLWZ256rr */
  },
  { /* 7662 */
    768,
    /* VPMULLWZ256rrk */
  },
  { /* 7663 */
    769,
    /* VPMULLWZ256rrkz */
  },
  { /* 7664 */
    325,
    /* VPMULLWZrm */
  },
  { /* 7665 */
    770,
    /* VPMULLWZrmk */
  },
  { /* 7666 */
    771,
    /* VPMULLWZrmkz */
  },
  { /* 7667 */
    331,
    /* VPMULLWZrr */
  },
  { /* 7668 */
    772,
    /* VPMULLWZrrk */
  },
  { /* 7669 */
    773,
    /* VPMULLWZrrkz */
  },
  { /* 7670 */
    334,
    /* VPMULLWrm */
  },
  { /* 7671 */
    335,
    /* VPMULLWrr */
  },
  { /* 7672 */
    302,
    /* VPMULUDQYrm */
  },
  { /* 7673 */
    303,
    /* VPMULUDQYrr */
  },
  { /* 7674 */
    325,
    /* VPMULUDQZrm */
  },
  { /* 7675 */
    759,
    /* VPMULUDQZrmb */
  },
  { /* 7676 */
    761,
    /* VPMULUDQZrmbk */
  },
  { /* 7677 */
    761,
    /* VPMULUDQZrmbkz */
  },
  { /* 7678 */
    330,
    /* VPMULUDQZrmk */
  },
  { /* 7679 */
    330,
    /* VPMULUDQZrmkz */
  },
  { /* 7680 */
    331,
    /* VPMULUDQZrr */
  },
  { /* 7681 */
    333,
    /* VPMULUDQZrrk */
  },
  { /* 7682 */
    333,
    /* VPMULUDQZrrkz */
  },
  { /* 7683 */
    334,
    /* VPMULUDQrm */
  },
  { /* 7684 */
    335,
    /* VPMULUDQrr */
  },
  { /* 7685 */
    304,
    /* VPORDZ128rm */
  },
  { /* 7686 */
    744,
    /* VPORDZ128rmb */
  },
  { /* 7687 */
    745,
    /* VPORDZ128rmbk */
  },
  { /* 7688 */
    746,
    /* VPORDZ128rmbkz */
  },
  { /* 7689 */
    339,
    /* VPORDZ128rmk */
  },
  { /* 7690 */
    340,
    /* VPORDZ128rmkz */
  },
  { /* 7691 */
    310,
    /* VPORDZ128rr */
  },
  { /* 7692 */
    341,
    /* VPORDZ128rrk */
  },
  { /* 7693 */
    342,
    /* VPORDZ128rrkz */
  },
  { /* 7694 */
    313,
    /* VPORDZ256rm */
  },
  { /* 7695 */
    747,
    /* VPORDZ256rmb */
  },
  { /* 7696 */
    748,
    /* VPORDZ256rmbk */
  },
  { /* 7697 */
    749,
    /* VPORDZ256rmbkz */
  },
  { /* 7698 */
    346,
    /* VPORDZ256rmk */
  },
  { /* 7699 */
    347,
    /* VPORDZ256rmkz */
  },
  { /* 7700 */
    319,
    /* VPORDZ256rr */
  },
  { /* 7701 */
    348,
    /* VPORDZ256rrk */
  },
  { /* 7702 */
    349,
    /* VPORDZ256rrkz */
  },
  { /* 7703 */
    325,
    /* VPORDZrm */
  },
  { /* 7704 */
    750,
    /* VPORDZrmb */
  },
  { /* 7705 */
    751,
    /* VPORDZrmbk */
  },
  { /* 7706 */
    752,
    /* VPORDZrmbkz */
  },
  { /* 7707 */
    356,
    /* VPORDZrmk */
  },
  { /* 7708 */
    357,
    /* VPORDZrmkz */
  },
  { /* 7709 */
    331,
    /* VPORDZrr */
  },
  { /* 7710 */
    358,
    /* VPORDZrrk */
  },
  { /* 7711 */
    359,
    /* VPORDZrrkz */
  },
  { /* 7712 */
    304,
    /* VPORQZ128rm */
  },
  { /* 7713 */
    753,
    /* VPORQZ128rmb */
  },
  { /* 7714 */
    754,
    /* VPORQZ128rmbk */
  },
  { /* 7715 */
    755,
    /* VPORQZ128rmbkz */
  },
  { /* 7716 */
    308,
    /* VPORQZ128rmk */
  },
  { /* 7717 */
    309,
    /* VPORQZ128rmkz */
  },
  { /* 7718 */
    310,
    /* VPORQZ128rr */
  },
  { /* 7719 */
    311,
    /* VPORQZ128rrk */
  },
  { /* 7720 */
    312,
    /* VPORQZ128rrkz */
  },
  { /* 7721 */
    313,
    /* VPORQZ256rm */
  },
  { /* 7722 */
    756,
    /* VPORQZ256rmb */
  },
  { /* 7723 */
    757,
    /* VPORQZ256rmbk */
  },
  { /* 7724 */
    758,
    /* VPORQZ256rmbkz */
  },
  { /* 7725 */
    317,
    /* VPORQZ256rmk */
  },
  { /* 7726 */
    318,
    /* VPORQZ256rmkz */
  },
  { /* 7727 */
    319,
    /* VPORQZ256rr */
  },
  { /* 7728 */
    320,
    /* VPORQZ256rrk */
  },
  { /* 7729 */
    321,
    /* VPORQZ256rrkz */
  },
  { /* 7730 */
    325,
    /* VPORQZrm */
  },
  { /* 7731 */
    759,
    /* VPORQZrmb */
  },
  { /* 7732 */
    760,
    /* VPORQZrmbk */
  },
  { /* 7733 */
    761,
    /* VPORQZrmbkz */
  },
  { /* 7734 */
    329,
    /* VPORQZrmk */
  },
  { /* 7735 */
    330,
    /* VPORQZrmkz */
  },
  { /* 7736 */
    331,
    /* VPORQZrr */
  },
  { /* 7737 */
    332,
    /* VPORQZrrk */
  },
  { /* 7738 */
    333,
    /* VPORQZrrkz */
  },
  { /* 7739 */
    302,
    /* VPORYrm */
  },
  { /* 7740 */
    303,
    /* VPORYrr */
  },
  { /* 7741 */
    334,
    /* VPORrm */
  },
  { /* 7742 */
    335,
    /* VPORrr */
  },
  { /* 7743 */
    394,
    /* VPPERMmr */
  },
  { /* 7744 */
    579,
    /* VPPERMrm */
  },
  { /* 7745 */
    395,
    /* VPPERMrr */
  },
  { /* 7746 */
    986,
    /* VPROTBmi */
  },
  { /* 7747 */
    987,
    /* VPROTBmr */
  },
  { /* 7748 */
    988,
    /* VPROTBri */
  },
  { /* 7749 */
    334,
    /* VPROTBrm */
  },
  { /* 7750 */
    989,
    /* VPROTBrr */
  },
  { /* 7751 */
    986,
    /* VPROTDmi */
  },
  { /* 7752 */
    987,
    /* VPROTDmr */
  },
  { /* 7753 */
    988,
    /* VPROTDri */
  },
  { /* 7754 */
    334,
    /* VPROTDrm */
  },
  { /* 7755 */
    989,
    /* VPROTDrr */
  },
  { /* 7756 */
    986,
    /* VPROTQmi */
  },
  { /* 7757 */
    987,
    /* VPROTQmr */
  },
  { /* 7758 */
    988,
    /* VPROTQri */
  },
  { /* 7759 */
    334,
    /* VPROTQrm */
  },
  { /* 7760 */
    989,
    /* VPROTQrr */
  },
  { /* 7761 */
    986,
    /* VPROTWmi */
  },
  { /* 7762 */
    987,
    /* VPROTWmr */
  },
  { /* 7763 */
    988,
    /* VPROTWri */
  },
  { /* 7764 */
    334,
    /* VPROTWrm */
  },
  { /* 7765 */
    989,
    /* VPROTWrr */
  },
  { /* 7766 */
    302,
    /* VPSADBWYrm */
  },
  { /* 7767 */
    303,
    /* VPSADBWYrr */
  },
  { /* 7768 */
    334,
    /* VPSADBWrm */
  },
  { /* 7769 */
    335,
    /* VPSADBWrr */
  },
  { /* 7770 */
    990,
    /* VPSCATTERDDZmr */
  },
  { /* 7771 */
    991,
    /* VPSCATTERDQZmr */
  },
  { /* 7772 */
    992,
    /* VPSCATTERQDZmr */
  },
  { /* 7773 */
    991,
    /* VPSCATTERQQZmr */
  },
  { /* 7774 */
    987,
    /* VPSHABmr */
  },
  { /* 7775 */
    334,
    /* VPSHABrm */
  },
  { /* 7776 */
    989,
    /* VPSHABrr */
  },
  { /* 7777 */
    987,
    /* VPSHADmr */
  },
  { /* 7778 */
    334,
    /* VPSHADrm */
  },
  { /* 7779 */
    989,
    /* VPSHADrr */
  },
  { /* 7780 */
    987,
    /* VPSHAQmr */
  },
  { /* 7781 */
    334,
    /* VPSHAQrm */
  },
  { /* 7782 */
    989,
    /* VPSHAQrr */
  },
  { /* 7783 */
    987,
    /* VPSHAWmr */
  },
  { /* 7784 */
    334,
    /* VPSHAWrm */
  },
  { /* 7785 */
    989,
    /* VPSHAWrr */
  },
  { /* 7786 */
    987,
    /* VPSHLBmr */
  },
  { /* 7787 */
    334,
    /* VPSHLBrm */
  },
  { /* 7788 */
    989,
    /* VPSHLBrr */
  },
  { /* 7789 */
    987,
    /* VPSHLDmr */
  },
  { /* 7790 */
    334,
    /* VPSHLDrm */
  },
  { /* 7791 */
    989,
    /* VPSHLDrr */
  },
  { /* 7792 */
    987,
    /* VPSHLQmr */
  },
  { /* 7793 */
    334,
    /* VPSHLQrm */
  },
  { /* 7794 */
    989,
    /* VPSHLQrr */
  },
  { /* 7795 */
    987,
    /* VPSHLWmr */
  },
  { /* 7796 */
    334,
    /* VPSHLWrm */
  },
  { /* 7797 */
    989,
    /* VPSHLWrr */
  },
  { /* 7798 */
    302,
    /* VPSHUFBYrm */
  },
  { /* 7799 */
    303,
    /* VPSHUFBYrr */
  },
  { /* 7800 */
    334,
    /* VPSHUFBrm */
  },
  { /* 7801 */
    335,
    /* VPSHUFBrr */
  },
  { /* 7802 */
    941,
    /* VPSHUFDYmi */
  },
  { /* 7803 */
    942,
    /* VPSHUFDYri */
  },
  { /* 7804 */
    943,
    /* VPSHUFDZmi */
  },
  { /* 7805 */
    944,
    /* VPSHUFDZri */
  },
  { /* 7806 */
    46,
    /* VPSHUFDmi */
  },
  { /* 7807 */
    47,
    /* VPSHUFDri */
  },
  { /* 7808 */
    941,
    /* VPSHUFHWYmi */
  },
  { /* 7809 */
    942,
    /* VPSHUFHWYri */
  },
  { /* 7810 */
    46,
    /* VPSHUFHWmi */
  },
  { /* 7811 */
    47,
    /* VPSHUFHWri */
  },
  { /* 7812 */
    941,
    /* VPSHUFLWYmi */
  },
  { /* 7813 */
    942,
    /* VPSHUFLWYri */
  },
  { /* 7814 */
    46,
    /* VPSHUFLWmi */
  },
  { /* 7815 */
    47,
    /* VPSHUFLWri */
  },
  { /* 7816 */
    302,
    /* VPSIGNBYrm */
  },
  { /* 7817 */
    303,
    /* VPSIGNBYrr */
  },
  { /* 7818 */
    334,
    /* VPSIGNBrm */
  },
  { /* 7819 */
    335,
    /* VPSIGNBrr */
  },
  { /* 7820 */
    302,
    /* VPSIGNDYrm */
  },
  { /* 7821 */
    303,
    /* VPSIGNDYrr */
  },
  { /* 7822 */
    334,
    /* VPSIGNDrm */
  },
  { /* 7823 */
    335,
    /* VPSIGNDrr */
  },
  { /* 7824 */
    302,
    /* VPSIGNWYrm */
  },
  { /* 7825 */
    303,
    /* VPSIGNWYrr */
  },
  { /* 7826 */
    334,
    /* VPSIGNWrm */
  },
  { /* 7827 */
    335,
    /* VPSIGNWrr */
  },
  { /* 7828 */
    993,
    /* VPSLLDQYri */
  },
  { /* 7829 */
    994,
    /* VPSLLDQri */
  },
  { /* 7830 */
    993,
    /* VPSLLDYri */
  },
  { /* 7831 */
    995,
    /* VPSLLDYrm */
  },
  { /* 7832 */
    996,
    /* VPSLLDYrr */
  },
  { /* 7833 */
    997,
    /* VPSLLDZmi */
  },
  { /* 7834 */
    998,
    /* VPSLLDZmik */
  },
  { /* 7835 */
    999,
    /* VPSLLDZmikz */
  },
  { /* 7836 */
    1000,
    /* VPSLLDZri */
  },
  { /* 7837 */
    1001,
    /* VPSLLDZrik */
  },
  { /* 7838 */
    1002,
    /* VPSLLDZrikz */
  },
  { /* 7839 */
    1003,
    /* VPSLLDZrm */
  },
  { /* 7840 */
    1004,
    /* VPSLLDZrmk */
  },
  { /* 7841 */
    1005,
    /* VPSLLDZrmkz */
  },
  { /* 7842 */
    1006,
    /* VPSLLDZrr */
  },
  { /* 7843 */
    1007,
    /* VPSLLDZrrk */
  },
  { /* 7844 */
    1008,
    /* VPSLLDZrrkz */
  },
  { /* 7845 */
    994,
    /* VPSLLDri */
  },
  { /* 7846 */
    334,
    /* VPSLLDrm */
  },
  { /* 7847 */
    335,
    /* VPSLLDrr */
  },
  { /* 7848 */
    993,
    /* VPSLLQYri */
  },
  { /* 7849 */
    995,
    /* VPSLLQYrm */
  },
  { /* 7850 */
    996,
    /* VPSLLQYrr */
  },
  { /* 7851 */
    997,
    /* VPSLLQZmi */
  },
  { /* 7852 */
    1009,
    /* VPSLLQZmik */
  },
  { /* 7853 */
    1010,
    /* VPSLLQZmikz */
  },
  { /* 7854 */
    1000,
    /* VPSLLQZri */
  },
  { /* 7855 */
    1011,
    /* VPSLLQZrik */
  },
  { /* 7856 */
    1012,
    /* VPSLLQZrikz */
  },
  { /* 7857 */
    1003,
    /* VPSLLQZrm */
  },
  { /* 7858 */
    1013,
    /* VPSLLQZrmk */
  },
  { /* 7859 */
    1014,
    /* VPSLLQZrmkz */
  },
  { /* 7860 */
    1006,
    /* VPSLLQZrr */
  },
  { /* 7861 */
    1015,
    /* VPSLLQZrrk */
  },
  { /* 7862 */
    1016,
    /* VPSLLQZrrkz */
  },
  { /* 7863 */
    994,
    /* VPSLLQri */
  },
  { /* 7864 */
    334,
    /* VPSLLQrm */
  },
  { /* 7865 */
    335,
    /* VPSLLQrr */
  },
  { /* 7866 */
    302,
    /* VPSLLVDYrm */
  },
  { /* 7867 */
    303,
    /* VPSLLVDYrr */
  },
  { /* 7868 */
    1017,
    /* VPSLLVDZrm */
  },
  { /* 7869 */
    1018,
    /* VPSLLVDZrmk */
  },
  { /* 7870 */
    1019,
    /* VPSLLVDZrmkz */
  },
  { /* 7871 */
    1020,
    /* VPSLLVDZrr */
  },
  { /* 7872 */
    1021,
    /* VPSLLVDZrrk */
  },
  { /* 7873 */
    1022,
    /* VPSLLVDZrrkz */
  },
  { /* 7874 */
    334,
    /* VPSLLVDrm */
  },
  { /* 7875 */
    335,
    /* VPSLLVDrr */
  },
  { /* 7876 */
    302,
    /* VPSLLVQYrm */
  },
  { /* 7877 */
    303,
    /* VPSLLVQYrr */
  },
  { /* 7878 */
    1017,
    /* VPSLLVQZrm */
  },
  { /* 7879 */
    1023,
    /* VPSLLVQZrmk */
  },
  { /* 7880 */
    1024,
    /* VPSLLVQZrmkz */
  },
  { /* 7881 */
    1020,
    /* VPSLLVQZrr */
  },
  { /* 7882 */
    1025,
    /* VPSLLVQZrrk */
  },
  { /* 7883 */
    1026,
    /* VPSLLVQZrrkz */
  },
  { /* 7884 */
    334,
    /* VPSLLVQrm */
  },
  { /* 7885 */
    335,
    /* VPSLLVQrr */
  },
  { /* 7886 */
    993,
    /* VPSLLWYri */
  },
  { /* 7887 */
    995,
    /* VPSLLWYrm */
  },
  { /* 7888 */
    996,
    /* VPSLLWYrr */
  },
  { /* 7889 */
    994,
    /* VPSLLWri */
  },
  { /* 7890 */
    334,
    /* VPSLLWrm */
  },
  { /* 7891 */
    335,
    /* VPSLLWrr */
  },
  { /* 7892 */
    993,
    /* VPSRADYri */
  },
  { /* 7893 */
    995,
    /* VPSRADYrm */
  },
  { /* 7894 */
    996,
    /* VPSRADYrr */
  },
  { /* 7895 */
    997,
    /* VPSRADZmi */
  },
  { /* 7896 */
    998,
    /* VPSRADZmik */
  },
  { /* 7897 */
    999,
    /* VPSRADZmikz */
  },
  { /* 7898 */
    1000,
    /* VPSRADZri */
  },
  { /* 7899 */
    1001,
    /* VPSRADZrik */
  },
  { /* 7900 */
    1002,
    /* VPSRADZrikz */
  },
  { /* 7901 */
    1003,
    /* VPSRADZrm */
  },
  { /* 7902 */
    1004,
    /* VPSRADZrmk */
  },
  { /* 7903 */
    1005,
    /* VPSRADZrmkz */
  },
  { /* 7904 */
    1006,
    /* VPSRADZrr */
  },
  { /* 7905 */
    1007,
    /* VPSRADZrrk */
  },
  { /* 7906 */
    1008,
    /* VPSRADZrrkz */
  },
  { /* 7907 */
    994,
    /* VPSRADri */
  },
  { /* 7908 */
    334,
    /* VPSRADrm */
  },
  { /* 7909 */
    335,
    /* VPSRADrr */
  },
  { /* 7910 */
    997,
    /* VPSRAQZmi */
  },
  { /* 7911 */
    1009,
    /* VPSRAQZmik */
  },
  { /* 7912 */
    1010,
    /* VPSRAQZmikz */
  },
  { /* 7913 */
    1000,
    /* VPSRAQZri */
  },
  { /* 7914 */
    1011,
    /* VPSRAQZrik */
  },
  { /* 7915 */
    1012,
    /* VPSRAQZrikz */
  },
  { /* 7916 */
    1003,
    /* VPSRAQZrm */
  },
  { /* 7917 */
    1013,
    /* VPSRAQZrmk */
  },
  { /* 7918 */
    1014,
    /* VPSRAQZrmkz */
  },
  { /* 7919 */
    1006,
    /* VPSRAQZrr */
  },
  { /* 7920 */
    1015,
    /* VPSRAQZrrk */
  },
  { /* 7921 */
    1016,
    /* VPSRAQZrrkz */
  },
  { /* 7922 */
    302,
    /* VPSRAVDYrm */
  },
  { /* 7923 */
    303,
    /* VPSRAVDYrr */
  },
  { /* 7924 */
    1017,
    /* VPSRAVDZrm */
  },
  { /* 7925 */
    1018,
    /* VPSRAVDZrmk */
  },
  { /* 7926 */
    1019,
    /* VPSRAVDZrmkz */
  },
  { /* 7927 */
    1020,
    /* VPSRAVDZrr */
  },
  { /* 7928 */
    1021,
    /* VPSRAVDZrrk */
  },
  { /* 7929 */
    1022,
    /* VPSRAVDZrrkz */
  },
  { /* 7930 */
    334,
    /* VPSRAVDrm */
  },
  { /* 7931 */
    335,
    /* VPSRAVDrr */
  },
  { /* 7932 */
    1017,
    /* VPSRAVQZrm */
  },
  { /* 7933 */
    1023,
    /* VPSRAVQZrmk */
  },
  { /* 7934 */
    1024,
    /* VPSRAVQZrmkz */
  },
  { /* 7935 */
    1020,
    /* VPSRAVQZrr */
  },
  { /* 7936 */
    1025,
    /* VPSRAVQZrrk */
  },
  { /* 7937 */
    1026,
    /* VPSRAVQZrrkz */
  },
  { /* 7938 */
    993,
    /* VPSRAWYri */
  },
  { /* 7939 */
    995,
    /* VPSRAWYrm */
  },
  { /* 7940 */
    996,
    /* VPSRAWYrr */
  },
  { /* 7941 */
    994,
    /* VPSRAWri */
  },
  { /* 7942 */
    334,
    /* VPSRAWrm */
  },
  { /* 7943 */
    335,
    /* VPSRAWrr */
  },
  { /* 7944 */
    993,
    /* VPSRLDQYri */
  },
  { /* 7945 */
    994,
    /* VPSRLDQri */
  },
  { /* 7946 */
    993,
    /* VPSRLDYri */
  },
  { /* 7947 */
    995,
    /* VPSRLDYrm */
  },
  { /* 7948 */
    996,
    /* VPSRLDYrr */
  },
  { /* 7949 */
    997,
    /* VPSRLDZmi */
  },
  { /* 7950 */
    998,
    /* VPSRLDZmik */
  },
  { /* 7951 */
    999,
    /* VPSRLDZmikz */
  },
  { /* 7952 */
    1000,
    /* VPSRLDZri */
  },
  { /* 7953 */
    1001,
    /* VPSRLDZrik */
  },
  { /* 7954 */
    1002,
    /* VPSRLDZrikz */
  },
  { /* 7955 */
    1003,
    /* VPSRLDZrm */
  },
  { /* 7956 */
    1004,
    /* VPSRLDZrmk */
  },
  { /* 7957 */
    1005,
    /* VPSRLDZrmkz */
  },
  { /* 7958 */
    1006,
    /* VPSRLDZrr */
  },
  { /* 7959 */
    1007,
    /* VPSRLDZrrk */
  },
  { /* 7960 */
    1008,
    /* VPSRLDZrrkz */
  },
  { /* 7961 */
    994,
    /* VPSRLDri */
  },
  { /* 7962 */
    334,
    /* VPSRLDrm */
  },
  { /* 7963 */
    335,
    /* VPSRLDrr */
  },
  { /* 7964 */
    993,
    /* VPSRLQYri */
  },
  { /* 7965 */
    995,
    /* VPSRLQYrm */
  },
  { /* 7966 */
    996,
    /* VPSRLQYrr */
  },
  { /* 7967 */
    997,
    /* VPSRLQZmi */
  },
  { /* 7968 */
    1009,
    /* VPSRLQZmik */
  },
  { /* 7969 */
    1010,
    /* VPSRLQZmikz */
  },
  { /* 7970 */
    1000,
    /* VPSRLQZri */
  },
  { /* 7971 */
    1011,
    /* VPSRLQZrik */
  },
  { /* 7972 */
    1012,
    /* VPSRLQZrikz */
  },
  { /* 7973 */
    1003,
    /* VPSRLQZrm */
  },
  { /* 7974 */
    1013,
    /* VPSRLQZrmk */
  },
  { /* 7975 */
    1014,
    /* VPSRLQZrmkz */
  },
  { /* 7976 */
    1006,
    /* VPSRLQZrr */
  },
  { /* 7977 */
    1015,
    /* VPSRLQZrrk */
  },
  { /* 7978 */
    1016,
    /* VPSRLQZrrkz */
  },
  { /* 7979 */
    994,
    /* VPSRLQri */
  },
  { /* 7980 */
    334,
    /* VPSRLQrm */
  },
  { /* 7981 */
    335,
    /* VPSRLQrr */
  },
  { /* 7982 */
    302,
    /* VPSRLVDYrm */
  },
  { /* 7983 */
    303,
    /* VPSRLVDYrr */
  },
  { /* 7984 */
    1017,
    /* VPSRLVDZrm */
  },
  { /* 7985 */
    1018,
    /* VPSRLVDZrmk */
  },
  { /* 7986 */
    1019,
    /* VPSRLVDZrmkz */
  },
  { /* 7987 */
    1020,
    /* VPSRLVDZrr */
  },
  { /* 7988 */
    1021,
    /* VPSRLVDZrrk */
  },
  { /* 7989 */
    1022,
    /* VPSRLVDZrrkz */
  },
  { /* 7990 */
    334,
    /* VPSRLVDrm */
  },
  { /* 7991 */
    335,
    /* VPSRLVDrr */
  },
  { /* 7992 */
    302,
    /* VPSRLVQYrm */
  },
  { /* 7993 */
    303,
    /* VPSRLVQYrr */
  },
  { /* 7994 */
    1017,
    /* VPSRLVQZrm */
  },
  { /* 7995 */
    1023,
    /* VPSRLVQZrmk */
  },
  { /* 7996 */
    1024,
    /* VPSRLVQZrmkz */
  },
  { /* 7997 */
    1020,
    /* VPSRLVQZrr */
  },
  { /* 7998 */
    1025,
    /* VPSRLVQZrrk */
  },
  { /* 7999 */
    1026,
    /* VPSRLVQZrrkz */
  },
  { /* 8000 */
    334,
    /* VPSRLVQrm */
  },
  { /* 8001 */
    335,
    /* VPSRLVQrr */
  },
  { /* 8002 */
    993,
    /* VPSRLWYri */
  },
  { /* 8003 */
    995,
    /* VPSRLWYrm */
  },
  { /* 8004 */
    996,
    /* VPSRLWYrr */
  },
  { /* 8005 */
    994,
    /* VPSRLWri */
  },
  { /* 8006 */
    334,
    /* VPSRLWrm */
  },
  { /* 8007 */
    335,
    /* VPSRLWrr */
  },
  { /* 8008 */
    302,
    /* VPSUBBYrm */
  },
  { /* 8009 */
    303,
    /* VPSUBBYrr */
  },
  { /* 8010 */
    304,
    /* VPSUBBZ128rm */
  },
  { /* 8011 */
    732,
    /* VPSUBBZ128rmk */
  },
  { /* 8012 */
    733,
    /* VPSUBBZ128rmkz */
  },
  { /* 8013 */
    310,
    /* VPSUBBZ128rr */
  },
  { /* 8014 */
    734,
    /* VPSUBBZ128rrk */
  },
  { /* 8015 */
    735,
    /* VPSUBBZ128rrkz */
  },
  { /* 8016 */
    313,
    /* VPSUBBZ256rm */
  },
  { /* 8017 */
    736,
    /* VPSUBBZ256rmk */
  },
  { /* 8018 */
    737,
    /* VPSUBBZ256rmkz */
  },
  { /* 8019 */
    319,
    /* VPSUBBZ256rr */
  },
  { /* 8020 */
    738,
    /* VPSUBBZ256rrk */
  },
  { /* 8021 */
    739,
    /* VPSUBBZ256rrkz */
  },
  { /* 8022 */
    325,
    /* VPSUBBZrm */
  },
  { /* 8023 */
    740,
    /* VPSUBBZrmk */
  },
  { /* 8024 */
    741,
    /* VPSUBBZrmkz */
  },
  { /* 8025 */
    331,
    /* VPSUBBZrr */
  },
  { /* 8026 */
    742,
    /* VPSUBBZrrk */
  },
  { /* 8027 */
    743,
    /* VPSUBBZrrkz */
  },
  { /* 8028 */
    334,
    /* VPSUBBrm */
  },
  { /* 8029 */
    335,
    /* VPSUBBrr */
  },
  { /* 8030 */
    302,
    /* VPSUBDYrm */
  },
  { /* 8031 */
    303,
    /* VPSUBDYrr */
  },
  { /* 8032 */
    304,
    /* VPSUBDZ128rm */
  },
  { /* 8033 */
    744,
    /* VPSUBDZ128rmb */
  },
  { /* 8034 */
    745,
    /* VPSUBDZ128rmbk */
  },
  { /* 8035 */
    746,
    /* VPSUBDZ128rmbkz */
  },
  { /* 8036 */
    339,
    /* VPSUBDZ128rmk */
  },
  { /* 8037 */
    340,
    /* VPSUBDZ128rmkz */
  },
  { /* 8038 */
    310,
    /* VPSUBDZ128rr */
  },
  { /* 8039 */
    341,
    /* VPSUBDZ128rrk */
  },
  { /* 8040 */
    342,
    /* VPSUBDZ128rrkz */
  },
  { /* 8041 */
    313,
    /* VPSUBDZ256rm */
  },
  { /* 8042 */
    747,
    /* VPSUBDZ256rmb */
  },
  { /* 8043 */
    748,
    /* VPSUBDZ256rmbk */
  },
  { /* 8044 */
    749,
    /* VPSUBDZ256rmbkz */
  },
  { /* 8045 */
    346,
    /* VPSUBDZ256rmk */
  },
  { /* 8046 */
    347,
    /* VPSUBDZ256rmkz */
  },
  { /* 8047 */
    319,
    /* VPSUBDZ256rr */
  },
  { /* 8048 */
    348,
    /* VPSUBDZ256rrk */
  },
  { /* 8049 */
    349,
    /* VPSUBDZ256rrkz */
  },
  { /* 8050 */
    325,
    /* VPSUBDZrm */
  },
  { /* 8051 */
    750,
    /* VPSUBDZrmb */
  },
  { /* 8052 */
    751,
    /* VPSUBDZrmbk */
  },
  { /* 8053 */
    752,
    /* VPSUBDZrmbkz */
  },
  { /* 8054 */
    356,
    /* VPSUBDZrmk */
  },
  { /* 8055 */
    357,
    /* VPSUBDZrmkz */
  },
  { /* 8056 */
    331,
    /* VPSUBDZrr */
  },
  { /* 8057 */
    358,
    /* VPSUBDZrrk */
  },
  { /* 8058 */
    359,
    /* VPSUBDZrrkz */
  },
  { /* 8059 */
    334,
    /* VPSUBDrm */
  },
  { /* 8060 */
    335,
    /* VPSUBDrr */
  },
  { /* 8061 */
    302,
    /* VPSUBQYrm */
  },
  { /* 8062 */
    303,
    /* VPSUBQYrr */
  },
  { /* 8063 */
    304,
    /* VPSUBQZ128rm */
  },
  { /* 8064 */
    753,
    /* VPSUBQZ128rmb */
  },
  { /* 8065 */
    754,
    /* VPSUBQZ128rmbk */
  },
  { /* 8066 */
    755,
    /* VPSUBQZ128rmbkz */
  },
  { /* 8067 */
    308,
    /* VPSUBQZ128rmk */
  },
  { /* 8068 */
    309,
    /* VPSUBQZ128rmkz */
  },
  { /* 8069 */
    310,
    /* VPSUBQZ128rr */
  },
  { /* 8070 */
    311,
    /* VPSUBQZ128rrk */
  },
  { /* 8071 */
    312,
    /* VPSUBQZ128rrkz */
  },
  { /* 8072 */
    313,
    /* VPSUBQZ256rm */
  },
  { /* 8073 */
    756,
    /* VPSUBQZ256rmb */
  },
  { /* 8074 */
    757,
    /* VPSUBQZ256rmbk */
  },
  { /* 8075 */
    758,
    /* VPSUBQZ256rmbkz */
  },
  { /* 8076 */
    317,
    /* VPSUBQZ256rmk */
  },
  { /* 8077 */
    318,
    /* VPSUBQZ256rmkz */
  },
  { /* 8078 */
    319,
    /* VPSUBQZ256rr */
  },
  { /* 8079 */
    320,
    /* VPSUBQZ256rrk */
  },
  { /* 8080 */
    321,
    /* VPSUBQZ256rrkz */
  },
  { /* 8081 */
    325,
    /* VPSUBQZrm */
  },
  { /* 8082 */
    759,
    /* VPSUBQZrmb */
  },
  { /* 8083 */
    760,
    /* VPSUBQZrmbk */
  },
  { /* 8084 */
    761,
    /* VPSUBQZrmbkz */
  },
  { /* 8085 */
    329,
    /* VPSUBQZrmk */
  },
  { /* 8086 */
    330,
    /* VPSUBQZrmkz */
  },
  { /* 8087 */
    331,
    /* VPSUBQZrr */
  },
  { /* 8088 */
    332,
    /* VPSUBQZrrk */
  },
  { /* 8089 */
    333,
    /* VPSUBQZrrkz */
  },
  { /* 8090 */
    334,
    /* VPSUBQrm */
  },
  { /* 8091 */
    335,
    /* VPSUBQrr */
  },
  { /* 8092 */
    302,
    /* VPSUBSBYrm */
  },
  { /* 8093 */
    303,
    /* VPSUBSBYrr */
  },
  { /* 8094 */
    334,
    /* VPSUBSBrm */
  },
  { /* 8095 */
    335,
    /* VPSUBSBrr */
  },
  { /* 8096 */
    302,
    /* VPSUBSWYrm */
  },
  { /* 8097 */
    303,
    /* VPSUBSWYrr */
  },
  { /* 8098 */
    334,
    /* VPSUBSWrm */
  },
  { /* 8099 */
    335,
    /* VPSUBSWrr */
  },
  { /* 8100 */
    302,
    /* VPSUBUSBYrm */
  },
  { /* 8101 */
    303,
    /* VPSUBUSBYrr */
  },
  { /* 8102 */
    334,
    /* VPSUBUSBrm */
  },
  { /* 8103 */
    335,
    /* VPSUBUSBrr */
  },
  { /* 8104 */
    302,
    /* VPSUBUSWYrm */
  },
  { /* 8105 */
    303,
    /* VPSUBUSWYrr */
  },
  { /* 8106 */
    334,
    /* VPSUBUSWrm */
  },
  { /* 8107 */
    335,
    /* VPSUBUSWrr */
  },
  { /* 8108 */
    302,
    /* VPSUBWYrm */
  },
  { /* 8109 */
    303,
    /* VPSUBWYrr */
  },
  { /* 8110 */
    304,
    /* VPSUBWZ128rm */
  },
  { /* 8111 */
    762,
    /* VPSUBWZ128rmk */
  },
  { /* 8112 */
    763,
    /* VPSUBWZ128rmkz */
  },
  { /* 8113 */
    310,
    /* VPSUBWZ128rr */
  },
  { /* 8114 */
    764,
    /* VPSUBWZ128rrk */
  },
  { /* 8115 */
    765,
    /* VPSUBWZ128rrkz */
  },
  { /* 8116 */
    313,
    /* VPSUBWZ256rm */
  },
  { /* 8117 */
    766,
    /* VPSUBWZ256rmk */
  },
  { /* 8118 */
    767,
    /* VPSUBWZ256rmkz */
  },
  { /* 8119 */
    319,
    /* VPSUBWZ256rr */
  },
  { /* 8120 */
    768,
    /* VPSUBWZ256rrk */
  },
  { /* 8121 */
    769,
    /* VPSUBWZ256rrkz */
  },
  { /* 8122 */
    325,
    /* VPSUBWZrm */
  },
  { /* 8123 */
    770,
    /* VPSUBWZrmk */
  },
  { /* 8124 */
    771,
    /* VPSUBWZrmkz */
  },
  { /* 8125 */
    331,
    /* VPSUBWZrr */
  },
  { /* 8126 */
    772,
    /* VPSUBWZrrk */
  },
  { /* 8127 */
    773,
    /* VPSUBWZrrkz */
  },
  { /* 8128 */
    334,
    /* VPSUBWrm */
  },
  { /* 8129 */
    335,
    /* VPSUBWrr */
  },
  { /* 8130 */
    865,
    /* VPTESTMDZrm */
  },
  { /* 8131 */
    869,
    /* VPTESTMDZrr */
  },
  { /* 8132 */
    883,
    /* VPTESTMQZrm */
  },
  { /* 8133 */
    887,
    /* VPTESTMQZrr */
  },
  { /* 8134 */
    865,
    /* VPTESTNMDZrm */
  },
  { /* 8135 */
    869,
    /* VPTESTNMDZrr */
  },
  { /* 8136 */
    883,
    /* VPTESTNMQZrm */
  },
  { /* 8137 */
    887,
    /* VPTESTNMQZrr */
  },
  { /* 8138 */
    475,
    /* VPTESTYrm */
  },
  { /* 8139 */
    476,
    /* VPTESTYrr */
  },
  { /* 8140 */
    44,
    /* VPTESTrm */
  },
  { /* 8141 */
    45,
    /* VPTESTrr */
  },
  { /* 8142 */
    302,
    /* VPUNPCKHBWYrm */
  },
  { /* 8143 */
    303,
    /* VPUNPCKHBWYrr */
  },
  { /* 8144 */
    334,
    /* VPUNPCKHBWrm */
  },
  { /* 8145 */
    335,
    /* VPUNPCKHBWrr */
  },
  { /* 8146 */
    302,
    /* VPUNPCKHDQYrm */
  },
  { /* 8147 */
    303,
    /* VPUNPCKHDQYrr */
  },
  { /* 8148 */
    325,
    /* VPUNPCKHDQZrm */
  },
  { /* 8149 */
    331,
    /* VPUNPCKHDQZrr */
  },
  { /* 8150 */
    334,
    /* VPUNPCKHDQrm */
  },
  { /* 8151 */
    335,
    /* VPUNPCKHDQrr */
  },
  { /* 8152 */
    302,
    /* VPUNPCKHQDQYrm */
  },
  { /* 8153 */
    303,
    /* VPUNPCKHQDQYrr */
  },
  { /* 8154 */
    325,
    /* VPUNPCKHQDQZrm */
  },
  { /* 8155 */
    331,
    /* VPUNPCKHQDQZrr */
  },
  { /* 8156 */
    334,
    /* VPUNPCKHQDQrm */
  },
  { /* 8157 */
    335,
    /* VPUNPCKHQDQrr */
  },
  { /* 8158 */
    302,
    /* VPUNPCKHWDYrm */
  },
  { /* 8159 */
    303,
    /* VPUNPCKHWDYrr */
  },
  { /* 8160 */
    334,
    /* VPUNPCKHWDrm */
  },
  { /* 8161 */
    335,
    /* VPUNPCKHWDrr */
  },
  { /* 8162 */
    302,
    /* VPUNPCKLBWYrm */
  },
  { /* 8163 */
    303,
    /* VPUNPCKLBWYrr */
  },
  { /* 8164 */
    334,
    /* VPUNPCKLBWrm */
  },
  { /* 8165 */
    335,
    /* VPUNPCKLBWrr */
  },
  { /* 8166 */
    302,
    /* VPUNPCKLDQYrm */
  },
  { /* 8167 */
    303,
    /* VPUNPCKLDQYrr */
  },
  { /* 8168 */
    325,
    /* VPUNPCKLDQZrm */
  },
  { /* 8169 */
    331,
    /* VPUNPCKLDQZrr */
  },
  { /* 8170 */
    334,
    /* VPUNPCKLDQrm */
  },
  { /* 8171 */
    335,
    /* VPUNPCKLDQrr */
  },
  { /* 8172 */
    302,
    /* VPUNPCKLQDQYrm */
  },
  { /* 8173 */
    303,
    /* VPUNPCKLQDQYrr */
  },
  { /* 8174 */
    325,
    /* VPUNPCKLQDQZrm */
  },
  { /* 8175 */
    331,
    /* VPUNPCKLQDQZrr */
  },
  { /* 8176 */
    334,
    /* VPUNPCKLQDQrm */
  },
  { /* 8177 */
    335,
    /* VPUNPCKLQDQrr */
  },
  { /* 8178 */
    302,
    /* VPUNPCKLWDYrm */
  },
  { /* 8179 */
    303,
    /* VPUNPCKLWDYrr */
  },
  { /* 8180 */
    334,
    /* VPUNPCKLWDrm */
  },
  { /* 8181 */
    335,
    /* VPUNPCKLWDrr */
  },
  { /* 8182 */
    304,
    /* VPXORDZ128rm */
  },
  { /* 8183 */
    744,
    /* VPXORDZ128rmb */
  },
  { /* 8184 */
    745,
    /* VPXORDZ128rmbk */
  },
  { /* 8185 */
    746,
    /* VPXORDZ128rmbkz */
  },
  { /* 8186 */
    339,
    /* VPXORDZ128rmk */
  },
  { /* 8187 */
    340,
    /* VPXORDZ128rmkz */
  },
  { /* 8188 */
    310,
    /* VPXORDZ128rr */
  },
  { /* 8189 */
    341,
    /* VPXORDZ128rrk */
  },
  { /* 8190 */
    342,
    /* VPXORDZ128rrkz */
  },
  { /* 8191 */
    313,
    /* VPXORDZ256rm */
  },
  { /* 8192 */
    747,
    /* VPXORDZ256rmb */
  },
  { /* 8193 */
    748,
    /* VPXORDZ256rmbk */
  },
  { /* 8194 */
    749,
    /* VPXORDZ256rmbkz */
  },
  { /* 8195 */
    346,
    /* VPXORDZ256rmk */
  },
  { /* 8196 */
    347,
    /* VPXORDZ256rmkz */
  },
  { /* 8197 */
    319,
    /* VPXORDZ256rr */
  },
  { /* 8198 */
    348,
    /* VPXORDZ256rrk */
  },
  { /* 8199 */
    349,
    /* VPXORDZ256rrkz */
  },
  { /* 8200 */
    325,
    /* VPXORDZrm */
  },
  { /* 8201 */
    750,
    /* VPXORDZrmb */
  },
  { /* 8202 */
    751,
    /* VPXORDZrmbk */
  },
  { /* 8203 */
    752,
    /* VPXORDZrmbkz */
  },
  { /* 8204 */
    356,
    /* VPXORDZrmk */
  },
  { /* 8205 */
    357,
    /* VPXORDZrmkz */
  },
  { /* 8206 */
    331,
    /* VPXORDZrr */
  },
  { /* 8207 */
    358,
    /* VPXORDZrrk */
  },
  { /* 8208 */
    359,
    /* VPXORDZrrkz */
  },
  { /* 8209 */
    304,
    /* VPXORQZ128rm */
  },
  { /* 8210 */
    753,
    /* VPXORQZ128rmb */
  },
  { /* 8211 */
    754,
    /* VPXORQZ128rmbk */
  },
  { /* 8212 */
    755,
    /* VPXORQZ128rmbkz */
  },
  { /* 8213 */
    308,
    /* VPXORQZ128rmk */
  },
  { /* 8214 */
    309,
    /* VPXORQZ128rmkz */
  },
  { /* 8215 */
    310,
    /* VPXORQZ128rr */
  },
  { /* 8216 */
    311,
    /* VPXORQZ128rrk */
  },
  { /* 8217 */
    312,
    /* VPXORQZ128rrkz */
  },
  { /* 8218 */
    313,
    /* VPXORQZ256rm */
  },
  { /* 8219 */
    756,
    /* VPXORQZ256rmb */
  },
  { /* 8220 */
    757,
    /* VPXORQZ256rmbk */
  },
  { /* 8221 */
    758,
    /* VPXORQZ256rmbkz */
  },
  { /* 8222 */
    317,
    /* VPXORQZ256rmk */
  },
  { /* 8223 */
    318,
    /* VPXORQZ256rmkz */
  },
  { /* 8224 */
    319,
    /* VPXORQZ256rr */
  },
  { /* 8225 */
    320,
    /* VPXORQZ256rrk */
  },
  { /* 8226 */
    321,
    /* VPXORQZ256rrkz */
  },
  { /* 8227 */
    325,
    /* VPXORQZrm */
  },
  { /* 8228 */
    759,
    /* VPXORQZrmb */
  },
  { /* 8229 */
    760,
    /* VPXORQZrmbk */
  },
  { /* 8230 */
    761,
    /* VPXORQZrmbkz */
  },
  { /* 8231 */
    329,
    /* VPXORQZrmk */
  },
  { /* 8232 */
    330,
    /* VPXORQZrmkz */
  },
  { /* 8233 */
    331,
    /* VPXORQZrr */
  },
  { /* 8234 */
    332,
    /* VPXORQZrrk */
  },
  { /* 8235 */
    333,
    /* VPXORQZrrkz */
  },
  { /* 8236 */
    302,
    /* VPXORYrm */
  },
  { /* 8237 */
    303,
    /* VPXORYrr */
  },
  { /* 8238 */
    334,
    /* VPXORrm */
  },
  { /* 8239 */
    335,
    /* VPXORrr */
  },
  { /* 8240 */
    637,
    /* VRCP14PDZ128m */
  },
  { /* 8241 */
    1027,
    /* VRCP14PDZ128mb */
  },
  { /* 8242 */
    1028,
    /* VRCP14PDZ128mbk */
  },
  { /* 8243 */
    1029,
    /* VRCP14PDZ128mbkz */
  },
  { /* 8244 */
    638,
    /* VRCP14PDZ128mk */
  },
  { /* 8245 */
    639,
    /* VRCP14PDZ128mkz */
  },
  { /* 8246 */
    640,
    /* VRCP14PDZ128r */
  },
  { /* 8247 */
    545,
    /* VRCP14PDZ128rk */
  },
  { /* 8248 */
    546,
    /* VRCP14PDZ128rkz */
  },
  { /* 8249 */
    644,
    /* VRCP14PDZ256m */
  },
  { /* 8250 */
    403,
    /* VRCP14PDZ256mb */
  },
  { /* 8251 */
    404,
    /* VRCP14PDZ256mbk */
  },
  { /* 8252 */
    405,
    /* VRCP14PDZ256mbkz */
  },
  { /* 8253 */
    645,
    /* VRCP14PDZ256mk */
  },
  { /* 8254 */
    646,
    /* VRCP14PDZ256mkz */
  },
  { /* 8255 */
    647,
    /* VRCP14PDZ256r */
  },
  { /* 8256 */
    549,
    /* VRCP14PDZ256rk */
  },
  { /* 8257 */
    550,
    /* VRCP14PDZ256rkz */
  },
  { /* 8258 */
    477,
    /* VRCP14PDZm */
  },
  { /* 8259 */
    409,
    /* VRCP14PDZmb */
  },
  { /* 8260 */
    410,
    /* VRCP14PDZmbk */
  },
  { /* 8261 */
    411,
    /* VRCP14PDZmbkz */
  },
  { /* 8262 */
    528,
    /* VRCP14PDZmk */
  },
  { /* 8263 */
    529,
    /* VRCP14PDZmkz */
  },
  { /* 8264 */
    478,
    /* VRCP14PDZr */
  },
  { /* 8265 */
    533,
    /* VRCP14PDZrk */
  },
  { /* 8266 */
    534,
    /* VRCP14PDZrkz */
  },
  { /* 8267 */
    637,
    /* VRCP14PSZ128m */
  },
  { /* 8268 */
    416,
    /* VRCP14PSZ128mb */
  },
  { /* 8269 */
    417,
    /* VRCP14PSZ128mbk */
  },
  { /* 8270 */
    418,
    /* VRCP14PSZ128mbkz */
  },
  { /* 8271 */
    653,
    /* VRCP14PSZ128mk */
  },
  { /* 8272 */
    654,
    /* VRCP14PSZ128mkz */
  },
  { /* 8273 */
    640,
    /* VRCP14PSZ128r */
  },
  { /* 8274 */
    555,
    /* VRCP14PSZ128rk */
  },
  { /* 8275 */
    556,
    /* VRCP14PSZ128rkz */
  },
  { /* 8276 */
    644,
    /* VRCP14PSZ256m */
  },
  { /* 8277 */
    422,
    /* VRCP14PSZ256mb */
  },
  { /* 8278 */
    423,
    /* VRCP14PSZ256mbk */
  },
  { /* 8279 */
    424,
    /* VRCP14PSZ256mbkz */
  },
  { /* 8280 */
    656,
    /* VRCP14PSZ256mk */
  },
  { /* 8281 */
    657,
    /* VRCP14PSZ256mkz */
  },
  { /* 8282 */
    647,
    /* VRCP14PSZ256r */
  },
  { /* 8283 */
    559,
    /* VRCP14PSZ256rk */
  },
  { /* 8284 */
    560,
    /* VRCP14PSZ256rkz */
  },
  { /* 8285 */
    477,
    /* VRCP14PSZm */
  },
  { /* 8286 */
    428,
    /* VRCP14PSZmb */
  },
  { /* 8287 */
    429,
    /* VRCP14PSZmbk */
  },
  { /* 8288 */
    430,
    /* VRCP14PSZmbkz */
  },
  { /* 8289 */
    537,
    /* VRCP14PSZmk */
  },
  { /* 8290 */
    538,
    /* VRCP14PSZmkz */
  },
  { /* 8291 */
    478,
    /* VRCP14PSZr */
  },
  { /* 8292 */
    541,
    /* VRCP14PSZrk */
  },
  { /* 8293 */
    542,
    /* VRCP14PSZrkz */
  },
  { /* 8294 */
    1030,
    /* VRCP14SDrm */
  },
  { /* 8295 */
    1031,
    /* VRCP14SDrr */
  },
  { /* 8296 */
    1032,
    /* VRCP14SSrm */
  },
  { /* 8297 */
    1033,
    /* VRCP14SSrr */
  },
  { /* 8298 */
    477,
    /* VRCP28PDm */
  },
  { /* 8299 */
    525,
    /* VRCP28PDmb */
  },
  { /* 8300 */
    526,
    /* VRCP28PDmbk */
  },
  { /* 8301 */
    527,
    /* VRCP28PDmbkz */
  },
  { /* 8302 */
    528,
    /* VRCP28PDmk */
  },
  { /* 8303 */
    529,
    /* VRCP28PDmkz */
  },
  { /* 8304 */
    478,
    /* VRCP28PDr */
  },
  { /* 8305 */
    530,
    /* VRCP28PDrb */
  },
  { /* 8306 */
    531,
    /* VRCP28PDrbk */
  },
  { /* 8307 */
    532,
    /* VRCP28PDrbkz */
  },
  { /* 8308 */
    533,
    /* VRCP28PDrk */
  },
  { /* 8309 */
    534,
    /* VRCP28PDrkz */
  },
  { /* 8310 */
    477,
    /* VRCP28PSm */
  },
  { /* 8311 */
    525,
    /* VRCP28PSmb */
  },
  { /* 8312 */
    535,
    /* VRCP28PSmbk */
  },
  { /* 8313 */
    536,
    /* VRCP28PSmbkz */
  },
  { /* 8314 */
    537,
    /* VRCP28PSmk */
  },
  { /* 8315 */
    538,
    /* VRCP28PSmkz */
  },
  { /* 8316 */
    478,
    /* VRCP28PSr */
  },
  { /* 8317 */
    530,
    /* VRCP28PSrb */
  },
  { /* 8318 */
    539,
    /* VRCP28PSrbk */
  },
  { /* 8319 */
    540,
    /* VRCP28PSrbkz */
  },
  { /* 8320 */
    541,
    /* VRCP28PSrk */
  },
  { /* 8321 */
    542,
    /* VRCP28PSrkz */
  },
  { /* 8322 */
    360,
    /* VRCP28SDm */
  },
  { /* 8323 */
    361,
    /* VRCP28SDmk */
  },
  { /* 8324 */
    362,
    /* VRCP28SDmkz */
  },
  { /* 8325 */
    363,
    /* VRCP28SDr */
  },
  { /* 8326 */
    363,
    /* VRCP28SDrb */
  },
  { /* 8327 */
    364,
    /* VRCP28SDrbk */
  },
  { /* 8328 */
    365,
    /* VRCP28SDrbkz */
  },
  { /* 8329 */
    364,
    /* VRCP28SDrk */
  },
  { /* 8330 */
    365,
    /* VRCP28SDrkz */
  },
  { /* 8331 */
    371,
    /* VRCP28SSm */
  },
  { /* 8332 */
    372,
    /* VRCP28SSmk */
  },
  { /* 8333 */
    373,
    /* VRCP28SSmkz */
  },
  { /* 8334 */
    374,
    /* VRCP28SSr */
  },
  { /* 8335 */
    374,
    /* VRCP28SSrb */
  },
  { /* 8336 */
    375,
    /* VRCP28SSrbk */
  },
  { /* 8337 */
    376,
    /* VRCP28SSrbkz */
  },
  { /* 8338 */
    375,
    /* VRCP28SSrk */
  },
  { /* 8339 */
    376,
    /* VRCP28SSrkz */
  },
  { /* 8340 */
    475,
    /* VRCPPSYm */
  },
  { /* 8341 */
    0,
    /*  */
  },
  { /* 8342 */
    476,
    /* VRCPPSYr */
  },
  { /* 8343 */
    0,
    /*  */
  },
  { /* 8344 */
    44,
    /* VRCPPSm */
  },
  { /* 8345 */
    0,
    /*  */
  },
  { /* 8346 */
    45,
    /* VRCPPSr */
  },
  { /* 8347 */
    0,
    /*  */
  },
  { /* 8348 */
    380,
    /* VRCPSSm */
  },
  { /* 8349 */
    0,
    /*  */
  },
  { /* 8350 */
    381,
    /* VRCPSSr */
  },
  { /* 8351 */
    943,
    /* VRNDSCALEPDZm */
  },
  { /* 8352 */
    944,
    /* VRNDSCALEPDZr */
  },
  { /* 8353 */
    943,
    /* VRNDSCALEPSZm */
  },
  { /* 8354 */
    944,
    /* VRNDSCALEPSZr */
  },
  { /* 8355 */
    1034,
    /* VRNDSCALESDm */
  },
  { /* 8356 */
    1035,
    /* VRNDSCALESDmk */
  },
  { /* 8357 */
    1036,
    /* VRNDSCALESDmkz */
  },
  { /* 8358 */
    1037,
    /* VRNDSCALESDr */
  },
  { /* 8359 */
    1037,
    /* VRNDSCALESDrb */
  },
  { /* 8360 */
    1038,
    /* VRNDSCALESDrbk */
  },
  { /* 8361 */
    1039,
    /* VRNDSCALESDrbkz */
  },
  { /* 8362 */
    1038,
    /* VRNDSCALESDrk */
  },
  { /* 8363 */
    1039,
    /* VRNDSCALESDrkz */
  },
  { /* 8364 */
    1040,
    /* VRNDSCALESSm */
  },
  { /* 8365 */
    1041,
    /* VRNDSCALESSmk */
  },
  { /* 8366 */
    1042,
    /* VRNDSCALESSmkz */
  },
  { /* 8367 */
    1043,
    /* VRNDSCALESSr */
  },
  { /* 8368 */
    1043,
    /* VRNDSCALESSrb */
  },
  { /* 8369 */
    1044,
    /* VRNDSCALESSrbk */
  },
  { /* 8370 */
    1045,
    /* VRNDSCALESSrbkz */
  },
  { /* 8371 */
    1044,
    /* VRNDSCALESSrk */
  },
  { /* 8372 */
    1045,
    /* VRNDSCALESSrkz */
  },
  { /* 8373 */
    46,
    /* VROUNDPDm */
  },
  { /* 8374 */
    47,
    /* VROUNDPDr */
  },
  { /* 8375 */
    46,
    /* VROUNDPSm */
  },
  { /* 8376 */
    47,
    /* VROUNDPSr */
  },
  { /* 8377 */
    1046,
    /* VROUNDSDm */
  },
  { /* 8378 */
    1047,
    /* VROUNDSDr */
  },
  { /* 8379 */
    0,
    /*  */
  },
  { /* 8380 */
    627,
    /* VROUNDSSm */
  },
  { /* 8381 */
    1048,
    /* VROUNDSSr */
  },
  { /* 8382 */
    0,
    /*  */
  },
  { /* 8383 */
    941,
    /* VROUNDYPDm */
  },
  { /* 8384 */
    942,
    /* VROUNDYPDr */
  },
  { /* 8385 */
    941,
    /* VROUNDYPSm */
  },
  { /* 8386 */
    942,
    /* VROUNDYPSr */
  },
  { /* 8387 */
    637,
    /* VRSQRT14PDZ128m */
  },
  { /* 8388 */
    1027,
    /* VRSQRT14PDZ128mb */
  },
  { /* 8389 */
    1028,
    /* VRSQRT14PDZ128mbk */
  },
  { /* 8390 */
    1029,
    /* VRSQRT14PDZ128mbkz */
  },
  { /* 8391 */
    638,
    /* VRSQRT14PDZ128mk */
  },
  { /* 8392 */
    639,
    /* VRSQRT14PDZ128mkz */
  },
  { /* 8393 */
    640,
    /* VRSQRT14PDZ128r */
  },
  { /* 8394 */
    545,
    /* VRSQRT14PDZ128rk */
  },
  { /* 8395 */
    546,
    /* VRSQRT14PDZ128rkz */
  },
  { /* 8396 */
    644,
    /* VRSQRT14PDZ256m */
  },
  { /* 8397 */
    403,
    /* VRSQRT14PDZ256mb */
  },
  { /* 8398 */
    404,
    /* VRSQRT14PDZ256mbk */
  },
  { /* 8399 */
    405,
    /* VRSQRT14PDZ256mbkz */
  },
  { /* 8400 */
    645,
    /* VRSQRT14PDZ256mk */
  },
  { /* 8401 */
    646,
    /* VRSQRT14PDZ256mkz */
  },
  { /* 8402 */
    647,
    /* VRSQRT14PDZ256r */
  },
  { /* 8403 */
    549,
    /* VRSQRT14PDZ256rk */
  },
  { /* 8404 */
    550,
    /* VRSQRT14PDZ256rkz */
  },
  { /* 8405 */
    477,
    /* VRSQRT14PDZm */
  },
  { /* 8406 */
    409,
    /* VRSQRT14PDZmb */
  },
  { /* 8407 */
    410,
    /* VRSQRT14PDZmbk */
  },
  { /* 8408 */
    411,
    /* VRSQRT14PDZmbkz */
  },
  { /* 8409 */
    528,
    /* VRSQRT14PDZmk */
  },
  { /* 8410 */
    529,
    /* VRSQRT14PDZmkz */
  },
  { /* 8411 */
    478,
    /* VRSQRT14PDZr */
  },
  { /* 8412 */
    533,
    /* VRSQRT14PDZrk */
  },
  { /* 8413 */
    534,
    /* VRSQRT14PDZrkz */
  },
  { /* 8414 */
    637,
    /* VRSQRT14PSZ128m */
  },
  { /* 8415 */
    416,
    /* VRSQRT14PSZ128mb */
  },
  { /* 8416 */
    417,
    /* VRSQRT14PSZ128mbk */
  },
  { /* 8417 */
    418,
    /* VRSQRT14PSZ128mbkz */
  },
  { /* 8418 */
    653,
    /* VRSQRT14PSZ128mk */
  },
  { /* 8419 */
    654,
    /* VRSQRT14PSZ128mkz */
  },
  { /* 8420 */
    640,
    /* VRSQRT14PSZ128r */
  },
  { /* 8421 */
    555,
    /* VRSQRT14PSZ128rk */
  },
  { /* 8422 */
    556,
    /* VRSQRT14PSZ128rkz */
  },
  { /* 8423 */
    644,
    /* VRSQRT14PSZ256m */
  },
  { /* 8424 */
    422,
    /* VRSQRT14PSZ256mb */
  },
  { /* 8425 */
    423,
    /* VRSQRT14PSZ256mbk */
  },
  { /* 8426 */
    424,
    /* VRSQRT14PSZ256mbkz */
  },
  { /* 8427 */
    656,
    /* VRSQRT14PSZ256mk */
  },
  { /* 8428 */
    657,
    /* VRSQRT14PSZ256mkz */
  },
  { /* 8429 */
    647,
    /* VRSQRT14PSZ256r */
  },
  { /* 8430 */
    559,
    /* VRSQRT14PSZ256rk */
  },
  { /* 8431 */
    560,
    /* VRSQRT14PSZ256rkz */
  },
  { /* 8432 */
    477,
    /* VRSQRT14PSZm */
  },
  { /* 8433 */
    428,
    /* VRSQRT14PSZmb */
  },
  { /* 8434 */
    429,
    /* VRSQRT14PSZmbk */
  },
  { /* 8435 */
    430,
    /* VRSQRT14PSZmbkz */
  },
  { /* 8436 */
    537,
    /* VRSQRT14PSZmk */
  },
  { /* 8437 */
    538,
    /* VRSQRT14PSZmkz */
  },
  { /* 8438 */
    478,
    /* VRSQRT14PSZr */
  },
  { /* 8439 */
    541,
    /* VRSQRT14PSZrk */
  },
  { /* 8440 */
    542,
    /* VRSQRT14PSZrkz */
  },
  { /* 8441 */
    1030,
    /* VRSQRT14SDrm */
  },
  { /* 8442 */
    1031,
    /* VRSQRT14SDrr */
  },
  { /* 8443 */
    1032,
    /* VRSQRT14SSrm */
  },
  { /* 8444 */
    1033,
    /* VRSQRT14SSrr */
  },
  { /* 8445 */
    477,
    /* VRSQRT28PDm */
  },
  { /* 8446 */
    525,
    /* VRSQRT28PDmb */
  },
  { /* 8447 */
    526,
    /* VRSQRT28PDmbk */
  },
  { /* 8448 */
    527,
    /* VRSQRT28PDmbkz */
  },
  { /* 8449 */
    528,
    /* VRSQRT28PDmk */
  },
  { /* 8450 */
    529,
    /* VRSQRT28PDmkz */
  },
  { /* 8451 */
    478,
    /* VRSQRT28PDr */
  },
  { /* 8452 */
    530,
    /* VRSQRT28PDrb */
  },
  { /* 8453 */
    531,
    /* VRSQRT28PDrbk */
  },
  { /* 8454 */
    532,
    /* VRSQRT28PDrbkz */
  },
  { /* 8455 */
    533,
    /* VRSQRT28PDrk */
  },
  { /* 8456 */
    534,
    /* VRSQRT28PDrkz */
  },
  { /* 8457 */
    477,
    /* VRSQRT28PSm */
  },
  { /* 8458 */
    525,
    /* VRSQRT28PSmb */
  },
  { /* 8459 */
    535,
    /* VRSQRT28PSmbk */
  },
  { /* 8460 */
    536,
    /* VRSQRT28PSmbkz */
  },
  { /* 8461 */
    537,
    /* VRSQRT28PSmk */
  },
  { /* 8462 */
    538,
    /* VRSQRT28PSmkz */
  },
  { /* 8463 */
    478,
    /* VRSQRT28PSr */
  },
  { /* 8464 */
    530,
    /* VRSQRT28PSrb */
  },
  { /* 8465 */
    539,
    /* VRSQRT28PSrbk */
  },
  { /* 8466 */
    540,
    /* VRSQRT28PSrbkz */
  },
  { /* 8467 */
    541,
    /* VRSQRT28PSrk */
  },
  { /* 8468 */
    542,
    /* VRSQRT28PSrkz */
  },
  { /* 8469 */
    360,
    /* VRSQRT28SDm */
  },
  { /* 8470 */
    361,
    /* VRSQRT28SDmk */
  },
  { /* 8471 */
    362,
    /* VRSQRT28SDmkz */
  },
  { /* 8472 */
    363,
    /* VRSQRT28SDr */
  },
  { /* 8473 */
    363,
    /* VRSQRT28SDrb */
  },
  { /* 8474 */
    364,
    /* VRSQRT28SDrbk */
  },
  { /* 8475 */
    365,
    /* VRSQRT28SDrbkz */
  },
  { /* 8476 */
    364,
    /* VRSQRT28SDrk */
  },
  { /* 8477 */
    365,
    /* VRSQRT28SDrkz */
  },
  { /* 8478 */
    371,
    /* VRSQRT28SSm */
  },
  { /* 8479 */
    372,
    /* VRSQRT28SSmk */
  },
  { /* 8480 */
    373,
    /* VRSQRT28SSmkz */
  },
  { /* 8481 */
    374,
    /* VRSQRT28SSr */
  },
  { /* 8482 */
    374,
    /* VRSQRT28SSrb */
  },
  { /* 8483 */
    375,
    /* VRSQRT28SSrbk */
  },
  { /* 8484 */
    376,
    /* VRSQRT28SSrbkz */
  },
  { /* 8485 */
    375,
    /* VRSQRT28SSrk */
  },
  { /* 8486 */
    376,
    /* VRSQRT28SSrkz */
  },
  { /* 8487 */
    475,
    /* VRSQRTPSYm */
  },
  { /* 8488 */
    0,
    /*  */
  },
  { /* 8489 */
    476,
    /* VRSQRTPSYr */
  },
  { /* 8490 */
    0,
    /*  */
  },
  { /* 8491 */
    44,
    /* VRSQRTPSm */
  },
  { /* 8492 */
    0,
    /*  */
  },
  { /* 8493 */
    45,
    /* VRSQRTPSr */
  },
  { /* 8494 */
    0,
    /*  */
  },
  { /* 8495 */
    380,
    /* VRSQRTSSm */
  },
  { /* 8496 */
    0,
    /*  */
  },
  { /* 8497 */
    381,
    /* VRSQRTSSr */
  },
  { /* 8498 */
    991,
    /* VSCATTERDPDZmr */
  },
  { /* 8499 */
    990,
    /* VSCATTERDPSZmr */
  },
  { /* 8500 */
    617,
    /* VSCATTERPF0DPDm */
  },
  { /* 8501 */
    618,
    /* VSCATTERPF0DPSm */
  },
  { /* 8502 */
    619,
    /* VSCATTERPF0QPDm */
  },
  { /* 8503 */
    619,
    /* VSCATTERPF0QPSm */
  },
  { /* 8504 */
    617,
    /* VSCATTERPF1DPDm */
  },
  { /* 8505 */
    618,
    /* VSCATTERPF1DPSm */
  },
  { /* 8506 */
    619,
    /* VSCATTERPF1QPDm */
  },
  { /* 8507 */
    619,
    /* VSCATTERPF1QPSm */
  },
  { /* 8508 */
    991,
    /* VSCATTERQPDZmr */
  },
  { /* 8509 */
    992,
    /* VSCATTERQPSZmr */
  },
  { /* 8510 */
    388,
    /* VSHUFPDYrmi */
  },
  { /* 8511 */
    389,
    /* VSHUFPDYrri */
  },
  { /* 8512 */
    382,
    /* VSHUFPDZrmi */
  },
  { /* 8513 */
    383,
    /* VSHUFPDZrri */
  },
  { /* 8514 */
    390,
    /* VSHUFPDrmi */
  },
  { /* 8515 */
    391,
    /* VSHUFPDrri */
  },
  { /* 8516 */
    388,
    /* VSHUFPSYrmi */
  },
  { /* 8517 */
    389,
    /* VSHUFPSYrri */
  },
  { /* 8518 */
    382,
    /* VSHUFPSZrmi */
  },
  { /* 8519 */
    383,
    /* VSHUFPSZrri */
  },
  { /* 8520 */
    390,
    /* VSHUFPSrmi */
  },
  { /* 8521 */
    391,
    /* VSHUFPSrri */
  },
  { /* 8522 */
    475,
    /* VSQRTPDYm */
  },
  { /* 8523 */
    476,
    /* VSQRTPDYr */
  },
  { /* 8524 */
    637,
    /* VSQRTPDZ128m */
  },
  { /* 8525 */
    1027,
    /* VSQRTPDZ128mb */
  },
  { /* 8526 */
    1028,
    /* VSQRTPDZ128mbk */
  },
  { /* 8527 */
    1029,
    /* VSQRTPDZ128mbkz */
  },
  { /* 8528 */
    638,
    /* VSQRTPDZ128mk */
  },
  { /* 8529 */
    639,
    /* VSQRTPDZ128mkz */
  },
  { /* 8530 */
    640,
    /* VSQRTPDZ128r */
  },
  { /* 8531 */
    545,
    /* VSQRTPDZ128rk */
  },
  { /* 8532 */
    546,
    /* VSQRTPDZ128rkz */
  },
  { /* 8533 */
    644,
    /* VSQRTPDZ256m */
  },
  { /* 8534 */
    403,
    /* VSQRTPDZ256mb */
  },
  { /* 8535 */
    404,
    /* VSQRTPDZ256mbk */
  },
  { /* 8536 */
    405,
    /* VSQRTPDZ256mbkz */
  },
  { /* 8537 */
    645,
    /* VSQRTPDZ256mk */
  },
  { /* 8538 */
    646,
    /* VSQRTPDZ256mkz */
  },
  { /* 8539 */
    647,
    /* VSQRTPDZ256r */
  },
  { /* 8540 */
    549,
    /* VSQRTPDZ256rk */
  },
  { /* 8541 */
    550,
    /* VSQRTPDZ256rkz */
  },
  { /* 8542 */
    477,
    /* VSQRTPDZm */
  },
  { /* 8543 */
    409,
    /* VSQRTPDZmb */
  },
  { /* 8544 */
    410,
    /* VSQRTPDZmbk */
  },
  { /* 8545 */
    411,
    /* VSQRTPDZmbkz */
  },
  { /* 8546 */
    528,
    /* VSQRTPDZmk */
  },
  { /* 8547 */
    529,
    /* VSQRTPDZmkz */
  },
  { /* 8548 */
    478,
    /* VSQRTPDZr */
  },
  { /* 8549 */
    533,
    /* VSQRTPDZrk */
  },
  { /* 8550 */
    534,
    /* VSQRTPDZrkz */
  },
  { /* 8551 */
    44,
    /* VSQRTPDm */
  },
  { /* 8552 */
    45,
    /* VSQRTPDr */
  },
  { /* 8553 */
    475,
    /* VSQRTPSYm */
  },
  { /* 8554 */
    476,
    /* VSQRTPSYr */
  },
  { /* 8555 */
    637,
    /* VSQRTPSZ128m */
  },
  { /* 8556 */
    416,
    /* VSQRTPSZ128mb */
  },
  { /* 8557 */
    417,
    /* VSQRTPSZ128mbk */
  },
  { /* 8558 */
    418,
    /* VSQRTPSZ128mbkz */
  },
  { /* 8559 */
    653,
    /* VSQRTPSZ128mk */
  },
  { /* 8560 */
    654,
    /* VSQRTPSZ128mkz */
  },
  { /* 8561 */
    640,
    /* VSQRTPSZ128r */
  },
  { /* 8562 */
    555,
    /* VSQRTPSZ128rk */
  },
  { /* 8563 */
    556,
    /* VSQRTPSZ128rkz */
  },
  { /* 8564 */
    644,
    /* VSQRTPSZ256m */
  },
  { /* 8565 */
    422,
    /* VSQRTPSZ256mb */
  },
  { /* 8566 */
    423,
    /* VSQRTPSZ256mbk */
  },
  { /* 8567 */
    424,
    /* VSQRTPSZ256mbkz */
  },
  { /* 8568 */
    656,
    /* VSQRTPSZ256mk */
  },
  { /* 8569 */
    657,
    /* VSQRTPSZ256mkz */
  },
  { /* 8570 */
    647,
    /* VSQRTPSZ256r */
  },
  { /* 8571 */
    559,
    /* VSQRTPSZ256rk */
  },
  { /* 8572 */
    560,
    /* VSQRTPSZ256rkz */
  },
  { /* 8573 */
    477,
    /* VSQRTPSZm */
  },
  { /* 8574 */
    428,
    /* VSQRTPSZmb */
  },
  { /* 8575 */
    429,
    /* VSQRTPSZmbk */
  },
  { /* 8576 */
    430,
    /* VSQRTPSZmbkz */
  },
  { /* 8577 */
    537,
    /* VSQRTPSZmk */
  },
  { /* 8578 */
    538,
    /* VSQRTPSZmkz */
  },
  { /* 8579 */
    478,
    /* VSQRTPSZr */
  },
  { /* 8580 */
    541,
    /* VSQRTPSZrk */
  },
  { /* 8581 */
    542,
    /* VSQRTPSZrkz */
  },
  { /* 8582 */
    44,
    /* VSQRTPSm */
  },
  { /* 8583 */
    45,
    /* VSQRTPSr */
  },
  { /* 8584 */
    1030,
    /* VSQRTSDZm */
  },
  { /* 8585 */
    0,
    /*  */
  },
  { /* 8586 */
    1049,
    /* VSQRTSDZr */
  },
  { /* 8587 */
    0,
    /*  */
  },
  { /* 8588 */
    369,
    /* VSQRTSDm */
  },
  { /* 8589 */
    0,
    /*  */
  },
  { /* 8590 */
    370,
    /* VSQRTSDr */
  },
  { /* 8591 */
    1032,
    /* VSQRTSSZm */
  },
  { /* 8592 */
    0,
    /*  */
  },
  { /* 8593 */
    1050,
    /* VSQRTSSZr */
  },
  { /* 8594 */
    0,
    /*  */
  },
  { /* 8595 */
    380,
    /* VSQRTSSm */
  },
  { /* 8596 */
    0,
    /*  */
  },
  { /* 8597 */
    381,
    /* VSQRTSSr */
  },
  { /* 8598 */
    38,
    /* VSTMXCSR */
  },
  { /* 8599 */
    302,
    /* VSUBPDYrm */
  },
  { /* 8600 */
    303,
    /* VSUBPDYrr */
  },
  { /* 8601 */
    304,
    /* VSUBPDZ128rm */
  },
  { /* 8602 */
    305,
    /* VSUBPDZ128rmb */
  },
  { /* 8603 */
    306,
    /* VSUBPDZ128rmbk */
  },
  { /* 8604 */
    307,
    /* VSUBPDZ128rmbkz */
  },
  { /* 8605 */
    308,
    /* VSUBPDZ128rmk */
  },
  { /* 8606 */
    309,
    /* VSUBPDZ128rmkz */
  },
  { /* 8607 */
    310,
    /* VSUBPDZ128rr */
  },
  { /* 8608 */
    311,
    /* VSUBPDZ128rrk */
  },
  { /* 8609 */
    312,
    /* VSUBPDZ128rrkz */
  },
  { /* 8610 */
    313,
    /* VSUBPDZ256rm */
  },
  { /* 8611 */
    314,
    /* VSUBPDZ256rmb */
  },
  { /* 8612 */
    315,
    /* VSUBPDZ256rmbk */
  },
  { /* 8613 */
    316,
    /* VSUBPDZ256rmbkz */
  },
  { /* 8614 */
    317,
    /* VSUBPDZ256rmk */
  },
  { /* 8615 */
    318,
    /* VSUBPDZ256rmkz */
  },
  { /* 8616 */
    319,
    /* VSUBPDZ256rr */
  },
  { /* 8617 */
    320,
    /* VSUBPDZ256rrk */
  },
  { /* 8618 */
    321,
    /* VSUBPDZ256rrkz */
  },
  { /* 8619 */
    322,
    /* VSUBPDZrb */
  },
  { /* 8620 */
    323,
    /* VSUBPDZrbk */
  },
  { /* 8621 */
    324,
    /* VSUBPDZrbkz */
  },
  { /* 8622 */
    325,
    /* VSUBPDZrm */
  },
  { /* 8623 */
    326,
    /* VSUBPDZrmb */
  },
  { /* 8624 */
    327,
    /* VSUBPDZrmbk */
  },
  { /* 8625 */
    328,
    /* VSUBPDZrmbkz */
  },
  { /* 8626 */
    329,
    /* VSUBPDZrmk */
  },
  { /* 8627 */
    330,
    /* VSUBPDZrmkz */
  },
  { /* 8628 */
    331,
    /* VSUBPDZrr */
  },
  { /* 8629 */
    332,
    /* VSUBPDZrrk */
  },
  { /* 8630 */
    333,
    /* VSUBPDZrrkz */
  },
  { /* 8631 */
    334,
    /* VSUBPDrm */
  },
  { /* 8632 */
    335,
    /* VSUBPDrr */
  },
  { /* 8633 */
    302,
    /* VSUBPSYrm */
  },
  { /* 8634 */
    303,
    /* VSUBPSYrr */
  },
  { /* 8635 */
    304,
    /* VSUBPSZ128rm */
  },
  { /* 8636 */
    336,
    /* VSUBPSZ128rmb */
  },
  { /* 8637 */
    337,
    /* VSUBPSZ128rmbk */
  },
  { /* 8638 */
    338,
    /* VSUBPSZ128rmbkz */
  },
  { /* 8639 */
    339,
    /* VSUBPSZ128rmk */
  },
  { /* 8640 */
    340,
    /* VSUBPSZ128rmkz */
  },
  { /* 8641 */
    310,
    /* VSUBPSZ128rr */
  },
  { /* 8642 */
    341,
    /* VSUBPSZ128rrk */
  },
  { /* 8643 */
    342,
    /* VSUBPSZ128rrkz */
  },
  { /* 8644 */
    313,
    /* VSUBPSZ256rm */
  },
  { /* 8645 */
    343,
    /* VSUBPSZ256rmb */
  },
  { /* 8646 */
    344,
    /* VSUBPSZ256rmbk */
  },
  { /* 8647 */
    345,
    /* VSUBPSZ256rmbkz */
  },
  { /* 8648 */
    346,
    /* VSUBPSZ256rmk */
  },
  { /* 8649 */
    347,
    /* VSUBPSZ256rmkz */
  },
  { /* 8650 */
    319,
    /* VSUBPSZ256rr */
  },
  { /* 8651 */
    348,
    /* VSUBPSZ256rrk */
  },
  { /* 8652 */
    349,
    /* VSUBPSZ256rrkz */
  },
  { /* 8653 */
    350,
    /* VSUBPSZrb */
  },
  { /* 8654 */
    351,
    /* VSUBPSZrbk */
  },
  { /* 8655 */
    352,
    /* VSUBPSZrbkz */
  },
  { /* 8656 */
    325,
    /* VSUBPSZrm */
  },
  { /* 8657 */
    353,
    /* VSUBPSZrmb */
  },
  { /* 8658 */
    354,
    /* VSUBPSZrmbk */
  },
  { /* 8659 */
    355,
    /* VSUBPSZrmbkz */
  },
  { /* 8660 */
    356,
    /* VSUBPSZrmk */
  },
  { /* 8661 */
    357,
    /* VSUBPSZrmkz */
  },
  { /* 8662 */
    331,
    /* VSUBPSZrr */
  },
  { /* 8663 */
    358,
    /* VSUBPSZrrk */
  },
  { /* 8664 */
    359,
    /* VSUBPSZrrkz */
  },
  { /* 8665 */
    334,
    /* VSUBPSrm */
  },
  { /* 8666 */
    335,
    /* VSUBPSrr */
  },
  { /* 8667 */
    0,
    /*  */
  },
  { /* 8668 */
    360,
    /* VSUBSDZrm_Int */
  },
  { /* 8669 */
    361,
    /* VSUBSDZrm_Intk */
  },
  { /* 8670 */
    362,
    /* VSUBSDZrm_Intkz */
  },
  { /* 8671 */
    0,
    /*  */
  },
  { /* 8672 */
    363,
    /* VSUBSDZrr_Int */
  },
  { /* 8673 */
    364,
    /* VSUBSDZrr_Intk */
  },
  { /* 8674 */
    365,
    /* VSUBSDZrr_Intkz */
  },
  { /* 8675 */
    366,
    /* VSUBSDZrrb */
  },
  { /* 8676 */
    367,
    /* VSUBSDZrrbk */
  },
  { /* 8677 */
    368,
    /* VSUBSDZrrbkz */
  },
  { /* 8678 */
    369,
    /* VSUBSDrm */
  },
  { /* 8679 */
    0,
    /*  */
  },
  { /* 8680 */
    370,
    /* VSUBSDrr */
  },
  { /* 8681 */
    0,
    /*  */
  },
  { /* 8682 */
    0,
    /*  */
  },
  { /* 8683 */
    371,
    /* VSUBSSZrm_Int */
  },
  { /* 8684 */
    372,
    /* VSUBSSZrm_Intk */
  },
  { /* 8685 */
    373,
    /* VSUBSSZrm_Intkz */
  },
  { /* 8686 */
    0,
    /*  */
  },
  { /* 8687 */
    374,
    /* VSUBSSZrr_Int */
  },
  { /* 8688 */
    375,
    /* VSUBSSZrr_Intk */
  },
  { /* 8689 */
    376,
    /* VSUBSSZrr_Intkz */
  },
  { /* 8690 */
    377,
    /* VSUBSSZrrb */
  },
  { /* 8691 */
    378,
    /* VSUBSSZrrbk */
  },
  { /* 8692 */
    379,
    /* VSUBSSZrrbkz */
  },
  { /* 8693 */
    380,
    /* VSUBSSrm */
  },
  { /* 8694 */
    0,
    /*  */
  },
  { /* 8695 */
    381,
    /* VSUBSSrr */
  },
  { /* 8696 */
    0,
    /*  */
  },
  { /* 8697 */
    475,
    /* VTESTPDYrm */
  },
  { /* 8698 */
    476,
    /* VTESTPDYrr */
  },
  { /* 8699 */
    44,
    /* VTESTPDrm */
  },
  { /* 8700 */
    45,
    /* VTESTPDrr */
  },
  { /* 8701 */
    475,
    /* VTESTPSYrm */
  },
  { /* 8702 */
    476,
    /* VTESTPSYrr */
  },
  { /* 8703 */
    44,
    /* VTESTPSrm */
  },
  { /* 8704 */
    45,
    /* VTESTPSrr */
  },
  { /* 8705 */
    712,
    /* VUCOMISDZrm */
  },
  { /* 8706 */
    1051,
    /* VUCOMISDZrr */
  },
  { /* 8707 */
    257,
    /* VUCOMISDrm */
  },
  { /* 8708 */
    301,
    /* VUCOMISDrr */
  },
  { /* 8709 */
    721,
    /* VUCOMISSZrm */
  },
  { /* 8710 */
    1052,
    /* VUCOMISSZrr */
  },
  { /* 8711 */
    261,
    /* VUCOMISSrm */
  },
  { /* 8712 */
    287,
    /* VUCOMISSrr */
  },
  { /* 8713 */
    302,
    /* VUNPCKHPDYrm */
  },
  { /* 8714 */
    303,
    /* VUNPCKHPDYrr */
  },
  { /* 8715 */
    325,
    /* VUNPCKHPDZrm */
  },
  { /* 8716 */
    331,
    /* VUNPCKHPDZrr */
  },
  { /* 8717 */
    334,
    /* VUNPCKHPDrm */
  },
  { /* 8718 */
    335,
    /* VUNPCKHPDrr */
  },
  { /* 8719 */
    302,
    /* VUNPCKHPSYrm */
  },
  { /* 8720 */
    303,
    /* VUNPCKHPSYrr */
  },
  { /* 8721 */
    325,
    /* VUNPCKHPSZrm */
  },
  { /* 8722 */
    331,
    /* VUNPCKHPSZrr */
  },
  { /* 8723 */
    334,
    /* VUNPCKHPSrm */
  },
  { /* 8724 */
    335,
    /* VUNPCKHPSrr */
  },
  { /* 8725 */
    302,
    /* VUNPCKLPDYrm */
  },
  { /* 8726 */
    303,
    /* VUNPCKLPDYrr */
  },
  { /* 8727 */
    325,
    /* VUNPCKLPDZrm */
  },
  { /* 8728 */
    331,
    /* VUNPCKLPDZrr */
  },
  { /* 8729 */
    334,
    /* VUNPCKLPDrm */
  },
  { /* 8730 */
    335,
    /* VUNPCKLPDrr */
  },
  { /* 8731 */
    302,
    /* VUNPCKLPSYrm */
  },
  { /* 8732 */
    303,
    /* VUNPCKLPSYrr */
  },
  { /* 8733 */
    325,
    /* VUNPCKLPSZrm */
  },
  { /* 8734 */
    331,
    /* VUNPCKLPSZrr */
  },
  { /* 8735 */
    334,
    /* VUNPCKLPSrm */
  },
  { /* 8736 */
    335,
    /* VUNPCKLPSrr */
  },
  { /* 8737 */
    302,
    /* VXORPDYrm */
  },
  { /* 8738 */
    303,
    /* VXORPDYrr */
  },
  { /* 8739 */
    334,
    /* VXORPDrm */
  },
  { /* 8740 */
    335,
    /* VXORPDrr */
  },
  { /* 8741 */
    302,
    /* VXORPSYrm */
  },
  { /* 8742 */
    303,
    /* VXORPSYrr */
  },
  { /* 8743 */
    334,
    /* VXORPSrm */
  },
  { /* 8744 */
    335,
    /* VXORPSrr */
  },
  { /* 8745 */
    0,
    /* VZEROALL */
  },
  { /* 8746 */
    0,
    /* VZEROUPPER */
  },
  { /* 8747 */
    0,
    /*  */
  },
  { /* 8748 */
    0,
    /*  */
  },
  { /* 8749 */
    0,
    /* WAIT */
  },
  { /* 8750 */
    0,
    /* WBINVD */
  },
  { /* 8751 */
    0,
    /*  */
  },
  { /* 8752 */
    0,
    /*  */
  },
  { /* 8753 */
    0,
    /*  */
  },
  { /* 8754 */
    288,
    /* WRFSBASE */
  },
  { /* 8755 */
    79,
    /* WRFSBASE64 */
  },
  { /* 8756 */
    288,
    /* WRGSBASE */
  },
  { /* 8757 */
    79,
    /* WRGSBASE64 */
  },
  { /* 8758 */
    0,
    /* WRMSR */
  },
  { /* 8759 */
    1,
    /* XABORT */
  },
  { /* 8760 */
    0,
    /*  */
  },
  { /* 8761 */
    5,
    /* XADD16rm */
  },
  { /* 8762 */
    73,
    /* XADD16rr */
  },
  { /* 8763 */
    5,
    /* XADD32rm */
  },
  { /* 8764 */
    73,
    /* XADD32rr */
  },
  { /* 8765 */
    16,
    /* XADD64rm */
  },
  { /* 8766 */
    76,
    /* XADD64rr */
  },
  { /* 8767 */
    23,
    /* XADD8rm */
  },
  { /* 8768 */
    87,
    /* XADD8rr */
  },
  { /* 8769 */
    0,
    /*  */
  },
  { /* 8770 */
    157,
    /* XBEGIN_2 */
  },
  { /* 8771 */
    157,
    /* XBEGIN_4 */
  },
  { /* 8772 */
    278,
    /* XCHG16ar */
  },
  { /* 8773 */
    8,
    /* XCHG16rm */
  },
  { /* 8774 */
    10,
    /* XCHG16rr */
  },
  { /* 8775 */
    278,
    /* XCHG32ar */
  },
  { /* 8776 */
    278,
    /* XCHG32ar64 */
  },
  { /* 8777 */
    8,
    /* XCHG32rm */
  },
  { /* 8778 */
    10,
    /* XCHG32rr */
  },
  { /* 8779 */
    279,
    /* XCHG64ar */
  },
  { /* 8780 */
    19,
    /* XCHG64rm */
  },
  { /* 8781 */
    21,
    /* XCHG64rr */
  },
  { /* 8782 */
    25,
    /* XCHG8rm */
  },
  { /* 8783 */
    27,
    /* XCHG8rr */
  },
  { /* 8784 */
    39,
    /* XCH_F */
  },
  { /* 8785 */
    0,
    /* XCRYPTCBC */
  },
  { /* 8786 */
    0,
    /* XCRYPTCFB */
  },
  { /* 8787 */
    0,
    /* XCRYPTCTR */
  },
  { /* 8788 */
    0,
    /* XCRYPTECB */
  },
  { /* 8789 */
    0,
    /* XCRYPTOFB */
  },
  { /* 8790 */
    0,
    /* XEND */
  },
  { /* 8791 */
    0,
    /* XGETBV */
  },
  { /* 8792 */
    0,
    /* XLAT */
  },
  { /* 8793 */
    2,
    /* XOR16i16 */
  },
  { /* 8794 */
    3,
    /* XOR16mi */
  },
  { /* 8795 */
    4,
    /* XOR16mi8 */
  },
  { /* 8796 */
    5,
    /* XOR16mr */
  },
  { /* 8797 */
    6,
    /* XOR16ri */
  },
  { /* 8798 */
    7,
    /* XOR16ri8 */
  },
  { /* 8799 */
    8,
    /* XOR16rm */
  },
  { /* 8800 */
    9,
    /* XOR16rr */
  },
  { /* 8801 */
    10,
    /* XOR16rr_REV */
  },
  { /* 8802 */
    2,
    /* XOR32i32 */
  },
  { /* 8803 */
    3,
    /* XOR32mi */
  },
  { /* 8804 */
    11,
    /* XOR32mi8 */
  },
  { /* 8805 */
    5,
    /* XOR32mr */
  },
  { /* 8806 */
    6,
    /* XOR32ri */
  },
  { /* 8807 */
    12,
    /* XOR32ri8 */
  },
  { /* 8808 */
    8,
    /* XOR32rm */
  },
  { /* 8809 */
    9,
    /* XOR32rr */
  },
  { /* 8810 */
    10,
    /* XOR32rr_REV */
  },
  { /* 8811 */
    13,
    /* XOR64i32 */
  },
  { /* 8812 */
    14,
    /* XOR64mi32 */
  },
  { /* 8813 */
    15,
    /* XOR64mi8 */
  },
  { /* 8814 */
    16,
    /* XOR64mr */
  },
  { /* 8815 */
    17,
    /* XOR64ri32 */
  },
  { /* 8816 */
    18,
    /* XOR64ri8 */
  },
  { /* 8817 */
    19,
    /* XOR64rm */
  },
  { /* 8818 */
    20,
    /* XOR64rr */
  },
  { /* 8819 */
    21,
    /* XOR64rr_REV */
  },
  { /* 8820 */
    1,
    /* XOR8i8 */
  },
  { /* 8821 */
    22,
    /* XOR8mi */
  },
  { /* 8822 */
    22,
    /* XOR8mi8 */
  },
  { /* 8823 */
    23,
    /* XOR8mr */
  },
  { /* 8824 */
    24,
    /* XOR8ri */
  },
  { /* 8825 */
    24,
    /* XOR8ri8 */
  },
  { /* 8826 */
    25,
    /* XOR8rm */
  },
  { /* 8827 */
    26,
    /* XOR8rr */
  },
  { /* 8828 */
    27,
    /* XOR8rr_REV */
  },
  { /* 8829 */
    30,
    /* XORPDrm */
  },
  { /* 8830 */
    31,
    /* XORPDrr */
  },
  { /* 8831 */
    30,
    /* XORPSrm */
  },
  { /* 8832 */
    31,
    /* XORPSrr */
  },
  { /* 8833 */
    0,
    /*  */
  },
  { /* 8834 */
    140,
    /* XRSTOR */
  },
  { /* 8835 */
    140,
    /* XRSTOR64 */
  },
  { /* 8836 */
    140,
    /* XRSTORS */
  },
  { /* 8837 */
    140,
    /* XRSTORS64 */
  },
  { /* 8838 */
    140,
    /* XSAVE */
  },
  { /* 8839 */
    140,
    /* XSAVE64 */
  },
  { /* 8840 */
    140,
    /* XSAVEC */
  },
  { /* 8841 */
    140,
    /* XSAVEC64 */
  },
  { /* 8842 */
    140,
    /* XSAVEOPT */
  },
  { /* 8843 */
    140,
    /* XSAVEOPT64 */
  },
  { /* 8844 */
    140,
    /* XSAVES */
  },
  { /* 8845 */
    140,
    /* XSAVES64 */
  },
  { /* 8846 */
    0,
    /* XSETBV */
  },
  { /* 8847 */
    0,
    /* XSHA1 */
  },
  { /* 8848 */
    0,
    /* XSHA256 */
  },
  { /* 8849 */
    0,
    /* XSTORE */
  },
  { /* 8850 */
    0,
    /* XTEST */
  },
  { /* 8851 */
    0,
    /* fdisi8087_nop */
  },
  { /* 8852 */
    0,
    /* feni8087_nop */
  }
};

static const uint8_t x86DisassemblerContexts[16384] = {
  IC, /* 0 */
  IC_64BIT, /* 1 */
  IC_XS, /* 2 */
  IC_64BIT_XS, /* 3 */
  IC_XD, /* 4 */
  IC_64BIT_XD, /* 5 */
  IC_XS, /* 6 */
  IC_64BIT_XS, /* 7 */
  IC, /* 8 */
  IC_64BIT_REXW, /* 9 */
  IC_XS, /* 10 */
  IC_64BIT_REXW_XS, /* 11 */
  IC_XD, /* 12 */
  IC_64BIT_REXW_XD, /* 13 */
  IC_XS, /* 14 */
  IC_64BIT_REXW_XS, /* 15 */
  IC_OPSIZE, /* 16 */
  IC_64BIT_OPSIZE, /* 17 */
  IC_XS_OPSIZE, /* 18 */
  IC_64BIT_XS_OPSIZE, /* 19 */
  IC_XD_OPSIZE, /* 20 */
  IC_64BIT_XD_OPSIZE, /* 21 */
  IC_XS_OPSIZE, /* 22 */
  IC_64BIT_XD_OPSIZE, /* 23 */
  IC_OPSIZE, /* 24 */
  IC_64BIT_REXW_OPSIZE, /* 25 */
  IC_XS_OPSIZE, /* 26 */
  IC_64BIT_REXW_XS, /* 27 */
  IC_XD_OPSIZE, /* 28 */
  IC_64BIT_REXW_XD, /* 29 */
  IC_XS_OPSIZE, /* 30 */
  IC_64BIT_REXW_XS, /* 31 */
  IC_ADSIZE, /* 32 */
  IC_64BIT_ADSIZE, /* 33 */
  IC_XS, /* 34 */
  IC_64BIT_XS, /* 35 */
  IC_XD, /* 36 */
  IC_64BIT_XD, /* 37 */
  IC_XS, /* 38 */
  IC_64BIT_XS, /* 39 */
  IC_ADSIZE, /* 40 */
  IC_64BIT_REXW_ADSIZE, /* 41 */
  IC_XS, /* 42 */
  IC_64BIT_REXW_XS, /* 43 */
  IC_XD, /* 44 */
  IC_64BIT_REXW_XD, /* 45 */
  IC_XS, /* 46 */
  IC_64BIT_REXW_XS, /* 47 */
  IC_OPSIZE_ADSIZE, /* 48 */
  IC_64BIT_OPSIZE_ADSIZE, /* 49 */
  IC_XS_OPSIZE, /* 50 */
  IC_64BIT_XS_OPSIZE, /* 51 */
  IC_XD_OPSIZE, /* 52 */
  IC_64BIT_XD_OPSIZE, /* 53 */
  IC_XS_OPSIZE, /* 54 */
  IC_64BIT_XD_OPSIZE, /* 55 */
  IC_OPSIZE_ADSIZE, /* 56 */
  IC_64BIT_REXW_OPSIZE, /* 57 */
  IC_XS_OPSIZE, /* 58 */
  IC_64BIT_REXW_XS, /* 59 */
  IC_XD_OPSIZE, /* 60 */
  IC_64BIT_REXW_XD, /* 61 */
  IC_XS_OPSIZE, /* 62 */
  IC_64BIT_REXW_XS, /* 63 */
  IC_VEX, /* 64 */
  IC_VEX, /* 65 */
  IC_VEX_XS, /* 66 */
  IC_VEX_XS, /* 67 */
  IC_VEX_XD, /* 68 */
  IC_VEX_XD, /* 69 */
  IC_VEX_XD, /* 70 */
  IC_VEX_XD, /* 71 */
  IC_VEX_W, /* 72 */
  IC_VEX_W, /* 73 */
  IC_VEX_W_XS, /* 74 */
  IC_VEX_W_XS, /* 75 */
  IC_VEX_W_XD, /* 76 */
  IC_VEX_W_XD, /* 77 */
  IC_VEX_W_XD, /* 78 */
  IC_VEX_W_XD, /* 79 */
  IC_VEX_OPSIZE, /* 80 */
  IC_VEX_OPSIZE, /* 81 */
  IC_VEX_OPSIZE, /* 82 */
  IC_VEX_OPSIZE, /* 83 */
  IC_VEX_OPSIZE, /* 84 */
  IC_VEX_OPSIZE, /* 85 */
  IC_VEX_OPSIZE, /* 86 */
  IC_VEX_OPSIZE, /* 87 */
  IC_VEX_W_OPSIZE, /* 88 */
  IC_VEX_W_OPSIZE, /* 89 */
  IC_VEX_W_OPSIZE, /* 90 */
  IC_VEX_W_OPSIZE, /* 91 */
  IC_VEX_W_OPSIZE, /* 92 */
  IC_VEX_W_OPSIZE, /* 93 */
  IC_VEX_W_OPSIZE, /* 94 */
  IC_VEX_W_OPSIZE, /* 95 */
  IC_VEX, /* 96 */
  IC_VEX, /* 97 */
  IC_VEX_XS, /* 98 */
  IC_VEX_XS, /* 99 */
  IC_VEX_XD, /* 100 */
  IC_VEX_XD, /* 101 */
  IC_VEX_XD, /* 102 */
  IC_VEX_XD, /* 103 */
  IC_VEX_W, /* 104 */
  IC_VEX_W, /* 105 */
  IC_VEX_W_XS, /* 106 */
  IC_VEX_W_XS, /* 107 */
  IC_VEX_W_XD, /* 108 */
  IC_VEX_W_XD, /* 109 */
  IC_VEX_W_XD, /* 110 */
  IC_VEX_W_XD, /* 111 */
  IC_VEX_OPSIZE, /* 112 */
  IC_VEX_OPSIZE, /* 113 */
  IC_VEX_OPSIZE, /* 114 */
  IC_VEX_OPSIZE, /* 115 */
  IC_VEX_OPSIZE, /* 116 */
  IC_VEX_OPSIZE, /* 117 */
  IC_VEX_OPSIZE, /* 118 */
  IC_VEX_OPSIZE, /* 119 */
  IC_VEX_W_OPSIZE, /* 120 */
  IC_VEX_W_OPSIZE, /* 121 */
  IC_VEX_W_OPSIZE, /* 122 */
  IC_VEX_W_OPSIZE, /* 123 */
  IC_VEX_W_OPSIZE, /* 124 */
  IC_VEX_W_OPSIZE, /* 125 */
  IC_VEX_W_OPSIZE, /* 126 */
  IC_VEX_W_OPSIZE, /* 127 */
  IC_VEX_L, /* 128 */
  IC_VEX_L, /* 129 */
  IC_VEX_L_XS, /* 130 */
  IC_VEX_L_XS, /* 131 */
  IC_VEX_L_XD, /* 132 */
  IC_VEX_L_XD, /* 133 */
  IC_VEX_L_XD, /* 134 */
  IC_VEX_L_XD, /* 135 */
  IC_VEX_L_W, /* 136 */
  IC_VEX_L_W, /* 137 */
  IC_VEX_L_W_XS, /* 138 */
  IC_VEX_L_W_XS, /* 139 */
  IC_VEX_L_W_XD, /* 140 */
  IC_VEX_L_W_XD, /* 141 */
  IC_VEX_L_W_XD, /* 142 */
  IC_VEX_L_W_XD, /* 143 */
  IC_VEX_L_OPSIZE, /* 144 */
  IC_VEX_L_OPSIZE, /* 145 */
  IC_VEX_L_OPSIZE, /* 146 */
  IC_VEX_L_OPSIZE, /* 147 */
  IC_VEX_L_OPSIZE, /* 148 */
  IC_VEX_L_OPSIZE, /* 149 */
  IC_VEX_L_OPSIZE, /* 150 */
  IC_VEX_L_OPSIZE, /* 151 */
  IC_VEX_L_W_OPSIZE, /* 152 */
  IC_VEX_L_W_OPSIZE, /* 153 */
  IC_VEX_L_W_OPSIZE, /* 154 */
  IC_VEX_L_W_OPSIZE, /* 155 */
  IC_VEX_L_W_OPSIZE, /* 156 */
  IC_VEX_L_W_OPSIZE, /* 157 */
  IC_VEX_L_W_OPSIZE, /* 158 */
  IC_VEX_L_W_OPSIZE, /* 159 */
  IC_VEX_L, /* 160 */
  IC_VEX_L, /* 161 */
  IC_VEX_L_XS, /* 162 */
  IC_VEX_L_XS, /* 163 */
  IC_VEX_L_XD, /* 164 */
  IC_VEX_L_XD, /* 165 */
  IC_VEX_L_XD, /* 166 */
  IC_VEX_L_XD, /* 167 */
  IC_VEX_L_W, /* 168 */
  IC_VEX_L_W, /* 169 */
  IC_VEX_L_W_XS, /* 170 */
  IC_VEX_L_W_XS, /* 171 */
  IC_VEX_L_W_XD, /* 172 */
  IC_VEX_L_W_XD, /* 173 */
  IC_VEX_L_W_XD, /* 174 */
  IC_VEX_L_W_XD, /* 175 */
  IC_VEX_L_OPSIZE, /* 176 */
  IC_VEX_L_OPSIZE, /* 177 */
  IC_VEX_L_OPSIZE, /* 178 */
  IC_VEX_L_OPSIZE, /* 179 */
  IC_VEX_L_OPSIZE, /* 180 */
  IC_VEX_L_OPSIZE, /* 181 */
  IC_VEX_L_OPSIZE, /* 182 */
  IC_VEX_L_OPSIZE, /* 183 */
  IC_VEX_L_W_OPSIZE, /* 184 */
  IC_VEX_L_W_OPSIZE, /* 185 */
  IC_VEX_L_W_OPSIZE, /* 186 */
  IC_VEX_L_W_OPSIZE, /* 187 */
  IC_VEX_L_W_OPSIZE, /* 188 */
  IC_VEX_L_W_OPSIZE, /* 189 */
  IC_VEX_L_W_OPSIZE, /* 190 */
  IC_VEX_L_W_OPSIZE, /* 191 */
  IC_VEX_L, /* 192 */
  IC_VEX_L, /* 193 */
  IC_VEX_L_XS, /* 194 */
  IC_VEX_L_XS, /* 195 */
  IC_VEX_L_XD, /* 196 */
  IC_VEX_L_XD, /* 197 */
  IC_VEX_L_XD, /* 198 */
  IC_VEX_L_XD, /* 199 */
  IC_VEX_L_W, /* 200 */
  IC_VEX_L_W, /* 201 */
  IC_VEX_L_W_XS, /* 202 */
  IC_VEX_L_W_XS, /* 203 */
  IC_VEX_L_W_XD, /* 204 */
  IC_VEX_L_W_XD, /* 205 */
  IC_VEX_L_W_XD, /* 206 */
  IC_VEX_L_W_XD, /* 207 */
  IC_VEX_L_OPSIZE, /* 208 */
  IC_VEX_L_OPSIZE, /* 209 */
  IC_VEX_L_OPSIZE, /* 210 */
  IC_VEX_L_OPSIZE, /* 211 */
  IC_VEX_L_OPSIZE, /* 212 */
  IC_VEX_L_OPSIZE, /* 213 */
  IC_VEX_L_OPSIZE, /* 214 */
  IC_VEX_L_OPSIZE, /* 215 */
  IC_VEX_L_W_OPSIZE, /* 216 */
  IC_VEX_L_W_OPSIZE, /* 217 */
  IC_VEX_L_W_OPSIZE, /* 218 */
  IC_VEX_L_W_OPSIZE, /* 219 */
  IC_VEX_L_W_OPSIZE, /* 220 */
  IC_VEX_L_W_OPSIZE, /* 221 */
  IC_VEX_L_W_OPSIZE, /* 222 */
  IC_VEX_L_W_OPSIZE, /* 223 */
  IC_VEX_L, /* 224 */
  IC_VEX_L, /* 225 */
  IC_VEX_L_XS, /* 226 */
  IC_VEX_L_XS, /* 227 */
  IC_VEX_L_XD, /* 228 */
  IC_VEX_L_XD, /* 229 */
  IC_VEX_L_XD, /* 230 */
  IC_VEX_L_XD, /* 231 */
  IC_VEX_L_W, /* 232 */
  IC_VEX_L_W, /* 233 */
  IC_VEX_L_W_XS, /* 234 */
  IC_VEX_L_W_XS, /* 235 */
  IC_VEX_L_W_XD, /* 236 */
  IC_VEX_L_W_XD, /* 237 */
  IC_VEX_L_W_XD, /* 238 */
  IC_VEX_L_W_XD, /* 239 */
  IC_VEX_L_OPSIZE, /* 240 */
  IC_VEX_L_OPSIZE, /* 241 */
  IC_VEX_L_OPSIZE, /* 242 */
  IC_VEX_L_OPSIZE, /* 243 */
  IC_VEX_L_OPSIZE, /* 244 */
  IC_VEX_L_OPSIZE, /* 245 */
  IC_VEX_L_OPSIZE, /* 246 */
  IC_VEX_L_OPSIZE, /* 247 */
  IC_VEX_L_W_OPSIZE, /* 248 */
  IC_VEX_L_W_OPSIZE, /* 249 */
  IC_VEX_L_W_OPSIZE, /* 250 */
  IC_VEX_L_W_OPSIZE, /* 251 */
  IC_VEX_L_W_OPSIZE, /* 252 */
  IC_VEX_L_W_OPSIZE, /* 253 */
  IC_VEX_L_W_OPSIZE, /* 254 */
  IC_VEX_L_W_OPSIZE, /* 255 */
  IC_EVEX, /* 256 */
  IC_EVEX, /* 257 */
  IC_EVEX_XS, /* 258 */
  IC_EVEX_XS, /* 259 */
  IC_EVEX_XD, /* 260 */
  IC_EVEX_XD, /* 261 */
  IC_EVEX_XD, /* 262 */
  IC_EVEX_XD, /* 263 */
  IC_EVEX_W, /* 264 */
  IC_EVEX_W, /* 265 */
  IC_EVEX_W_XS, /* 266 */
  IC_EVEX_W_XS, /* 267 */
  IC_EVEX_W_XD, /* 268 */
  IC_EVEX_W_XD, /* 269 */
  IC_EVEX_W_XD, /* 270 */
  IC_EVEX_W_XD, /* 271 */
  IC_EVEX_OPSIZE, /* 272 */
  IC_EVEX_OPSIZE, /* 273 */
  IC_EVEX_OPSIZE, /* 274 */
  IC_EVEX_OPSIZE, /* 275 */
  IC_EVEX_OPSIZE, /* 276 */
  IC_EVEX_OPSIZE, /* 277 */
  IC_EVEX_OPSIZE, /* 278 */
  IC_EVEX_OPSIZE, /* 279 */
  IC_EVEX_W_OPSIZE, /* 280 */
  IC_EVEX_W_OPSIZE, /* 281 */
  IC_EVEX_W_OPSIZE, /* 282 */
  IC_EVEX_W_OPSIZE, /* 283 */
  IC_EVEX_W_OPSIZE, /* 284 */
  IC_EVEX_W_OPSIZE, /* 285 */
  IC_EVEX_W_OPSIZE, /* 286 */
  IC_EVEX_W_OPSIZE, /* 287 */
  IC_EVEX, /* 288 */
  IC_EVEX, /* 289 */
  IC_EVEX_XS, /* 290 */
  IC_EVEX_XS, /* 291 */
  IC_EVEX_XD, /* 292 */
  IC_EVEX_XD, /* 293 */
  IC_EVEX_XD, /* 294 */
  IC_EVEX_XD, /* 295 */
  IC_EVEX_W, /* 296 */
  IC_EVEX_W, /* 297 */
  IC_EVEX_W_XS, /* 298 */
  IC_EVEX_W_XS, /* 299 */
  IC_EVEX_W_XD, /* 300 */
  IC_EVEX_W_XD, /* 301 */
  IC_EVEX_W_XD, /* 302 */
  IC_EVEX_W_XD, /* 303 */
  IC_EVEX_OPSIZE, /* 304 */
  IC_EVEX_OPSIZE, /* 305 */
  IC_EVEX_OPSIZE, /* 306 */
  IC_EVEX_OPSIZE, /* 307 */
  IC_EVEX_OPSIZE, /* 308 */
  IC_EVEX_OPSIZE, /* 309 */
  IC_EVEX_OPSIZE, /* 310 */
  IC_EVEX_OPSIZE, /* 311 */
  IC_EVEX_W_OPSIZE, /* 312 */
  IC_EVEX_W_OPSIZE, /* 313 */
  IC_EVEX_W_OPSIZE, /* 314 */
  IC_EVEX_W_OPSIZE, /* 315 */
  IC_EVEX_W_OPSIZE, /* 316 */
  IC_EVEX_W_OPSIZE, /* 317 */
  IC_EVEX_W_OPSIZE, /* 318 */
  IC_EVEX_W_OPSIZE, /* 319 */
  IC_EVEX, /* 320 */
  IC_EVEX, /* 321 */
  IC_EVEX_XS, /* 322 */
  IC_EVEX_XS, /* 323 */
  IC_EVEX_XD, /* 324 */
  IC_EVEX_XD, /* 325 */
  IC_EVEX_XD, /* 326 */
  IC_EVEX_XD, /* 327 */
  IC_EVEX_W, /* 328 */
  IC_EVEX_W, /* 329 */
  IC_EVEX_W_XS, /* 330 */
  IC_EVEX_W_XS, /* 331 */
  IC_EVEX_W_XD, /* 332 */
  IC_EVEX_W_XD, /* 333 */
  IC_EVEX_W_XD, /* 334 */
  IC_EVEX_W_XD, /* 335 */
  IC_EVEX_OPSIZE, /* 336 */
  IC_EVEX_OPSIZE, /* 337 */
  IC_EVEX_OPSIZE, /* 338 */
  IC_EVEX_OPSIZE, /* 339 */
  IC_EVEX_OPSIZE, /* 340 */
  IC_EVEX_OPSIZE, /* 341 */
  IC_EVEX_OPSIZE, /* 342 */
  IC_EVEX_OPSIZE, /* 343 */
  IC_EVEX_W_OPSIZE, /* 344 */
  IC_EVEX_W_OPSIZE, /* 345 */
  IC_EVEX_W_OPSIZE, /* 346 */
  IC_EVEX_W_OPSIZE, /* 347 */
  IC_EVEX_W_OPSIZE, /* 348 */
  IC_EVEX_W_OPSIZE, /* 349 */
  IC_EVEX_W_OPSIZE, /* 350 */
  IC_EVEX_W_OPSIZE, /* 351 */
  IC_EVEX, /* 352 */
  IC_EVEX, /* 353 */
  IC_EVEX_XS, /* 354 */
  IC_EVEX_XS, /* 355 */
  IC_EVEX_XD, /* 356 */
  IC_EVEX_XD, /* 357 */
  IC_EVEX_XD, /* 358 */
  IC_EVEX_XD, /* 359 */
  IC_EVEX_W, /* 360 */
  IC_EVEX_W, /* 361 */
  IC_EVEX_W_XS, /* 362 */
  IC_EVEX_W_XS, /* 363 */
  IC_EVEX_W_XD, /* 364 */
  IC_EVEX_W_XD, /* 365 */
  IC_EVEX_W_XD, /* 366 */
  IC_EVEX_W_XD, /* 367 */
  IC_EVEX_OPSIZE, /* 368 */
  IC_EVEX_OPSIZE, /* 369 */
  IC_EVEX_OPSIZE, /* 370 */
  IC_EVEX_OPSIZE, /* 371 */
  IC_EVEX_OPSIZE, /* 372 */
  IC_EVEX_OPSIZE, /* 373 */
  IC_EVEX_OPSIZE, /* 374 */
  IC_EVEX_OPSIZE, /* 375 */
  IC_EVEX_W_OPSIZE, /* 376 */
  IC_EVEX_W_OPSIZE, /* 377 */
  IC_EVEX_W_OPSIZE, /* 378 */
  IC_EVEX_W_OPSIZE, /* 379 */
  IC_EVEX_W_OPSIZE, /* 380 */
  IC_EVEX_W_OPSIZE, /* 381 */
  IC_EVEX_W_OPSIZE, /* 382 */
  IC_EVEX_W_OPSIZE, /* 383 */
  IC_EVEX, /* 384 */
  IC_EVEX, /* 385 */
  IC_EVEX_XS, /* 386 */
  IC_EVEX_XS, /* 387 */
  IC_EVEX_XD, /* 388 */
  IC_EVEX_XD, /* 389 */
  IC_EVEX_XD, /* 390 */
  IC_EVEX_XD, /* 391 */
  IC_EVEX_W, /* 392 */
  IC_EVEX_W, /* 393 */
  IC_EVEX_W_XS, /* 394 */
  IC_EVEX_W_XS, /* 395 */
  IC_EVEX_W_XD, /* 396 */
  IC_EVEX_W_XD, /* 397 */
  IC_EVEX_W_XD, /* 398 */
  IC_EVEX_W_XD, /* 399 */
  IC_EVEX_OPSIZE, /* 400 */
  IC_EVEX_OPSIZE, /* 401 */
  IC_EVEX_OPSIZE, /* 402 */
  IC_EVEX_OPSIZE, /* 403 */
  IC_EVEX_OPSIZE, /* 404 */
  IC_EVEX_OPSIZE, /* 405 */
  IC_EVEX_OPSIZE, /* 406 */
  IC_EVEX_OPSIZE, /* 407 */
  IC_EVEX_W_OPSIZE, /* 408 */
  IC_EVEX_W_OPSIZE, /* 409 */
  IC_EVEX_W_OPSIZE, /* 410 */
  IC_EVEX_W_OPSIZE, /* 411 */
  IC_EVEX_W_OPSIZE, /* 412 */
  IC_EVEX_W_OPSIZE, /* 413 */
  IC_EVEX_W_OPSIZE, /* 414 */
  IC_EVEX_W_OPSIZE, /* 415 */
  IC_EVEX, /* 416 */
  IC_EVEX, /* 417 */
  IC_EVEX_XS, /* 418 */
  IC_EVEX_XS, /* 419 */
  IC_EVEX_XD, /* 420 */
  IC_EVEX_XD, /* 421 */
  IC_EVEX_XD, /* 422 */
  IC_EVEX_XD, /* 423 */
  IC_EVEX_W, /* 424 */
  IC_EVEX_W, /* 425 */
  IC_EVEX_W_XS, /* 426 */
  IC_EVEX_W_XS, /* 427 */
  IC_EVEX_W_XD, /* 428 */
  IC_EVEX_W_XD, /* 429 */
  IC_EVEX_W_XD, /* 430 */
  IC_EVEX_W_XD, /* 431 */
  IC_EVEX_OPSIZE, /* 432 */
  IC_EVEX_OPSIZE, /* 433 */
  IC_EVEX_OPSIZE, /* 434 */
  IC_EVEX_OPSIZE, /* 435 */
  IC_EVEX_OPSIZE, /* 436 */
  IC_EVEX_OPSIZE, /* 437 */
  IC_EVEX_OPSIZE, /* 438 */
  IC_EVEX_OPSIZE, /* 439 */
  IC_EVEX_W_OPSIZE, /* 440 */
  IC_EVEX_W_OPSIZE, /* 441 */
  IC_EVEX_W_OPSIZE, /* 442 */
  IC_EVEX_W_OPSIZE, /* 443 */
  IC_EVEX_W_OPSIZE, /* 444 */
  IC_EVEX_W_OPSIZE, /* 445 */
  IC_EVEX_W_OPSIZE, /* 446 */
  IC_EVEX_W_OPSIZE, /* 447 */
  IC_EVEX, /* 448 */
  IC_EVEX, /* 449 */
  IC_EVEX_XS, /* 450 */
  IC_EVEX_XS, /* 451 */
  IC_EVEX_XD, /* 452 */
  IC_EVEX_XD, /* 453 */
  IC_EVEX_XD, /* 454 */
  IC_EVEX_XD, /* 455 */
  IC_EVEX_W, /* 456 */
  IC_EVEX_W, /* 457 */
  IC_EVEX_W_XS, /* 458 */
  IC_EVEX_W_XS, /* 459 */
  IC_EVEX_W_XD, /* 460 */
  IC_EVEX_W_XD, /* 461 */
  IC_EVEX_W_XD, /* 462 */
  IC_EVEX_W_XD, /* 463 */
  IC_EVEX_OPSIZE, /* 464 */
  IC_EVEX_OPSIZE, /* 465 */
  IC_EVEX_OPSIZE, /* 466 */
  IC_EVEX_OPSIZE, /* 467 */
  IC_EVEX_OPSIZE, /* 468 */
  IC_EVEX_OPSIZE, /* 469 */
  IC_EVEX_OPSIZE, /* 470 */
  IC_EVEX_OPSIZE, /* 471 */
  IC_EVEX_W_OPSIZE, /* 472 */
  IC_EVEX_W_OPSIZE, /* 473 */
  IC_EVEX_W_OPSIZE, /* 474 */
  IC_EVEX_W_OPSIZE, /* 475 */
  IC_EVEX_W_OPSIZE, /* 476 */
  IC_EVEX_W_OPSIZE, /* 477 */
  IC_EVEX_W_OPSIZE, /* 478 */
  IC_EVEX_W_OPSIZE, /* 479 */
  IC_EVEX, /* 480 */
  IC_EVEX, /* 481 */
  IC_EVEX_XS, /* 482 */
  IC_EVEX_XS, /* 483 */
  IC_EVEX_XD, /* 484 */
  IC_EVEX_XD, /* 485 */
  IC_EVEX_XD, /* 486 */
  IC_EVEX_XD, /* 487 */
  IC_EVEX_W, /* 488 */
  IC_EVEX_W, /* 489 */
  IC_EVEX_W_XS, /* 490 */
  IC_EVEX_W_XS, /* 491 */
  IC_EVEX_W_XD, /* 492 */
  IC_EVEX_W_XD, /* 493 */
  IC_EVEX_W_XD, /* 494 */
  IC_EVEX_W_XD, /* 495 */
  IC_EVEX_OPSIZE, /* 496 */
  IC_EVEX_OPSIZE, /* 497 */
  IC_EVEX_OPSIZE, /* 498 */
  IC_EVEX_OPSIZE, /* 499 */
  IC_EVEX_OPSIZE, /* 500 */
  IC_EVEX_OPSIZE, /* 501 */
  IC_EVEX_OPSIZE, /* 502 */
  IC_EVEX_OPSIZE, /* 503 */
  IC_EVEX_W_OPSIZE, /* 504 */
  IC_EVEX_W_OPSIZE, /* 505 */
  IC_EVEX_W_OPSIZE, /* 506 */
  IC_EVEX_W_OPSIZE, /* 507 */
  IC_EVEX_W_OPSIZE, /* 508 */
  IC_EVEX_W_OPSIZE, /* 509 */
  IC_EVEX_W_OPSIZE, /* 510 */
  IC_EVEX_W_OPSIZE, /* 511 */
  IC, /* 512 */
  IC_64BIT, /* 513 */
  IC_XS, /* 514 */
  IC_64BIT_XS, /* 515 */
  IC_XD, /* 516 */
  IC_64BIT_XD, /* 517 */
  IC_XS, /* 518 */
  IC_64BIT_XS, /* 519 */
  IC, /* 520 */
  IC_64BIT_REXW, /* 521 */
  IC_XS, /* 522 */
  IC_64BIT_REXW_XS, /* 523 */
  IC_XD, /* 524 */
  IC_64BIT_REXW_XD, /* 525 */
  IC_XS, /* 526 */
  IC_64BIT_REXW_XS, /* 527 */
  IC_OPSIZE, /* 528 */
  IC_64BIT_OPSIZE, /* 529 */
  IC_XS_OPSIZE, /* 530 */
  IC_64BIT_XS_OPSIZE, /* 531 */
  IC_XD_OPSIZE, /* 532 */
  IC_64BIT_XD_OPSIZE, /* 533 */
  IC_XS_OPSIZE, /* 534 */
  IC_64BIT_XD_OPSIZE, /* 535 */
  IC_OPSIZE, /* 536 */
  IC_64BIT_REXW_OPSIZE, /* 537 */
  IC_XS_OPSIZE, /* 538 */
  IC_64BIT_REXW_XS, /* 539 */
  IC_XD_OPSIZE, /* 540 */
  IC_64BIT_REXW_XD, /* 541 */
  IC_XS_OPSIZE, /* 542 */
  IC_64BIT_REXW_XS, /* 543 */
  IC_ADSIZE, /* 544 */
  IC_64BIT_ADSIZE, /* 545 */
  IC_XS, /* 546 */
  IC_64BIT_XS, /* 547 */
  IC_XD, /* 548 */
  IC_64BIT_XD, /* 549 */
  IC_XS, /* 550 */
  IC_64BIT_XS, /* 551 */
  IC_ADSIZE, /* 552 */
  IC_64BIT_REXW_ADSIZE, /* 553 */
  IC_XS, /* 554 */
  IC_64BIT_REXW_XS, /* 555 */
  IC_XD, /* 556 */
  IC_64BIT_REXW_XD, /* 557 */
  IC_XS, /* 558 */
  IC_64BIT_REXW_XS, /* 559 */
  IC_OPSIZE_ADSIZE, /* 560 */
  IC_64BIT_OPSIZE_ADSIZE, /* 561 */
  IC_XS_OPSIZE, /* 562 */
  IC_64BIT_XS_OPSIZE, /* 563 */
  IC_XD_OPSIZE, /* 564 */
  IC_64BIT_XD_OPSIZE, /* 565 */
  IC_XS_OPSIZE, /* 566 */
  IC_64BIT_XD_OPSIZE, /* 567 */
  IC_OPSIZE_ADSIZE, /* 568 */
  IC_64BIT_REXW_OPSIZE, /* 569 */
  IC_XS_OPSIZE, /* 570 */
  IC_64BIT_REXW_XS, /* 571 */
  IC_XD_OPSIZE, /* 572 */
  IC_64BIT_REXW_XD, /* 573 */
  IC_XS_OPSIZE, /* 574 */
  IC_64BIT_REXW_XS, /* 575 */
  IC_VEX, /* 576 */
  IC_VEX, /* 577 */
  IC_VEX_XS, /* 578 */
  IC_VEX_XS, /* 579 */
  IC_VEX_XD, /* 580 */
  IC_VEX_XD, /* 581 */
  IC_VEX_XD, /* 582 */
  IC_VEX_XD, /* 583 */
  IC_VEX_W, /* 584 */
  IC_VEX_W, /* 585 */
  IC_VEX_W_XS, /* 586 */
  IC_VEX_W_XS, /* 587 */
  IC_VEX_W_XD, /* 588 */
  IC_VEX_W_XD, /* 589 */
  IC_VEX_W_XD, /* 590 */
  IC_VEX_W_XD, /* 591 */
  IC_VEX_OPSIZE, /* 592 */
  IC_VEX_OPSIZE, /* 593 */
  IC_VEX_OPSIZE, /* 594 */
  IC_VEX_OPSIZE, /* 595 */
  IC_VEX_OPSIZE, /* 596 */
  IC_VEX_OPSIZE, /* 597 */
  IC_VEX_OPSIZE, /* 598 */
  IC_VEX_OPSIZE, /* 599 */
  IC_VEX_W_OPSIZE, /* 600 */
  IC_VEX_W_OPSIZE, /* 601 */
  IC_VEX_W_OPSIZE, /* 602 */
  IC_VEX_W_OPSIZE, /* 603 */
  IC_VEX_W_OPSIZE, /* 604 */
  IC_VEX_W_OPSIZE, /* 605 */
  IC_VEX_W_OPSIZE, /* 606 */
  IC_VEX_W_OPSIZE, /* 607 */
  IC_VEX, /* 608 */
  IC_VEX, /* 609 */
  IC_VEX_XS, /* 610 */
  IC_VEX_XS, /* 611 */
  IC_VEX_XD, /* 612 */
  IC_VEX_XD, /* 613 */
  IC_VEX_XD, /* 614 */
  IC_VEX_XD, /* 615 */
  IC_VEX_W, /* 616 */
  IC_VEX_W, /* 617 */
  IC_VEX_W_XS, /* 618 */
  IC_VEX_W_XS, /* 619 */
  IC_VEX_W_XD, /* 620 */
  IC_VEX_W_XD, /* 621 */
  IC_VEX_W_XD, /* 622 */
  IC_VEX_W_XD, /* 623 */
  IC_VEX_OPSIZE, /* 624 */
  IC_VEX_OPSIZE, /* 625 */
  IC_VEX_OPSIZE, /* 626 */
  IC_VEX_OPSIZE, /* 627 */
  IC_VEX_OPSIZE, /* 628 */
  IC_VEX_OPSIZE, /* 629 */
  IC_VEX_OPSIZE, /* 630 */
  IC_VEX_OPSIZE, /* 631 */
  IC_VEX_W_OPSIZE, /* 632 */
  IC_VEX_W_OPSIZE, /* 633 */
  IC_VEX_W_OPSIZE, /* 634 */
  IC_VEX_W_OPSIZE, /* 635 */
  IC_VEX_W_OPSIZE, /* 636 */
  IC_VEX_W_OPSIZE, /* 637 */
  IC_VEX_W_OPSIZE, /* 638 */
  IC_VEX_W_OPSIZE, /* 639 */
  IC_VEX_L, /* 640 */
  IC_VEX_L, /* 641 */
  IC_VEX_L_XS, /* 642 */
  IC_VEX_L_XS, /* 643 */
  IC_VEX_L_XD, /* 644 */
  IC_VEX_L_XD, /* 645 */
  IC_VEX_L_XD, /* 646 */
  IC_VEX_L_XD, /* 647 */
  IC_VEX_L_W, /* 648 */
  IC_VEX_L_W, /* 649 */
  IC_VEX_L_W_XS, /* 650 */
  IC_VEX_L_W_XS, /* 651 */
  IC_VEX_L_W_XD, /* 652 */
  IC_VEX_L_W_XD, /* 653 */
  IC_VEX_L_W_XD, /* 654 */
  IC_VEX_L_W_XD, /* 655 */
  IC_VEX_L_OPSIZE, /* 656 */
  IC_VEX_L_OPSIZE, /* 657 */
  IC_VEX_L_OPSIZE, /* 658 */
  IC_VEX_L_OPSIZE, /* 659 */
  IC_VEX_L_OPSIZE, /* 660 */
  IC_VEX_L_OPSIZE, /* 661 */
  IC_VEX_L_OPSIZE, /* 662 */
  IC_VEX_L_OPSIZE, /* 663 */
  IC_VEX_L_W_OPSIZE, /* 664 */
  IC_VEX_L_W_OPSIZE, /* 665 */
  IC_VEX_L_W_OPSIZE, /* 666 */
  IC_VEX_L_W_OPSIZE, /* 667 */
  IC_VEX_L_W_OPSIZE, /* 668 */
  IC_VEX_L_W_OPSIZE, /* 669 */
  IC_VEX_L_W_OPSIZE, /* 670 */
  IC_VEX_L_W_OPSIZE, /* 671 */
  IC_VEX_L, /* 672 */
  IC_VEX_L, /* 673 */
  IC_VEX_L_XS, /* 674 */
  IC_VEX_L_XS, /* 675 */
  IC_VEX_L_XD, /* 676 */
  IC_VEX_L_XD, /* 677 */
  IC_VEX_L_XD, /* 678 */
  IC_VEX_L_XD, /* 679 */
  IC_VEX_L_W, /* 680 */
  IC_VEX_L_W, /* 681 */
  IC_VEX_L_W_XS, /* 682 */
  IC_VEX_L_W_XS, /* 683 */
  IC_VEX_L_W_XD, /* 684 */
  IC_VEX_L_W_XD, /* 685 */
  IC_VEX_L_W_XD, /* 686 */
  IC_VEX_L_W_XD, /* 687 */
  IC_VEX_L_OPSIZE, /* 688 */
  IC_VEX_L_OPSIZE, /* 689 */
  IC_VEX_L_OPSIZE, /* 690 */
  IC_VEX_L_OPSIZE, /* 691 */
  IC_VEX_L_OPSIZE, /* 692 */
  IC_VEX_L_OPSIZE, /* 693 */
  IC_VEX_L_OPSIZE, /* 694 */
  IC_VEX_L_OPSIZE, /* 695 */
  IC_VEX_L_W_OPSIZE, /* 696 */
  IC_VEX_L_W_OPSIZE, /* 697 */
  IC_VEX_L_W_OPSIZE, /* 698 */
  IC_VEX_L_W_OPSIZE, /* 699 */
  IC_VEX_L_W_OPSIZE, /* 700 */
  IC_VEX_L_W_OPSIZE, /* 701 */
  IC_VEX_L_W_OPSIZE, /* 702 */
  IC_VEX_L_W_OPSIZE, /* 703 */
  IC_VEX_L, /* 704 */
  IC_VEX_L, /* 705 */
  IC_VEX_L_XS, /* 706 */
  IC_VEX_L_XS, /* 707 */
  IC_VEX_L_XD, /* 708 */
  IC_VEX_L_XD, /* 709 */
  IC_VEX_L_XD, /* 710 */
  IC_VEX_L_XD, /* 711 */
  IC_VEX_L_W, /* 712 */
  IC_VEX_L_W, /* 713 */
  IC_VEX_L_W_XS, /* 714 */
  IC_VEX_L_W_XS, /* 715 */
  IC_VEX_L_W_XD, /* 716 */
  IC_VEX_L_W_XD, /* 717 */
  IC_VEX_L_W_XD, /* 718 */
  IC_VEX_L_W_XD, /* 719 */
  IC_VEX_L_OPSIZE, /* 720 */
  IC_VEX_L_OPSIZE, /* 721 */
  IC_VEX_L_OPSIZE, /* 722 */
  IC_VEX_L_OPSIZE, /* 723 */
  IC_VEX_L_OPSIZE, /* 724 */
  IC_VEX_L_OPSIZE, /* 725 */
  IC_VEX_L_OPSIZE, /* 726 */
  IC_VEX_L_OPSIZE, /* 727 */
  IC_VEX_L_W_OPSIZE, /* 728 */
  IC_VEX_L_W_OPSIZE, /* 729 */
  IC_VEX_L_W_OPSIZE, /* 730 */
  IC_VEX_L_W_OPSIZE, /* 731 */
  IC_VEX_L_W_OPSIZE, /* 732 */
  IC_VEX_L_W_OPSIZE, /* 733 */
  IC_VEX_L_W_OPSIZE, /* 734 */
  IC_VEX_L_W_OPSIZE, /* 735 */
  IC_VEX_L, /* 736 */
  IC_VEX_L, /* 737 */
  IC_VEX_L_XS, /* 738 */
  IC_VEX_L_XS, /* 739 */
  IC_VEX_L_XD, /* 740 */
  IC_VEX_L_XD, /* 741 */
  IC_VEX_L_XD, /* 742 */
  IC_VEX_L_XD, /* 743 */
  IC_VEX_L_W, /* 744 */
  IC_VEX_L_W, /* 745 */
  IC_VEX_L_W_XS, /* 746 */
  IC_VEX_L_W_XS, /* 747 */
  IC_VEX_L_W_XD, /* 748 */
  IC_VEX_L_W_XD, /* 749 */
  IC_VEX_L_W_XD, /* 750 */
  IC_VEX_L_W_XD, /* 751 */
  IC_VEX_L_OPSIZE, /* 752 */
  IC_VEX_L_OPSIZE, /* 753 */
  IC_VEX_L_OPSIZE, /* 754 */
  IC_VEX_L_OPSIZE, /* 755 */
  IC_VEX_L_OPSIZE, /* 756 */
  IC_VEX_L_OPSIZE, /* 757 */
  IC_VEX_L_OPSIZE, /* 758 */
  IC_VEX_L_OPSIZE, /* 759 */
  IC_VEX_L_W_OPSIZE, /* 760 */
  IC_VEX_L_W_OPSIZE, /* 761 */
  IC_VEX_L_W_OPSIZE, /* 762 */
  IC_VEX_L_W_OPSIZE, /* 763 */
  IC_VEX_L_W_OPSIZE, /* 764 */
  IC_VEX_L_W_OPSIZE, /* 765 */
  IC_VEX_L_W_OPSIZE, /* 766 */
  IC_VEX_L_W_OPSIZE, /* 767 */
  IC_EVEX_L, /* 768 */
  IC_EVEX_L, /* 769 */
  IC_EVEX_L_XS, /* 770 */
  IC_EVEX_L_XS, /* 771 */
  IC_EVEX_L_XD, /* 772 */
  IC_EVEX_L_XD, /* 773 */
  IC_EVEX_L_XD, /* 774 */
  IC_EVEX_L_XD, /* 775 */
  IC_EVEX_L_W, /* 776 */
  IC_EVEX_L_W, /* 777 */
  IC_EVEX_L_W_XS, /* 778 */
  IC_EVEX_L_W_XS, /* 779 */
  IC_EVEX_L_W_XD, /* 780 */
  IC_EVEX_L_W_XD, /* 781 */
  IC_EVEX_L_W_XD, /* 782 */
  IC_EVEX_L_W_XD, /* 783 */
  IC_EVEX_L_OPSIZE, /* 784 */
  IC_EVEX_L_OPSIZE, /* 785 */
  IC_EVEX_L_OPSIZE, /* 786 */
  IC_EVEX_L_OPSIZE, /* 787 */
  IC_EVEX_L_OPSIZE, /* 788 */
  IC_EVEX_L_OPSIZE, /* 789 */
  IC_EVEX_L_OPSIZE, /* 790 */
  IC_EVEX_L_OPSIZE, /* 791 */
  IC_EVEX_L_W_OPSIZE, /* 792 */
  IC_EVEX_L_W_OPSIZE, /* 793 */
  IC_EVEX_L_W_OPSIZE, /* 794 */
  IC_EVEX_L_W_OPSIZE, /* 795 */
  IC_EVEX_L_W_OPSIZE, /* 796 */
  IC_EVEX_L_W_OPSIZE, /* 797 */
  IC_EVEX_L_W_OPSIZE, /* 798 */
  IC_EVEX_L_W_OPSIZE, /* 799 */
  IC_EVEX_L, /* 800 */
  IC_EVEX_L, /* 801 */
  IC_EVEX_L_XS, /* 802 */
  IC_EVEX_L_XS, /* 803 */
  IC_EVEX_L_XD, /* 804 */
  IC_EVEX_L_XD, /* 805 */
  IC_EVEX_L_XD, /* 806 */
  IC_EVEX_L_XD, /* 807 */
  IC_EVEX_L_W, /* 808 */
  IC_EVEX_L_W, /* 809 */
  IC_EVEX_L_W_XS, /* 810 */
  IC_EVEX_L_W_XS, /* 811 */
  IC_EVEX_L_W_XD, /* 812 */
  IC_EVEX_L_W_XD, /* 813 */
  IC_EVEX_L_W_XD, /* 814 */
  IC_EVEX_L_W_XD, /* 815 */
  IC_EVEX_L_OPSIZE, /* 816 */
  IC_EVEX_L_OPSIZE, /* 817 */
  IC_EVEX_L_OPSIZE, /* 818 */
  IC_EVEX_L_OPSIZE, /* 819 */
  IC_EVEX_L_OPSIZE, /* 820 */
  IC_EVEX_L_OPSIZE, /* 821 */
  IC_EVEX_L_OPSIZE, /* 822 */
  IC_EVEX_L_OPSIZE, /* 823 */
  IC_EVEX_L_W_OPSIZE, /* 824 */
  IC_EVEX_L_W_OPSIZE, /* 825 */
  IC_EVEX_L_W_OPSIZE, /* 826 */
  IC_EVEX_L_W_OPSIZE, /* 827 */
  IC_EVEX_L_W_OPSIZE, /* 828 */
  IC_EVEX_L_W_OPSIZE, /* 829 */
  IC_EVEX_L_W_OPSIZE, /* 830 */
  IC_EVEX_L_W_OPSIZE, /* 831 */
  IC_EVEX_L, /* 832 */
  IC_EVEX_L, /* 833 */
  IC_EVEX_L_XS, /* 834 */
  IC_EVEX_L_XS, /* 835 */
  IC_EVEX_L_XD, /* 836 */
  IC_EVEX_L_XD, /* 837 */
  IC_EVEX_L_XD, /* 838 */
  IC_EVEX_L_XD, /* 839 */
  IC_EVEX_L_W, /* 840 */
  IC_EVEX_L_W, /* 841 */
  IC_EVEX_L_W_XS, /* 842 */
  IC_EVEX_L_W_XS, /* 843 */
  IC_EVEX_L_W_XD, /* 844 */
  IC_EVEX_L_W_XD, /* 845 */
  IC_EVEX_L_W_XD, /* 846 */
  IC_EVEX_L_W_XD, /* 847 */
  IC_EVEX_L_OPSIZE, /* 848 */
  IC_EVEX_L_OPSIZE, /* 849 */
  IC_EVEX_L_OPSIZE, /* 850 */
  IC_EVEX_L_OPSIZE, /* 851 */
  IC_EVEX_L_OPSIZE, /* 852 */
  IC_EVEX_L_OPSIZE, /* 853 */
  IC_EVEX_L_OPSIZE, /* 854 */
  IC_EVEX_L_OPSIZE, /* 855 */
  IC_EVEX_L_W_OPSIZE, /* 856 */
  IC_EVEX_L_W_OPSIZE, /* 857 */
  IC_EVEX_L_W_OPSIZE, /* 858 */
  IC_EVEX_L_W_OPSIZE, /* 859 */
  IC_EVEX_L_W_OPSIZE, /* 860 */
  IC_EVEX_L_W_OPSIZE, /* 861 */
  IC_EVEX_L_W_OPSIZE, /* 862 */
  IC_EVEX_L_W_OPSIZE, /* 863 */
  IC_EVEX_L, /* 864 */
  IC_EVEX_L, /* 865 */
  IC_EVEX_L_XS, /* 866 */
  IC_EVEX_L_XS, /* 867 */
  IC_EVEX_L_XD, /* 868 */
  IC_EVEX_L_XD, /* 869 */
  IC_EVEX_L_XD, /* 870 */
  IC_EVEX_L_XD, /* 871 */
  IC_EVEX_L_W, /* 872 */
  IC_EVEX_L_W, /* 873 */
  IC_EVEX_L_W_XS, /* 874 */
  IC_EVEX_L_W_XS, /* 875 */
  IC_EVEX_L_W_XD, /* 876 */
  IC_EVEX_L_W_XD, /* 877 */
  IC_EVEX_L_W_XD, /* 878 */
  IC_EVEX_L_W_XD, /* 879 */
  IC_EVEX_L_OPSIZE, /* 880 */
  IC_EVEX_L_OPSIZE, /* 881 */
  IC_EVEX_L_OPSIZE, /* 882 */
  IC_EVEX_L_OPSIZE, /* 883 */
  IC_EVEX_L_OPSIZE, /* 884 */
  IC_EVEX_L_OPSIZE, /* 885 */
  IC_EVEX_L_OPSIZE, /* 886 */
  IC_EVEX_L_OPSIZE, /* 887 */
  IC_EVEX_L_W_OPSIZE, /* 888 */
  IC_EVEX_L_W_OPSIZE, /* 889 */
  IC_EVEX_L_W_OPSIZE, /* 890 */
  IC_EVEX_L_W_OPSIZE, /* 891 */
  IC_EVEX_L_W_OPSIZE, /* 892 */
  IC_EVEX_L_W_OPSIZE, /* 893 */
  IC_EVEX_L_W_OPSIZE, /* 894 */
  IC_EVEX_L_W_OPSIZE, /* 895 */
  IC_EVEX_L, /* 896 */
  IC_EVEX_L, /* 897 */
  IC_EVEX_L_XS, /* 898 */
  IC_EVEX_L_XS, /* 899 */
  IC_EVEX_L_XD, /* 900 */
  IC_EVEX_L_XD, /* 901 */
  IC_EVEX_L_XD, /* 902 */
  IC_EVEX_L_XD, /* 903 */
  IC_EVEX_L_W, /* 904 */
  IC_EVEX_L_W, /* 905 */
  IC_EVEX_L_W_XS, /* 906 */
  IC_EVEX_L_W_XS, /* 907 */
  IC_EVEX_L_W_XD, /* 908 */
  IC_EVEX_L_W_XD, /* 909 */
  IC_EVEX_L_W_XD, /* 910 */
  IC_EVEX_L_W_XD, /* 911 */
  IC_EVEX_L_OPSIZE, /* 912 */
  IC_EVEX_L_OPSIZE, /* 913 */
  IC_EVEX_L_OPSIZE, /* 914 */
  IC_EVEX_L_OPSIZE, /* 915 */
  IC_EVEX_L_OPSIZE, /* 916 */
  IC_EVEX_L_OPSIZE, /* 917 */
  IC_EVEX_L_OPSIZE, /* 918 */
  IC_EVEX_L_OPSIZE, /* 919 */
  IC_EVEX_L_W_OPSIZE, /* 920 */
  IC_EVEX_L_W_OPSIZE, /* 921 */
  IC_EVEX_L_W_OPSIZE, /* 922 */
  IC_EVEX_L_W_OPSIZE, /* 923 */
  IC_EVEX_L_W_OPSIZE, /* 924 */
  IC_EVEX_L_W_OPSIZE, /* 925 */
  IC_EVEX_L_W_OPSIZE, /* 926 */
  IC_EVEX_L_W_OPSIZE, /* 927 */
  IC_EVEX_L, /* 928 */
  IC_EVEX_L, /* 929 */
  IC_EVEX_L_XS, /* 930 */
  IC_EVEX_L_XS, /* 931 */
  IC_EVEX_L_XD, /* 932 */
  IC_EVEX_L_XD, /* 933 */
  IC_EVEX_L_XD, /* 934 */
  IC_EVEX_L_XD, /* 935 */
  IC_EVEX_L_W, /* 936 */
  IC_EVEX_L_W, /* 937 */
  IC_EVEX_L_W_XS, /* 938 */
  IC_EVEX_L_W_XS, /* 939 */
  IC_EVEX_L_W_XD, /* 940 */
  IC_EVEX_L_W_XD, /* 941 */
  IC_EVEX_L_W_XD, /* 942 */
  IC_EVEX_L_W_XD, /* 943 */
  IC_EVEX_L_OPSIZE, /* 944 */
  IC_EVEX_L_OPSIZE, /* 945 */
  IC_EVEX_L_OPSIZE, /* 946 */
  IC_EVEX_L_OPSIZE, /* 947 */
  IC_EVEX_L_OPSIZE, /* 948 */
  IC_EVEX_L_OPSIZE, /* 949 */
  IC_EVEX_L_OPSIZE, /* 950 */
  IC_EVEX_L_OPSIZE, /* 951 */
  IC_EVEX_L_W_OPSIZE, /* 952 */
  IC_EVEX_L_W_OPSIZE, /* 953 */
  IC_EVEX_L_W_OPSIZE, /* 954 */
  IC_EVEX_L_W_OPSIZE, /* 955 */
  IC_EVEX_L_W_OPSIZE, /* 956 */
  IC_EVEX_L_W_OPSIZE, /* 957 */
  IC_EVEX_L_W_OPSIZE, /* 958 */
  IC_EVEX_L_W_OPSIZE, /* 959 */
  IC_EVEX_L, /* 960 */
  IC_EVEX_L, /* 961 */
  IC_EVEX_L_XS, /* 962 */
  IC_EVEX_L_XS, /* 963 */
  IC_EVEX_L_XD, /* 964 */
  IC_EVEX_L_XD, /* 965 */
  IC_EVEX_L_XD, /* 966 */
  IC_EVEX_L_XD, /* 967 */
  IC_EVEX_L_W, /* 968 */
  IC_EVEX_L_W, /* 969 */
  IC_EVEX_L_W_XS, /* 970 */
  IC_EVEX_L_W_XS, /* 971 */
  IC_EVEX_L_W_XD, /* 972 */
  IC_EVEX_L_W_XD, /* 973 */
  IC_EVEX_L_W_XD, /* 974 */
  IC_EVEX_L_W_XD, /* 975 */
  IC_EVEX_L_OPSIZE, /* 976 */
  IC_EVEX_L_OPSIZE, /* 977 */
  IC_EVEX_L_OPSIZE, /* 978 */
  IC_EVEX_L_OPSIZE, /* 979 */
  IC_EVEX_L_OPSIZE, /* 980 */
  IC_EVEX_L_OPSIZE, /* 981 */
  IC_EVEX_L_OPSIZE, /* 982 */
  IC_EVEX_L_OPSIZE, /* 983 */
  IC_EVEX_L_W_OPSIZE, /* 984 */
  IC_EVEX_L_W_OPSIZE, /* 985 */
  IC_EVEX_L_W_OPSIZE, /* 986 */
  IC_EVEX_L_W_OPSIZE, /* 987 */
  IC_EVEX_L_W_OPSIZE, /* 988 */
  IC_EVEX_L_W_OPSIZE, /* 989 */
  IC_EVEX_L_W_OPSIZE, /* 990 */
  IC_EVEX_L_W_OPSIZE, /* 991 */
  IC_EVEX_L, /* 992 */
  IC_EVEX_L, /* 993 */
  IC_EVEX_L_XS, /* 994 */
  IC_EVEX_L_XS, /* 995 */
  IC_EVEX_L_XD, /* 996 */
  IC_EVEX_L_XD, /* 997 */
  IC_EVEX_L_XD, /* 998 */
  IC_EVEX_L_XD, /* 999 */
  IC_EVEX_L_W, /* 1000 */
  IC_EVEX_L_W, /* 1001 */
  IC_EVEX_L_W_XS, /* 1002 */
  IC_EVEX_L_W_XS, /* 1003 */
  IC_EVEX_L_W_XD, /* 1004 */
  IC_EVEX_L_W_XD, /* 1005 */
  IC_EVEX_L_W_XD, /* 1006 */
  IC_EVEX_L_W_XD, /* 1007 */
  IC_EVEX_L_OPSIZE, /* 1008 */
  IC_EVEX_L_OPSIZE, /* 1009 */
  IC_EVEX_L_OPSIZE, /* 1010 */
  IC_EVEX_L_OPSIZE, /* 1011 */
  IC_EVEX_L_OPSIZE, /* 1012 */
  IC_EVEX_L_OPSIZE, /* 1013 */
  IC_EVEX_L_OPSIZE, /* 1014 */
  IC_EVEX_L_OPSIZE, /* 1015 */
  IC_EVEX_L_W_OPSIZE, /* 1016 */
  IC_EVEX_L_W_OPSIZE, /* 1017 */
  IC_EVEX_L_W_OPSIZE, /* 1018 */
  IC_EVEX_L_W_OPSIZE, /* 1019 */
  IC_EVEX_L_W_OPSIZE, /* 1020 */
  IC_EVEX_L_W_OPSIZE, /* 1021 */
  IC_EVEX_L_W_OPSIZE, /* 1022 */
  IC_EVEX_L_W_OPSIZE, /* 1023 */
  IC, /* 1024 */
  IC_64BIT, /* 1025 */
  IC_XS, /* 1026 */
  IC_64BIT_XS, /* 1027 */
  IC_XD, /* 1028 */
  IC_64BIT_XD, /* 1029 */
  IC_XS, /* 1030 */
  IC_64BIT_XS, /* 1031 */
  IC, /* 1032 */
  IC_64BIT_REXW, /* 1033 */
  IC_XS, /* 1034 */
  IC_64BIT_REXW_XS, /* 1035 */
  IC_XD, /* 1036 */
  IC_64BIT_REXW_XD, /* 1037 */
  IC_XS, /* 1038 */
  IC_64BIT_REXW_XS, /* 1039 */
  IC_OPSIZE, /* 1040 */
  IC_64BIT_OPSIZE, /* 1041 */
  IC_XS_OPSIZE, /* 1042 */
  IC_64BIT_XS_OPSIZE, /* 1043 */
  IC_XD_OPSIZE, /* 1044 */
  IC_64BIT_XD_OPSIZE, /* 1045 */
  IC_XS_OPSIZE, /* 1046 */
  IC_64BIT_XD_OPSIZE, /* 1047 */
  IC_OPSIZE, /* 1048 */
  IC_64BIT_REXW_OPSIZE, /* 1049 */
  IC_XS_OPSIZE, /* 1050 */
  IC_64BIT_REXW_XS, /* 1051 */
  IC_XD_OPSIZE, /* 1052 */
  IC_64BIT_REXW_XD, /* 1053 */
  IC_XS_OPSIZE, /* 1054 */
  IC_64BIT_REXW_XS, /* 1055 */
  IC_ADSIZE, /* 1056 */
  IC_64BIT_ADSIZE, /* 1057 */
  IC_XS, /* 1058 */
  IC_64BIT_XS, /* 1059 */
  IC_XD, /* 1060 */
  IC_64BIT_XD, /* 1061 */
  IC_XS, /* 1062 */
  IC_64BIT_XS, /* 1063 */
  IC_ADSIZE, /* 1064 */
  IC_64BIT_REXW_ADSIZE, /* 1065 */
  IC_XS, /* 1066 */
  IC_64BIT_REXW_XS, /* 1067 */
  IC_XD, /* 1068 */
  IC_64BIT_REXW_XD, /* 1069 */
  IC_XS, /* 1070 */
  IC_64BIT_REXW_XS, /* 1071 */
  IC_OPSIZE_ADSIZE, /* 1072 */
  IC_64BIT_OPSIZE_ADSIZE, /* 1073 */
  IC_XS_OPSIZE, /* 1074 */
  IC_64BIT_XS_OPSIZE, /* 1075 */
  IC_XD_OPSIZE, /* 1076 */
  IC_64BIT_XD_OPSIZE, /* 1077 */
  IC_XS_OPSIZE, /* 1078 */
  IC_64BIT_XD_OPSIZE, /* 1079 */
  IC_OPSIZE_ADSIZE, /* 1080 */
  IC_64BIT_REXW_OPSIZE, /* 1081 */
  IC_XS_OPSIZE, /* 1082 */
  IC_64BIT_REXW_XS, /* 1083 */
  IC_XD_OPSIZE, /* 1084 */
  IC_64BIT_REXW_XD, /* 1085 */
  IC_XS_OPSIZE, /* 1086 */
  IC_64BIT_REXW_XS, /* 1087 */
  IC_VEX, /* 1088 */
  IC_VEX, /* 1089 */
  IC_VEX_XS, /* 1090 */
  IC_VEX_XS, /* 1091 */
  IC_VEX_XD, /* 1092 */
  IC_VEX_XD, /* 1093 */
  IC_VEX_XD, /* 1094 */
  IC_VEX_XD, /* 1095 */
  IC_VEX_W, /* 1096 */
  IC_VEX_W, /* 1097 */
  IC_VEX_W_XS, /* 1098 */
  IC_VEX_W_XS, /* 1099 */
  IC_VEX_W_XD, /* 1100 */
  IC_VEX_W_XD, /* 1101 */
  IC_VEX_W_XD, /* 1102 */
  IC_VEX_W_XD, /* 1103 */
  IC_VEX_OPSIZE, /* 1104 */
  IC_VEX_OPSIZE, /* 1105 */
  IC_VEX_OPSIZE, /* 1106 */
  IC_VEX_OPSIZE, /* 1107 */
  IC_VEX_OPSIZE, /* 1108 */
  IC_VEX_OPSIZE, /* 1109 */
  IC_VEX_OPSIZE, /* 1110 */
  IC_VEX_OPSIZE, /* 1111 */
  IC_VEX_W_OPSIZE, /* 1112 */
  IC_VEX_W_OPSIZE, /* 1113 */
  IC_VEX_W_OPSIZE, /* 1114 */
  IC_VEX_W_OPSIZE, /* 1115 */
  IC_VEX_W_OPSIZE, /* 1116 */
  IC_VEX_W_OPSIZE, /* 1117 */
  IC_VEX_W_OPSIZE, /* 1118 */
  IC_VEX_W_OPSIZE, /* 1119 */
  IC_VEX, /* 1120 */
  IC_VEX, /* 1121 */
  IC_VEX_XS, /* 1122 */
  IC_VEX_XS, /* 1123 */
  IC_VEX_XD, /* 1124 */
  IC_VEX_XD, /* 1125 */
  IC_VEX_XD, /* 1126 */
  IC_VEX_XD, /* 1127 */
  IC_VEX_W, /* 1128 */
  IC_VEX_W, /* 1129 */
  IC_VEX_W_XS, /* 1130 */
  IC_VEX_W_XS, /* 1131 */
  IC_VEX_W_XD, /* 1132 */
  IC_VEX_W_XD, /* 1133 */
  IC_VEX_W_XD, /* 1134 */
  IC_VEX_W_XD, /* 1135 */
  IC_VEX_OPSIZE, /* 1136 */
  IC_VEX_OPSIZE, /* 1137 */
  IC_VEX_OPSIZE, /* 1138 */
  IC_VEX_OPSIZE, /* 1139 */
  IC_VEX_OPSIZE, /* 1140 */
  IC_VEX_OPSIZE, /* 1141 */
  IC_VEX_OPSIZE, /* 1142 */
  IC_VEX_OPSIZE, /* 1143 */
  IC_VEX_W_OPSIZE, /* 1144 */
  IC_VEX_W_OPSIZE, /* 1145 */
  IC_VEX_W_OPSIZE, /* 1146 */
  IC_VEX_W_OPSIZE, /* 1147 */
  IC_VEX_W_OPSIZE, /* 1148 */
  IC_VEX_W_OPSIZE, /* 1149 */
  IC_VEX_W_OPSIZE, /* 1150 */
  IC_VEX_W_OPSIZE, /* 1151 */
  IC_VEX_L, /* 1152 */
  IC_VEX_L, /* 1153 */
  IC_VEX_L_XS, /* 1154 */
  IC_VEX_L_XS, /* 1155 */
  IC_VEX_L_XD, /* 1156 */
  IC_VEX_L_XD, /* 1157 */
  IC_VEX_L_XD, /* 1158 */
  IC_VEX_L_XD, /* 1159 */
  IC_VEX_L_W, /* 1160 */
  IC_VEX_L_W, /* 1161 */
  IC_VEX_L_W_XS, /* 1162 */
  IC_VEX_L_W_XS, /* 1163 */
  IC_VEX_L_W_XD, /* 1164 */
  IC_VEX_L_W_XD, /* 1165 */
  IC_VEX_L_W_XD, /* 1166 */
  IC_VEX_L_W_XD, /* 1167 */
  IC_VEX_L_OPSIZE, /* 1168 */
  IC_VEX_L_OPSIZE, /* 1169 */
  IC_VEX_L_OPSIZE, /* 1170 */
  IC_VEX_L_OPSIZE, /* 1171 */
  IC_VEX_L_OPSIZE, /* 1172 */
  IC_VEX_L_OPSIZE, /* 1173 */
  IC_VEX_L_OPSIZE, /* 1174 */
  IC_VEX_L_OPSIZE, /* 1175 */
  IC_VEX_L_W_OPSIZE, /* 1176 */
  IC_VEX_L_W_OPSIZE, /* 1177 */
  IC_VEX_L_W_OPSIZE, /* 1178 */
  IC_VEX_L_W_OPSIZE, /* 1179 */
  IC_VEX_L_W_OPSIZE, /* 1180 */
  IC_VEX_L_W_OPSIZE, /* 1181 */
  IC_VEX_L_W_OPSIZE, /* 1182 */
  IC_VEX_L_W_OPSIZE, /* 1183 */
  IC_VEX_L, /* 1184 */
  IC_VEX_L, /* 1185 */
  IC_VEX_L_XS, /* 1186 */
  IC_VEX_L_XS, /* 1187 */
  IC_VEX_L_XD, /* 1188 */
  IC_VEX_L_XD, /* 1189 */
  IC_VEX_L_XD, /* 1190 */
  IC_VEX_L_XD, /* 1191 */
  IC_VEX_L_W, /* 1192 */
  IC_VEX_L_W, /* 1193 */
  IC_VEX_L_W_XS, /* 1194 */
  IC_VEX_L_W_XS, /* 1195 */
  IC_VEX_L_W_XD, /* 1196 */
  IC_VEX_L_W_XD, /* 1197 */
  IC_VEX_L_W_XD, /* 1198 */
  IC_VEX_L_W_XD, /* 1199 */
  IC_VEX_L_OPSIZE, /* 1200 */
  IC_VEX_L_OPSIZE, /* 1201 */
  IC_VEX_L_OPSIZE, /* 1202 */
  IC_VEX_L_OPSIZE, /* 1203 */
  IC_VEX_L_OPSIZE, /* 1204 */
  IC_VEX_L_OPSIZE, /* 1205 */
  IC_VEX_L_OPSIZE, /* 1206 */
  IC_VEX_L_OPSIZE, /* 1207 */
  IC_VEX_L_W_OPSIZE, /* 1208 */
  IC_VEX_L_W_OPSIZE, /* 1209 */
  IC_VEX_L_W_OPSIZE, /* 1210 */
  IC_VEX_L_W_OPSIZE, /* 1211 */
  IC_VEX_L_W_OPSIZE, /* 1212 */
  IC_VEX_L_W_OPSIZE, /* 1213 */
  IC_VEX_L_W_OPSIZE, /* 1214 */
  IC_VEX_L_W_OPSIZE, /* 1215 */
  IC_VEX_L, /* 1216 */
  IC_VEX_L, /* 1217 */
  IC_VEX_L_XS, /* 1218 */
  IC_VEX_L_XS, /* 1219 */
  IC_VEX_L_XD, /* 1220 */
  IC_VEX_L_XD, /* 1221 */
  IC_VEX_L_XD, /* 1222 */
  IC_VEX_L_XD, /* 1223 */
  IC_VEX_L_W, /* 1224 */
  IC_VEX_L_W, /* 1225 */
  IC_VEX_L_W_XS, /* 1226 */
  IC_VEX_L_W_XS, /* 1227 */
  IC_VEX_L_W_XD, /* 1228 */
  IC_VEX_L_W_XD, /* 1229 */
  IC_VEX_L_W_XD, /* 1230 */
  IC_VEX_L_W_XD, /* 1231 */
  IC_VEX_L_OPSIZE, /* 1232 */
  IC_VEX_L_OPSIZE, /* 1233 */
  IC_VEX_L_OPSIZE, /* 1234 */
  IC_VEX_L_OPSIZE, /* 1235 */
  IC_VEX_L_OPSIZE, /* 1236 */
  IC_VEX_L_OPSIZE, /* 1237 */
  IC_VEX_L_OPSIZE, /* 1238 */
  IC_VEX_L_OPSIZE, /* 1239 */
  IC_VEX_L_W_OPSIZE, /* 1240 */
  IC_VEX_L_W_OPSIZE, /* 1241 */
  IC_VEX_L_W_OPSIZE, /* 1242 */
  IC_VEX_L_W_OPSIZE, /* 1243 */
  IC_VEX_L_W_OPSIZE, /* 1244 */
  IC_VEX_L_W_OPSIZE, /* 1245 */
  IC_VEX_L_W_OPSIZE, /* 1246 */
  IC_VEX_L_W_OPSIZE, /* 1247 */
  IC_VEX_L, /* 1248 */
  IC_VEX_L, /* 1249 */
  IC_VEX_L_XS, /* 1250 */
  IC_VEX_L_XS, /* 1251 */
  IC_VEX_L_XD, /* 1252 */
  IC_VEX_L_XD, /* 1253 */
  IC_VEX_L_XD, /* 1254 */
  IC_VEX_L_XD, /* 1255 */
  IC_VEX_L_W, /* 1256 */
  IC_VEX_L_W, /* 1257 */
  IC_VEX_L_W_XS, /* 1258 */
  IC_VEX_L_W_XS, /* 1259 */
  IC_VEX_L_W_XD, /* 1260 */
  IC_VEX_L_W_XD, /* 1261 */
  IC_VEX_L_W_XD, /* 1262 */
  IC_VEX_L_W_XD, /* 1263 */
  IC_VEX_L_OPSIZE, /* 1264 */
  IC_VEX_L_OPSIZE, /* 1265 */
  IC_VEX_L_OPSIZE, /* 1266 */
  IC_VEX_L_OPSIZE, /* 1267 */
  IC_VEX_L_OPSIZE, /* 1268 */
  IC_VEX_L_OPSIZE, /* 1269 */
  IC_VEX_L_OPSIZE, /* 1270 */
  IC_VEX_L_OPSIZE, /* 1271 */
  IC_VEX_L_W_OPSIZE, /* 1272 */
  IC_VEX_L_W_OPSIZE, /* 1273 */
  IC_VEX_L_W_OPSIZE, /* 1274 */
  IC_VEX_L_W_OPSIZE, /* 1275 */
  IC_VEX_L_W_OPSIZE, /* 1276 */
  IC_VEX_L_W_OPSIZE, /* 1277 */
  IC_VEX_L_W_OPSIZE, /* 1278 */
  IC_VEX_L_W_OPSIZE, /* 1279 */
  IC_EVEX_L2, /* 1280 */
  IC_EVEX_L2, /* 1281 */
  IC_EVEX_L2_XS, /* 1282 */
  IC_EVEX_L2_XS, /* 1283 */
  IC_EVEX_L2_XD, /* 1284 */
  IC_EVEX_L2_XD, /* 1285 */
  IC_EVEX_L2_XD, /* 1286 */
  IC_EVEX_L2_XD, /* 1287 */
  IC_EVEX_L2_W, /* 1288 */
  IC_EVEX_L2_W, /* 1289 */
  IC_EVEX_L2_W_XS, /* 1290 */
  IC_EVEX_L2_W_XS, /* 1291 */
  IC_EVEX_L2_W_XD, /* 1292 */
  IC_EVEX_L2_W_XD, /* 1293 */
  IC_EVEX_L2_W_XD, /* 1294 */
  IC_EVEX_L2_W_XD, /* 1295 */
  IC_EVEX_L2_OPSIZE, /* 1296 */
  IC_EVEX_L2_OPSIZE, /* 1297 */
  IC_EVEX_L2_OPSIZE, /* 1298 */
  IC_EVEX_L2_OPSIZE, /* 1299 */
  IC_EVEX_L2_OPSIZE, /* 1300 */
  IC_EVEX_L2_OPSIZE, /* 1301 */
  IC_EVEX_L2_OPSIZE, /* 1302 */
  IC_EVEX_L2_OPSIZE, /* 1303 */
  IC_EVEX_L2_W_OPSIZE, /* 1304 */
  IC_EVEX_L2_W_OPSIZE, /* 1305 */
  IC_EVEX_L2_W_OPSIZE, /* 1306 */
  IC_EVEX_L2_W_OPSIZE, /* 1307 */
  IC_EVEX_L2_W_OPSIZE, /* 1308 */
  IC_EVEX_L2_W_OPSIZE, /* 1309 */
  IC_EVEX_L2_W_OPSIZE, /* 1310 */
  IC_EVEX_L2_W_OPSIZE, /* 1311 */
  IC_EVEX_L2, /* 1312 */
  IC_EVEX_L2, /* 1313 */
  IC_EVEX_L2_XS, /* 1314 */
  IC_EVEX_L2_XS, /* 1315 */
  IC_EVEX_L2_XD, /* 1316 */
  IC_EVEX_L2_XD, /* 1317 */
  IC_EVEX_L2_XD, /* 1318 */
  IC_EVEX_L2_XD, /* 1319 */
  IC_EVEX_L2_W, /* 1320 */
  IC_EVEX_L2_W, /* 1321 */
  IC_EVEX_L2_W_XS, /* 1322 */
  IC_EVEX_L2_W_XS, /* 1323 */
  IC_EVEX_L2_W_XD, /* 1324 */
  IC_EVEX_L2_W_XD, /* 1325 */
  IC_EVEX_L2_W_XD, /* 1326 */
  IC_EVEX_L2_W_XD, /* 1327 */
  IC_EVEX_L2_OPSIZE, /* 1328 */
  IC_EVEX_L2_OPSIZE, /* 1329 */
  IC_EVEX_L2_OPSIZE, /* 1330 */
  IC_EVEX_L2_OPSIZE, /* 1331 */
  IC_EVEX_L2_OPSIZE, /* 1332 */
  IC_EVEX_L2_OPSIZE, /* 1333 */
  IC_EVEX_L2_OPSIZE, /* 1334 */
  IC_EVEX_L2_OPSIZE, /* 1335 */
  IC_EVEX_L2_W_OPSIZE, /* 1336 */
  IC_EVEX_L2_W_OPSIZE, /* 1337 */
  IC_EVEX_L2_W_OPSIZE, /* 1338 */
  IC_EVEX_L2_W_OPSIZE, /* 1339 */
  IC_EVEX_L2_W_OPSIZE, /* 1340 */
  IC_EVEX_L2_W_OPSIZE, /* 1341 */
  IC_EVEX_L2_W_OPSIZE, /* 1342 */
  IC_EVEX_L2_W_OPSIZE, /* 1343 */
  IC_EVEX_L2, /* 1344 */
  IC_EVEX_L2, /* 1345 */
  IC_EVEX_L2_XS, /* 1346 */
  IC_EVEX_L2_XS, /* 1347 */
  IC_EVEX_L2_XD, /* 1348 */
  IC_EVEX_L2_XD, /* 1349 */
  IC_EVEX_L2_XD, /* 1350 */
  IC_EVEX_L2_XD, /* 1351 */
  IC_EVEX_L2_W, /* 1352 */
  IC_EVEX_L2_W, /* 1353 */
  IC_EVEX_L2_W_XS, /* 1354 */
  IC_EVEX_L2_W_XS, /* 1355 */
  IC_EVEX_L2_W_XD, /* 1356 */
  IC_EVEX_L2_W_XD, /* 1357 */
  IC_EVEX_L2_W_XD, /* 1358 */
  IC_EVEX_L2_W_XD, /* 1359 */
  IC_EVEX_L2_OPSIZE, /* 1360 */
  IC_EVEX_L2_OPSIZE, /* 1361 */
  IC_EVEX_L2_OPSIZE, /* 1362 */
  IC_EVEX_L2_OPSIZE, /* 1363 */
  IC_EVEX_L2_OPSIZE, /* 1364 */
  IC_EVEX_L2_OPSIZE, /* 1365 */
  IC_EVEX_L2_OPSIZE, /* 1366 */
  IC_EVEX_L2_OPSIZE, /* 1367 */
  IC_EVEX_L2_W_OPSIZE, /* 1368 */
  IC_EVEX_L2_W_OPSIZE, /* 1369 */
  IC_EVEX_L2_W_OPSIZE, /* 1370 */
  IC_EVEX_L2_W_OPSIZE, /* 1371 */
  IC_EVEX_L2_W_OPSIZE, /* 1372 */
  IC_EVEX_L2_W_OPSIZE, /* 1373 */
  IC_EVEX_L2_W_OPSIZE, /* 1374 */
  IC_EVEX_L2_W_OPSIZE, /* 1375 */
  IC_EVEX_L2, /* 1376 */
  IC_EVEX_L2, /* 1377 */
  IC_EVEX_L2_XS, /* 1378 */
  IC_EVEX_L2_XS, /* 1379 */
  IC_EVEX_L2_XD, /* 1380 */
  IC_EVEX_L2_XD, /* 1381 */
  IC_EVEX_L2_XD, /* 1382 */
  IC_EVEX_L2_XD, /* 1383 */
  IC_EVEX_L2_W, /* 1384 */
  IC_EVEX_L2_W, /* 1385 */
  IC_EVEX_L2_W_XS, /* 1386 */
  IC_EVEX_L2_W_XS, /* 1387 */
  IC_EVEX_L2_W_XD, /* 1388 */
  IC_EVEX_L2_W_XD, /* 1389 */
  IC_EVEX_L2_W_XD, /* 1390 */
  IC_EVEX_L2_W_XD, /* 1391 */
  IC_EVEX_L2_OPSIZE, /* 1392 */
  IC_EVEX_L2_OPSIZE, /* 1393 */
  IC_EVEX_L2_OPSIZE, /* 1394 */
  IC_EVEX_L2_OPSIZE, /* 1395 */
  IC_EVEX_L2_OPSIZE, /* 1396 */
  IC_EVEX_L2_OPSIZE, /* 1397 */
  IC_EVEX_L2_OPSIZE, /* 1398 */
  IC_EVEX_L2_OPSIZE, /* 1399 */
  IC_EVEX_L2_W_OPSIZE, /* 1400 */
  IC_EVEX_L2_W_OPSIZE, /* 1401 */
  IC_EVEX_L2_W_OPSIZE, /* 1402 */
  IC_EVEX_L2_W_OPSIZE, /* 1403 */
  IC_EVEX_L2_W_OPSIZE, /* 1404 */
  IC_EVEX_L2_W_OPSIZE, /* 1405 */
  IC_EVEX_L2_W_OPSIZE, /* 1406 */
  IC_EVEX_L2_W_OPSIZE, /* 1407 */
  IC_EVEX_L2, /* 1408 */
  IC_EVEX_L2, /* 1409 */
  IC_EVEX_L2_XS, /* 1410 */
  IC_EVEX_L2_XS, /* 1411 */
  IC_EVEX_L2_XD, /* 1412 */
  IC_EVEX_L2_XD, /* 1413 */
  IC_EVEX_L2_XD, /* 1414 */
  IC_EVEX_L2_XD, /* 1415 */
  IC_EVEX_L2_W, /* 1416 */
  IC_EVEX_L2_W, /* 1417 */
  IC_EVEX_L2_W_XS, /* 1418 */
  IC_EVEX_L2_W_XS, /* 1419 */
  IC_EVEX_L2_W_XD, /* 1420 */
  IC_EVEX_L2_W_XD, /* 1421 */
  IC_EVEX_L2_W_XD, /* 1422 */
  IC_EVEX_L2_W_XD, /* 1423 */
  IC_EVEX_L2_OPSIZE, /* 1424 */
  IC_EVEX_L2_OPSIZE, /* 1425 */
  IC_EVEX_L2_OPSIZE, /* 1426 */
  IC_EVEX_L2_OPSIZE, /* 1427 */
  IC_EVEX_L2_OPSIZE, /* 1428 */
  IC_EVEX_L2_OPSIZE, /* 1429 */
  IC_EVEX_L2_OPSIZE, /* 1430 */
  IC_EVEX_L2_OPSIZE, /* 1431 */
  IC_EVEX_L2_W_OPSIZE, /* 1432 */
  IC_EVEX_L2_W_OPSIZE, /* 1433 */
  IC_EVEX_L2_W_OPSIZE, /* 1434 */
  IC_EVEX_L2_W_OPSIZE, /* 1435 */
  IC_EVEX_L2_W_OPSIZE, /* 1436 */
  IC_EVEX_L2_W_OPSIZE, /* 1437 */
  IC_EVEX_L2_W_OPSIZE, /* 1438 */
  IC_EVEX_L2_W_OPSIZE, /* 1439 */
  IC_EVEX_L2, /* 1440 */
  IC_EVEX_L2, /* 1441 */
  IC_EVEX_L2_XS, /* 1442 */
  IC_EVEX_L2_XS, /* 1443 */
  IC_EVEX_L2_XD, /* 1444 */
  IC_EVEX_L2_XD, /* 1445 */
  IC_EVEX_L2_XD, /* 1446 */
  IC_EVEX_L2_XD, /* 1447 */
  IC_EVEX_L2_W, /* 1448 */
  IC_EVEX_L2_W, /* 1449 */
  IC_EVEX_L2_W_XS, /* 1450 */
  IC_EVEX_L2_W_XS, /* 1451 */
  IC_EVEX_L2_W_XD, /* 1452 */
  IC_EVEX_L2_W_XD, /* 1453 */
  IC_EVEX_L2_W_XD, /* 1454 */
  IC_EVEX_L2_W_XD, /* 1455 */
  IC_EVEX_L2_OPSIZE, /* 1456 */
  IC_EVEX_L2_OPSIZE, /* 1457 */
  IC_EVEX_L2_OPSIZE, /* 1458 */
  IC_EVEX_L2_OPSIZE, /* 1459 */
  IC_EVEX_L2_OPSIZE, /* 1460 */
  IC_EVEX_L2_OPSIZE, /* 1461 */
  IC_EVEX_L2_OPSIZE, /* 1462 */
  IC_EVEX_L2_OPSIZE, /* 1463 */
  IC_EVEX_L2_W_OPSIZE, /* 1464 */
  IC_EVEX_L2_W_OPSIZE, /* 1465 */
  IC_EVEX_L2_W_OPSIZE, /* 1466 */
  IC_EVEX_L2_W_OPSIZE, /* 1467 */
  IC_EVEX_L2_W_OPSIZE, /* 1468 */
  IC_EVEX_L2_W_OPSIZE, /* 1469 */
  IC_EVEX_L2_W_OPSIZE, /* 1470 */
  IC_EVEX_L2_W_OPSIZE, /* 1471 */
  IC_EVEX_L2, /* 1472 */
  IC_EVEX_L2, /* 1473 */
  IC_EVEX_L2_XS, /* 1474 */
  IC_EVEX_L2_XS, /* 1475 */
  IC_EVEX_L2_XD, /* 1476 */
  IC_EVEX_L2_XD, /* 1477 */
  IC_EVEX_L2_XD, /* 1478 */
  IC_EVEX_L2_XD, /* 1479 */
  IC_EVEX_L2_W, /* 1480 */
  IC_EVEX_L2_W, /* 1481 */
  IC_EVEX_L2_W_XS, /* 1482 */
  IC_EVEX_L2_W_XS, /* 1483 */
  IC_EVEX_L2_W_XD, /* 1484 */
  IC_EVEX_L2_W_XD, /* 1485 */
  IC_EVEX_L2_W_XD, /* 1486 */
  IC_EVEX_L2_W_XD, /* 1487 */
  IC_EVEX_L2_OPSIZE, /* 1488 */
  IC_EVEX_L2_OPSIZE, /* 1489 */
  IC_EVEX_L2_OPSIZE, /* 1490 */
  IC_EVEX_L2_OPSIZE, /* 1491 */
  IC_EVEX_L2_OPSIZE, /* 1492 */
  IC_EVEX_L2_OPSIZE, /* 1493 */
  IC_EVEX_L2_OPSIZE, /* 1494 */
  IC_EVEX_L2_OPSIZE, /* 1495 */
  IC_EVEX_L2_W_OPSIZE, /* 1496 */
  IC_EVEX_L2_W_OPSIZE, /* 1497 */
  IC_EVEX_L2_W_OPSIZE, /* 1498 */
  IC_EVEX_L2_W_OPSIZE, /* 1499 */
  IC_EVEX_L2_W_OPSIZE, /* 1500 */
  IC_EVEX_L2_W_OPSIZE, /* 1501 */
  IC_EVEX_L2_W_OPSIZE, /* 1502 */
  IC_EVEX_L2_W_OPSIZE, /* 1503 */
  IC_EVEX_L2, /* 1504 */
  IC_EVEX_L2, /* 1505 */
  IC_EVEX_L2_XS, /* 1506 */
  IC_EVEX_L2_XS, /* 1507 */
  IC_EVEX_L2_XD, /* 1508 */
  IC_EVEX_L2_XD, /* 1509 */
  IC_EVEX_L2_XD, /* 1510 */
  IC_EVEX_L2_XD, /* 1511 */
  IC_EVEX_L2_W, /* 1512 */
  IC_EVEX_L2_W, /* 1513 */
  IC_EVEX_L2_W_XS, /* 1514 */
  IC_EVEX_L2_W_XS, /* 1515 */
  IC_EVEX_L2_W_XD, /* 1516 */
  IC_EVEX_L2_W_XD, /* 1517 */
  IC_EVEX_L2_W_XD, /* 1518 */
  IC_EVEX_L2_W_XD, /* 1519 */
  IC_EVEX_L2_OPSIZE, /* 1520 */
  IC_EVEX_L2_OPSIZE, /* 1521 */
  IC_EVEX_L2_OPSIZE, /* 1522 */
  IC_EVEX_L2_OPSIZE, /* 1523 */
  IC_EVEX_L2_OPSIZE, /* 1524 */
  IC_EVEX_L2_OPSIZE, /* 1525 */
  IC_EVEX_L2_OPSIZE, /* 1526 */
  IC_EVEX_L2_OPSIZE, /* 1527 */
  IC_EVEX_L2_W_OPSIZE, /* 1528 */
  IC_EVEX_L2_W_OPSIZE, /* 1529 */
  IC_EVEX_L2_W_OPSIZE, /* 1530 */
  IC_EVEX_L2_W_OPSIZE, /* 1531 */
  IC_EVEX_L2_W_OPSIZE, /* 1532 */
  IC_EVEX_L2_W_OPSIZE, /* 1533 */
  IC_EVEX_L2_W_OPSIZE, /* 1534 */
  IC_EVEX_L2_W_OPSIZE, /* 1535 */
  IC, /* 1536 */
  IC_64BIT, /* 1537 */
  IC_XS, /* 1538 */
  IC_64BIT_XS, /* 1539 */
  IC_XD, /* 1540 */
  IC_64BIT_XD, /* 1541 */
  IC_XS, /* 1542 */
  IC_64BIT_XS, /* 1543 */
  IC, /* 1544 */
  IC_64BIT_REXW, /* 1545 */
  IC_XS, /* 1546 */
  IC_64BIT_REXW_XS, /* 1547 */
  IC_XD, /* 1548 */
  IC_64BIT_REXW_XD, /* 1549 */
  IC_XS, /* 1550 */
  IC_64BIT_REXW_XS, /* 1551 */
  IC_OPSIZE, /* 1552 */
  IC_64BIT_OPSIZE, /* 1553 */
  IC_XS_OPSIZE, /* 1554 */
  IC_64BIT_XS_OPSIZE, /* 1555 */
  IC_XD_OPSIZE, /* 1556 */
  IC_64BIT_XD_OPSIZE, /* 1557 */
  IC_XS_OPSIZE, /* 1558 */
  IC_64BIT_XD_OPSIZE, /* 1559 */
  IC_OPSIZE, /* 1560 */
  IC_64BIT_REXW_OPSIZE, /* 1561 */
  IC_XS_OPSIZE, /* 1562 */
  IC_64BIT_REXW_XS, /* 1563 */
  IC_XD_OPSIZE, /* 1564 */
  IC_64BIT_REXW_XD, /* 1565 */
  IC_XS_OPSIZE, /* 1566 */
  IC_64BIT_REXW_XS, /* 1567 */
  IC_ADSIZE, /* 1568 */
  IC_64BIT_ADSIZE, /* 1569 */
  IC_XS, /* 1570 */
  IC_64BIT_XS, /* 1571 */
  IC_XD, /* 1572 */
  IC_64BIT_XD, /* 1573 */
  IC_XS, /* 1574 */
  IC_64BIT_XS, /* 1575 */
  IC_ADSIZE, /* 1576 */
  IC_64BIT_REXW_ADSIZE, /* 1577 */
  IC_XS, /* 1578 */
  IC_64BIT_REXW_XS, /* 1579 */
  IC_XD, /* 1580 */
  IC_64BIT_REXW_XD, /* 1581 */
  IC_XS, /* 1582 */
  IC_64BIT_REXW_XS, /* 1583 */
  IC_OPSIZE_ADSIZE, /* 1584 */
  IC_64BIT_OPSIZE_ADSIZE, /* 1585 */
  IC_XS_OPSIZE, /* 1586 */
  IC_64BIT_XS_OPSIZE, /* 1587 */
  IC_XD_OPSIZE, /* 1588 */
  IC_64BIT_XD_OPSIZE, /* 1589 */
  IC_XS_OPSIZE, /* 1590 */
  IC_64BIT_XD_OPSIZE, /* 1591 */
  IC_OPSIZE_ADSIZE, /* 1592 */
  IC_64BIT_REXW_OPSIZE, /* 1593 */
  IC_XS_OPSIZE, /* 1594 */
  IC_64BIT_REXW_XS, /* 1595 */
  IC_XD_OPSIZE, /* 1596 */
  IC_64BIT_REXW_XD, /* 1597 */
  IC_XS_OPSIZE, /* 1598 */
  IC_64BIT_REXW_XS, /* 1599 */
  IC_VEX, /* 1600 */
  IC_VEX, /* 1601 */
  IC_VEX_XS, /* 1602 */
  IC_VEX_XS, /* 1603 */
  IC_VEX_XD, /* 1604 */
  IC_VEX_XD, /* 1605 */
  IC_VEX_XD, /* 1606 */
  IC_VEX_XD, /* 1607 */
  IC_VEX_W, /* 1608 */
  IC_VEX_W, /* 1609 */
  IC_VEX_W_XS, /* 1610 */
  IC_VEX_W_XS, /* 1611 */
  IC_VEX_W_XD, /* 1612 */
  IC_VEX_W_XD, /* 1613 */
  IC_VEX_W_XD, /* 1614 */
  IC_VEX_W_XD, /* 1615 */
  IC_VEX_OPSIZE, /* 1616 */
  IC_VEX_OPSIZE, /* 1617 */
  IC_VEX_OPSIZE, /* 1618 */
  IC_VEX_OPSIZE, /* 1619 */
  IC_VEX_OPSIZE, /* 1620 */
  IC_VEX_OPSIZE, /* 1621 */
  IC_VEX_OPSIZE, /* 1622 */
  IC_VEX_OPSIZE, /* 1623 */
  IC_VEX_W_OPSIZE, /* 1624 */
  IC_VEX_W_OPSIZE, /* 1625 */
  IC_VEX_W_OPSIZE, /* 1626 */
  IC_VEX_W_OPSIZE, /* 1627 */
  IC_VEX_W_OPSIZE, /* 1628 */
  IC_VEX_W_OPSIZE, /* 1629 */
  IC_VEX_W_OPSIZE, /* 1630 */
  IC_VEX_W_OPSIZE, /* 1631 */
  IC_VEX, /* 1632 */
  IC_VEX, /* 1633 */
  IC_VEX_XS, /* 1634 */
  IC_VEX_XS, /* 1635 */
  IC_VEX_XD, /* 1636 */
  IC_VEX_XD, /* 1637 */
  IC_VEX_XD, /* 1638 */
  IC_VEX_XD, /* 1639 */
  IC_VEX_W, /* 1640 */
  IC_VEX_W, /* 1641 */
  IC_VEX_W_XS, /* 1642 */
  IC_VEX_W_XS, /* 1643 */
  IC_VEX_W_XD, /* 1644 */
  IC_VEX_W_XD, /* 1645 */
  IC_VEX_W_XD, /* 1646 */
  IC_VEX_W_XD, /* 1647 */
  IC_VEX_OPSIZE, /* 1648 */
  IC_VEX_OPSIZE, /* 1649 */
  IC_VEX_OPSIZE, /* 1650 */
  IC_VEX_OPSIZE, /* 1651 */
  IC_VEX_OPSIZE, /* 1652 */
  IC_VEX_OPSIZE, /* 1653 */
  IC_VEX_OPSIZE, /* 1654 */
  IC_VEX_OPSIZE, /* 1655 */
  IC_VEX_W_OPSIZE, /* 1656 */
  IC_VEX_W_OPSIZE, /* 1657 */
  IC_VEX_W_OPSIZE, /* 1658 */
  IC_VEX_W_OPSIZE, /* 1659 */
  IC_VEX_W_OPSIZE, /* 1660 */
  IC_VEX_W_OPSIZE, /* 1661 */
  IC_VEX_W_OPSIZE, /* 1662 */
  IC_VEX_W_OPSIZE, /* 1663 */
  IC_VEX_L, /* 1664 */
  IC_VEX_L, /* 1665 */
  IC_VEX_L_XS, /* 1666 */
  IC_VEX_L_XS, /* 1667 */
  IC_VEX_L_XD, /* 1668 */
  IC_VEX_L_XD, /* 1669 */
  IC_VEX_L_XD, /* 1670 */
  IC_VEX_L_XD, /* 1671 */
  IC_VEX_L_W, /* 1672 */
  IC_VEX_L_W, /* 1673 */
  IC_VEX_L_W_XS, /* 1674 */
  IC_VEX_L_W_XS, /* 1675 */
  IC_VEX_L_W_XD, /* 1676 */
  IC_VEX_L_W_XD, /* 1677 */
  IC_VEX_L_W_XD, /* 1678 */
  IC_VEX_L_W_XD, /* 1679 */
  IC_VEX_L_OPSIZE, /* 1680 */
  IC_VEX_L_OPSIZE, /* 1681 */
  IC_VEX_L_OPSIZE, /* 1682 */
  IC_VEX_L_OPSIZE, /* 1683 */
  IC_VEX_L_OPSIZE, /* 1684 */
  IC_VEX_L_OPSIZE, /* 1685 */
  IC_VEX_L_OPSIZE, /* 1686 */
  IC_VEX_L_OPSIZE, /* 1687 */
  IC_VEX_L_W_OPSIZE, /* 1688 */
  IC_VEX_L_W_OPSIZE, /* 1689 */
  IC_VEX_L_W_OPSIZE, /* 1690 */
  IC_VEX_L_W_OPSIZE, /* 1691 */
  IC_VEX_L_W_OPSIZE, /* 1692 */
  IC_VEX_L_W_OPSIZE, /* 1693 */
  IC_VEX_L_W_OPSIZE, /* 1694 */
  IC_VEX_L_W_OPSIZE, /* 1695 */
  IC_VEX_L, /* 1696 */
  IC_VEX_L, /* 1697 */
  IC_VEX_L_XS, /* 1698 */
  IC_VEX_L_XS, /* 1699 */
  IC_VEX_L_XD, /* 1700 */
  IC_VEX_L_XD, /* 1701 */
  IC_VEX_L_XD, /* 1702 */
  IC_VEX_L_XD, /* 1703 */
  IC_VEX_L_W, /* 1704 */
  IC_VEX_L_W, /* 1705 */
  IC_VEX_L_W_XS, /* 1706 */
  IC_VEX_L_W_XS, /* 1707 */
  IC_VEX_L_W_XD, /* 1708 */
  IC_VEX_L_W_XD, /* 1709 */
  IC_VEX_L_W_XD, /* 1710 */
  IC_VEX_L_W_XD, /* 1711 */
  IC_VEX_L_OPSIZE, /* 1712 */
  IC_VEX_L_OPSIZE, /* 1713 */
  IC_VEX_L_OPSIZE, /* 1714 */
  IC_VEX_L_OPSIZE, /* 1715 */
  IC_VEX_L_OPSIZE, /* 1716 */
  IC_VEX_L_OPSIZE, /* 1717 */
  IC_VEX_L_OPSIZE, /* 1718 */
  IC_VEX_L_OPSIZE, /* 1719 */
  IC_VEX_L_W_OPSIZE, /* 1720 */
  IC_VEX_L_W_OPSIZE, /* 1721 */
  IC_VEX_L_W_OPSIZE, /* 1722 */
  IC_VEX_L_W_OPSIZE, /* 1723 */
  IC_VEX_L_W_OPSIZE, /* 1724 */
  IC_VEX_L_W_OPSIZE, /* 1725 */
  IC_VEX_L_W_OPSIZE, /* 1726 */
  IC_VEX_L_W_OPSIZE, /* 1727 */
  IC_VEX_L, /* 1728 */
  IC_VEX_L, /* 1729 */
  IC_VEX_L_XS, /* 1730 */
  IC_VEX_L_XS, /* 1731 */
  IC_VEX_L_XD, /* 1732 */
  IC_VEX_L_XD, /* 1733 */
  IC_VEX_L_XD, /* 1734 */
  IC_VEX_L_XD, /* 1735 */
  IC_VEX_L_W, /* 1736 */
  IC_VEX_L_W, /* 1737 */
  IC_VEX_L_W_XS, /* 1738 */
  IC_VEX_L_W_XS, /* 1739 */
  IC_VEX_L_W_XD, /* 1740 */
  IC_VEX_L_W_XD, /* 1741 */
  IC_VEX_L_W_XD, /* 1742 */
  IC_VEX_L_W_XD, /* 1743 */
  IC_VEX_L_OPSIZE, /* 1744 */
  IC_VEX_L_OPSIZE, /* 1745 */
  IC_VEX_L_OPSIZE, /* 1746 */
  IC_VEX_L_OPSIZE, /* 1747 */
  IC_VEX_L_OPSIZE, /* 1748 */
  IC_VEX_L_OPSIZE, /* 1749 */
  IC_VEX_L_OPSIZE, /* 1750 */
  IC_VEX_L_OPSIZE, /* 1751 */
  IC_VEX_L_W_OPSIZE, /* 1752 */
  IC_VEX_L_W_OPSIZE, /* 1753 */
  IC_VEX_L_W_OPSIZE, /* 1754 */
  IC_VEX_L_W_OPSIZE, /* 1755 */
  IC_VEX_L_W_OPSIZE, /* 1756 */
  IC_VEX_L_W_OPSIZE, /* 1757 */
  IC_VEX_L_W_OPSIZE, /* 1758 */
  IC_VEX_L_W_OPSIZE, /* 1759 */
  IC_VEX_L, /* 1760 */
  IC_VEX_L, /* 1761 */
  IC_VEX_L_XS, /* 1762 */
  IC_VEX_L_XS, /* 1763 */
  IC_VEX_L_XD, /* 1764 */
  IC_VEX_L_XD, /* 1765 */
  IC_VEX_L_XD, /* 1766 */
  IC_VEX_L_XD, /* 1767 */
  IC_VEX_L_W, /* 1768 */
  IC_VEX_L_W, /* 1769 */
  IC_VEX_L_W_XS, /* 1770 */
  IC_VEX_L_W_XS, /* 1771 */
  IC_VEX_L_W_XD, /* 1772 */
  IC_VEX_L_W_XD, /* 1773 */
  IC_VEX_L_W_XD, /* 1774 */
  IC_VEX_L_W_XD, /* 1775 */
  IC_VEX_L_OPSIZE, /* 1776 */
  IC_VEX_L_OPSIZE, /* 1777 */
  IC_VEX_L_OPSIZE, /* 1778 */
  IC_VEX_L_OPSIZE, /* 1779 */
  IC_VEX_L_OPSIZE, /* 1780 */
  IC_VEX_L_OPSIZE, /* 1781 */
  IC_VEX_L_OPSIZE, /* 1782 */
  IC_VEX_L_OPSIZE, /* 1783 */
  IC_VEX_L_W_OPSIZE, /* 1784 */
  IC_VEX_L_W_OPSIZE, /* 1785 */
  IC_VEX_L_W_OPSIZE, /* 1786 */
  IC_VEX_L_W_OPSIZE, /* 1787 */
  IC_VEX_L_W_OPSIZE, /* 1788 */
  IC_VEX_L_W_OPSIZE, /* 1789 */
  IC_VEX_L_W_OPSIZE, /* 1790 */
  IC_VEX_L_W_OPSIZE, /* 1791 */
  IC_EVEX_L2, /* 1792 */
  IC_EVEX_L2, /* 1793 */
  IC_EVEX_L2_XS, /* 1794 */
  IC_EVEX_L2_XS, /* 1795 */
  IC_EVEX_L2_XD, /* 1796 */
  IC_EVEX_L2_XD, /* 1797 */
  IC_EVEX_L2_XD, /* 1798 */
  IC_EVEX_L2_XD, /* 1799 */
  IC_EVEX_L2_W, /* 1800 */
  IC_EVEX_L2_W, /* 1801 */
  IC_EVEX_L2_W_XS, /* 1802 */
  IC_EVEX_L2_W_XS, /* 1803 */
  IC_EVEX_L2_W_XD, /* 1804 */
  IC_EVEX_L2_W_XD, /* 1805 */
  IC_EVEX_L2_W_XD, /* 1806 */
  IC_EVEX_L2_W_XD, /* 1807 */
  IC_EVEX_L2_OPSIZE, /* 1808 */
  IC_EVEX_L2_OPSIZE, /* 1809 */
  IC_EVEX_L2_OPSIZE, /* 1810 */
  IC_EVEX_L2_OPSIZE, /* 1811 */
  IC_EVEX_L2_OPSIZE, /* 1812 */
  IC_EVEX_L2_OPSIZE, /* 1813 */
  IC_EVEX_L2_OPSIZE, /* 1814 */
  IC_EVEX_L2_OPSIZE, /* 1815 */
  IC_EVEX_L2_W_OPSIZE, /* 1816 */
  IC_EVEX_L2_W_OPSIZE, /* 1817 */
  IC_EVEX_L2_W_OPSIZE, /* 1818 */
  IC_EVEX_L2_W_OPSIZE, /* 1819 */
  IC_EVEX_L2_W_OPSIZE, /* 1820 */
  IC_EVEX_L2_W_OPSIZE, /* 1821 */
  IC_EVEX_L2_W_OPSIZE, /* 1822 */
  IC_EVEX_L2_W_OPSIZE, /* 1823 */
  IC_EVEX_L2, /* 1824 */
  IC_EVEX_L2, /* 1825 */
  IC_EVEX_L2_XS, /* 1826 */
  IC_EVEX_L2_XS, /* 1827 */
  IC_EVEX_L2_XD, /* 1828 */
  IC_EVEX_L2_XD, /* 1829 */
  IC_EVEX_L2_XD, /* 1830 */
  IC_EVEX_L2_XD, /* 1831 */
  IC_EVEX_L2_W, /* 1832 */
  IC_EVEX_L2_W, /* 1833 */
  IC_EVEX_L2_W_XS, /* 1834 */
  IC_EVEX_L2_W_XS, /* 1835 */
  IC_EVEX_L2_W_XD, /* 1836 */
  IC_EVEX_L2_W_XD, /* 1837 */
  IC_EVEX_L2_W_XD, /* 1838 */
  IC_EVEX_L2_W_XD, /* 1839 */
  IC_EVEX_L2_OPSIZE, /* 1840 */
  IC_EVEX_L2_OPSIZE, /* 1841 */
  IC_EVEX_L2_OPSIZE, /* 1842 */
  IC_EVEX_L2_OPSIZE, /* 1843 */
  IC_EVEX_L2_OPSIZE, /* 1844 */
  IC_EVEX_L2_OPSIZE, /* 1845 */
  IC_EVEX_L2_OPSIZE, /* 1846 */
  IC_EVEX_L2_OPSIZE, /* 1847 */
  IC_EVEX_L2_W_OPSIZE, /* 1848 */
  IC_EVEX_L2_W_OPSIZE, /* 1849 */
  IC_EVEX_L2_W_OPSIZE, /* 1850 */
  IC_EVEX_L2_W_OPSIZE, /* 1851 */
  IC_EVEX_L2_W_OPSIZE, /* 1852 */
  IC_EVEX_L2_W_OPSIZE, /* 1853 */
  IC_EVEX_L2_W_OPSIZE, /* 1854 */
  IC_EVEX_L2_W_OPSIZE, /* 1855 */
  IC_EVEX_L2, /* 1856 */
  IC_EVEX_L2, /* 1857 */
  IC_EVEX_L2_XS, /* 1858 */
  IC_EVEX_L2_XS, /* 1859 */
  IC_EVEX_L2_XD, /* 1860 */
  IC_EVEX_L2_XD, /* 1861 */
  IC_EVEX_L2_XD, /* 1862 */
  IC_EVEX_L2_XD, /* 1863 */
  IC_EVEX_L2_W, /* 1864 */
  IC_EVEX_L2_W, /* 1865 */
  IC_EVEX_L2_W_XS, /* 1866 */
  IC_EVEX_L2_W_XS, /* 1867 */
  IC_EVEX_L2_W_XD, /* 1868 */
  IC_EVEX_L2_W_XD, /* 1869 */
  IC_EVEX_L2_W_XD, /* 1870 */
  IC_EVEX_L2_W_XD, /* 1871 */
  IC_EVEX_L2_OPSIZE, /* 1872 */
  IC_EVEX_L2_OPSIZE, /* 1873 */
  IC_EVEX_L2_OPSIZE, /* 1874 */
  IC_EVEX_L2_OPSIZE, /* 1875 */
  IC_EVEX_L2_OPSIZE, /* 1876 */
  IC_EVEX_L2_OPSIZE, /* 1877 */
  IC_EVEX_L2_OPSIZE, /* 1878 */
  IC_EVEX_L2_OPSIZE, /* 1879 */
  IC_EVEX_L2_W_OPSIZE, /* 1880 */
  IC_EVEX_L2_W_OPSIZE, /* 1881 */
  IC_EVEX_L2_W_OPSIZE, /* 1882 */
  IC_EVEX_L2_W_OPSIZE, /* 1883 */
  IC_EVEX_L2_W_OPSIZE, /* 1884 */
  IC_EVEX_L2_W_OPSIZE, /* 1885 */
  IC_EVEX_L2_W_OPSIZE, /* 1886 */
  IC_EVEX_L2_W_OPSIZE, /* 1887 */
  IC_EVEX_L2, /* 1888 */
  IC_EVEX_L2, /* 1889 */
  IC_EVEX_L2_XS, /* 1890 */
  IC_EVEX_L2_XS, /* 1891 */
  IC_EVEX_L2_XD, /* 1892 */
  IC_EVEX_L2_XD, /* 1893 */
  IC_EVEX_L2_XD, /* 1894 */
  IC_EVEX_L2_XD, /* 1895 */
  IC_EVEX_L2_W, /* 1896 */
  IC_EVEX_L2_W, /* 1897 */
  IC_EVEX_L2_W_XS, /* 1898 */
  IC_EVEX_L2_W_XS, /* 1899 */
  IC_EVEX_L2_W_XD, /* 1900 */
  IC_EVEX_L2_W_XD, /* 1901 */
  IC_EVEX_L2_W_XD, /* 1902 */
  IC_EVEX_L2_W_XD, /* 1903 */
  IC_EVEX_L2_OPSIZE, /* 1904 */
  IC_EVEX_L2_OPSIZE, /* 1905 */
  IC_EVEX_L2_OPSIZE, /* 1906 */
  IC_EVEX_L2_OPSIZE, /* 1907 */
  IC_EVEX_L2_OPSIZE, /* 1908 */
  IC_EVEX_L2_OPSIZE, /* 1909 */
  IC_EVEX_L2_OPSIZE, /* 1910 */
  IC_EVEX_L2_OPSIZE, /* 1911 */
  IC_EVEX_L2_W_OPSIZE, /* 1912 */
  IC_EVEX_L2_W_OPSIZE, /* 1913 */
  IC_EVEX_L2_W_OPSIZE, /* 1914 */
  IC_EVEX_L2_W_OPSIZE, /* 1915 */
  IC_EVEX_L2_W_OPSIZE, /* 1916 */
  IC_EVEX_L2_W_OPSIZE, /* 1917 */
  IC_EVEX_L2_W_OPSIZE, /* 1918 */
  IC_EVEX_L2_W_OPSIZE, /* 1919 */
  IC_EVEX_L2, /* 1920 */
  IC_EVEX_L2, /* 1921 */
  IC_EVEX_L2_XS, /* 1922 */
  IC_EVEX_L2_XS, /* 1923 */
  IC_EVEX_L2_XD, /* 1924 */
  IC_EVEX_L2_XD, /* 1925 */
  IC_EVEX_L2_XD, /* 1926 */
  IC_EVEX_L2_XD, /* 1927 */
  IC_EVEX_L2_W, /* 1928 */
  IC_EVEX_L2_W, /* 1929 */
  IC_EVEX_L2_W_XS, /* 1930 */
  IC_EVEX_L2_W_XS, /* 1931 */
  IC_EVEX_L2_W_XD, /* 1932 */
  IC_EVEX_L2_W_XD, /* 1933 */
  IC_EVEX_L2_W_XD, /* 1934 */
  IC_EVEX_L2_W_XD, /* 1935 */
  IC_EVEX_L2_OPSIZE, /* 1936 */
  IC_EVEX_L2_OPSIZE, /* 1937 */
  IC_EVEX_L2_OPSIZE, /* 1938 */
  IC_EVEX_L2_OPSIZE, /* 1939 */
  IC_EVEX_L2_OPSIZE, /* 1940 */
  IC_EVEX_L2_OPSIZE, /* 1941 */
  IC_EVEX_L2_OPSIZE, /* 1942 */
  IC_EVEX_L2_OPSIZE, /* 1943 */
  IC_EVEX_L2_W_OPSIZE, /* 1944 */
  IC_EVEX_L2_W_OPSIZE, /* 1945 */
  IC_EVEX_L2_W_OPSIZE, /* 1946 */
  IC_EVEX_L2_W_OPSIZE, /* 1947 */
  IC_EVEX_L2_W_OPSIZE, /* 1948 */
  IC_EVEX_L2_W_OPSIZE, /* 1949 */
  IC_EVEX_L2_W_OPSIZE, /* 1950 */
  IC_EVEX_L2_W_OPSIZE, /* 1951 */
  IC_EVEX_L2, /* 1952 */
  IC_EVEX_L2, /* 1953 */
  IC_EVEX_L2_XS, /* 1954 */
  IC_EVEX_L2_XS, /* 1955 */
  IC_EVEX_L2_XD, /* 1956 */
  IC_EVEX_L2_XD, /* 1957 */
  IC_EVEX_L2_XD, /* 1958 */
  IC_EVEX_L2_XD, /* 1959 */
  IC_EVEX_L2_W, /* 1960 */
  IC_EVEX_L2_W, /* 1961 */
  IC_EVEX_L2_W_XS, /* 1962 */
  IC_EVEX_L2_W_XS, /* 1963 */
  IC_EVEX_L2_W_XD, /* 1964 */
  IC_EVEX_L2_W_XD, /* 1965 */
  IC_EVEX_L2_W_XD, /* 1966 */
  IC_EVEX_L2_W_XD, /* 1967 */
  IC_EVEX_L2_OPSIZE, /* 1968 */
  IC_EVEX_L2_OPSIZE, /* 1969 */
  IC_EVEX_L2_OPSIZE, /* 1970 */
  IC_EVEX_L2_OPSIZE, /* 1971 */
  IC_EVEX_L2_OPSIZE, /* 1972 */
  IC_EVEX_L2_OPSIZE, /* 1973 */
  IC_EVEX_L2_OPSIZE, /* 1974 */
  IC_EVEX_L2_OPSIZE, /* 1975 */
  IC_EVEX_L2_W_OPSIZE, /* 1976 */
  IC_EVEX_L2_W_OPSIZE, /* 1977 */
  IC_EVEX_L2_W_OPSIZE, /* 1978 */
  IC_EVEX_L2_W_OPSIZE, /* 1979 */
  IC_EVEX_L2_W_OPSIZE, /* 1980 */
  IC_EVEX_L2_W_OPSIZE, /* 1981 */
  IC_EVEX_L2_W_OPSIZE, /* 1982 */
  IC_EVEX_L2_W_OPSIZE, /* 1983 */
  IC_EVEX_L2, /* 1984 */
  IC_EVEX_L2, /* 1985 */
  IC_EVEX_L2_XS, /* 1986 */
  IC_EVEX_L2_XS, /* 1987 */
  IC_EVEX_L2_XD, /* 1988 */
  IC_EVEX_L2_XD, /* 1989 */
  IC_EVEX_L2_XD, /* 1990 */
  IC_EVEX_L2_XD, /* 1991 */
  IC_EVEX_L2_W, /* 1992 */
  IC_EVEX_L2_W, /* 1993 */
  IC_EVEX_L2_W_XS, /* 1994 */
  IC_EVEX_L2_W_XS, /* 1995 */
  IC_EVEX_L2_W_XD, /* 1996 */
  IC_EVEX_L2_W_XD, /* 1997 */
  IC_EVEX_L2_W_XD, /* 1998 */
  IC_EVEX_L2_W_XD, /* 1999 */
  IC_EVEX_L2_OPSIZE, /* 2000 */
  IC_EVEX_L2_OPSIZE, /* 2001 */
  IC_EVEX_L2_OPSIZE, /* 2002 */
  IC_EVEX_L2_OPSIZE, /* 2003 */
  IC_EVEX_L2_OPSIZE, /* 2004 */
  IC_EVEX_L2_OPSIZE, /* 2005 */
  IC_EVEX_L2_OPSIZE, /* 2006 */
  IC_EVEX_L2_OPSIZE, /* 2007 */
  IC_EVEX_L2_W_OPSIZE, /* 2008 */
  IC_EVEX_L2_W_OPSIZE, /* 2009 */
  IC_EVEX_L2_W_OPSIZE, /* 2010 */
  IC_EVEX_L2_W_OPSIZE, /* 2011 */
  IC_EVEX_L2_W_OPSIZE, /* 2012 */
  IC_EVEX_L2_W_OPSIZE, /* 2013 */
  IC_EVEX_L2_W_OPSIZE, /* 2014 */
  IC_EVEX_L2_W_OPSIZE, /* 2015 */
  IC_EVEX_L2, /* 2016 */
  IC_EVEX_L2, /* 2017 */
  IC_EVEX_L2_XS, /* 2018 */
  IC_EVEX_L2_XS, /* 2019 */
  IC_EVEX_L2_XD, /* 2020 */
  IC_EVEX_L2_XD, /* 2021 */
  IC_EVEX_L2_XD, /* 2022 */
  IC_EVEX_L2_XD, /* 2023 */
  IC_EVEX_L2_W, /* 2024 */
  IC_EVEX_L2_W, /* 2025 */
  IC_EVEX_L2_W_XS, /* 2026 */
  IC_EVEX_L2_W_XS, /* 2027 */
  IC_EVEX_L2_W_XD, /* 2028 */
  IC_EVEX_L2_W_XD, /* 2029 */
  IC_EVEX_L2_W_XD, /* 2030 */
  IC_EVEX_L2_W_XD, /* 2031 */
  IC_EVEX_L2_OPSIZE, /* 2032 */
  IC_EVEX_L2_OPSIZE, /* 2033 */
  IC_EVEX_L2_OPSIZE, /* 2034 */
  IC_EVEX_L2_OPSIZE, /* 2035 */
  IC_EVEX_L2_OPSIZE, /* 2036 */
  IC_EVEX_L2_OPSIZE, /* 2037 */
  IC_EVEX_L2_OPSIZE, /* 2038 */
  IC_EVEX_L2_OPSIZE, /* 2039 */
  IC_EVEX_L2_W_OPSIZE, /* 2040 */
  IC_EVEX_L2_W_OPSIZE, /* 2041 */
  IC_EVEX_L2_W_OPSIZE, /* 2042 */
  IC_EVEX_L2_W_OPSIZE, /* 2043 */
  IC_EVEX_L2_W_OPSIZE, /* 2044 */
  IC_EVEX_L2_W_OPSIZE, /* 2045 */
  IC_EVEX_L2_W_OPSIZE, /* 2046 */
  IC_EVEX_L2_W_OPSIZE, /* 2047 */
  IC, /* 2048 */
  IC_64BIT, /* 2049 */
  IC_XS, /* 2050 */
  IC_64BIT_XS, /* 2051 */
  IC_XD, /* 2052 */
  IC_64BIT_XD, /* 2053 */
  IC_XS, /* 2054 */
  IC_64BIT_XS, /* 2055 */
  IC, /* 2056 */
  IC_64BIT_REXW, /* 2057 */
  IC_XS, /* 2058 */
  IC_64BIT_REXW_XS, /* 2059 */
  IC_XD, /* 2060 */
  IC_64BIT_REXW_XD, /* 2061 */
  IC_XS, /* 2062 */
  IC_64BIT_REXW_XS, /* 2063 */
  IC_OPSIZE, /* 2064 */
  IC_64BIT_OPSIZE, /* 2065 */
  IC_XS_OPSIZE, /* 2066 */
  IC_64BIT_XS_OPSIZE, /* 2067 */
  IC_XD_OPSIZE, /* 2068 */
  IC_64BIT_XD_OPSIZE, /* 2069 */
  IC_XS_OPSIZE, /* 2070 */
  IC_64BIT_XD_OPSIZE, /* 2071 */
  IC_OPSIZE, /* 2072 */
  IC_64BIT_REXW_OPSIZE, /* 2073 */
  IC_XS_OPSIZE, /* 2074 */
  IC_64BIT_REXW_XS, /* 2075 */
  IC_XD_OPSIZE, /* 2076 */
  IC_64BIT_REXW_XD, /* 2077 */
  IC_XS_OPSIZE, /* 2078 */
  IC_64BIT_REXW_XS, /* 2079 */
  IC_ADSIZE, /* 2080 */
  IC_64BIT_ADSIZE, /* 2081 */
  IC_XS, /* 2082 */
  IC_64BIT_XS, /* 2083 */
  IC_XD, /* 2084 */
  IC_64BIT_XD, /* 2085 */
  IC_XS, /* 2086 */
  IC_64BIT_XS, /* 2087 */
  IC_ADSIZE, /* 2088 */
  IC_64BIT_REXW_ADSIZE, /* 2089 */
  IC_XS, /* 2090 */
  IC_64BIT_REXW_XS, /* 2091 */
  IC_XD, /* 2092 */
  IC_64BIT_REXW_XD, /* 2093 */
  IC_XS, /* 2094 */
  IC_64BIT_REXW_XS, /* 2095 */
  IC_OPSIZE_ADSIZE, /* 2096 */
  IC_64BIT_OPSIZE_ADSIZE, /* 2097 */
  IC_XS_OPSIZE, /* 2098 */
  IC_64BIT_XS_OPSIZE, /* 2099 */
  IC_XD_OPSIZE, /* 2100 */
  IC_64BIT_XD_OPSIZE, /* 2101 */
  IC_XS_OPSIZE, /* 2102 */
  IC_64BIT_XD_OPSIZE, /* 2103 */
  IC_OPSIZE_ADSIZE, /* 2104 */
  IC_64BIT_REXW_OPSIZE, /* 2105 */
  IC_XS_OPSIZE, /* 2106 */
  IC_64BIT_REXW_XS, /* 2107 */
  IC_XD_OPSIZE, /* 2108 */
  IC_64BIT_REXW_XD, /* 2109 */
  IC_XS_OPSIZE, /* 2110 */
  IC_64BIT_REXW_XS, /* 2111 */
  IC_VEX, /* 2112 */
  IC_VEX, /* 2113 */
  IC_VEX_XS, /* 2114 */
  IC_VEX_XS, /* 2115 */
  IC_VEX_XD, /* 2116 */
  IC_VEX_XD, /* 2117 */
  IC_VEX_XD, /* 2118 */
  IC_VEX_XD, /* 2119 */
  IC_VEX_W, /* 2120 */
  IC_VEX_W, /* 2121 */
  IC_VEX_W_XS, /* 2122 */
  IC_VEX_W_XS, /* 2123 */
  IC_VEX_W_XD, /* 2124 */
  IC_VEX_W_XD, /* 2125 */
  IC_VEX_W_XD, /* 2126 */
  IC_VEX_W_XD, /* 2127 */
  IC_VEX_OPSIZE, /* 2128 */
  IC_VEX_OPSIZE, /* 2129 */
  IC_VEX_OPSIZE, /* 2130 */
  IC_VEX_OPSIZE, /* 2131 */
  IC_VEX_OPSIZE, /* 2132 */
  IC_VEX_OPSIZE, /* 2133 */
  IC_VEX_OPSIZE, /* 2134 */
  IC_VEX_OPSIZE, /* 2135 */
  IC_VEX_W_OPSIZE, /* 2136 */
  IC_VEX_W_OPSIZE, /* 2137 */
  IC_VEX_W_OPSIZE, /* 2138 */
  IC_VEX_W_OPSIZE, /* 2139 */
  IC_VEX_W_OPSIZE, /* 2140 */
  IC_VEX_W_OPSIZE, /* 2141 */
  IC_VEX_W_OPSIZE, /* 2142 */
  IC_VEX_W_OPSIZE, /* 2143 */
  IC_VEX, /* 2144 */
  IC_VEX, /* 2145 */
  IC_VEX_XS, /* 2146 */
  IC_VEX_XS, /* 2147 */
  IC_VEX_XD, /* 2148 */
  IC_VEX_XD, /* 2149 */
  IC_VEX_XD, /* 2150 */
  IC_VEX_XD, /* 2151 */
  IC_VEX_W, /* 2152 */
  IC_VEX_W, /* 2153 */
  IC_VEX_W_XS, /* 2154 */
  IC_VEX_W_XS, /* 2155 */
  IC_VEX_W_XD, /* 2156 */
  IC_VEX_W_XD, /* 2157 */
  IC_VEX_W_XD, /* 2158 */
  IC_VEX_W_XD, /* 2159 */
  IC_VEX_OPSIZE, /* 2160 */
  IC_VEX_OPSIZE, /* 2161 */
  IC_VEX_OPSIZE, /* 2162 */
  IC_VEX_OPSIZE, /* 2163 */
  IC_VEX_OPSIZE, /* 2164 */
  IC_VEX_OPSIZE, /* 2165 */
  IC_VEX_OPSIZE, /* 2166 */
  IC_VEX_OPSIZE, /* 2167 */
  IC_VEX_W_OPSIZE, /* 2168 */
  IC_VEX_W_OPSIZE, /* 2169 */
  IC_VEX_W_OPSIZE, /* 2170 */
  IC_VEX_W_OPSIZE, /* 2171 */
  IC_VEX_W_OPSIZE, /* 2172 */
  IC_VEX_W_OPSIZE, /* 2173 */
  IC_VEX_W_OPSIZE, /* 2174 */
  IC_VEX_W_OPSIZE, /* 2175 */
  IC_VEX_L, /* 2176 */
  IC_VEX_L, /* 2177 */
  IC_VEX_L_XS, /* 2178 */
  IC_VEX_L_XS, /* 2179 */
  IC_VEX_L_XD, /* 2180 */
  IC_VEX_L_XD, /* 2181 */
  IC_VEX_L_XD, /* 2182 */
  IC_VEX_L_XD, /* 2183 */
  IC_VEX_L_W, /* 2184 */
  IC_VEX_L_W, /* 2185 */
  IC_VEX_L_W_XS, /* 2186 */
  IC_VEX_L_W_XS, /* 2187 */
  IC_VEX_L_W_XD, /* 2188 */
  IC_VEX_L_W_XD, /* 2189 */
  IC_VEX_L_W_XD, /* 2190 */
  IC_VEX_L_W_XD, /* 2191 */
  IC_VEX_L_OPSIZE, /* 2192 */
  IC_VEX_L_OPSIZE, /* 2193 */
  IC_VEX_L_OPSIZE, /* 2194 */
  IC_VEX_L_OPSIZE, /* 2195 */
  IC_VEX_L_OPSIZE, /* 2196 */
  IC_VEX_L_OPSIZE, /* 2197 */
  IC_VEX_L_OPSIZE, /* 2198 */
  IC_VEX_L_OPSIZE, /* 2199 */
  IC_VEX_L_W_OPSIZE, /* 2200 */
  IC_VEX_L_W_OPSIZE, /* 2201 */
  IC_VEX_L_W_OPSIZE, /* 2202 */
  IC_VEX_L_W_OPSIZE, /* 2203 */
  IC_VEX_L_W_OPSIZE, /* 2204 */
  IC_VEX_L_W_OPSIZE, /* 2205 */
  IC_VEX_L_W_OPSIZE, /* 2206 */
  IC_VEX_L_W_OPSIZE, /* 2207 */
  IC_VEX_L, /* 2208 */
  IC_VEX_L, /* 2209 */
  IC_VEX_L_XS, /* 2210 */
  IC_VEX_L_XS, /* 2211 */
  IC_VEX_L_XD, /* 2212 */
  IC_VEX_L_XD, /* 2213 */
  IC_VEX_L_XD, /* 2214 */
  IC_VEX_L_XD, /* 2215 */
  IC_VEX_L_W, /* 2216 */
  IC_VEX_L_W, /* 2217 */
  IC_VEX_L_W_XS, /* 2218 */
  IC_VEX_L_W_XS, /* 2219 */
  IC_VEX_L_W_XD, /* 2220 */
  IC_VEX_L_W_XD, /* 2221 */
  IC_VEX_L_W_XD, /* 2222 */
  IC_VEX_L_W_XD, /* 2223 */
  IC_VEX_L_OPSIZE, /* 2224 */
  IC_VEX_L_OPSIZE, /* 2225 */
  IC_VEX_L_OPSIZE, /* 2226 */
  IC_VEX_L_OPSIZE, /* 2227 */
  IC_VEX_L_OPSIZE, /* 2228 */
  IC_VEX_L_OPSIZE, /* 2229 */
  IC_VEX_L_OPSIZE, /* 2230 */
  IC_VEX_L_OPSIZE, /* 2231 */
  IC_VEX_L_W_OPSIZE, /* 2232 */
  IC_VEX_L_W_OPSIZE, /* 2233 */
  IC_VEX_L_W_OPSIZE, /* 2234 */
  IC_VEX_L_W_OPSIZE, /* 2235 */
  IC_VEX_L_W_OPSIZE, /* 2236 */
  IC_VEX_L_W_OPSIZE, /* 2237 */
  IC_VEX_L_W_OPSIZE, /* 2238 */
  IC_VEX_L_W_OPSIZE, /* 2239 */
  IC_VEX_L, /* 2240 */
  IC_VEX_L, /* 2241 */
  IC_VEX_L_XS, /* 2242 */
  IC_VEX_L_XS, /* 2243 */
  IC_VEX_L_XD, /* 2244 */
  IC_VEX_L_XD, /* 2245 */
  IC_VEX_L_XD, /* 2246 */
  IC_VEX_L_XD, /* 2247 */
  IC_VEX_L_W, /* 2248 */
  IC_VEX_L_W, /* 2249 */
  IC_VEX_L_W_XS, /* 2250 */
  IC_VEX_L_W_XS, /* 2251 */
  IC_VEX_L_W_XD, /* 2252 */
  IC_VEX_L_W_XD, /* 2253 */
  IC_VEX_L_W_XD, /* 2254 */
  IC_VEX_L_W_XD, /* 2255 */
  IC_VEX_L_OPSIZE, /* 2256 */
  IC_VEX_L_OPSIZE, /* 2257 */
  IC_VEX_L_OPSIZE, /* 2258 */
  IC_VEX_L_OPSIZE, /* 2259 */
  IC_VEX_L_OPSIZE, /* 2260 */
  IC_VEX_L_OPSIZE, /* 2261 */
  IC_VEX_L_OPSIZE, /* 2262 */
  IC_VEX_L_OPSIZE, /* 2263 */
  IC_VEX_L_W_OPSIZE, /* 2264 */
  IC_VEX_L_W_OPSIZE, /* 2265 */
  IC_VEX_L_W_OPSIZE, /* 2266 */
  IC_VEX_L_W_OPSIZE, /* 2267 */
  IC_VEX_L_W_OPSIZE, /* 2268 */
  IC_VEX_L_W_OPSIZE, /* 2269 */
  IC_VEX_L_W_OPSIZE, /* 2270 */
  IC_VEX_L_W_OPSIZE, /* 2271 */
  IC_VEX_L, /* 2272 */
  IC_VEX_L, /* 2273 */
  IC_VEX_L_XS, /* 2274 */
  IC_VEX_L_XS, /* 2275 */
  IC_VEX_L_XD, /* 2276 */
  IC_VEX_L_XD, /* 2277 */
  IC_VEX_L_XD, /* 2278 */
  IC_VEX_L_XD, /* 2279 */
  IC_VEX_L_W, /* 2280 */
  IC_VEX_L_W, /* 2281 */
  IC_VEX_L_W_XS, /* 2282 */
  IC_VEX_L_W_XS, /* 2283 */
  IC_VEX_L_W_XD, /* 2284 */
  IC_VEX_L_W_XD, /* 2285 */
  IC_VEX_L_W_XD, /* 2286 */
  IC_VEX_L_W_XD, /* 2287 */
  IC_VEX_L_OPSIZE, /* 2288 */
  IC_VEX_L_OPSIZE, /* 2289 */
  IC_VEX_L_OPSIZE, /* 2290 */
  IC_VEX_L_OPSIZE, /* 2291 */
  IC_VEX_L_OPSIZE, /* 2292 */
  IC_VEX_L_OPSIZE, /* 2293 */
  IC_VEX_L_OPSIZE, /* 2294 */
  IC_VEX_L_OPSIZE, /* 2295 */
  IC_VEX_L_W_OPSIZE, /* 2296 */
  IC_VEX_L_W_OPSIZE, /* 2297 */
  IC_VEX_L_W_OPSIZE, /* 2298 */
  IC_VEX_L_W_OPSIZE, /* 2299 */
  IC_VEX_L_W_OPSIZE, /* 2300 */
  IC_VEX_L_W_OPSIZE, /* 2301 */
  IC_VEX_L_W_OPSIZE, /* 2302 */
  IC_VEX_L_W_OPSIZE, /* 2303 */
  IC_EVEX_K, /* 2304 */
  IC_EVEX_K, /* 2305 */
  IC_EVEX_XS_K, /* 2306 */
  IC_EVEX_XS_K, /* 2307 */
  IC_EVEX_XD_K, /* 2308 */
  IC_EVEX_XD_K, /* 2309 */
  IC_EVEX_XD_K, /* 2310 */
  IC_EVEX_XD_K, /* 2311 */
  IC_EVEX_W_K, /* 2312 */
  IC_EVEX_W_K, /* 2313 */
  IC_EVEX_W_XS_K, /* 2314 */
  IC_EVEX_W_XS_K, /* 2315 */
  IC_EVEX_W_XD_K, /* 2316 */
  IC_EVEX_W_XD_K, /* 2317 */
  IC_EVEX_W_XD_K, /* 2318 */
  IC_EVEX_W_XD_K, /* 2319 */
  IC_EVEX_OPSIZE_K, /* 2320 */
  IC_EVEX_OPSIZE_K, /* 2321 */
  IC_EVEX_OPSIZE_K, /* 2322 */
  IC_EVEX_OPSIZE_K, /* 2323 */
  IC_EVEX_OPSIZE_K, /* 2324 */
  IC_EVEX_OPSIZE_K, /* 2325 */
  IC_EVEX_OPSIZE_K, /* 2326 */
  IC_EVEX_OPSIZE_K, /* 2327 */
  IC_EVEX_W_OPSIZE_K, /* 2328 */
  IC_EVEX_W_OPSIZE_K, /* 2329 */
  IC_EVEX_W_OPSIZE_K, /* 2330 */
  IC_EVEX_W_OPSIZE_K, /* 2331 */
  IC_EVEX_W_OPSIZE_K, /* 2332 */
  IC_EVEX_W_OPSIZE_K, /* 2333 */
  IC_EVEX_W_OPSIZE_K, /* 2334 */
  IC_EVEX_W_OPSIZE_K, /* 2335 */
  IC_EVEX_K, /* 2336 */
  IC_EVEX_K, /* 2337 */
  IC_EVEX_XS_K, /* 2338 */
  IC_EVEX_XS_K, /* 2339 */
  IC_EVEX_XD_K, /* 2340 */
  IC_EVEX_XD_K, /* 2341 */
  IC_EVEX_XD_K, /* 2342 */
  IC_EVEX_XD_K, /* 2343 */
  IC_EVEX_W_K, /* 2344 */
  IC_EVEX_W_K, /* 2345 */
  IC_EVEX_W_XS_K, /* 2346 */
  IC_EVEX_W_XS_K, /* 2347 */
  IC_EVEX_W_XD_K, /* 2348 */
  IC_EVEX_W_XD_K, /* 2349 */
  IC_EVEX_W_XD_K, /* 2350 */
  IC_EVEX_W_XD_K, /* 2351 */
  IC_EVEX_OPSIZE_K, /* 2352 */
  IC_EVEX_OPSIZE_K, /* 2353 */
  IC_EVEX_OPSIZE_K, /* 2354 */
  IC_EVEX_OPSIZE_K, /* 2355 */
  IC_EVEX_OPSIZE_K, /* 2356 */
  IC_EVEX_OPSIZE_K, /* 2357 */
  IC_EVEX_OPSIZE_K, /* 2358 */
  IC_EVEX_OPSIZE_K, /* 2359 */
  IC_EVEX_W_OPSIZE_K, /* 2360 */
  IC_EVEX_W_OPSIZE_K, /* 2361 */
  IC_EVEX_W_OPSIZE_K, /* 2362 */
  IC_EVEX_W_OPSIZE_K, /* 2363 */
  IC_EVEX_W_OPSIZE_K, /* 2364 */
  IC_EVEX_W_OPSIZE_K, /* 2365 */
  IC_EVEX_W_OPSIZE_K, /* 2366 */
  IC_EVEX_W_OPSIZE_K, /* 2367 */
  IC_EVEX_K, /* 2368 */
  IC_EVEX_K, /* 2369 */
  IC_EVEX_XS_K, /* 2370 */
  IC_EVEX_XS_K, /* 2371 */
  IC_EVEX_XD_K, /* 2372 */
  IC_EVEX_XD_K, /* 2373 */
  IC_EVEX_XD_K, /* 2374 */
  IC_EVEX_XD_K, /* 2375 */
  IC_EVEX_W_K, /* 2376 */
  IC_EVEX_W_K, /* 2377 */
  IC_EVEX_W_XS_K, /* 2378 */
  IC_EVEX_W_XS_K, /* 2379 */
  IC_EVEX_W_XD_K, /* 2380 */
  IC_EVEX_W_XD_K, /* 2381 */
  IC_EVEX_W_XD_K, /* 2382 */
  IC_EVEX_W_XD_K, /* 2383 */
  IC_EVEX_OPSIZE_K, /* 2384 */
  IC_EVEX_OPSIZE_K, /* 2385 */
  IC_EVEX_OPSIZE_K, /* 2386 */
  IC_EVEX_OPSIZE_K, /* 2387 */
  IC_EVEX_OPSIZE_K, /* 2388 */
  IC_EVEX_OPSIZE_K, /* 2389 */
  IC_EVEX_OPSIZE_K, /* 2390 */
  IC_EVEX_OPSIZE_K, /* 2391 */
  IC_EVEX_W_OPSIZE_K, /* 2392 */
  IC_EVEX_W_OPSIZE_K, /* 2393 */
  IC_EVEX_W_OPSIZE_K, /* 2394 */
  IC_EVEX_W_OPSIZE_K, /* 2395 */
  IC_EVEX_W_OPSIZE_K, /* 2396 */
  IC_EVEX_W_OPSIZE_K, /* 2397 */
  IC_EVEX_W_OPSIZE_K, /* 2398 */
  IC_EVEX_W_OPSIZE_K, /* 2399 */
  IC_EVEX_K, /* 2400 */
  IC_EVEX_K, /* 2401 */
  IC_EVEX_XS_K, /* 2402 */
  IC_EVEX_XS_K, /* 2403 */
  IC_EVEX_XD_K, /* 2404 */
  IC_EVEX_XD_K, /* 2405 */
  IC_EVEX_XD_K, /* 2406 */
  IC_EVEX_XD_K, /* 2407 */
  IC_EVEX_W_K, /* 2408 */
  IC_EVEX_W_K, /* 2409 */
  IC_EVEX_W_XS_K, /* 2410 */
  IC_EVEX_W_XS_K, /* 2411 */
  IC_EVEX_W_XD_K, /* 2412 */
  IC_EVEX_W_XD_K, /* 2413 */
  IC_EVEX_W_XD_K, /* 2414 */
  IC_EVEX_W_XD_K, /* 2415 */
  IC_EVEX_OPSIZE_K, /* 2416 */
  IC_EVEX_OPSIZE_K, /* 2417 */
  IC_EVEX_OPSIZE_K, /* 2418 */
  IC_EVEX_OPSIZE_K, /* 2419 */
  IC_EVEX_OPSIZE_K, /* 2420 */
  IC_EVEX_OPSIZE_K, /* 2421 */
  IC_EVEX_OPSIZE_K, /* 2422 */
  IC_EVEX_OPSIZE_K, /* 2423 */
  IC_EVEX_W_OPSIZE_K, /* 2424 */
  IC_EVEX_W_OPSIZE_K, /* 2425 */
  IC_EVEX_W_OPSIZE_K, /* 2426 */
  IC_EVEX_W_OPSIZE_K, /* 2427 */
  IC_EVEX_W_OPSIZE_K, /* 2428 */
  IC_EVEX_W_OPSIZE_K, /* 2429 */
  IC_EVEX_W_OPSIZE_K, /* 2430 */
  IC_EVEX_W_OPSIZE_K, /* 2431 */
  IC_EVEX_K, /* 2432 */
  IC_EVEX_K, /* 2433 */
  IC_EVEX_XS_K, /* 2434 */
  IC_EVEX_XS_K, /* 2435 */
  IC_EVEX_XD_K, /* 2436 */
  IC_EVEX_XD_K, /* 2437 */
  IC_EVEX_XD_K, /* 2438 */
  IC_EVEX_XD_K, /* 2439 */
  IC_EVEX_W_K, /* 2440 */
  IC_EVEX_W_K, /* 2441 */
  IC_EVEX_W_XS_K, /* 2442 */
  IC_EVEX_W_XS_K, /* 2443 */
  IC_EVEX_W_XD_K, /* 2444 */
  IC_EVEX_W_XD_K, /* 2445 */
  IC_EVEX_W_XD_K, /* 2446 */
  IC_EVEX_W_XD_K, /* 2447 */
  IC_EVEX_OPSIZE_K, /* 2448 */
  IC_EVEX_OPSIZE_K, /* 2449 */
  IC_EVEX_OPSIZE_K, /* 2450 */
  IC_EVEX_OPSIZE_K, /* 2451 */
  IC_EVEX_OPSIZE_K, /* 2452 */
  IC_EVEX_OPSIZE_K, /* 2453 */
  IC_EVEX_OPSIZE_K, /* 2454 */
  IC_EVEX_OPSIZE_K, /* 2455 */
  IC_EVEX_W_OPSIZE_K, /* 2456 */
  IC_EVEX_W_OPSIZE_K, /* 2457 */
  IC_EVEX_W_OPSIZE_K, /* 2458 */
  IC_EVEX_W_OPSIZE_K, /* 2459 */
  IC_EVEX_W_OPSIZE_K, /* 2460 */
  IC_EVEX_W_OPSIZE_K, /* 2461 */
  IC_EVEX_W_OPSIZE_K, /* 2462 */
  IC_EVEX_W_OPSIZE_K, /* 2463 */
  IC_EVEX_K, /* 2464 */
  IC_EVEX_K, /* 2465 */
  IC_EVEX_XS_K, /* 2466 */
  IC_EVEX_XS_K, /* 2467 */
  IC_EVEX_XD_K, /* 2468 */
  IC_EVEX_XD_K, /* 2469 */
  IC_EVEX_XD_K, /* 2470 */
  IC_EVEX_XD_K, /* 2471 */
  IC_EVEX_W_K, /* 2472 */
  IC_EVEX_W_K, /* 2473 */
  IC_EVEX_W_XS_K, /* 2474 */
  IC_EVEX_W_XS_K, /* 2475 */
  IC_EVEX_W_XD_K, /* 2476 */
  IC_EVEX_W_XD_K, /* 2477 */
  IC_EVEX_W_XD_K, /* 2478 */
  IC_EVEX_W_XD_K, /* 2479 */
  IC_EVEX_OPSIZE_K, /* 2480 */
  IC_EVEX_OPSIZE_K, /* 2481 */
  IC_EVEX_OPSIZE_K, /* 2482 */
  IC_EVEX_OPSIZE_K, /* 2483 */
  IC_EVEX_OPSIZE_K, /* 2484 */
  IC_EVEX_OPSIZE_K, /* 2485 */
  IC_EVEX_OPSIZE_K, /* 2486 */
  IC_EVEX_OPSIZE_K, /* 2487 */
  IC_EVEX_W_OPSIZE_K, /* 2488 */
  IC_EVEX_W_OPSIZE_K, /* 2489 */
  IC_EVEX_W_OPSIZE_K, /* 2490 */
  IC_EVEX_W_OPSIZE_K, /* 2491 */
  IC_EVEX_W_OPSIZE_K, /* 2492 */
  IC_EVEX_W_OPSIZE_K, /* 2493 */
  IC_EVEX_W_OPSIZE_K, /* 2494 */
  IC_EVEX_W_OPSIZE_K, /* 2495 */
  IC_EVEX_K, /* 2496 */
  IC_EVEX_K, /* 2497 */
  IC_EVEX_XS_K, /* 2498 */
  IC_EVEX_XS_K, /* 2499 */
  IC_EVEX_XD_K, /* 2500 */
  IC_EVEX_XD_K, /* 2501 */
  IC_EVEX_XD_K, /* 2502 */
  IC_EVEX_XD_K, /* 2503 */
  IC_EVEX_W_K, /* 2504 */
  IC_EVEX_W_K, /* 2505 */
  IC_EVEX_W_XS_K, /* 2506 */
  IC_EVEX_W_XS_K, /* 2507 */
  IC_EVEX_W_XD_K, /* 2508 */
  IC_EVEX_W_XD_K, /* 2509 */
  IC_EVEX_W_XD_K, /* 2510 */
  IC_EVEX_W_XD_K, /* 2511 */
  IC_EVEX_OPSIZE_K, /* 2512 */
  IC_EVEX_OPSIZE_K, /* 2513 */
  IC_EVEX_OPSIZE_K, /* 2514 */
  IC_EVEX_OPSIZE_K, /* 2515 */
  IC_EVEX_OPSIZE_K, /* 2516 */
  IC_EVEX_OPSIZE_K, /* 2517 */
  IC_EVEX_OPSIZE_K, /* 2518 */
  IC_EVEX_OPSIZE_K, /* 2519 */
  IC_EVEX_W_OPSIZE_K, /* 2520 */
  IC_EVEX_W_OPSIZE_K, /* 2521 */
  IC_EVEX_W_OPSIZE_K, /* 2522 */
  IC_EVEX_W_OPSIZE_K, /* 2523 */
  IC_EVEX_W_OPSIZE_K, /* 2524 */
  IC_EVEX_W_OPSIZE_K, /* 2525 */
  IC_EVEX_W_OPSIZE_K, /* 2526 */
  IC_EVEX_W_OPSIZE_K, /* 2527 */
  IC_EVEX_K, /* 2528 */
  IC_EVEX_K, /* 2529 */
  IC_EVEX_XS_K, /* 2530 */
  IC_EVEX_XS_K, /* 2531 */
  IC_EVEX_XD_K, /* 2532 */
  IC_EVEX_XD_K, /* 2533 */
  IC_EVEX_XD_K, /* 2534 */
  IC_EVEX_XD_K, /* 2535 */
  IC_EVEX_W_K, /* 2536 */
  IC_EVEX_W_K, /* 2537 */
  IC_EVEX_W_XS_K, /* 2538 */
  IC_EVEX_W_XS_K, /* 2539 */
  IC_EVEX_W_XD_K, /* 2540 */
  IC_EVEX_W_XD_K, /* 2541 */
  IC_EVEX_W_XD_K, /* 2542 */
  IC_EVEX_W_XD_K, /* 2543 */
  IC_EVEX_OPSIZE_K, /* 2544 */
  IC_EVEX_OPSIZE_K, /* 2545 */
  IC_EVEX_OPSIZE_K, /* 2546 */
  IC_EVEX_OPSIZE_K, /* 2547 */
  IC_EVEX_OPSIZE_K, /* 2548 */
  IC_EVEX_OPSIZE_K, /* 2549 */
  IC_EVEX_OPSIZE_K, /* 2550 */
  IC_EVEX_OPSIZE_K, /* 2551 */
  IC_EVEX_W_OPSIZE_K, /* 2552 */
  IC_EVEX_W_OPSIZE_K, /* 2553 */
  IC_EVEX_W_OPSIZE_K, /* 2554 */
  IC_EVEX_W_OPSIZE_K, /* 2555 */
  IC_EVEX_W_OPSIZE_K, /* 2556 */
  IC_EVEX_W_OPSIZE_K, /* 2557 */
  IC_EVEX_W_OPSIZE_K, /* 2558 */
  IC_EVEX_W_OPSIZE_K, /* 2559 */
  IC, /* 2560 */
  IC_64BIT, /* 2561 */
  IC_XS, /* 2562 */
  IC_64BIT_XS, /* 2563 */
  IC_XD, /* 2564 */
  IC_64BIT_XD, /* 2565 */
  IC_XS, /* 2566 */
  IC_64BIT_XS, /* 2567 */
  IC, /* 2568 */
  IC_64BIT_REXW, /* 2569 */
  IC_XS, /* 2570 */
  IC_64BIT_REXW_XS, /* 2571 */
  IC_XD, /* 2572 */
  IC_64BIT_REXW_XD, /* 2573 */
  IC_XS, /* 2574 */
  IC_64BIT_REXW_XS, /* 2575 */
  IC_OPSIZE, /* 2576 */
  IC_64BIT_OPSIZE, /* 2577 */
  IC_XS_OPSIZE, /* 2578 */
  IC_64BIT_XS_OPSIZE, /* 2579 */
  IC_XD_OPSIZE, /* 2580 */
  IC_64BIT_XD_OPSIZE, /* 2581 */
  IC_XS_OPSIZE, /* 2582 */
  IC_64BIT_XD_OPSIZE, /* 2583 */
  IC_OPSIZE, /* 2584 */
  IC_64BIT_REXW_OPSIZE, /* 2585 */
  IC_XS_OPSIZE, /* 2586 */
  IC_64BIT_REXW_XS, /* 2587 */
  IC_XD_OPSIZE, /* 2588 */
  IC_64BIT_REXW_XD, /* 2589 */
  IC_XS_OPSIZE, /* 2590 */
  IC_64BIT_REXW_XS, /* 2591 */
  IC_ADSIZE, /* 2592 */
  IC_64BIT_ADSIZE, /* 2593 */
  IC_XS, /* 2594 */
  IC_64BIT_XS, /* 2595 */
  IC_XD, /* 2596 */
  IC_64BIT_XD, /* 2597 */
  IC_XS, /* 2598 */
  IC_64BIT_XS, /* 2599 */
  IC_ADSIZE, /* 2600 */
  IC_64BIT_REXW_ADSIZE, /* 2601 */
  IC_XS, /* 2602 */
  IC_64BIT_REXW_XS, /* 2603 */
  IC_XD, /* 2604 */
  IC_64BIT_REXW_XD, /* 2605 */
  IC_XS, /* 2606 */
  IC_64BIT_REXW_XS, /* 2607 */
  IC_OPSIZE_ADSIZE, /* 2608 */
  IC_64BIT_OPSIZE_ADSIZE, /* 2609 */
  IC_XS_OPSIZE, /* 2610 */
  IC_64BIT_XS_OPSIZE, /* 2611 */
  IC_XD_OPSIZE, /* 2612 */
  IC_64BIT_XD_OPSIZE, /* 2613 */
  IC_XS_OPSIZE, /* 2614 */
  IC_64BIT_XD_OPSIZE, /* 2615 */
  IC_OPSIZE_ADSIZE, /* 2616 */
  IC_64BIT_REXW_OPSIZE, /* 2617 */
  IC_XS_OPSIZE, /* 2618 */
  IC_64BIT_REXW_XS, /* 2619 */
  IC_XD_OPSIZE, /* 2620 */
  IC_64BIT_REXW_XD, /* 2621 */
  IC_XS_OPSIZE, /* 2622 */
  IC_64BIT_REXW_XS, /* 2623 */
  IC_VEX, /* 2624 */
  IC_VEX, /* 2625 */
  IC_VEX_XS, /* 2626 */
  IC_VEX_XS, /* 2627 */
  IC_VEX_XD, /* 2628 */
  IC_VEX_XD, /* 2629 */
  IC_VEX_XD, /* 2630 */
  IC_VEX_XD, /* 2631 */
  IC_VEX_W, /* 2632 */
  IC_VEX_W, /* 2633 */
  IC_VEX_W_XS, /* 2634 */
  IC_VEX_W_XS, /* 2635 */
  IC_VEX_W_XD, /* 2636 */
  IC_VEX_W_XD, /* 2637 */
  IC_VEX_W_XD, /* 2638 */
  IC_VEX_W_XD, /* 2639 */
  IC_VEX_OPSIZE, /* 2640 */
  IC_VEX_OPSIZE, /* 2641 */
  IC_VEX_OPSIZE, /* 2642 */
  IC_VEX_OPSIZE, /* 2643 */
  IC_VEX_OPSIZE, /* 2644 */
  IC_VEX_OPSIZE, /* 2645 */
  IC_VEX_OPSIZE, /* 2646 */
  IC_VEX_OPSIZE, /* 2647 */
  IC_VEX_W_OPSIZE, /* 2648 */
  IC_VEX_W_OPSIZE, /* 2649 */
  IC_VEX_W_OPSIZE, /* 2650 */
  IC_VEX_W_OPSIZE, /* 2651 */
  IC_VEX_W_OPSIZE, /* 2652 */
  IC_VEX_W_OPSIZE, /* 2653 */
  IC_VEX_W_OPSIZE, /* 2654 */
  IC_VEX_W_OPSIZE, /* 2655 */
  IC_VEX, /* 2656 */
  IC_VEX, /* 2657 */
  IC_VEX_XS, /* 2658 */
  IC_VEX_XS, /* 2659 */
  IC_VEX_XD, /* 2660 */
  IC_VEX_XD, /* 2661 */
  IC_VEX_XD, /* 2662 */
  IC_VEX_XD, /* 2663 */
  IC_VEX_W, /* 2664 */
  IC_VEX_W, /* 2665 */
  IC_VEX_W_XS, /* 2666 */
  IC_VEX_W_XS, /* 2667 */
  IC_VEX_W_XD, /* 2668 */
  IC_VEX_W_XD, /* 2669 */
  IC_VEX_W_XD, /* 2670 */
  IC_VEX_W_XD, /* 2671 */
  IC_VEX_OPSIZE, /* 2672 */
  IC_VEX_OPSIZE, /* 2673 */
  IC_VEX_OPSIZE, /* 2674 */
  IC_VEX_OPSIZE, /* 2675 */
  IC_VEX_OPSIZE, /* 2676 */
  IC_VEX_OPSIZE, /* 2677 */
  IC_VEX_OPSIZE, /* 2678 */
  IC_VEX_OPSIZE, /* 2679 */
  IC_VEX_W_OPSIZE, /* 2680 */
  IC_VEX_W_OPSIZE, /* 2681 */
  IC_VEX_W_OPSIZE, /* 2682 */
  IC_VEX_W_OPSIZE, /* 2683 */
  IC_VEX_W_OPSIZE, /* 2684 */
  IC_VEX_W_OPSIZE, /* 2685 */
  IC_VEX_W_OPSIZE, /* 2686 */
  IC_VEX_W_OPSIZE, /* 2687 */
  IC_VEX_L, /* 2688 */
  IC_VEX_L, /* 2689 */
  IC_VEX_L_XS, /* 2690 */
  IC_VEX_L_XS, /* 2691 */
  IC_VEX_L_XD, /* 2692 */
  IC_VEX_L_XD, /* 2693 */
  IC_VEX_L_XD, /* 2694 */
  IC_VEX_L_XD, /* 2695 */
  IC_VEX_L_W, /* 2696 */
  IC_VEX_L_W, /* 2697 */
  IC_VEX_L_W_XS, /* 2698 */
  IC_VEX_L_W_XS, /* 2699 */
  IC_VEX_L_W_XD, /* 2700 */
  IC_VEX_L_W_XD, /* 2701 */
  IC_VEX_L_W_XD, /* 2702 */
  IC_VEX_L_W_XD, /* 2703 */
  IC_VEX_L_OPSIZE, /* 2704 */
  IC_VEX_L_OPSIZE, /* 2705 */
  IC_VEX_L_OPSIZE, /* 2706 */
  IC_VEX_L_OPSIZE, /* 2707 */
  IC_VEX_L_OPSIZE, /* 2708 */
  IC_VEX_L_OPSIZE, /* 2709 */
  IC_VEX_L_OPSIZE, /* 2710 */
  IC_VEX_L_OPSIZE, /* 2711 */
  IC_VEX_L_W_OPSIZE, /* 2712 */
  IC_VEX_L_W_OPSIZE, /* 2713 */
  IC_VEX_L_W_OPSIZE, /* 2714 */
  IC_VEX_L_W_OPSIZE, /* 2715 */
  IC_VEX_L_W_OPSIZE, /* 2716 */
  IC_VEX_L_W_OPSIZE, /* 2717 */
  IC_VEX_L_W_OPSIZE, /* 2718 */
  IC_VEX_L_W_OPSIZE, /* 2719 */
  IC_VEX_L, /* 2720 */
  IC_VEX_L, /* 2721 */
  IC_VEX_L_XS, /* 2722 */
  IC_VEX_L_XS, /* 2723 */
  IC_VEX_L_XD, /* 2724 */
  IC_VEX_L_XD, /* 2725 */
  IC_VEX_L_XD, /* 2726 */
  IC_VEX_L_XD, /* 2727 */
  IC_VEX_L_W, /* 2728 */
  IC_VEX_L_W, /* 2729 */
  IC_VEX_L_W_XS, /* 2730 */
  IC_VEX_L_W_XS, /* 2731 */
  IC_VEX_L_W_XD, /* 2732 */
  IC_VEX_L_W_XD, /* 2733 */
  IC_VEX_L_W_XD, /* 2734 */
  IC_VEX_L_W_XD, /* 2735 */
  IC_VEX_L_OPSIZE, /* 2736 */
  IC_VEX_L_OPSIZE, /* 2737 */
  IC_VEX_L_OPSIZE, /* 2738 */
  IC_VEX_L_OPSIZE, /* 2739 */
  IC_VEX_L_OPSIZE, /* 2740 */
  IC_VEX_L_OPSIZE, /* 2741 */
  IC_VEX_L_OPSIZE, /* 2742 */
  IC_VEX_L_OPSIZE, /* 2743 */
  IC_VEX_L_W_OPSIZE, /* 2744 */
  IC_VEX_L_W_OPSIZE, /* 2745 */
  IC_VEX_L_W_OPSIZE, /* 2746 */
  IC_VEX_L_W_OPSIZE, /* 2747 */
  IC_VEX_L_W_OPSIZE, /* 2748 */
  IC_VEX_L_W_OPSIZE, /* 2749 */
  IC_VEX_L_W_OPSIZE, /* 2750 */
  IC_VEX_L_W_OPSIZE, /* 2751 */
  IC_VEX_L, /* 2752 */
  IC_VEX_L, /* 2753 */
  IC_VEX_L_XS, /* 2754 */
  IC_VEX_L_XS, /* 2755 */
  IC_VEX_L_XD, /* 2756 */
  IC_VEX_L_XD, /* 2757 */
  IC_VEX_L_XD, /* 2758 */
  IC_VEX_L_XD, /* 2759 */
  IC_VEX_L_W, /* 2760 */
  IC_VEX_L_W, /* 2761 */
  IC_VEX_L_W_XS, /* 2762 */
  IC_VEX_L_W_XS, /* 2763 */
  IC_VEX_L_W_XD, /* 2764 */
  IC_VEX_L_W_XD, /* 2765 */
  IC_VEX_L_W_XD, /* 2766 */
  IC_VEX_L_W_XD, /* 2767 */
  IC_VEX_L_OPSIZE, /* 2768 */
  IC_VEX_L_OPSIZE, /* 2769 */
  IC_VEX_L_OPSIZE, /* 2770 */
  IC_VEX_L_OPSIZE, /* 2771 */
  IC_VEX_L_OPSIZE, /* 2772 */
  IC_VEX_L_OPSIZE, /* 2773 */
  IC_VEX_L_OPSIZE, /* 2774 */
  IC_VEX_L_OPSIZE, /* 2775 */
  IC_VEX_L_W_OPSIZE, /* 2776 */
  IC_VEX_L_W_OPSIZE, /* 2777 */
  IC_VEX_L_W_OPSIZE, /* 2778 */
  IC_VEX_L_W_OPSIZE, /* 2779 */
  IC_VEX_L_W_OPSIZE, /* 2780 */
  IC_VEX_L_W_OPSIZE, /* 2781 */
  IC_VEX_L_W_OPSIZE, /* 2782 */
  IC_VEX_L_W_OPSIZE, /* 2783 */
  IC_VEX_L, /* 2784 */
  IC_VEX_L, /* 2785 */
  IC_VEX_L_XS, /* 2786 */
  IC_VEX_L_XS, /* 2787 */
  IC_VEX_L_XD, /* 2788 */
  IC_VEX_L_XD, /* 2789 */
  IC_VEX_L_XD, /* 2790 */
  IC_VEX_L_XD, /* 2791 */
  IC_VEX_L_W, /* 2792 */
  IC_VEX_L_W, /* 2793 */
  IC_VEX_L_W_XS, /* 2794 */
  IC_VEX_L_W_XS, /* 2795 */
  IC_VEX_L_W_XD, /* 2796 */
  IC_VEX_L_W_XD, /* 2797 */
  IC_VEX_L_W_XD, /* 2798 */
  IC_VEX_L_W_XD, /* 2799 */
  IC_VEX_L_OPSIZE, /* 2800 */
  IC_VEX_L_OPSIZE, /* 2801 */
  IC_VEX_L_OPSIZE, /* 2802 */
  IC_VEX_L_OPSIZE, /* 2803 */
  IC_VEX_L_OPSIZE, /* 2804 */
  IC_VEX_L_OPSIZE, /* 2805 */
  IC_VEX_L_OPSIZE, /* 2806 */
  IC_VEX_L_OPSIZE, /* 2807 */
  IC_VEX_L_W_OPSIZE, /* 2808 */
  IC_VEX_L_W_OPSIZE, /* 2809 */
  IC_VEX_L_W_OPSIZE, /* 2810 */
  IC_VEX_L_W_OPSIZE, /* 2811 */
  IC_VEX_L_W_OPSIZE, /* 2812 */
  IC_VEX_L_W_OPSIZE, /* 2813 */
  IC_VEX_L_W_OPSIZE, /* 2814 */
  IC_VEX_L_W_OPSIZE, /* 2815 */
  IC_EVEX_L_K, /* 2816 */
  IC_EVEX_L_K, /* 2817 */
  IC_EVEX_L_XS_K, /* 2818 */
  IC_EVEX_L_XS_K, /* 2819 */
  IC_EVEX_L_XD_K, /* 2820 */
  IC_EVEX_L_XD_K, /* 2821 */
  IC_EVEX_L_XD_K, /* 2822 */
  IC_EVEX_L_XD_K, /* 2823 */
  IC_EVEX_L_W_K, /* 2824 */
  IC_EVEX_L_W_K, /* 2825 */
  IC_EVEX_L_W_XS_K, /* 2826 */
  IC_EVEX_L_W_XS_K, /* 2827 */
  IC_EVEX_L_W_XD_K, /* 2828 */
  IC_EVEX_L_W_XD_K, /* 2829 */
  IC_EVEX_L_W_XD_K, /* 2830 */
  IC_EVEX_L_W_XD_K, /* 2831 */
  IC_EVEX_L_OPSIZE_K, /* 2832 */
  IC_EVEX_L_OPSIZE_K, /* 2833 */
  IC_EVEX_L_OPSIZE_K, /* 2834 */
  IC_EVEX_L_OPSIZE_K, /* 2835 */
  IC_EVEX_L_OPSIZE_K, /* 2836 */
  IC_EVEX_L_OPSIZE_K, /* 2837 */
  IC_EVEX_L_OPSIZE_K, /* 2838 */
  IC_EVEX_L_OPSIZE_K, /* 2839 */
  IC_EVEX_L_W_OPSIZE_K, /* 2840 */
  IC_EVEX_L_W_OPSIZE_K, /* 2841 */
  IC_EVEX_L_W_OPSIZE_K, /* 2842 */
  IC_EVEX_L_W_OPSIZE_K, /* 2843 */
  IC_EVEX_L_W_OPSIZE_K, /* 2844 */
  IC_EVEX_L_W_OPSIZE_K, /* 2845 */
  IC_EVEX_L_W_OPSIZE_K, /* 2846 */
  IC_EVEX_L_W_OPSIZE_K, /* 2847 */
  IC_EVEX_L_K, /* 2848 */
  IC_EVEX_L_K, /* 2849 */
  IC_EVEX_L_XS_K, /* 2850 */
  IC_EVEX_L_XS_K, /* 2851 */
  IC_EVEX_L_XD_K, /* 2852 */
  IC_EVEX_L_XD_K, /* 2853 */
  IC_EVEX_L_XD_K, /* 2854 */
  IC_EVEX_L_XD_K, /* 2855 */
  IC_EVEX_L_W_K, /* 2856 */
  IC_EVEX_L_W_K, /* 2857 */
  IC_EVEX_L_W_XS_K, /* 2858 */
  IC_EVEX_L_W_XS_K, /* 2859 */
  IC_EVEX_L_W_XD_K, /* 2860 */
  IC_EVEX_L_W_XD_K, /* 2861 */
  IC_EVEX_L_W_XD_K, /* 2862 */
  IC_EVEX_L_W_XD_K, /* 2863 */
  IC_EVEX_L_OPSIZE_K, /* 2864 */
  IC_EVEX_L_OPSIZE_K, /* 2865 */
  IC_EVEX_L_OPSIZE_K, /* 2866 */
  IC_EVEX_L_OPSIZE_K, /* 2867 */
  IC_EVEX_L_OPSIZE_K, /* 2868 */
  IC_EVEX_L_OPSIZE_K, /* 2869 */
  IC_EVEX_L_OPSIZE_K, /* 2870 */
  IC_EVEX_L_OPSIZE_K, /* 2871 */
  IC_EVEX_L_W_OPSIZE_K, /* 2872 */
  IC_EVEX_L_W_OPSIZE_K, /* 2873 */
  IC_EVEX_L_W_OPSIZE_K, /* 2874 */
  IC_EVEX_L_W_OPSIZE_K, /* 2875 */
  IC_EVEX_L_W_OPSIZE_K, /* 2876 */
  IC_EVEX_L_W_OPSIZE_K, /* 2877 */
  IC_EVEX_L_W_OPSIZE_K, /* 2878 */
  IC_EVEX_L_W_OPSIZE_K, /* 2879 */
  IC_EVEX_L_K, /* 2880 */
  IC_EVEX_L_K, /* 2881 */
  IC_EVEX_L_XS_K, /* 2882 */
  IC_EVEX_L_XS_K, /* 2883 */
  IC_EVEX_L_XD_K, /* 2884 */
  IC_EVEX_L_XD_K, /* 2885 */
  IC_EVEX_L_XD_K, /* 2886 */
  IC_EVEX_L_XD_K, /* 2887 */
  IC_EVEX_L_W_K, /* 2888 */
  IC_EVEX_L_W_K, /* 2889 */
  IC_EVEX_L_W_XS_K, /* 2890 */
  IC_EVEX_L_W_XS_K, /* 2891 */
  IC_EVEX_L_W_XD_K, /* 2892 */
  IC_EVEX_L_W_XD_K, /* 2893 */
  IC_EVEX_L_W_XD_K, /* 2894 */
  IC_EVEX_L_W_XD_K, /* 2895 */
  IC_EVEX_L_OPSIZE_K, /* 2896 */
  IC_EVEX_L_OPSIZE_K, /* 2897 */
  IC_EVEX_L_OPSIZE_K, /* 2898 */
  IC_EVEX_L_OPSIZE_K, /* 2899 */
  IC_EVEX_L_OPSIZE_K, /* 2900 */
  IC_EVEX_L_OPSIZE_K, /* 2901 */
  IC_EVEX_L_OPSIZE_K, /* 2902 */
  IC_EVEX_L_OPSIZE_K, /* 2903 */
  IC_EVEX_L_W_OPSIZE_K, /* 2904 */
  IC_EVEX_L_W_OPSIZE_K, /* 2905 */
  IC_EVEX_L_W_OPSIZE_K, /* 2906 */
  IC_EVEX_L_W_OPSIZE_K, /* 2907 */
  IC_EVEX_L_W_OPSIZE_K, /* 2908 */
  IC_EVEX_L_W_OPSIZE_K, /* 2909 */
  IC_EVEX_L_W_OPSIZE_K, /* 2910 */
  IC_EVEX_L_W_OPSIZE_K, /* 2911 */
  IC_EVEX_L_K, /* 2912 */
  IC_EVEX_L_K, /* 2913 */
  IC_EVEX_L_XS_K, /* 2914 */
  IC_EVEX_L_XS_K, /* 2915 */
  IC_EVEX_L_XD_K, /* 2916 */
  IC_EVEX_L_XD_K, /* 2917 */
  IC_EVEX_L_XD_K, /* 2918 */
  IC_EVEX_L_XD_K, /* 2919 */
  IC_EVEX_L_W_K, /* 2920 */
  IC_EVEX_L_W_K, /* 2921 */
  IC_EVEX_L_W_XS_K, /* 2922 */
  IC_EVEX_L_W_XS_K, /* 2923 */
  IC_EVEX_L_W_XD_K, /* 2924 */
  IC_EVEX_L_W_XD_K, /* 2925 */
  IC_EVEX_L_W_XD_K, /* 2926 */
  IC_EVEX_L_W_XD_K, /* 2927 */
  IC_EVEX_L_OPSIZE_K, /* 2928 */
  IC_EVEX_L_OPSIZE_K, /* 2929 */
  IC_EVEX_L_OPSIZE_K, /* 2930 */
  IC_EVEX_L_OPSIZE_K, /* 2931 */
  IC_EVEX_L_OPSIZE_K, /* 2932 */
  IC_EVEX_L_OPSIZE_K, /* 2933 */
  IC_EVEX_L_OPSIZE_K, /* 2934 */
  IC_EVEX_L_OPSIZE_K, /* 2935 */
  IC_EVEX_L_W_OPSIZE_K, /* 2936 */
  IC_EVEX_L_W_OPSIZE_K, /* 2937 */
  IC_EVEX_L_W_OPSIZE_K, /* 2938 */
  IC_EVEX_L_W_OPSIZE_K, /* 2939 */
  IC_EVEX_L_W_OPSIZE_K, /* 2940 */
  IC_EVEX_L_W_OPSIZE_K, /* 2941 */
  IC_EVEX_L_W_OPSIZE_K, /* 2942 */
  IC_EVEX_L_W_OPSIZE_K, /* 2943 */
  IC_EVEX_L_K, /* 2944 */
  IC_EVEX_L_K, /* 2945 */
  IC_EVEX_L_XS_K, /* 2946 */
  IC_EVEX_L_XS_K, /* 2947 */
  IC_EVEX_L_XD_K, /* 2948 */
  IC_EVEX_L_XD_K, /* 2949 */
  IC_EVEX_L_XD_K, /* 2950 */
  IC_EVEX_L_XD_K, /* 2951 */
  IC_EVEX_L_W_K, /* 2952 */
  IC_EVEX_L_W_K, /* 2953 */
  IC_EVEX_L_W_XS_K, /* 2954 */
  IC_EVEX_L_W_XS_K, /* 2955 */
  IC_EVEX_L_W_XD_K, /* 2956 */
  IC_EVEX_L_W_XD_K, /* 2957 */
  IC_EVEX_L_W_XD_K, /* 2958 */
  IC_EVEX_L_W_XD_K, /* 2959 */
  IC_EVEX_L_OPSIZE_K, /* 2960 */
  IC_EVEX_L_OPSIZE_K, /* 2961 */
  IC_EVEX_L_OPSIZE_K, /* 2962 */
  IC_EVEX_L_OPSIZE_K, /* 2963 */
  IC_EVEX_L_OPSIZE_K, /* 2964 */
  IC_EVEX_L_OPSIZE_K, /* 2965 */
  IC_EVEX_L_OPSIZE_K, /* 2966 */
  IC_EVEX_L_OPSIZE_K, /* 2967 */
  IC_EVEX_L_W_OPSIZE_K, /* 2968 */
  IC_EVEX_L_W_OPSIZE_K, /* 2969 */
  IC_EVEX_L_W_OPSIZE_K, /* 2970 */
  IC_EVEX_L_W_OPSIZE_K, /* 2971 */
  IC_EVEX_L_W_OPSIZE_K, /* 2972 */
  IC_EVEX_L_W_OPSIZE_K, /* 2973 */
  IC_EVEX_L_W_OPSIZE_K, /* 2974 */
  IC_EVEX_L_W_OPSIZE_K, /* 2975 */
  IC_EVEX_L_K, /* 2976 */
  IC_EVEX_L_K, /* 2977 */
  IC_EVEX_L_XS_K, /* 2978 */
  IC_EVEX_L_XS_K, /* 2979 */
  IC_EVEX_L_XD_K, /* 2980 */
  IC_EVEX_L_XD_K, /* 2981 */
  IC_EVEX_L_XD_K, /* 2982 */
  IC_EVEX_L_XD_K, /* 2983 */
  IC_EVEX_L_W_K, /* 2984 */
  IC_EVEX_L_W_K, /* 2985 */
  IC_EVEX_L_W_XS_K, /* 2986 */
  IC_EVEX_L_W_XS_K, /* 2987 */
  IC_EVEX_L_W_XD_K, /* 2988 */
  IC_EVEX_L_W_XD_K, /* 2989 */
  IC_EVEX_L_W_XD_K, /* 2990 */
  IC_EVEX_L_W_XD_K, /* 2991 */
  IC_EVEX_L_OPSIZE_K, /* 2992 */
  IC_EVEX_L_OPSIZE_K, /* 2993 */
  IC_EVEX_L_OPSIZE_K, /* 2994 */
  IC_EVEX_L_OPSIZE_K, /* 2995 */
  IC_EVEX_L_OPSIZE_K, /* 2996 */
  IC_EVEX_L_OPSIZE_K, /* 2997 */
  IC_EVEX_L_OPSIZE_K, /* 2998 */
  IC_EVEX_L_OPSIZE_K, /* 2999 */
  IC_EVEX_L_W_OPSIZE_K, /* 3000 */
  IC_EVEX_L_W_OPSIZE_K, /* 3001 */
  IC_EVEX_L_W_OPSIZE_K, /* 3002 */
  IC_EVEX_L_W_OPSIZE_K, /* 3003 */
  IC_EVEX_L_W_OPSIZE_K, /* 3004 */
  IC_EVEX_L_W_OPSIZE_K, /* 3005 */
  IC_EVEX_L_W_OPSIZE_K, /* 3006 */
  IC_EVEX_L_W_OPSIZE_K, /* 3007 */
  IC_EVEX_L_K, /* 3008 */
  IC_EVEX_L_K, /* 3009 */
  IC_EVEX_L_XS_K, /* 3010 */
  IC_EVEX_L_XS_K, /* 3011 */
  IC_EVEX_L_XD_K, /* 3012 */
  IC_EVEX_L_XD_K, /* 3013 */
  IC_EVEX_L_XD_K, /* 3014 */
  IC_EVEX_L_XD_K, /* 3015 */
  IC_EVEX_L_W_K, /* 3016 */
  IC_EVEX_L_W_K, /* 3017 */
  IC_EVEX_L_W_XS_K, /* 3018 */
  IC_EVEX_L_W_XS_K, /* 3019 */
  IC_EVEX_L_W_XD_K, /* 3020 */
  IC_EVEX_L_W_XD_K, /* 3021 */
  IC_EVEX_L_W_XD_K, /* 3022 */
  IC_EVEX_L_W_XD_K, /* 3023 */
  IC_EVEX_L_OPSIZE_K, /* 3024 */
  IC_EVEX_L_OPSIZE_K, /* 3025 */
  IC_EVEX_L_OPSIZE_K, /* 3026 */
  IC_EVEX_L_OPSIZE_K, /* 3027 */
  IC_EVEX_L_OPSIZE_K, /* 3028 */
  IC_EVEX_L_OPSIZE_K, /* 3029 */
  IC_EVEX_L_OPSIZE_K, /* 3030 */
  IC_EVEX_L_OPSIZE_K, /* 3031 */
  IC_EVEX_L_W_OPSIZE_K, /* 3032 */
  IC_EVEX_L_W_OPSIZE_K, /* 3033 */
  IC_EVEX_L_W_OPSIZE_K, /* 3034 */
  IC_EVEX_L_W_OPSIZE_K, /* 3035 */
  IC_EVEX_L_W_OPSIZE_K, /* 3036 */
  IC_EVEX_L_W_OPSIZE_K, /* 3037 */
  IC_EVEX_L_W_OPSIZE_K, /* 3038 */
  IC_EVEX_L_W_OPSIZE_K, /* 3039 */
  IC_EVEX_L_K, /* 3040 */
  IC_EVEX_L_K, /* 3041 */
  IC_EVEX_L_XS_K, /* 3042 */
  IC_EVEX_L_XS_K, /* 3043 */
  IC_EVEX_L_XD_K, /* 3044 */
  IC_EVEX_L_XD_K, /* 3045 */
  IC_EVEX_L_XD_K, /* 3046 */
  IC_EVEX_L_XD_K, /* 3047 */
  IC_EVEX_L_W_K, /* 3048 */
  IC_EVEX_L_W_K, /* 3049 */
  IC_EVEX_L_W_XS_K, /* 3050 */
  IC_EVEX_L_W_XS_K, /* 3051 */
  IC_EVEX_L_W_XD_K, /* 3052 */
  IC_EVEX_L_W_XD_K, /* 3053 */
  IC_EVEX_L_W_XD_K, /* 3054 */
  IC_EVEX_L_W_XD_K, /* 3055 */
  IC_EVEX_L_OPSIZE_K, /* 3056 */
  IC_EVEX_L_OPSIZE_K, /* 3057 */
  IC_EVEX_L_OPSIZE_K, /* 3058 */
  IC_EVEX_L_OPSIZE_K, /* 3059 */
  IC_EVEX_L_OPSIZE_K, /* 3060 */
  IC_EVEX_L_OPSIZE_K, /* 3061 */
  IC_EVEX_L_OPSIZE_K, /* 3062 */
  IC_EVEX_L_OPSIZE_K, /* 3063 */
  IC_EVEX_L_W_OPSIZE_K, /* 3064 */
  IC_EVEX_L_W_OPSIZE_K, /* 3065 */
  IC_EVEX_L_W_OPSIZE_K, /* 3066 */
  IC_EVEX_L_W_OPSIZE_K, /* 3067 */
  IC_EVEX_L_W_OPSIZE_K, /* 3068 */
  IC_EVEX_L_W_OPSIZE_K, /* 3069 */
  IC_EVEX_L_W_OPSIZE_K, /* 3070 */
  IC_EVEX_L_W_OPSIZE_K, /* 3071 */
  IC, /* 3072 */
  IC_64BIT, /* 3073 */
  IC_XS, /* 3074 */
  IC_64BIT_XS, /* 3075 */
  IC_XD, /* 3076 */
  IC_64BIT_XD, /* 3077 */
  IC_XS, /* 3078 */
  IC_64BIT_XS, /* 3079 */
  IC, /* 3080 */
  IC_64BIT_REXW, /* 3081 */
  IC_XS, /* 3082 */
  IC_64BIT_REXW_XS, /* 3083 */
  IC_XD, /* 3084 */
  IC_64BIT_REXW_XD, /* 3085 */
  IC_XS, /* 3086 */
  IC_64BIT_REXW_XS, /* 3087 */
  IC_OPSIZE, /* 3088 */
  IC_64BIT_OPSIZE, /* 3089 */
  IC_XS_OPSIZE, /* 3090 */
  IC_64BIT_XS_OPSIZE, /* 3091 */
  IC_XD_OPSIZE, /* 3092 */
  IC_64BIT_XD_OPSIZE, /* 3093 */
  IC_XS_OPSIZE, /* 3094 */
  IC_64BIT_XD_OPSIZE, /* 3095 */
  IC_OPSIZE, /* 3096 */
  IC_64BIT_REXW_OPSIZE, /* 3097 */
  IC_XS_OPSIZE, /* 3098 */
  IC_64BIT_REXW_XS, /* 3099 */
  IC_XD_OPSIZE, /* 3100 */
  IC_64BIT_REXW_XD, /* 3101 */
  IC_XS_OPSIZE, /* 3102 */
  IC_64BIT_REXW_XS, /* 3103 */
  IC_ADSIZE, /* 3104 */
  IC_64BIT_ADSIZE, /* 3105 */
  IC_XS, /* 3106 */
  IC_64BIT_XS, /* 3107 */
  IC_XD, /* 3108 */
  IC_64BIT_XD, /* 3109 */
  IC_XS, /* 3110 */
  IC_64BIT_XS, /* 3111 */
  IC_ADSIZE, /* 3112 */
  IC_64BIT_REXW_ADSIZE, /* 3113 */
  IC_XS, /* 3114 */
  IC_64BIT_REXW_XS, /* 3115 */
  IC_XD, /* 3116 */
  IC_64BIT_REXW_XD, /* 3117 */
  IC_XS, /* 3118 */
  IC_64BIT_REXW_XS, /* 3119 */
  IC_OPSIZE_ADSIZE, /* 3120 */
  IC_64BIT_OPSIZE_ADSIZE, /* 3121 */
  IC_XS_OPSIZE, /* 3122 */
  IC_64BIT_XS_OPSIZE, /* 3123 */
  IC_XD_OPSIZE, /* 3124 */
  IC_64BIT_XD_OPSIZE, /* 3125 */
  IC_XS_OPSIZE, /* 3126 */
  IC_64BIT_XD_OPSIZE, /* 3127 */
  IC_OPSIZE_ADSIZE, /* 3128 */
  IC_64BIT_REXW_OPSIZE, /* 3129 */
  IC_XS_OPSIZE, /* 3130 */
  IC_64BIT_REXW_XS, /* 3131 */
  IC_XD_OPSIZE, /* 3132 */
  IC_64BIT_REXW_XD, /* 3133 */
  IC_XS_OPSIZE, /* 3134 */
  IC_64BIT_REXW_XS, /* 3135 */
  IC_VEX, /* 3136 */
  IC_VEX, /* 3137 */
  IC_VEX_XS, /* 3138 */
  IC_VEX_XS, /* 3139 */
  IC_VEX_XD, /* 3140 */
  IC_VEX_XD, /* 3141 */
  IC_VEX_XD, /* 3142 */
  IC_VEX_XD, /* 3143 */
  IC_VEX_W, /* 3144 */
  IC_VEX_W, /* 3145 */
  IC_VEX_W_XS, /* 3146 */
  IC_VEX_W_XS, /* 3147 */
  IC_VEX_W_XD, /* 3148 */
  IC_VEX_W_XD, /* 3149 */
  IC_VEX_W_XD, /* 3150 */
  IC_VEX_W_XD, /* 3151 */
  IC_VEX_OPSIZE, /* 3152 */
  IC_VEX_OPSIZE, /* 3153 */
  IC_VEX_OPSIZE, /* 3154 */
  IC_VEX_OPSIZE, /* 3155 */
  IC_VEX_OPSIZE, /* 3156 */
  IC_VEX_OPSIZE, /* 3157 */
  IC_VEX_OPSIZE, /* 3158 */
  IC_VEX_OPSIZE, /* 3159 */
  IC_VEX_W_OPSIZE, /* 3160 */
  IC_VEX_W_OPSIZE, /* 3161 */
  IC_VEX_W_OPSIZE, /* 3162 */
  IC_VEX_W_OPSIZE, /* 3163 */
  IC_VEX_W_OPSIZE, /* 3164 */
  IC_VEX_W_OPSIZE, /* 3165 */
  IC_VEX_W_OPSIZE, /* 3166 */
  IC_VEX_W_OPSIZE, /* 3167 */
  IC_VEX, /* 3168 */
  IC_VEX, /* 3169 */
  IC_VEX_XS, /* 3170 */
  IC_VEX_XS, /* 3171 */
  IC_VEX_XD, /* 3172 */
  IC_VEX_XD, /* 3173 */
  IC_VEX_XD, /* 3174 */
  IC_VEX_XD, /* 3175 */
  IC_VEX_W, /* 3176 */
  IC_VEX_W, /* 3177 */
  IC_VEX_W_XS, /* 3178 */
  IC_VEX_W_XS, /* 3179 */
  IC_VEX_W_XD, /* 3180 */
  IC_VEX_W_XD, /* 3181 */
  IC_VEX_W_XD, /* 3182 */
  IC_VEX_W_XD, /* 3183 */
  IC_VEX_OPSIZE, /* 3184 */
  IC_VEX_OPSIZE, /* 3185 */
  IC_VEX_OPSIZE, /* 3186 */
  IC_VEX_OPSIZE, /* 3187 */
  IC_VEX_OPSIZE, /* 3188 */
  IC_VEX_OPSIZE, /* 3189 */
  IC_VEX_OPSIZE, /* 3190 */
  IC_VEX_OPSIZE, /* 3191 */
  IC_VEX_W_OPSIZE, /* 3192 */
  IC_VEX_W_OPSIZE, /* 3193 */
  IC_VEX_W_OPSIZE, /* 3194 */
  IC_VEX_W_OPSIZE, /* 3195 */
  IC_VEX_W_OPSIZE, /* 3196 */
  IC_VEX_W_OPSIZE, /* 3197 */
  IC_VEX_W_OPSIZE, /* 3198 */
  IC_VEX_W_OPSIZE, /* 3199 */
  IC_VEX_L, /* 3200 */
  IC_VEX_L, /* 3201 */
  IC_VEX_L_XS, /* 3202 */
  IC_VEX_L_XS, /* 3203 */
  IC_VEX_L_XD, /* 3204 */
  IC_VEX_L_XD, /* 3205 */
  IC_VEX_L_XD, /* 3206 */
  IC_VEX_L_XD, /* 3207 */
  IC_VEX_L_W, /* 3208 */
  IC_VEX_L_W, /* 3209 */
  IC_VEX_L_W_XS, /* 3210 */
  IC_VEX_L_W_XS, /* 3211 */
  IC_VEX_L_W_XD, /* 3212 */
  IC_VEX_L_W_XD, /* 3213 */
  IC_VEX_L_W_XD, /* 3214 */
  IC_VEX_L_W_XD, /* 3215 */
  IC_VEX_L_OPSIZE, /* 3216 */
  IC_VEX_L_OPSIZE, /* 3217 */
  IC_VEX_L_OPSIZE, /* 3218 */
  IC_VEX_L_OPSIZE, /* 3219 */
  IC_VEX_L_OPSIZE, /* 3220 */
  IC_VEX_L_OPSIZE, /* 3221 */
  IC_VEX_L_OPSIZE, /* 3222 */
  IC_VEX_L_OPSIZE, /* 3223 */
  IC_VEX_L_W_OPSIZE, /* 3224 */
  IC_VEX_L_W_OPSIZE, /* 3225 */
  IC_VEX_L_W_OPSIZE, /* 3226 */
  IC_VEX_L_W_OPSIZE, /* 3227 */
  IC_VEX_L_W_OPSIZE, /* 3228 */
  IC_VEX_L_W_OPSIZE, /* 3229 */
  IC_VEX_L_W_OPSIZE, /* 3230 */
  IC_VEX_L_W_OPSIZE, /* 3231 */
  IC_VEX_L, /* 3232 */
  IC_VEX_L, /* 3233 */
  IC_VEX_L_XS, /* 3234 */
  IC_VEX_L_XS, /* 3235 */
  IC_VEX_L_XD, /* 3236 */
  IC_VEX_L_XD, /* 3237 */
  IC_VEX_L_XD, /* 3238 */
  IC_VEX_L_XD, /* 3239 */
  IC_VEX_L_W, /* 3240 */
  IC_VEX_L_W, /* 3241 */
  IC_VEX_L_W_XS, /* 3242 */
  IC_VEX_L_W_XS, /* 3243 */
  IC_VEX_L_W_XD, /* 3244 */
  IC_VEX_L_W_XD, /* 3245 */
  IC_VEX_L_W_XD, /* 3246 */
  IC_VEX_L_W_XD, /* 3247 */
  IC_VEX_L_OPSIZE, /* 3248 */
  IC_VEX_L_OPSIZE, /* 3249 */
  IC_VEX_L_OPSIZE, /* 3250 */
  IC_VEX_L_OPSIZE, /* 3251 */
  IC_VEX_L_OPSIZE, /* 3252 */
  IC_VEX_L_OPSIZE, /* 3253 */
  IC_VEX_L_OPSIZE, /* 3254 */
  IC_VEX_L_OPSIZE, /* 3255 */
  IC_VEX_L_W_OPSIZE, /* 3256 */
  IC_VEX_L_W_OPSIZE, /* 3257 */
  IC_VEX_L_W_OPSIZE, /* 3258 */
  IC_VEX_L_W_OPSIZE, /* 3259 */
  IC_VEX_L_W_OPSIZE, /* 3260 */
  IC_VEX_L_W_OPSIZE, /* 3261 */
  IC_VEX_L_W_OPSIZE, /* 3262 */
  IC_VEX_L_W_OPSIZE, /* 3263 */
  IC_VEX_L, /* 3264 */
  IC_VEX_L, /* 3265 */
  IC_VEX_L_XS, /* 3266 */
  IC_VEX_L_XS, /* 3267 */
  IC_VEX_L_XD, /* 3268 */
  IC_VEX_L_XD, /* 3269 */
  IC_VEX_L_XD, /* 3270 */
  IC_VEX_L_XD, /* 3271 */
  IC_VEX_L_W, /* 3272 */
  IC_VEX_L_W, /* 3273 */
  IC_VEX_L_W_XS, /* 3274 */
  IC_VEX_L_W_XS, /* 3275 */
  IC_VEX_L_W_XD, /* 3276 */
  IC_VEX_L_W_XD, /* 3277 */
  IC_VEX_L_W_XD, /* 3278 */
  IC_VEX_L_W_XD, /* 3279 */
  IC_VEX_L_OPSIZE, /* 3280 */
  IC_VEX_L_OPSIZE, /* 3281 */
  IC_VEX_L_OPSIZE, /* 3282 */
  IC_VEX_L_OPSIZE, /* 3283 */
  IC_VEX_L_OPSIZE, /* 3284 */
  IC_VEX_L_OPSIZE, /* 3285 */
  IC_VEX_L_OPSIZE, /* 3286 */
  IC_VEX_L_OPSIZE, /* 3287 */
  IC_VEX_L_W_OPSIZE, /* 3288 */
  IC_VEX_L_W_OPSIZE, /* 3289 */
  IC_VEX_L_W_OPSIZE, /* 3290 */
  IC_VEX_L_W_OPSIZE, /* 3291 */
  IC_VEX_L_W_OPSIZE, /* 3292 */
  IC_VEX_L_W_OPSIZE, /* 3293 */
  IC_VEX_L_W_OPSIZE, /* 3294 */
  IC_VEX_L_W_OPSIZE, /* 3295 */
  IC_VEX_L, /* 3296 */
  IC_VEX_L, /* 3297 */
  IC_VEX_L_XS, /* 3298 */
  IC_VEX_L_XS, /* 3299 */
  IC_VEX_L_XD, /* 3300 */
  IC_VEX_L_XD, /* 3301 */
  IC_VEX_L_XD, /* 3302 */
  IC_VEX_L_XD, /* 3303 */
  IC_VEX_L_W, /* 3304 */
  IC_VEX_L_W, /* 3305 */
  IC_VEX_L_W_XS, /* 3306 */
  IC_VEX_L_W_XS, /* 3307 */
  IC_VEX_L_W_XD, /* 3308 */
  IC_VEX_L_W_XD, /* 3309 */
  IC_VEX_L_W_XD, /* 3310 */
  IC_VEX_L_W_XD, /* 3311 */
  IC_VEX_L_OPSIZE, /* 3312 */
  IC_VEX_L_OPSIZE, /* 3313 */
  IC_VEX_L_OPSIZE, /* 3314 */
  IC_VEX_L_OPSIZE, /* 3315 */
  IC_VEX_L_OPSIZE, /* 3316 */
  IC_VEX_L_OPSIZE, /* 3317 */
  IC_VEX_L_OPSIZE, /* 3318 */
  IC_VEX_L_OPSIZE, /* 3319 */
  IC_VEX_L_W_OPSIZE, /* 3320 */
  IC_VEX_L_W_OPSIZE, /* 3321 */
  IC_VEX_L_W_OPSIZE, /* 3322 */
  IC_VEX_L_W_OPSIZE, /* 3323 */
  IC_VEX_L_W_OPSIZE, /* 3324 */
  IC_VEX_L_W_OPSIZE, /* 3325 */
  IC_VEX_L_W_OPSIZE, /* 3326 */
  IC_VEX_L_W_OPSIZE, /* 3327 */
  IC_EVEX_L2_K, /* 3328 */
  IC_EVEX_L2_K, /* 3329 */
  IC_EVEX_L2_XS_K, /* 3330 */
  IC_EVEX_L2_XS_K, /* 3331 */
  IC_EVEX_L2_XD_K, /* 3332 */
  IC_EVEX_L2_XD_K, /* 3333 */
  IC_EVEX_L2_XD_K, /* 3334 */
  IC_EVEX_L2_XD_K, /* 3335 */
  IC_EVEX_L2_W_K, /* 3336 */
  IC_EVEX_L2_W_K, /* 3337 */
  IC_EVEX_L2_W_XS_K, /* 3338 */
  IC_EVEX_L2_W_XS_K, /* 3339 */
  IC_EVEX_L2_W_XD_K, /* 3340 */
  IC_EVEX_L2_W_XD_K, /* 3341 */
  IC_EVEX_L2_W_XD_K, /* 3342 */
  IC_EVEX_L2_W_XD_K, /* 3343 */
  IC_EVEX_L2_OPSIZE_K, /* 3344 */
  IC_EVEX_L2_OPSIZE_K, /* 3345 */
  IC_EVEX_L2_OPSIZE_K, /* 3346 */
  IC_EVEX_L2_OPSIZE_K, /* 3347 */
  IC_EVEX_L2_OPSIZE_K, /* 3348 */
  IC_EVEX_L2_OPSIZE_K, /* 3349 */
  IC_EVEX_L2_OPSIZE_K, /* 3350 */
  IC_EVEX_L2_OPSIZE_K, /* 3351 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3352 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3353 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3354 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3355 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3356 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3357 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3358 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3359 */
  IC_EVEX_L2_K, /* 3360 */
  IC_EVEX_L2_K, /* 3361 */
  IC_EVEX_L2_XS_K, /* 3362 */
  IC_EVEX_L2_XS_K, /* 3363 */
  IC_EVEX_L2_XD_K, /* 3364 */
  IC_EVEX_L2_XD_K, /* 3365 */
  IC_EVEX_L2_XD_K, /* 3366 */
  IC_EVEX_L2_XD_K, /* 3367 */
  IC_EVEX_L2_W_K, /* 3368 */
  IC_EVEX_L2_W_K, /* 3369 */
  IC_EVEX_L2_W_XS_K, /* 3370 */
  IC_EVEX_L2_W_XS_K, /* 3371 */
  IC_EVEX_L2_W_XD_K, /* 3372 */
  IC_EVEX_L2_W_XD_K, /* 3373 */
  IC_EVEX_L2_W_XD_K, /* 3374 */
  IC_EVEX_L2_W_XD_K, /* 3375 */
  IC_EVEX_L2_OPSIZE_K, /* 3376 */
  IC_EVEX_L2_OPSIZE_K, /* 3377 */
  IC_EVEX_L2_OPSIZE_K, /* 3378 */
  IC_EVEX_L2_OPSIZE_K, /* 3379 */
  IC_EVEX_L2_OPSIZE_K, /* 3380 */
  IC_EVEX_L2_OPSIZE_K, /* 3381 */
  IC_EVEX_L2_OPSIZE_K, /* 3382 */
  IC_EVEX_L2_OPSIZE_K, /* 3383 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3384 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3385 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3386 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3387 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3388 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3389 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3390 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3391 */
  IC_EVEX_L2_K, /* 3392 */
  IC_EVEX_L2_K, /* 3393 */
  IC_EVEX_L2_XS_K, /* 3394 */
  IC_EVEX_L2_XS_K, /* 3395 */
  IC_EVEX_L2_XD_K, /* 3396 */
  IC_EVEX_L2_XD_K, /* 3397 */
  IC_EVEX_L2_XD_K, /* 3398 */
  IC_EVEX_L2_XD_K, /* 3399 */
  IC_EVEX_L2_W_K, /* 3400 */
  IC_EVEX_L2_W_K, /* 3401 */
  IC_EVEX_L2_W_XS_K, /* 3402 */
  IC_EVEX_L2_W_XS_K, /* 3403 */
  IC_EVEX_L2_W_XD_K, /* 3404 */
  IC_EVEX_L2_W_XD_K, /* 3405 */
  IC_EVEX_L2_W_XD_K, /* 3406 */
  IC_EVEX_L2_W_XD_K, /* 3407 */
  IC_EVEX_L2_OPSIZE_K, /* 3408 */
  IC_EVEX_L2_OPSIZE_K, /* 3409 */
  IC_EVEX_L2_OPSIZE_K, /* 3410 */
  IC_EVEX_L2_OPSIZE_K, /* 3411 */
  IC_EVEX_L2_OPSIZE_K, /* 3412 */
  IC_EVEX_L2_OPSIZE_K, /* 3413 */
  IC_EVEX_L2_OPSIZE_K, /* 3414 */
  IC_EVEX_L2_OPSIZE_K, /* 3415 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3416 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3417 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3418 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3419 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3420 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3421 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3422 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3423 */
  IC_EVEX_L2_K, /* 3424 */
  IC_EVEX_L2_K, /* 3425 */
  IC_EVEX_L2_XS_K, /* 3426 */
  IC_EVEX_L2_XS_K, /* 3427 */
  IC_EVEX_L2_XD_K, /* 3428 */
  IC_EVEX_L2_XD_K, /* 3429 */
  IC_EVEX_L2_XD_K, /* 3430 */
  IC_EVEX_L2_XD_K, /* 3431 */
  IC_EVEX_L2_W_K, /* 3432 */
  IC_EVEX_L2_W_K, /* 3433 */
  IC_EVEX_L2_W_XS_K, /* 3434 */
  IC_EVEX_L2_W_XS_K, /* 3435 */
  IC_EVEX_L2_W_XD_K, /* 3436 */
  IC_EVEX_L2_W_XD_K, /* 3437 */
  IC_EVEX_L2_W_XD_K, /* 3438 */
  IC_EVEX_L2_W_XD_K, /* 3439 */
  IC_EVEX_L2_OPSIZE_K, /* 3440 */
  IC_EVEX_L2_OPSIZE_K, /* 3441 */
  IC_EVEX_L2_OPSIZE_K, /* 3442 */
  IC_EVEX_L2_OPSIZE_K, /* 3443 */
  IC_EVEX_L2_OPSIZE_K, /* 3444 */
  IC_EVEX_L2_OPSIZE_K, /* 3445 */
  IC_EVEX_L2_OPSIZE_K, /* 3446 */
  IC_EVEX_L2_OPSIZE_K, /* 3447 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3448 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3449 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3450 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3451 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3452 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3453 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3454 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3455 */
  IC_EVEX_L2_K, /* 3456 */
  IC_EVEX_L2_K, /* 3457 */
  IC_EVEX_L2_XS_K, /* 3458 */
  IC_EVEX_L2_XS_K, /* 3459 */
  IC_EVEX_L2_XD_K, /* 3460 */
  IC_EVEX_L2_XD_K, /* 3461 */
  IC_EVEX_L2_XD_K, /* 3462 */
  IC_EVEX_L2_XD_K, /* 3463 */
  IC_EVEX_L2_W_K, /* 3464 */
  IC_EVEX_L2_W_K, /* 3465 */
  IC_EVEX_L2_W_XS_K, /* 3466 */
  IC_EVEX_L2_W_XS_K, /* 3467 */
  IC_EVEX_L2_W_XD_K, /* 3468 */
  IC_EVEX_L2_W_XD_K, /* 3469 */
  IC_EVEX_L2_W_XD_K, /* 3470 */
  IC_EVEX_L2_W_XD_K, /* 3471 */
  IC_EVEX_L2_OPSIZE_K, /* 3472 */
  IC_EVEX_L2_OPSIZE_K, /* 3473 */
  IC_EVEX_L2_OPSIZE_K, /* 3474 */
  IC_EVEX_L2_OPSIZE_K, /* 3475 */
  IC_EVEX_L2_OPSIZE_K, /* 3476 */
  IC_EVEX_L2_OPSIZE_K, /* 3477 */
  IC_EVEX_L2_OPSIZE_K, /* 3478 */
  IC_EVEX_L2_OPSIZE_K, /* 3479 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3480 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3481 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3482 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3483 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3484 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3485 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3486 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3487 */
  IC_EVEX_L2_K, /* 3488 */
  IC_EVEX_L2_K, /* 3489 */
  IC_EVEX_L2_XS_K, /* 3490 */
  IC_EVEX_L2_XS_K, /* 3491 */
  IC_EVEX_L2_XD_K, /* 3492 */
  IC_EVEX_L2_XD_K, /* 3493 */
  IC_EVEX_L2_XD_K, /* 3494 */
  IC_EVEX_L2_XD_K, /* 3495 */
  IC_EVEX_L2_W_K, /* 3496 */
  IC_EVEX_L2_W_K, /* 3497 */
  IC_EVEX_L2_W_XS_K, /* 3498 */
  IC_EVEX_L2_W_XS_K, /* 3499 */
  IC_EVEX_L2_W_XD_K, /* 3500 */
  IC_EVEX_L2_W_XD_K, /* 3501 */
  IC_EVEX_L2_W_XD_K, /* 3502 */
  IC_EVEX_L2_W_XD_K, /* 3503 */
  IC_EVEX_L2_OPSIZE_K, /* 3504 */
  IC_EVEX_L2_OPSIZE_K, /* 3505 */
  IC_EVEX_L2_OPSIZE_K, /* 3506 */
  IC_EVEX_L2_OPSIZE_K, /* 3507 */
  IC_EVEX_L2_OPSIZE_K, /* 3508 */
  IC_EVEX_L2_OPSIZE_K, /* 3509 */
  IC_EVEX_L2_OPSIZE_K, /* 3510 */
  IC_EVEX_L2_OPSIZE_K, /* 3511 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3512 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3513 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3514 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3515 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3516 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3517 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3518 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3519 */
  IC_EVEX_L2_K, /* 3520 */
  IC_EVEX_L2_K, /* 3521 */
  IC_EVEX_L2_XS_K, /* 3522 */
  IC_EVEX_L2_XS_K, /* 3523 */
  IC_EVEX_L2_XD_K, /* 3524 */
  IC_EVEX_L2_XD_K, /* 3525 */
  IC_EVEX_L2_XD_K, /* 3526 */
  IC_EVEX_L2_XD_K, /* 3527 */
  IC_EVEX_L2_W_K, /* 3528 */
  IC_EVEX_L2_W_K, /* 3529 */
  IC_EVEX_L2_W_XS_K, /* 3530 */
  IC_EVEX_L2_W_XS_K, /* 3531 */
  IC_EVEX_L2_W_XD_K, /* 3532 */
  IC_EVEX_L2_W_XD_K, /* 3533 */
  IC_EVEX_L2_W_XD_K, /* 3534 */
  IC_EVEX_L2_W_XD_K, /* 3535 */
  IC_EVEX_L2_OPSIZE_K, /* 3536 */
  IC_EVEX_L2_OPSIZE_K, /* 3537 */
  IC_EVEX_L2_OPSIZE_K, /* 3538 */
  IC_EVEX_L2_OPSIZE_K, /* 3539 */
  IC_EVEX_L2_OPSIZE_K, /* 3540 */
  IC_EVEX_L2_OPSIZE_K, /* 3541 */
  IC_EVEX_L2_OPSIZE_K, /* 3542 */
  IC_EVEX_L2_OPSIZE_K, /* 3543 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3544 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3545 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3546 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3547 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3548 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3549 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3550 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3551 */
  IC_EVEX_L2_K, /* 3552 */
  IC_EVEX_L2_K, /* 3553 */
  IC_EVEX_L2_XS_K, /* 3554 */
  IC_EVEX_L2_XS_K, /* 3555 */
  IC_EVEX_L2_XD_K, /* 3556 */
  IC_EVEX_L2_XD_K, /* 3557 */
  IC_EVEX_L2_XD_K, /* 3558 */
  IC_EVEX_L2_XD_K, /* 3559 */
  IC_EVEX_L2_W_K, /* 3560 */
  IC_EVEX_L2_W_K, /* 3561 */
  IC_EVEX_L2_W_XS_K, /* 3562 */
  IC_EVEX_L2_W_XS_K, /* 3563 */
  IC_EVEX_L2_W_XD_K, /* 3564 */
  IC_EVEX_L2_W_XD_K, /* 3565 */
  IC_EVEX_L2_W_XD_K, /* 3566 */
  IC_EVEX_L2_W_XD_K, /* 3567 */
  IC_EVEX_L2_OPSIZE_K, /* 3568 */
  IC_EVEX_L2_OPSIZE_K, /* 3569 */
  IC_EVEX_L2_OPSIZE_K, /* 3570 */
  IC_EVEX_L2_OPSIZE_K, /* 3571 */
  IC_EVEX_L2_OPSIZE_K, /* 3572 */
  IC_EVEX_L2_OPSIZE_K, /* 3573 */
  IC_EVEX_L2_OPSIZE_K, /* 3574 */
  IC_EVEX_L2_OPSIZE_K, /* 3575 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3576 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3577 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3578 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3579 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3580 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3581 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3582 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3583 */
  IC, /* 3584 */
  IC_64BIT, /* 3585 */
  IC_XS, /* 3586 */
  IC_64BIT_XS, /* 3587 */
  IC_XD, /* 3588 */
  IC_64BIT_XD, /* 3589 */
  IC_XS, /* 3590 */
  IC_64BIT_XS, /* 3591 */
  IC, /* 3592 */
  IC_64BIT_REXW, /* 3593 */
  IC_XS, /* 3594 */
  IC_64BIT_REXW_XS, /* 3595 */
  IC_XD, /* 3596 */
  IC_64BIT_REXW_XD, /* 3597 */
  IC_XS, /* 3598 */
  IC_64BIT_REXW_XS, /* 3599 */
  IC_OPSIZE, /* 3600 */
  IC_64BIT_OPSIZE, /* 3601 */
  IC_XS_OPSIZE, /* 3602 */
  IC_64BIT_XS_OPSIZE, /* 3603 */
  IC_XD_OPSIZE, /* 3604 */
  IC_64BIT_XD_OPSIZE, /* 3605 */
  IC_XS_OPSIZE, /* 3606 */
  IC_64BIT_XD_OPSIZE, /* 3607 */
  IC_OPSIZE, /* 3608 */
  IC_64BIT_REXW_OPSIZE, /* 3609 */
  IC_XS_OPSIZE, /* 3610 */
  IC_64BIT_REXW_XS, /* 3611 */
  IC_XD_OPSIZE, /* 3612 */
  IC_64BIT_REXW_XD, /* 3613 */
  IC_XS_OPSIZE, /* 3614 */
  IC_64BIT_REXW_XS, /* 3615 */
  IC_ADSIZE, /* 3616 */
  IC_64BIT_ADSIZE, /* 3617 */
  IC_XS, /* 3618 */
  IC_64BIT_XS, /* 3619 */
  IC_XD, /* 3620 */
  IC_64BIT_XD, /* 3621 */
  IC_XS, /* 3622 */
  IC_64BIT_XS, /* 3623 */
  IC_ADSIZE, /* 3624 */
  IC_64BIT_REXW_ADSIZE, /* 3625 */
  IC_XS, /* 3626 */
  IC_64BIT_REXW_XS, /* 3627 */
  IC_XD, /* 3628 */
  IC_64BIT_REXW_XD, /* 3629 */
  IC_XS, /* 3630 */
  IC_64BIT_REXW_XS, /* 3631 */
  IC_OPSIZE_ADSIZE, /* 3632 */
  IC_64BIT_OPSIZE_ADSIZE, /* 3633 */
  IC_XS_OPSIZE, /* 3634 */
  IC_64BIT_XS_OPSIZE, /* 3635 */
  IC_XD_OPSIZE, /* 3636 */
  IC_64BIT_XD_OPSIZE, /* 3637 */
  IC_XS_OPSIZE, /* 3638 */
  IC_64BIT_XD_OPSIZE, /* 3639 */
  IC_OPSIZE_ADSIZE, /* 3640 */
  IC_64BIT_REXW_OPSIZE, /* 3641 */
  IC_XS_OPSIZE, /* 3642 */
  IC_64BIT_REXW_XS, /* 3643 */
  IC_XD_OPSIZE, /* 3644 */
  IC_64BIT_REXW_XD, /* 3645 */
  IC_XS_OPSIZE, /* 3646 */
  IC_64BIT_REXW_XS, /* 3647 */
  IC_VEX, /* 3648 */
  IC_VEX, /* 3649 */
  IC_VEX_XS, /* 3650 */
  IC_VEX_XS, /* 3651 */
  IC_VEX_XD, /* 3652 */
  IC_VEX_XD, /* 3653 */
  IC_VEX_XD, /* 3654 */
  IC_VEX_XD, /* 3655 */
  IC_VEX_W, /* 3656 */
  IC_VEX_W, /* 3657 */
  IC_VEX_W_XS, /* 3658 */
  IC_VEX_W_XS, /* 3659 */
  IC_VEX_W_XD, /* 3660 */
  IC_VEX_W_XD, /* 3661 */
  IC_VEX_W_XD, /* 3662 */
  IC_VEX_W_XD, /* 3663 */
  IC_VEX_OPSIZE, /* 3664 */
  IC_VEX_OPSIZE, /* 3665 */
  IC_VEX_OPSIZE, /* 3666 */
  IC_VEX_OPSIZE, /* 3667 */
  IC_VEX_OPSIZE, /* 3668 */
  IC_VEX_OPSIZE, /* 3669 */
  IC_VEX_OPSIZE, /* 3670 */
  IC_VEX_OPSIZE, /* 3671 */
  IC_VEX_W_OPSIZE, /* 3672 */
  IC_VEX_W_OPSIZE, /* 3673 */
  IC_VEX_W_OPSIZE, /* 3674 */
  IC_VEX_W_OPSIZE, /* 3675 */
  IC_VEX_W_OPSIZE, /* 3676 */
  IC_VEX_W_OPSIZE, /* 3677 */
  IC_VEX_W_OPSIZE, /* 3678 */
  IC_VEX_W_OPSIZE, /* 3679 */
  IC_VEX, /* 3680 */
  IC_VEX, /* 3681 */
  IC_VEX_XS, /* 3682 */
  IC_VEX_XS, /* 3683 */
  IC_VEX_XD, /* 3684 */
  IC_VEX_XD, /* 3685 */
  IC_VEX_XD, /* 3686 */
  IC_VEX_XD, /* 3687 */
  IC_VEX_W, /* 3688 */
  IC_VEX_W, /* 3689 */
  IC_VEX_W_XS, /* 3690 */
  IC_VEX_W_XS, /* 3691 */
  IC_VEX_W_XD, /* 3692 */
  IC_VEX_W_XD, /* 3693 */
  IC_VEX_W_XD, /* 3694 */
  IC_VEX_W_XD, /* 3695 */
  IC_VEX_OPSIZE, /* 3696 */
  IC_VEX_OPSIZE, /* 3697 */
  IC_VEX_OPSIZE, /* 3698 */
  IC_VEX_OPSIZE, /* 3699 */
  IC_VEX_OPSIZE, /* 3700 */
  IC_VEX_OPSIZE, /* 3701 */
  IC_VEX_OPSIZE, /* 3702 */
  IC_VEX_OPSIZE, /* 3703 */
  IC_VEX_W_OPSIZE, /* 3704 */
  IC_VEX_W_OPSIZE, /* 3705 */
  IC_VEX_W_OPSIZE, /* 3706 */
  IC_VEX_W_OPSIZE, /* 3707 */
  IC_VEX_W_OPSIZE, /* 3708 */
  IC_VEX_W_OPSIZE, /* 3709 */
  IC_VEX_W_OPSIZE, /* 3710 */
  IC_VEX_W_OPSIZE, /* 3711 */
  IC_VEX_L, /* 3712 */
  IC_VEX_L, /* 3713 */
  IC_VEX_L_XS, /* 3714 */
  IC_VEX_L_XS, /* 3715 */
  IC_VEX_L_XD, /* 3716 */
  IC_VEX_L_XD, /* 3717 */
  IC_VEX_L_XD, /* 3718 */
  IC_VEX_L_XD, /* 3719 */
  IC_VEX_L_W, /* 3720 */
  IC_VEX_L_W, /* 3721 */
  IC_VEX_L_W_XS, /* 3722 */
  IC_VEX_L_W_XS, /* 3723 */
  IC_VEX_L_W_XD, /* 3724 */
  IC_VEX_L_W_XD, /* 3725 */
  IC_VEX_L_W_XD, /* 3726 */
  IC_VEX_L_W_XD, /* 3727 */
  IC_VEX_L_OPSIZE, /* 3728 */
  IC_VEX_L_OPSIZE, /* 3729 */
  IC_VEX_L_OPSIZE, /* 3730 */
  IC_VEX_L_OPSIZE, /* 3731 */
  IC_VEX_L_OPSIZE, /* 3732 */
  IC_VEX_L_OPSIZE, /* 3733 */
  IC_VEX_L_OPSIZE, /* 3734 */
  IC_VEX_L_OPSIZE, /* 3735 */
  IC_VEX_L_W_OPSIZE, /* 3736 */
  IC_VEX_L_W_OPSIZE, /* 3737 */
  IC_VEX_L_W_OPSIZE, /* 3738 */
  IC_VEX_L_W_OPSIZE, /* 3739 */
  IC_VEX_L_W_OPSIZE, /* 3740 */
  IC_VEX_L_W_OPSIZE, /* 3741 */
  IC_VEX_L_W_OPSIZE, /* 3742 */
  IC_VEX_L_W_OPSIZE, /* 3743 */
  IC_VEX_L, /* 3744 */
  IC_VEX_L, /* 3745 */
  IC_VEX_L_XS, /* 3746 */
  IC_VEX_L_XS, /* 3747 */
  IC_VEX_L_XD, /* 3748 */
  IC_VEX_L_XD, /* 3749 */
  IC_VEX_L_XD, /* 3750 */
  IC_VEX_L_XD, /* 3751 */
  IC_VEX_L_W, /* 3752 */
  IC_VEX_L_W, /* 3753 */
  IC_VEX_L_W_XS, /* 3754 */
  IC_VEX_L_W_XS, /* 3755 */
  IC_VEX_L_W_XD, /* 3756 */
  IC_VEX_L_W_XD, /* 3757 */
  IC_VEX_L_W_XD, /* 3758 */
  IC_VEX_L_W_XD, /* 3759 */
  IC_VEX_L_OPSIZE, /* 3760 */
  IC_VEX_L_OPSIZE, /* 3761 */
  IC_VEX_L_OPSIZE, /* 3762 */
  IC_VEX_L_OPSIZE, /* 3763 */
  IC_VEX_L_OPSIZE, /* 3764 */
  IC_VEX_L_OPSIZE, /* 3765 */
  IC_VEX_L_OPSIZE, /* 3766 */
  IC_VEX_L_OPSIZE, /* 3767 */
  IC_VEX_L_W_OPSIZE, /* 3768 */
  IC_VEX_L_W_OPSIZE, /* 3769 */
  IC_VEX_L_W_OPSIZE, /* 3770 */
  IC_VEX_L_W_OPSIZE, /* 3771 */
  IC_VEX_L_W_OPSIZE, /* 3772 */
  IC_VEX_L_W_OPSIZE, /* 3773 */
  IC_VEX_L_W_OPSIZE, /* 3774 */
  IC_VEX_L_W_OPSIZE, /* 3775 */
  IC_VEX_L, /* 3776 */
  IC_VEX_L, /* 3777 */
  IC_VEX_L_XS, /* 3778 */
  IC_VEX_L_XS, /* 3779 */
  IC_VEX_L_XD, /* 3780 */
  IC_VEX_L_XD, /* 3781 */
  IC_VEX_L_XD, /* 3782 */
  IC_VEX_L_XD, /* 3783 */
  IC_VEX_L_W, /* 3784 */
  IC_VEX_L_W, /* 3785 */
  IC_VEX_L_W_XS, /* 3786 */
  IC_VEX_L_W_XS, /* 3787 */
  IC_VEX_L_W_XD, /* 3788 */
  IC_VEX_L_W_XD, /* 3789 */
  IC_VEX_L_W_XD, /* 3790 */
  IC_VEX_L_W_XD, /* 3791 */
  IC_VEX_L_OPSIZE, /* 3792 */
  IC_VEX_L_OPSIZE, /* 3793 */
  IC_VEX_L_OPSIZE, /* 3794 */
  IC_VEX_L_OPSIZE, /* 3795 */
  IC_VEX_L_OPSIZE, /* 3796 */
  IC_VEX_L_OPSIZE, /* 3797 */
  IC_VEX_L_OPSIZE, /* 3798 */
  IC_VEX_L_OPSIZE, /* 3799 */
  IC_VEX_L_W_OPSIZE, /* 3800 */
  IC_VEX_L_W_OPSIZE, /* 3801 */
  IC_VEX_L_W_OPSIZE, /* 3802 */
  IC_VEX_L_W_OPSIZE, /* 3803 */
  IC_VEX_L_W_OPSIZE, /* 3804 */
  IC_VEX_L_W_OPSIZE, /* 3805 */
  IC_VEX_L_W_OPSIZE, /* 3806 */
  IC_VEX_L_W_OPSIZE, /* 3807 */
  IC_VEX_L, /* 3808 */
  IC_VEX_L, /* 3809 */
  IC_VEX_L_XS, /* 3810 */
  IC_VEX_L_XS, /* 3811 */
  IC_VEX_L_XD, /* 3812 */
  IC_VEX_L_XD, /* 3813 */
  IC_VEX_L_XD, /* 3814 */
  IC_VEX_L_XD, /* 3815 */
  IC_VEX_L_W, /* 3816 */
  IC_VEX_L_W, /* 3817 */
  IC_VEX_L_W_XS, /* 3818 */
  IC_VEX_L_W_XS, /* 3819 */
  IC_VEX_L_W_XD, /* 3820 */
  IC_VEX_L_W_XD, /* 3821 */
  IC_VEX_L_W_XD, /* 3822 */
  IC_VEX_L_W_XD, /* 3823 */
  IC_VEX_L_OPSIZE, /* 3824 */
  IC_VEX_L_OPSIZE, /* 3825 */
  IC_VEX_L_OPSIZE, /* 3826 */
  IC_VEX_L_OPSIZE, /* 3827 */
  IC_VEX_L_OPSIZE, /* 3828 */
  IC_VEX_L_OPSIZE, /* 3829 */
  IC_VEX_L_OPSIZE, /* 3830 */
  IC_VEX_L_OPSIZE, /* 3831 */
  IC_VEX_L_W_OPSIZE, /* 3832 */
  IC_VEX_L_W_OPSIZE, /* 3833 */
  IC_VEX_L_W_OPSIZE, /* 3834 */
  IC_VEX_L_W_OPSIZE, /* 3835 */
  IC_VEX_L_W_OPSIZE, /* 3836 */
  IC_VEX_L_W_OPSIZE, /* 3837 */
  IC_VEX_L_W_OPSIZE, /* 3838 */
  IC_VEX_L_W_OPSIZE, /* 3839 */
  IC_EVEX_L2_K, /* 3840 */
  IC_EVEX_L2_K, /* 3841 */
  IC_EVEX_L2_XS_K, /* 3842 */
  IC_EVEX_L2_XS_K, /* 3843 */
  IC_EVEX_L2_XD_K, /* 3844 */
  IC_EVEX_L2_XD_K, /* 3845 */
  IC_EVEX_L2_XD_K, /* 3846 */
  IC_EVEX_L2_XD_K, /* 3847 */
  IC_EVEX_L2_W_K, /* 3848 */
  IC_EVEX_L2_W_K, /* 3849 */
  IC_EVEX_L2_W_XS_K, /* 3850 */
  IC_EVEX_L2_W_XS_K, /* 3851 */
  IC_EVEX_L2_W_XD_K, /* 3852 */
  IC_EVEX_L2_W_XD_K, /* 3853 */
  IC_EVEX_L2_W_XD_K, /* 3854 */
  IC_EVEX_L2_W_XD_K, /* 3855 */
  IC_EVEX_L2_OPSIZE_K, /* 3856 */
  IC_EVEX_L2_OPSIZE_K, /* 3857 */
  IC_EVEX_L2_OPSIZE_K, /* 3858 */
  IC_EVEX_L2_OPSIZE_K, /* 3859 */
  IC_EVEX_L2_OPSIZE_K, /* 3860 */
  IC_EVEX_L2_OPSIZE_K, /* 3861 */
  IC_EVEX_L2_OPSIZE_K, /* 3862 */
  IC_EVEX_L2_OPSIZE_K, /* 3863 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3864 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3865 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3866 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3867 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3868 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3869 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3870 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3871 */
  IC_EVEX_L2_K, /* 3872 */
  IC_EVEX_L2_K, /* 3873 */
  IC_EVEX_L2_XS_K, /* 3874 */
  IC_EVEX_L2_XS_K, /* 3875 */
  IC_EVEX_L2_XD_K, /* 3876 */
  IC_EVEX_L2_XD_K, /* 3877 */
  IC_EVEX_L2_XD_K, /* 3878 */
  IC_EVEX_L2_XD_K, /* 3879 */
  IC_EVEX_L2_W_K, /* 3880 */
  IC_EVEX_L2_W_K, /* 3881 */
  IC_EVEX_L2_W_XS_K, /* 3882 */
  IC_EVEX_L2_W_XS_K, /* 3883 */
  IC_EVEX_L2_W_XD_K, /* 3884 */
  IC_EVEX_L2_W_XD_K, /* 3885 */
  IC_EVEX_L2_W_XD_K, /* 3886 */
  IC_EVEX_L2_W_XD_K, /* 3887 */
  IC_EVEX_L2_OPSIZE_K, /* 3888 */
  IC_EVEX_L2_OPSIZE_K, /* 3889 */
  IC_EVEX_L2_OPSIZE_K, /* 3890 */
  IC_EVEX_L2_OPSIZE_K, /* 3891 */
  IC_EVEX_L2_OPSIZE_K, /* 3892 */
  IC_EVEX_L2_OPSIZE_K, /* 3893 */
  IC_EVEX_L2_OPSIZE_K, /* 3894 */
  IC_EVEX_L2_OPSIZE_K, /* 3895 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3896 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3897 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3898 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3899 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3900 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3901 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3902 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3903 */
  IC_EVEX_L2_K, /* 3904 */
  IC_EVEX_L2_K, /* 3905 */
  IC_EVEX_L2_XS_K, /* 3906 */
  IC_EVEX_L2_XS_K, /* 3907 */
  IC_EVEX_L2_XD_K, /* 3908 */
  IC_EVEX_L2_XD_K, /* 3909 */
  IC_EVEX_L2_XD_K, /* 3910 */
  IC_EVEX_L2_XD_K, /* 3911 */
  IC_EVEX_L2_W_K, /* 3912 */
  IC_EVEX_L2_W_K, /* 3913 */
  IC_EVEX_L2_W_XS_K, /* 3914 */
  IC_EVEX_L2_W_XS_K, /* 3915 */
  IC_EVEX_L2_W_XD_K, /* 3916 */
  IC_EVEX_L2_W_XD_K, /* 3917 */
  IC_EVEX_L2_W_XD_K, /* 3918 */
  IC_EVEX_L2_W_XD_K, /* 3919 */
  IC_EVEX_L2_OPSIZE_K, /* 3920 */
  IC_EVEX_L2_OPSIZE_K, /* 3921 */
  IC_EVEX_L2_OPSIZE_K, /* 3922 */
  IC_EVEX_L2_OPSIZE_K, /* 3923 */
  IC_EVEX_L2_OPSIZE_K, /* 3924 */
  IC_EVEX_L2_OPSIZE_K, /* 3925 */
  IC_EVEX_L2_OPSIZE_K, /* 3926 */
  IC_EVEX_L2_OPSIZE_K, /* 3927 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3928 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3929 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3930 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3931 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3932 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3933 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3934 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3935 */
  IC_EVEX_L2_K, /* 3936 */
  IC_EVEX_L2_K, /* 3937 */
  IC_EVEX_L2_XS_K, /* 3938 */
  IC_EVEX_L2_XS_K, /* 3939 */
  IC_EVEX_L2_XD_K, /* 3940 */
  IC_EVEX_L2_XD_K, /* 3941 */
  IC_EVEX_L2_XD_K, /* 3942 */
  IC_EVEX_L2_XD_K, /* 3943 */
  IC_EVEX_L2_W_K, /* 3944 */
  IC_EVEX_L2_W_K, /* 3945 */
  IC_EVEX_L2_W_XS_K, /* 3946 */
  IC_EVEX_L2_W_XS_K, /* 3947 */
  IC_EVEX_L2_W_XD_K, /* 3948 */
  IC_EVEX_L2_W_XD_K, /* 3949 */
  IC_EVEX_L2_W_XD_K, /* 3950 */
  IC_EVEX_L2_W_XD_K, /* 3951 */
  IC_EVEX_L2_OPSIZE_K, /* 3952 */
  IC_EVEX_L2_OPSIZE_K, /* 3953 */
  IC_EVEX_L2_OPSIZE_K, /* 3954 */
  IC_EVEX_L2_OPSIZE_K, /* 3955 */
  IC_EVEX_L2_OPSIZE_K, /* 3956 */
  IC_EVEX_L2_OPSIZE_K, /* 3957 */
  IC_EVEX_L2_OPSIZE_K, /* 3958 */
  IC_EVEX_L2_OPSIZE_K, /* 3959 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3960 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3961 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3962 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3963 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3964 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3965 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3966 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3967 */
  IC_EVEX_L2_K, /* 3968 */
  IC_EVEX_L2_K, /* 3969 */
  IC_EVEX_L2_XS_K, /* 3970 */
  IC_EVEX_L2_XS_K, /* 3971 */
  IC_EVEX_L2_XD_K, /* 3972 */
  IC_EVEX_L2_XD_K, /* 3973 */
  IC_EVEX_L2_XD_K, /* 3974 */
  IC_EVEX_L2_XD_K, /* 3975 */
  IC_EVEX_L2_W_K, /* 3976 */
  IC_EVEX_L2_W_K, /* 3977 */
  IC_EVEX_L2_W_XS_K, /* 3978 */
  IC_EVEX_L2_W_XS_K, /* 3979 */
  IC_EVEX_L2_W_XD_K, /* 3980 */
  IC_EVEX_L2_W_XD_K, /* 3981 */
  IC_EVEX_L2_W_XD_K, /* 3982 */
  IC_EVEX_L2_W_XD_K, /* 3983 */
  IC_EVEX_L2_OPSIZE_K, /* 3984 */
  IC_EVEX_L2_OPSIZE_K, /* 3985 */
  IC_EVEX_L2_OPSIZE_K, /* 3986 */
  IC_EVEX_L2_OPSIZE_K, /* 3987 */
  IC_EVEX_L2_OPSIZE_K, /* 3988 */
  IC_EVEX_L2_OPSIZE_K, /* 3989 */
  IC_EVEX_L2_OPSIZE_K, /* 3990 */
  IC_EVEX_L2_OPSIZE_K, /* 3991 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3992 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3993 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3994 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3995 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3996 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3997 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3998 */
  IC_EVEX_L2_W_OPSIZE_K, /* 3999 */
  IC_EVEX_L2_K, /* 4000 */
  IC_EVEX_L2_K, /* 4001 */
  IC_EVEX_L2_XS_K, /* 4002 */
  IC_EVEX_L2_XS_K, /* 4003 */
  IC_EVEX_L2_XD_K, /* 4004 */
  IC_EVEX_L2_XD_K, /* 4005 */
  IC_EVEX_L2_XD_K, /* 4006 */
  IC_EVEX_L2_XD_K, /* 4007 */
  IC_EVEX_L2_W_K, /* 4008 */
  IC_EVEX_L2_W_K, /* 4009 */
  IC_EVEX_L2_W_XS_K, /* 4010 */
  IC_EVEX_L2_W_XS_K, /* 4011 */
  IC_EVEX_L2_W_XD_K, /* 4012 */
  IC_EVEX_L2_W_XD_K, /* 4013 */
  IC_EVEX_L2_W_XD_K, /* 4014 */
  IC_EVEX_L2_W_XD_K, /* 4015 */
  IC_EVEX_L2_OPSIZE_K, /* 4016 */
  IC_EVEX_L2_OPSIZE_K, /* 4017 */
  IC_EVEX_L2_OPSIZE_K, /* 4018 */
  IC_EVEX_L2_OPSIZE_K, /* 4019 */
  IC_EVEX_L2_OPSIZE_K, /* 4020 */
  IC_EVEX_L2_OPSIZE_K, /* 4021 */
  IC_EVEX_L2_OPSIZE_K, /* 4022 */
  IC_EVEX_L2_OPSIZE_K, /* 4023 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4024 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4025 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4026 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4027 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4028 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4029 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4030 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4031 */
  IC_EVEX_L2_K, /* 4032 */
  IC_EVEX_L2_K, /* 4033 */
  IC_EVEX_L2_XS_K, /* 4034 */
  IC_EVEX_L2_XS_K, /* 4035 */
  IC_EVEX_L2_XD_K, /* 4036 */
  IC_EVEX_L2_XD_K, /* 4037 */
  IC_EVEX_L2_XD_K, /* 4038 */
  IC_EVEX_L2_XD_K, /* 4039 */
  IC_EVEX_L2_W_K, /* 4040 */
  IC_EVEX_L2_W_K, /* 4041 */
  IC_EVEX_L2_W_XS_K, /* 4042 */
  IC_EVEX_L2_W_XS_K, /* 4043 */
  IC_EVEX_L2_W_XD_K, /* 4044 */
  IC_EVEX_L2_W_XD_K, /* 4045 */
  IC_EVEX_L2_W_XD_K, /* 4046 */
  IC_EVEX_L2_W_XD_K, /* 4047 */
  IC_EVEX_L2_OPSIZE_K, /* 4048 */
  IC_EVEX_L2_OPSIZE_K, /* 4049 */
  IC_EVEX_L2_OPSIZE_K, /* 4050 */
  IC_EVEX_L2_OPSIZE_K, /* 4051 */
  IC_EVEX_L2_OPSIZE_K, /* 4052 */
  IC_EVEX_L2_OPSIZE_K, /* 4053 */
  IC_EVEX_L2_OPSIZE_K, /* 4054 */
  IC_EVEX_L2_OPSIZE_K, /* 4055 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4056 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4057 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4058 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4059 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4060 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4061 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4062 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4063 */
  IC_EVEX_L2_K, /* 4064 */
  IC_EVEX_L2_K, /* 4065 */
  IC_EVEX_L2_XS_K, /* 4066 */
  IC_EVEX_L2_XS_K, /* 4067 */
  IC_EVEX_L2_XD_K, /* 4068 */
  IC_EVEX_L2_XD_K, /* 4069 */
  IC_EVEX_L2_XD_K, /* 4070 */
  IC_EVEX_L2_XD_K, /* 4071 */
  IC_EVEX_L2_W_K, /* 4072 */
  IC_EVEX_L2_W_K, /* 4073 */
  IC_EVEX_L2_W_XS_K, /* 4074 */
  IC_EVEX_L2_W_XS_K, /* 4075 */
  IC_EVEX_L2_W_XD_K, /* 4076 */
  IC_EVEX_L2_W_XD_K, /* 4077 */
  IC_EVEX_L2_W_XD_K, /* 4078 */
  IC_EVEX_L2_W_XD_K, /* 4079 */
  IC_EVEX_L2_OPSIZE_K, /* 4080 */
  IC_EVEX_L2_OPSIZE_K, /* 4081 */
  IC_EVEX_L2_OPSIZE_K, /* 4082 */
  IC_EVEX_L2_OPSIZE_K, /* 4083 */
  IC_EVEX_L2_OPSIZE_K, /* 4084 */
  IC_EVEX_L2_OPSIZE_K, /* 4085 */
  IC_EVEX_L2_OPSIZE_K, /* 4086 */
  IC_EVEX_L2_OPSIZE_K, /* 4087 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4088 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4089 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4090 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4091 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4092 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4093 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4094 */
  IC_EVEX_L2_W_OPSIZE_K, /* 4095 */
  IC, /* 4096 */
  IC_64BIT, /* 4097 */
  IC_XS, /* 4098 */
  IC_64BIT_XS, /* 4099 */
  IC_XD, /* 4100 */
  IC_64BIT_XD, /* 4101 */
  IC_XS, /* 4102 */
  IC_64BIT_XS, /* 4103 */
  IC, /* 4104 */
  IC_64BIT_REXW, /* 4105 */
  IC_XS, /* 4106 */
  IC_64BIT_REXW_XS, /* 4107 */
  IC_XD, /* 4108 */
  IC_64BIT_REXW_XD, /* 4109 */
  IC_XS, /* 4110 */
  IC_64BIT_REXW_XS, /* 4111 */
  IC_OPSIZE, /* 4112 */
  IC_64BIT_OPSIZE, /* 4113 */
  IC_XS_OPSIZE, /* 4114 */
  IC_64BIT_XS_OPSIZE, /* 4115 */
  IC_XD_OPSIZE, /* 4116 */
  IC_64BIT_XD_OPSIZE, /* 4117 */
  IC_XS_OPSIZE, /* 4118 */
  IC_64BIT_XD_OPSIZE, /* 4119 */
  IC_OPSIZE, /* 4120 */
  IC_64BIT_REXW_OPSIZE, /* 4121 */
  IC_XS_OPSIZE, /* 4122 */
  IC_64BIT_REXW_XS, /* 4123 */
  IC_XD_OPSIZE, /* 4124 */
  IC_64BIT_REXW_XD, /* 4125 */
  IC_XS_OPSIZE, /* 4126 */
  IC_64BIT_REXW_XS, /* 4127 */
  IC_ADSIZE, /* 4128 */
  IC_64BIT_ADSIZE, /* 4129 */
  IC_XS, /* 4130 */
  IC_64BIT_XS, /* 4131 */
  IC_XD, /* 4132 */
  IC_64BIT_XD, /* 4133 */
  IC_XS, /* 4134 */
  IC_64BIT_XS, /* 4135 */
  IC_ADSIZE, /* 4136 */
  IC_64BIT_REXW_ADSIZE, /* 4137 */
  IC_XS, /* 4138 */
  IC_64BIT_REXW_XS, /* 4139 */
  IC_XD, /* 4140 */
  IC_64BIT_REXW_XD, /* 4141 */
  IC_XS, /* 4142 */
  IC_64BIT_REXW_XS, /* 4143 */
  IC_OPSIZE_ADSIZE, /* 4144 */
  IC_64BIT_OPSIZE_ADSIZE, /* 4145 */
  IC_XS_OPSIZE, /* 4146 */
  IC_64BIT_XS_OPSIZE, /* 4147 */
  IC_XD_OPSIZE, /* 4148 */
  IC_64BIT_XD_OPSIZE, /* 4149 */
  IC_XS_OPSIZE, /* 4150 */
  IC_64BIT_XD_OPSIZE, /* 4151 */
  IC_OPSIZE_ADSIZE, /* 4152 */
  IC_64BIT_REXW_OPSIZE, /* 4153 */
  IC_XS_OPSIZE, /* 4154 */
  IC_64BIT_REXW_XS, /* 4155 */
  IC_XD_OPSIZE, /* 4156 */
  IC_64BIT_REXW_XD, /* 4157 */
  IC_XS_OPSIZE, /* 4158 */
  IC_64BIT_REXW_XS, /* 4159 */
  IC_VEX, /* 4160 */
  IC_VEX, /* 4161 */
  IC_VEX_XS, /* 4162 */
  IC_VEX_XS, /* 4163 */
  IC_VEX_XD, /* 4164 */
  IC_VEX_XD, /* 4165 */
  IC_VEX_XD, /* 4166 */
  IC_VEX_XD, /* 4167 */
  IC_VEX_W, /* 4168 */
  IC_VEX_W, /* 4169 */
  IC_VEX_W_XS, /* 4170 */
  IC_VEX_W_XS, /* 4171 */
  IC_VEX_W_XD, /* 4172 */
  IC_VEX_W_XD, /* 4173 */
  IC_VEX_W_XD, /* 4174 */
  IC_VEX_W_XD, /* 4175 */
  IC_VEX_OPSIZE, /* 4176 */
  IC_VEX_OPSIZE, /* 4177 */
  IC_VEX_OPSIZE, /* 4178 */
  IC_VEX_OPSIZE, /* 4179 */
  IC_VEX_OPSIZE, /* 4180 */
  IC_VEX_OPSIZE, /* 4181 */
  IC_VEX_OPSIZE, /* 4182 */
  IC_VEX_OPSIZE, /* 4183 */
  IC_VEX_W_OPSIZE, /* 4184 */
  IC_VEX_W_OPSIZE, /* 4185 */
  IC_VEX_W_OPSIZE, /* 4186 */
  IC_VEX_W_OPSIZE, /* 4187 */
  IC_VEX_W_OPSIZE, /* 4188 */
  IC_VEX_W_OPSIZE, /* 4189 */
  IC_VEX_W_OPSIZE, /* 4190 */
  IC_VEX_W_OPSIZE, /* 4191 */
  IC_VEX, /* 4192 */
  IC_VEX, /* 4193 */
  IC_VEX_XS, /* 4194 */
  IC_VEX_XS, /* 4195 */
  IC_VEX_XD, /* 4196 */
  IC_VEX_XD, /* 4197 */
  IC_VEX_XD, /* 4198 */
  IC_VEX_XD, /* 4199 */
  IC_VEX_W, /* 4200 */
  IC_VEX_W, /* 4201 */
  IC_VEX_W_XS, /* 4202 */
  IC_VEX_W_XS, /* 4203 */
  IC_VEX_W_XD, /* 4204 */
  IC_VEX_W_XD, /* 4205 */
  IC_VEX_W_XD, /* 4206 */
  IC_VEX_W_XD, /* 4207 */
  IC_VEX_OPSIZE, /* 4208 */
  IC_VEX_OPSIZE, /* 4209 */
  IC_VEX_OPSIZE, /* 4210 */
  IC_VEX_OPSIZE, /* 4211 */
  IC_VEX_OPSIZE, /* 4212 */
  IC_VEX_OPSIZE, /* 4213 */
  IC_VEX_OPSIZE, /* 4214 */
  IC_VEX_OPSIZE, /* 4215 */
  IC_VEX_W_OPSIZE, /* 4216 */
  IC_VEX_W_OPSIZE, /* 4217 */
  IC_VEX_W_OPSIZE, /* 4218 */
  IC_VEX_W_OPSIZE, /* 4219 */
  IC_VEX_W_OPSIZE, /* 4220 */
  IC_VEX_W_OPSIZE, /* 4221 */
  IC_VEX_W_OPSIZE, /* 4222 */
  IC_VEX_W_OPSIZE, /* 4223 */
  IC_VEX_L, /* 4224 */
  IC_VEX_L, /* 4225 */
  IC_VEX_L_XS, /* 4226 */
  IC_VEX_L_XS, /* 4227 */
  IC_VEX_L_XD, /* 4228 */
  IC_VEX_L_XD, /* 4229 */
  IC_VEX_L_XD, /* 4230 */
  IC_VEX_L_XD, /* 4231 */
  IC_VEX_L_W, /* 4232 */
  IC_VEX_L_W, /* 4233 */
  IC_VEX_L_W_XS, /* 4234 */
  IC_VEX_L_W_XS, /* 4235 */
  IC_VEX_L_W_XD, /* 4236 */
  IC_VEX_L_W_XD, /* 4237 */
  IC_VEX_L_W_XD, /* 4238 */
  IC_VEX_L_W_XD, /* 4239 */
  IC_VEX_L_OPSIZE, /* 4240 */
  IC_VEX_L_OPSIZE, /* 4241 */
  IC_VEX_L_OPSIZE, /* 4242 */
  IC_VEX_L_OPSIZE, /* 4243 */
  IC_VEX_L_OPSIZE, /* 4244 */
  IC_VEX_L_OPSIZE, /* 4245 */
  IC_VEX_L_OPSIZE, /* 4246 */
  IC_VEX_L_OPSIZE, /* 4247 */
  IC_VEX_L_W_OPSIZE, /* 4248 */
  IC_VEX_L_W_OPSIZE, /* 4249 */
  IC_VEX_L_W_OPSIZE, /* 4250 */
  IC_VEX_L_W_OPSIZE, /* 4251 */
  IC_VEX_L_W_OPSIZE, /* 4252 */
  IC_VEX_L_W_OPSIZE, /* 4253 */
  IC_VEX_L_W_OPSIZE, /* 4254 */
  IC_VEX_L_W_OPSIZE, /* 4255 */
  IC_VEX_L, /* 4256 */
  IC_VEX_L, /* 4257 */
  IC_VEX_L_XS, /* 4258 */
  IC_VEX_L_XS, /* 4259 */
  IC_VEX_L_XD, /* 4260 */
  IC_VEX_L_XD, /* 4261 */
  IC_VEX_L_XD, /* 4262 */
  IC_VEX_L_XD, /* 4263 */
  IC_VEX_L_W, /* 4264 */
  IC_VEX_L_W, /* 4265 */
  IC_VEX_L_W_XS, /* 4266 */
  IC_VEX_L_W_XS, /* 4267 */
  IC_VEX_L_W_XD, /* 4268 */
  IC_VEX_L_W_XD, /* 4269 */
  IC_VEX_L_W_XD, /* 4270 */
  IC_VEX_L_W_XD, /* 4271 */
  IC_VEX_L_OPSIZE, /* 4272 */
  IC_VEX_L_OPSIZE, /* 4273 */
  IC_VEX_L_OPSIZE, /* 4274 */
  IC_VEX_L_OPSIZE, /* 4275 */
  IC_VEX_L_OPSIZE, /* 4276 */
  IC_VEX_L_OPSIZE, /* 4277 */
  IC_VEX_L_OPSIZE, /* 4278 */
  IC_VEX_L_OPSIZE, /* 4279 */
  IC_VEX_L_W_OPSIZE, /* 4280 */
  IC_VEX_L_W_OPSIZE, /* 4281 */
  IC_VEX_L_W_OPSIZE, /* 4282 */
  IC_VEX_L_W_OPSIZE, /* 4283 */
  IC_VEX_L_W_OPSIZE, /* 4284 */
  IC_VEX_L_W_OPSIZE, /* 4285 */
  IC_VEX_L_W_OPSIZE, /* 4286 */
  IC_VEX_L_W_OPSIZE, /* 4287 */
  IC_VEX_L, /* 4288 */
  IC_VEX_L, /* 4289 */
  IC_VEX_L_XS, /* 4290 */
  IC_VEX_L_XS, /* 4291 */
  IC_VEX_L_XD, /* 4292 */
  IC_VEX_L_XD, /* 4293 */
  IC_VEX_L_XD, /* 4294 */
  IC_VEX_L_XD, /* 4295 */
  IC_VEX_L_W, /* 4296 */
  IC_VEX_L_W, /* 4297 */
  IC_VEX_L_W_XS, /* 4298 */
  IC_VEX_L_W_XS, /* 4299 */
  IC_VEX_L_W_XD, /* 4300 */
  IC_VEX_L_W_XD, /* 4301 */
  IC_VEX_L_W_XD, /* 4302 */
  IC_VEX_L_W_XD, /* 4303 */
  IC_VEX_L_OPSIZE, /* 4304 */
  IC_VEX_L_OPSIZE, /* 4305 */
  IC_VEX_L_OPSIZE, /* 4306 */
  IC_VEX_L_OPSIZE, /* 4307 */
  IC_VEX_L_OPSIZE, /* 4308 */
  IC_VEX_L_OPSIZE, /* 4309 */
  IC_VEX_L_OPSIZE, /* 4310 */
  IC_VEX_L_OPSIZE, /* 4311 */
  IC_VEX_L_W_OPSIZE, /* 4312 */
  IC_VEX_L_W_OPSIZE, /* 4313 */
  IC_VEX_L_W_OPSIZE, /* 4314 */
  IC_VEX_L_W_OPSIZE, /* 4315 */
  IC_VEX_L_W_OPSIZE, /* 4316 */
  IC_VEX_L_W_OPSIZE, /* 4317 */
  IC_VEX_L_W_OPSIZE, /* 4318 */
  IC_VEX_L_W_OPSIZE, /* 4319 */
  IC_VEX_L, /* 4320 */
  IC_VEX_L, /* 4321 */
  IC_VEX_L_XS, /* 4322 */
  IC_VEX_L_XS, /* 4323 */
  IC_VEX_L_XD, /* 4324 */
  IC_VEX_L_XD, /* 4325 */
  IC_VEX_L_XD, /* 4326 */
  IC_VEX_L_XD, /* 4327 */
  IC_VEX_L_W, /* 4328 */
  IC_VEX_L_W, /* 4329 */
  IC_VEX_L_W_XS, /* 4330 */
  IC_VEX_L_W_XS, /* 4331 */
  IC_VEX_L_W_XD, /* 4332 */
  IC_VEX_L_W_XD, /* 4333 */
  IC_VEX_L_W_XD, /* 4334 */
  IC_VEX_L_W_XD, /* 4335 */
  IC_VEX_L_OPSIZE, /* 4336 */
  IC_VEX_L_OPSIZE, /* 4337 */
  IC_VEX_L_OPSIZE, /* 4338 */
  IC_VEX_L_OPSIZE, /* 4339 */
  IC_VEX_L_OPSIZE, /* 4340 */
  IC_VEX_L_OPSIZE, /* 4341 */
  IC_VEX_L_OPSIZE, /* 4342 */
  IC_VEX_L_OPSIZE, /* 4343 */
  IC_VEX_L_W_OPSIZE, /* 4344 */
  IC_VEX_L_W_OPSIZE, /* 4345 */
  IC_VEX_L_W_OPSIZE, /* 4346 */
  IC_VEX_L_W_OPSIZE, /* 4347 */
  IC_VEX_L_W_OPSIZE, /* 4348 */
  IC_VEX_L_W_OPSIZE, /* 4349 */
  IC_VEX_L_W_OPSIZE, /* 4350 */
  IC_VEX_L_W_OPSIZE, /* 4351 */
  IC_EVEX_KZ, /* 4352 */
  IC_EVEX_KZ, /* 4353 */
  IC_EVEX_XS_KZ, /* 4354 */
  IC_EVEX_XS_KZ, /* 4355 */
  IC_EVEX_XD_KZ, /* 4356 */
  IC_EVEX_XD_KZ, /* 4357 */
  IC_EVEX_XD_KZ, /* 4358 */
  IC_EVEX_XD_KZ, /* 4359 */
  IC_EVEX_W_KZ, /* 4360 */
  IC_EVEX_W_KZ, /* 4361 */
  IC_EVEX_W_XS_KZ, /* 4362 */
  IC_EVEX_W_XS_KZ, /* 4363 */
  IC_EVEX_W_XD_KZ, /* 4364 */
  IC_EVEX_W_XD_KZ, /* 4365 */
  IC_EVEX_W_XD_KZ, /* 4366 */
  IC_EVEX_W_XD_KZ, /* 4367 */
  IC_EVEX_OPSIZE_KZ, /* 4368 */
  IC_EVEX_OPSIZE_KZ, /* 4369 */
  IC_EVEX_OPSIZE_KZ, /* 4370 */
  IC_EVEX_OPSIZE_KZ, /* 4371 */
  IC_EVEX_OPSIZE_KZ, /* 4372 */
  IC_EVEX_OPSIZE_KZ, /* 4373 */
  IC_EVEX_OPSIZE_KZ, /* 4374 */
  IC_EVEX_OPSIZE_KZ, /* 4375 */
  IC_EVEX_W_OPSIZE_KZ, /* 4376 */
  IC_EVEX_W_OPSIZE_KZ, /* 4377 */
  IC_EVEX_W_OPSIZE_KZ, /* 4378 */
  IC_EVEX_W_OPSIZE_KZ, /* 4379 */
  IC_EVEX_W_OPSIZE_KZ, /* 4380 */
  IC_EVEX_W_OPSIZE_KZ, /* 4381 */
  IC_EVEX_W_OPSIZE_KZ, /* 4382 */
  IC_EVEX_W_OPSIZE_KZ, /* 4383 */
  IC_EVEX_KZ, /* 4384 */
  IC_EVEX_KZ, /* 4385 */
  IC_EVEX_XS_KZ, /* 4386 */
  IC_EVEX_XS_KZ, /* 4387 */
  IC_EVEX_XD_KZ, /* 4388 */
  IC_EVEX_XD_KZ, /* 4389 */
  IC_EVEX_XD_KZ, /* 4390 */
  IC_EVEX_XD_KZ, /* 4391 */
  IC_EVEX_W_KZ, /* 4392 */
  IC_EVEX_W_KZ, /* 4393 */
  IC_EVEX_W_XS_KZ, /* 4394 */
  IC_EVEX_W_XS_KZ, /* 4395 */
  IC_EVEX_W_XD_KZ, /* 4396 */
  IC_EVEX_W_XD_KZ, /* 4397 */
  IC_EVEX_W_XD_KZ, /* 4398 */
  IC_EVEX_W_XD_KZ, /* 4399 */
  IC_EVEX_OPSIZE_KZ, /* 4400 */
  IC_EVEX_OPSIZE_KZ, /* 4401 */
  IC_EVEX_OPSIZE_KZ, /* 4402 */
  IC_EVEX_OPSIZE_KZ, /* 4403 */
  IC_EVEX_OPSIZE_KZ, /* 4404 */
  IC_EVEX_OPSIZE_KZ, /* 4405 */
  IC_EVEX_OPSIZE_KZ, /* 4406 */
  IC_EVEX_OPSIZE_KZ, /* 4407 */
  IC_EVEX_W_OPSIZE_KZ, /* 4408 */
  IC_EVEX_W_OPSIZE_KZ, /* 4409 */
  IC_EVEX_W_OPSIZE_KZ, /* 4410 */
  IC_EVEX_W_OPSIZE_KZ, /* 4411 */
  IC_EVEX_W_OPSIZE_KZ, /* 4412 */
  IC_EVEX_W_OPSIZE_KZ, /* 4413 */
  IC_EVEX_W_OPSIZE_KZ, /* 4414 */
  IC_EVEX_W_OPSIZE_KZ, /* 4415 */
  IC_EVEX_KZ, /* 4416 */
  IC_EVEX_KZ, /* 4417 */
  IC_EVEX_XS_KZ, /* 4418 */
  IC_EVEX_XS_KZ, /* 4419 */
  IC_EVEX_XD_KZ, /* 4420 */
  IC_EVEX_XD_KZ, /* 4421 */
  IC_EVEX_XD_KZ, /* 4422 */
  IC_EVEX_XD_KZ, /* 4423 */
  IC_EVEX_W_KZ, /* 4424 */
  IC_EVEX_W_KZ, /* 4425 */
  IC_EVEX_W_XS_KZ, /* 4426 */
  IC_EVEX_W_XS_KZ, /* 4427 */
  IC_EVEX_W_XD_KZ, /* 4428 */
  IC_EVEX_W_XD_KZ, /* 4429 */
  IC_EVEX_W_XD_KZ, /* 4430 */
  IC_EVEX_W_XD_KZ, /* 4431 */
  IC_EVEX_OPSIZE_KZ, /* 4432 */
  IC_EVEX_OPSIZE_KZ, /* 4433 */
  IC_EVEX_OPSIZE_KZ, /* 4434 */
  IC_EVEX_OPSIZE_KZ, /* 4435 */
  IC_EVEX_OPSIZE_KZ, /* 4436 */
  IC_EVEX_OPSIZE_KZ, /* 4437 */
  IC_EVEX_OPSIZE_KZ, /* 4438 */
  IC_EVEX_OPSIZE_KZ, /* 4439 */
  IC_EVEX_W_OPSIZE_KZ, /* 4440 */
  IC_EVEX_W_OPSIZE_KZ, /* 4441 */
  IC_EVEX_W_OPSIZE_KZ, /* 4442 */
  IC_EVEX_W_OPSIZE_KZ, /* 4443 */
  IC_EVEX_W_OPSIZE_KZ, /* 4444 */
  IC_EVEX_W_OPSIZE_KZ, /* 4445 */
  IC_EVEX_W_OPSIZE_KZ, /* 4446 */
  IC_EVEX_W_OPSIZE_KZ, /* 4447 */
  IC_EVEX_KZ, /* 4448 */
  IC_EVEX_KZ, /* 4449 */
  IC_EVEX_XS_KZ, /* 4450 */
  IC_EVEX_XS_KZ, /* 4451 */
  IC_EVEX_XD_KZ, /* 4452 */
  IC_EVEX_XD_KZ, /* 4453 */
  IC_EVEX_XD_KZ, /* 4454 */
  IC_EVEX_XD_KZ, /* 4455 */
  IC_EVEX_W_KZ, /* 4456 */
  IC_EVEX_W_KZ, /* 4457 */
  IC_EVEX_W_XS_KZ, /* 4458 */
  IC_EVEX_W_XS_KZ, /* 4459 */
  IC_EVEX_W_XD_KZ, /* 4460 */
  IC_EVEX_W_XD_KZ, /* 4461 */
  IC_EVEX_W_XD_KZ, /* 4462 */
  IC_EVEX_W_XD_KZ, /* 4463 */
  IC_EVEX_OPSIZE_KZ, /* 4464 */
  IC_EVEX_OPSIZE_KZ, /* 4465 */
  IC_EVEX_OPSIZE_KZ, /* 4466 */
  IC_EVEX_OPSIZE_KZ, /* 4467 */
  IC_EVEX_OPSIZE_KZ, /* 4468 */
  IC_EVEX_OPSIZE_KZ, /* 4469 */
  IC_EVEX_OPSIZE_KZ, /* 4470 */
  IC_EVEX_OPSIZE_KZ, /* 4471 */
  IC_EVEX_W_OPSIZE_KZ, /* 4472 */
  IC_EVEX_W_OPSIZE_KZ, /* 4473 */
  IC_EVEX_W_OPSIZE_KZ, /* 4474 */
  IC_EVEX_W_OPSIZE_KZ, /* 4475 */
  IC_EVEX_W_OPSIZE_KZ, /* 4476 */
  IC_EVEX_W_OPSIZE_KZ, /* 4477 */
  IC_EVEX_W_OPSIZE_KZ, /* 4478 */
  IC_EVEX_W_OPSIZE_KZ, /* 4479 */
  IC_EVEX_KZ, /* 4480 */
  IC_EVEX_KZ, /* 4481 */
  IC_EVEX_XS_KZ, /* 4482 */
  IC_EVEX_XS_KZ, /* 4483 */
  IC_EVEX_XD_KZ, /* 4484 */
  IC_EVEX_XD_KZ, /* 4485 */
  IC_EVEX_XD_KZ, /* 4486 */
  IC_EVEX_XD_KZ, /* 4487 */
  IC_EVEX_W_KZ, /* 4488 */
  IC_EVEX_W_KZ, /* 4489 */
  IC_EVEX_W_XS_KZ, /* 4490 */
  IC_EVEX_W_XS_KZ, /* 4491 */
  IC_EVEX_W_XD_KZ, /* 4492 */
  IC_EVEX_W_XD_KZ, /* 4493 */
  IC_EVEX_W_XD_KZ, /* 4494 */
  IC_EVEX_W_XD_KZ, /* 4495 */
  IC_EVEX_OPSIZE_KZ, /* 4496 */
  IC_EVEX_OPSIZE_KZ, /* 4497 */
  IC_EVEX_OPSIZE_KZ, /* 4498 */
  IC_EVEX_OPSIZE_KZ, /* 4499 */
  IC_EVEX_OPSIZE_KZ, /* 4500 */
  IC_EVEX_OPSIZE_KZ, /* 4501 */
  IC_EVEX_OPSIZE_KZ, /* 4502 */
  IC_EVEX_OPSIZE_KZ, /* 4503 */
  IC_EVEX_W_OPSIZE_KZ, /* 4504 */
  IC_EVEX_W_OPSIZE_KZ, /* 4505 */
  IC_EVEX_W_OPSIZE_KZ, /* 4506 */
  IC_EVEX_W_OPSIZE_KZ, /* 4507 */
  IC_EVEX_W_OPSIZE_KZ, /* 4508 */
  IC_EVEX_W_OPSIZE_KZ, /* 4509 */
  IC_EVEX_W_OPSIZE_KZ, /* 4510 */
  IC_EVEX_W_OPSIZE_KZ, /* 4511 */
  IC_EVEX_KZ, /* 4512 */
  IC_EVEX_KZ, /* 4513 */
  IC_EVEX_XS_KZ, /* 4514 */
  IC_EVEX_XS_KZ, /* 4515 */
  IC_EVEX_XD_KZ, /* 4516 */
  IC_EVEX_XD_KZ, /* 4517 */
  IC_EVEX_XD_KZ, /* 4518 */
  IC_EVEX_XD_KZ, /* 4519 */
  IC_EVEX_W_KZ, /* 4520 */
  IC_EVEX_W_KZ, /* 4521 */
  IC_EVEX_W_XS_KZ, /* 4522 */
  IC_EVEX_W_XS_KZ, /* 4523 */
  IC_EVEX_W_XD_KZ, /* 4524 */
  IC_EVEX_W_XD_KZ, /* 4525 */
  IC_EVEX_W_XD_KZ, /* 4526 */
  IC_EVEX_W_XD_KZ, /* 4527 */
  IC_EVEX_OPSIZE_KZ, /* 4528 */
  IC_EVEX_OPSIZE_KZ, /* 4529 */
  IC_EVEX_OPSIZE_KZ, /* 4530 */
  IC_EVEX_OPSIZE_KZ, /* 4531 */
  IC_EVEX_OPSIZE_KZ, /* 4532 */
  IC_EVEX_OPSIZE_KZ, /* 4533 */
  IC_EVEX_OPSIZE_KZ, /* 4534 */
  IC_EVEX_OPSIZE_KZ, /* 4535 */
  IC_EVEX_W_OPSIZE_KZ, /* 4536 */
  IC_EVEX_W_OPSIZE_KZ, /* 4537 */
  IC_EVEX_W_OPSIZE_KZ, /* 4538 */
  IC_EVEX_W_OPSIZE_KZ, /* 4539 */
  IC_EVEX_W_OPSIZE_KZ, /* 4540 */
  IC_EVEX_W_OPSIZE_KZ, /* 4541 */
  IC_EVEX_W_OPSIZE_KZ, /* 4542 */
  IC_EVEX_W_OPSIZE_KZ, /* 4543 */
  IC_EVEX_KZ, /* 4544 */
  IC_EVEX_KZ, /* 4545 */
  IC_EVEX_XS_KZ, /* 4546 */
  IC_EVEX_XS_KZ, /* 4547 */
  IC_EVEX_XD_KZ, /* 4548 */
  IC_EVEX_XD_KZ, /* 4549 */
  IC_EVEX_XD_KZ, /* 4550 */
  IC_EVEX_XD_KZ, /* 4551 */
  IC_EVEX_W_KZ, /* 4552 */
  IC_EVEX_W_KZ, /* 4553 */
  IC_EVEX_W_XS_KZ, /* 4554 */
  IC_EVEX_W_XS_KZ, /* 4555 */
  IC_EVEX_W_XD_KZ, /* 4556 */
  IC_EVEX_W_XD_KZ, /* 4557 */
  IC_EVEX_W_XD_KZ, /* 4558 */
  IC_EVEX_W_XD_KZ, /* 4559 */
  IC_EVEX_OPSIZE_KZ, /* 4560 */
  IC_EVEX_OPSIZE_KZ, /* 4561 */
  IC_EVEX_OPSIZE_KZ, /* 4562 */
  IC_EVEX_OPSIZE_KZ, /* 4563 */
  IC_EVEX_OPSIZE_KZ, /* 4564 */
  IC_EVEX_OPSIZE_KZ, /* 4565 */
  IC_EVEX_OPSIZE_KZ, /* 4566 */
  IC_EVEX_OPSIZE_KZ, /* 4567 */
  IC_EVEX_W_OPSIZE_KZ, /* 4568 */
  IC_EVEX_W_OPSIZE_KZ, /* 4569 */
  IC_EVEX_W_OPSIZE_KZ, /* 4570 */
  IC_EVEX_W_OPSIZE_KZ, /* 4571 */
  IC_EVEX_W_OPSIZE_KZ, /* 4572 */
  IC_EVEX_W_OPSIZE_KZ, /* 4573 */
  IC_EVEX_W_OPSIZE_KZ, /* 4574 */
  IC_EVEX_W_OPSIZE_KZ, /* 4575 */
  IC_EVEX_KZ, /* 4576 */
  IC_EVEX_KZ, /* 4577 */
  IC_EVEX_XS_KZ, /* 4578 */
  IC_EVEX_XS_KZ, /* 4579 */
  IC_EVEX_XD_KZ, /* 4580 */
  IC_EVEX_XD_KZ, /* 4581 */
  IC_EVEX_XD_KZ, /* 4582 */
  IC_EVEX_XD_KZ, /* 4583 */
  IC_EVEX_W_KZ, /* 4584 */
  IC_EVEX_W_KZ, /* 4585 */
  IC_EVEX_W_XS_KZ, /* 4586 */
  IC_EVEX_W_XS_KZ, /* 4587 */
  IC_EVEX_W_XD_KZ, /* 4588 */
  IC_EVEX_W_XD_KZ, /* 4589 */
  IC_EVEX_W_XD_KZ, /* 4590 */
  IC_EVEX_W_XD_KZ, /* 4591 */
  IC_EVEX_OPSIZE_KZ, /* 4592 */
  IC_EVEX_OPSIZE_KZ, /* 4593 */
  IC_EVEX_OPSIZE_KZ, /* 4594 */
  IC_EVEX_OPSIZE_KZ, /* 4595 */
  IC_EVEX_OPSIZE_KZ, /* 4596 */
  IC_EVEX_OPSIZE_KZ, /* 4597 */
  IC_EVEX_OPSIZE_KZ, /* 4598 */
  IC_EVEX_OPSIZE_KZ, /* 4599 */
  IC_EVEX_W_OPSIZE_KZ, /* 4600 */
  IC_EVEX_W_OPSIZE_KZ, /* 4601 */
  IC_EVEX_W_OPSIZE_KZ, /* 4602 */
  IC_EVEX_W_OPSIZE_KZ, /* 4603 */
  IC_EVEX_W_OPSIZE_KZ, /* 4604 */
  IC_EVEX_W_OPSIZE_KZ, /* 4605 */
  IC_EVEX_W_OPSIZE_KZ, /* 4606 */
  IC_EVEX_W_OPSIZE_KZ, /* 4607 */
  IC, /* 4608 */
  IC_64BIT, /* 4609 */
  IC_XS, /* 4610 */
  IC_64BIT_XS, /* 4611 */
  IC_XD, /* 4612 */
  IC_64BIT_XD, /* 4613 */
  IC_XS, /* 4614 */
  IC_64BIT_XS, /* 4615 */
  IC, /* 4616 */
  IC_64BIT_REXW, /* 4617 */
  IC_XS, /* 4618 */
  IC_64BIT_REXW_XS, /* 4619 */
  IC_XD, /* 4620 */
  IC_64BIT_REXW_XD, /* 4621 */
  IC_XS, /* 4622 */
  IC_64BIT_REXW_XS, /* 4623 */
  IC_OPSIZE, /* 4624 */
  IC_64BIT_OPSIZE, /* 4625 */
  IC_XS_OPSIZE, /* 4626 */
  IC_64BIT_XS_OPSIZE, /* 4627 */
  IC_XD_OPSIZE, /* 4628 */
  IC_64BIT_XD_OPSIZE, /* 4629 */
  IC_XS_OPSIZE, /* 4630 */
  IC_64BIT_XD_OPSIZE, /* 4631 */
  IC_OPSIZE, /* 4632 */
  IC_64BIT_REXW_OPSIZE, /* 4633 */
  IC_XS_OPSIZE, /* 4634 */
  IC_64BIT_REXW_XS, /* 4635 */
  IC_XD_OPSIZE, /* 4636 */
  IC_64BIT_REXW_XD, /* 4637 */
  IC_XS_OPSIZE, /* 4638 */
  IC_64BIT_REXW_XS, /* 4639 */
  IC_ADSIZE, /* 4640 */
  IC_64BIT_ADSIZE, /* 4641 */
  IC_XS, /* 4642 */
  IC_64BIT_XS, /* 4643 */
  IC_XD, /* 4644 */
  IC_64BIT_XD, /* 4645 */
  IC_XS, /* 4646 */
  IC_64BIT_XS, /* 4647 */
  IC_ADSIZE, /* 4648 */
  IC_64BIT_REXW_ADSIZE, /* 4649 */
  IC_XS, /* 4650 */
  IC_64BIT_REXW_XS, /* 4651 */
  IC_XD, /* 4652 */
  IC_64BIT_REXW_XD, /* 4653 */
  IC_XS, /* 4654 */
  IC_64BIT_REXW_XS, /* 4655 */
  IC_OPSIZE_ADSIZE, /* 4656 */
  IC_64BIT_OPSIZE_ADSIZE, /* 4657 */
  IC_XS_OPSIZE, /* 4658 */
  IC_64BIT_XS_OPSIZE, /* 4659 */
  IC_XD_OPSIZE, /* 4660 */
  IC_64BIT_XD_OPSIZE, /* 4661 */
  IC_XS_OPSIZE, /* 4662 */
  IC_64BIT_XD_OPSIZE, /* 4663 */
  IC_OPSIZE_ADSIZE, /* 4664 */
  IC_64BIT_REXW_OPSIZE, /* 4665 */
  IC_XS_OPSIZE, /* 4666 */
  IC_64BIT_REXW_XS, /* 4667 */
  IC_XD_OPSIZE, /* 4668 */
  IC_64BIT_REXW_XD, /* 4669 */
  IC_XS_OPSIZE, /* 4670 */
  IC_64BIT_REXW_XS, /* 4671 */
  IC_VEX, /* 4672 */
  IC_VEX, /* 4673 */
  IC_VEX_XS, /* 4674 */
  IC_VEX_XS, /* 4675 */
  IC_VEX_XD, /* 4676 */
  IC_VEX_XD, /* 4677 */
  IC_VEX_XD, /* 4678 */
  IC_VEX_XD, /* 4679 */
  IC_VEX_W, /* 4680 */
  IC_VEX_W, /* 4681 */
  IC_VEX_W_XS, /* 4682 */
  IC_VEX_W_XS, /* 4683 */
  IC_VEX_W_XD, /* 4684 */
  IC_VEX_W_XD, /* 4685 */
  IC_VEX_W_XD, /* 4686 */
  IC_VEX_W_XD, /* 4687 */
  IC_VEX_OPSIZE, /* 4688 */
  IC_VEX_OPSIZE, /* 4689 */
  IC_VEX_OPSIZE, /* 4690 */
  IC_VEX_OPSIZE, /* 4691 */
  IC_VEX_OPSIZE, /* 4692 */
  IC_VEX_OPSIZE, /* 4693 */
  IC_VEX_OPSIZE, /* 4694 */
  IC_VEX_OPSIZE, /* 4695 */
  IC_VEX_W_OPSIZE, /* 4696 */
  IC_VEX_W_OPSIZE, /* 4697 */
  IC_VEX_W_OPSIZE, /* 4698 */
  IC_VEX_W_OPSIZE, /* 4699 */
  IC_VEX_W_OPSIZE, /* 4700 */
  IC_VEX_W_OPSIZE, /* 4701 */
  IC_VEX_W_OPSIZE, /* 4702 */
  IC_VEX_W_OPSIZE, /* 4703 */
  IC_VEX, /* 4704 */
  IC_VEX, /* 4705 */
  IC_VEX_XS, /* 4706 */
  IC_VEX_XS, /* 4707 */
  IC_VEX_XD, /* 4708 */
  IC_VEX_XD, /* 4709 */
  IC_VEX_XD, /* 4710 */
  IC_VEX_XD, /* 4711 */
  IC_VEX_W, /* 4712 */
  IC_VEX_W, /* 4713 */
  IC_VEX_W_XS, /* 4714 */
  IC_VEX_W_XS, /* 4715 */
  IC_VEX_W_XD, /* 4716 */
  IC_VEX_W_XD, /* 4717 */
  IC_VEX_W_XD, /* 4718 */
  IC_VEX_W_XD, /* 4719 */
  IC_VEX_OPSIZE, /* 4720 */
  IC_VEX_OPSIZE, /* 4721 */
  IC_VEX_OPSIZE, /* 4722 */
  IC_VEX_OPSIZE, /* 4723 */
  IC_VEX_OPSIZE, /* 4724 */
  IC_VEX_OPSIZE, /* 4725 */
  IC_VEX_OPSIZE, /* 4726 */
  IC_VEX_OPSIZE, /* 4727 */
  IC_VEX_W_OPSIZE, /* 4728 */
  IC_VEX_W_OPSIZE, /* 4729 */
  IC_VEX_W_OPSIZE, /* 4730 */
  IC_VEX_W_OPSIZE, /* 4731 */
  IC_VEX_W_OPSIZE, /* 4732 */
  IC_VEX_W_OPSIZE, /* 4733 */
  IC_VEX_W_OPSIZE, /* 4734 */
  IC_VEX_W_OPSIZE, /* 4735 */
  IC_VEX_L, /* 4736 */
  IC_VEX_L, /* 4737 */
  IC_VEX_L_XS, /* 4738 */
  IC_VEX_L_XS, /* 4739 */
  IC_VEX_L_XD, /* 4740 */
  IC_VEX_L_XD, /* 4741 */
  IC_VEX_L_XD, /* 4742 */
  IC_VEX_L_XD, /* 4743 */
  IC_VEX_L_W, /* 4744 */
  IC_VEX_L_W, /* 4745 */
  IC_VEX_L_W_XS, /* 4746 */
  IC_VEX_L_W_XS, /* 4747 */
  IC_VEX_L_W_XD, /* 4748 */
  IC_VEX_L_W_XD, /* 4749 */
  IC_VEX_L_W_XD, /* 4750 */
  IC_VEX_L_W_XD, /* 4751 */
  IC_VEX_L_OPSIZE, /* 4752 */
  IC_VEX_L_OPSIZE, /* 4753 */
  IC_VEX_L_OPSIZE, /* 4754 */
  IC_VEX_L_OPSIZE, /* 4755 */
  IC_VEX_L_OPSIZE, /* 4756 */
  IC_VEX_L_OPSIZE, /* 4757 */
  IC_VEX_L_OPSIZE, /* 4758 */
  IC_VEX_L_OPSIZE, /* 4759 */
  IC_VEX_L_W_OPSIZE, /* 4760 */
  IC_VEX_L_W_OPSIZE, /* 4761 */
  IC_VEX_L_W_OPSIZE, /* 4762 */
  IC_VEX_L_W_OPSIZE, /* 4763 */
  IC_VEX_L_W_OPSIZE, /* 4764 */
  IC_VEX_L_W_OPSIZE, /* 4765 */
  IC_VEX_L_W_OPSIZE, /* 4766 */
  IC_VEX_L_W_OPSIZE, /* 4767 */
  IC_VEX_L, /* 4768 */
  IC_VEX_L, /* 4769 */
  IC_VEX_L_XS, /* 4770 */
  IC_VEX_L_XS, /* 4771 */
  IC_VEX_L_XD, /* 4772 */
  IC_VEX_L_XD, /* 4773 */
  IC_VEX_L_XD, /* 4774 */
  IC_VEX_L_XD, /* 4775 */
  IC_VEX_L_W, /* 4776 */
  IC_VEX_L_W, /* 4777 */
  IC_VEX_L_W_XS, /* 4778 */
  IC_VEX_L_W_XS, /* 4779 */
  IC_VEX_L_W_XD, /* 4780 */
  IC_VEX_L_W_XD, /* 4781 */
  IC_VEX_L_W_XD, /* 4782 */
  IC_VEX_L_W_XD, /* 4783 */
  IC_VEX_L_OPSIZE, /* 4784 */
  IC_VEX_L_OPSIZE, /* 4785 */
  IC_VEX_L_OPSIZE, /* 4786 */
  IC_VEX_L_OPSIZE, /* 4787 */
  IC_VEX_L_OPSIZE, /* 4788 */
  IC_VEX_L_OPSIZE, /* 4789 */
  IC_VEX_L_OPSIZE, /* 4790 */
  IC_VEX_L_OPSIZE, /* 4791 */
  IC_VEX_L_W_OPSIZE, /* 4792 */
  IC_VEX_L_W_OPSIZE, /* 4793 */
  IC_VEX_L_W_OPSIZE, /* 4794 */
  IC_VEX_L_W_OPSIZE, /* 4795 */
  IC_VEX_L_W_OPSIZE, /* 4796 */
  IC_VEX_L_W_OPSIZE, /* 4797 */
  IC_VEX_L_W_OPSIZE, /* 4798 */
  IC_VEX_L_W_OPSIZE, /* 4799 */
  IC_VEX_L, /* 4800 */
  IC_VEX_L, /* 4801 */
  IC_VEX_L_XS, /* 4802 */
  IC_VEX_L_XS, /* 4803 */
  IC_VEX_L_XD, /* 4804 */
  IC_VEX_L_XD, /* 4805 */
  IC_VEX_L_XD, /* 4806 */
  IC_VEX_L_XD, /* 4807 */
  IC_VEX_L_W, /* 4808 */
  IC_VEX_L_W, /* 4809 */
  IC_VEX_L_W_XS, /* 4810 */
  IC_VEX_L_W_XS, /* 4811 */
  IC_VEX_L_W_XD, /* 4812 */
  IC_VEX_L_W_XD, /* 4813 */
  IC_VEX_L_W_XD, /* 4814 */
  IC_VEX_L_W_XD, /* 4815 */
  IC_VEX_L_OPSIZE, /* 4816 */
  IC_VEX_L_OPSIZE, /* 4817 */
  IC_VEX_L_OPSIZE, /* 4818 */
  IC_VEX_L_OPSIZE, /* 4819 */
  IC_VEX_L_OPSIZE, /* 4820 */
  IC_VEX_L_OPSIZE, /* 4821 */
  IC_VEX_L_OPSIZE, /* 4822 */
  IC_VEX_L_OPSIZE, /* 4823 */
  IC_VEX_L_W_OPSIZE, /* 4824 */
  IC_VEX_L_W_OPSIZE, /* 4825 */
  IC_VEX_L_W_OPSIZE, /* 4826 */
  IC_VEX_L_W_OPSIZE, /* 4827 */
  IC_VEX_L_W_OPSIZE, /* 4828 */
  IC_VEX_L_W_OPSIZE, /* 4829 */
  IC_VEX_L_W_OPSIZE, /* 4830 */
  IC_VEX_L_W_OPSIZE, /* 4831 */
  IC_VEX_L, /* 4832 */
  IC_VEX_L, /* 4833 */
  IC_VEX_L_XS, /* 4834 */
  IC_VEX_L_XS, /* 4835 */
  IC_VEX_L_XD, /* 4836 */
  IC_VEX_L_XD, /* 4837 */
  IC_VEX_L_XD, /* 4838 */
  IC_VEX_L_XD, /* 4839 */
  IC_VEX_L_W, /* 4840 */
  IC_VEX_L_W, /* 4841 */
  IC_VEX_L_W_XS, /* 4842 */
  IC_VEX_L_W_XS, /* 4843 */
  IC_VEX_L_W_XD, /* 4844 */
  IC_VEX_L_W_XD, /* 4845 */
  IC_VEX_L_W_XD, /* 4846 */
  IC_VEX_L_W_XD, /* 4847 */
  IC_VEX_L_OPSIZE, /* 4848 */
  IC_VEX_L_OPSIZE, /* 4849 */
  IC_VEX_L_OPSIZE, /* 4850 */
  IC_VEX_L_OPSIZE, /* 4851 */
  IC_VEX_L_OPSIZE, /* 4852 */
  IC_VEX_L_OPSIZE, /* 4853 */
  IC_VEX_L_OPSIZE, /* 4854 */
  IC_VEX_L_OPSIZE, /* 4855 */
  IC_VEX_L_W_OPSIZE, /* 4856 */
  IC_VEX_L_W_OPSIZE, /* 4857 */
  IC_VEX_L_W_OPSIZE, /* 4858 */
  IC_VEX_L_W_OPSIZE, /* 4859 */
  IC_VEX_L_W_OPSIZE, /* 4860 */
  IC_VEX_L_W_OPSIZE, /* 4861 */
  IC_VEX_L_W_OPSIZE, /* 4862 */
  IC_VEX_L_W_OPSIZE, /* 4863 */
  IC_EVEX_L_KZ, /* 4864 */
  IC_EVEX_L_KZ, /* 4865 */
  IC_EVEX_L_XS_KZ, /* 4866 */
  IC_EVEX_L_XS_KZ, /* 4867 */
  IC_EVEX_L_XD_KZ, /* 4868 */
  IC_EVEX_L_XD_KZ, /* 4869 */
  IC_EVEX_L_XD_KZ, /* 4870 */
  IC_EVEX_L_XD_KZ, /* 4871 */
  IC_EVEX_L_W_KZ, /* 4872 */
  IC_EVEX_L_W_KZ, /* 4873 */
  IC_EVEX_L_W_XS_KZ, /* 4874 */
  IC_EVEX_L_W_XS_KZ, /* 4875 */
  IC_EVEX_L_W_XD_KZ, /* 4876 */
  IC_EVEX_L_W_XD_KZ, /* 4877 */
  IC_EVEX_L_W_XD_KZ, /* 4878 */
  IC_EVEX_L_W_XD_KZ, /* 4879 */
  IC_EVEX_L_OPSIZE_KZ, /* 4880 */
  IC_EVEX_L_OPSIZE_KZ, /* 4881 */
  IC_EVEX_L_OPSIZE_KZ, /* 4882 */
  IC_EVEX_L_OPSIZE_KZ, /* 4883 */
  IC_EVEX_L_OPSIZE_KZ, /* 4884 */
  IC_EVEX_L_OPSIZE_KZ, /* 4885 */
  IC_EVEX_L_OPSIZE_KZ, /* 4886 */
  IC_EVEX_L_OPSIZE_KZ, /* 4887 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4888 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4889 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4890 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4891 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4892 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4893 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4894 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4895 */
  IC_EVEX_L_KZ, /* 4896 */
  IC_EVEX_L_KZ, /* 4897 */
  IC_EVEX_L_XS_KZ, /* 4898 */
  IC_EVEX_L_XS_KZ, /* 4899 */
  IC_EVEX_L_XD_KZ, /* 4900 */
  IC_EVEX_L_XD_KZ, /* 4901 */
  IC_EVEX_L_XD_KZ, /* 4902 */
  IC_EVEX_L_XD_KZ, /* 4903 */
  IC_EVEX_L_W_KZ, /* 4904 */
  IC_EVEX_L_W_KZ, /* 4905 */
  IC_EVEX_L_W_XS_KZ, /* 4906 */
  IC_EVEX_L_W_XS_KZ, /* 4907 */
  IC_EVEX_L_W_XD_KZ, /* 4908 */
  IC_EVEX_L_W_XD_KZ, /* 4909 */
  IC_EVEX_L_W_XD_KZ, /* 4910 */
  IC_EVEX_L_W_XD_KZ, /* 4911 */
  IC_EVEX_L_OPSIZE_KZ, /* 4912 */
  IC_EVEX_L_OPSIZE_KZ, /* 4913 */
  IC_EVEX_L_OPSIZE_KZ, /* 4914 */
  IC_EVEX_L_OPSIZE_KZ, /* 4915 */
  IC_EVEX_L_OPSIZE_KZ, /* 4916 */
  IC_EVEX_L_OPSIZE_KZ, /* 4917 */
  IC_EVEX_L_OPSIZE_KZ, /* 4918 */
  IC_EVEX_L_OPSIZE_KZ, /* 4919 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4920 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4921 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4922 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4923 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4924 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4925 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4926 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4927 */
  IC_EVEX_L_KZ, /* 4928 */
  IC_EVEX_L_KZ, /* 4929 */
  IC_EVEX_L_XS_KZ, /* 4930 */
  IC_EVEX_L_XS_KZ, /* 4931 */
  IC_EVEX_L_XD_KZ, /* 4932 */
  IC_EVEX_L_XD_KZ, /* 4933 */
  IC_EVEX_L_XD_KZ, /* 4934 */
  IC_EVEX_L_XD_KZ, /* 4935 */
  IC_EVEX_L_W_KZ, /* 4936 */
  IC_EVEX_L_W_KZ, /* 4937 */
  IC_EVEX_L_W_XS_KZ, /* 4938 */
  IC_EVEX_L_W_XS_KZ, /* 4939 */
  IC_EVEX_L_W_XD_KZ, /* 4940 */
  IC_EVEX_L_W_XD_KZ, /* 4941 */
  IC_EVEX_L_W_XD_KZ, /* 4942 */
  IC_EVEX_L_W_XD_KZ, /* 4943 */
  IC_EVEX_L_OPSIZE_KZ, /* 4944 */
  IC_EVEX_L_OPSIZE_KZ, /* 4945 */
  IC_EVEX_L_OPSIZE_KZ, /* 4946 */
  IC_EVEX_L_OPSIZE_KZ, /* 4947 */
  IC_EVEX_L_OPSIZE_KZ, /* 4948 */
  IC_EVEX_L_OPSIZE_KZ, /* 4949 */
  IC_EVEX_L_OPSIZE_KZ, /* 4950 */
  IC_EVEX_L_OPSIZE_KZ, /* 4951 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4952 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4953 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4954 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4955 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4956 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4957 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4958 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4959 */
  IC_EVEX_L_KZ, /* 4960 */
  IC_EVEX_L_KZ, /* 4961 */
  IC_EVEX_L_XS_KZ, /* 4962 */
  IC_EVEX_L_XS_KZ, /* 4963 */
  IC_EVEX_L_XD_KZ, /* 4964 */
  IC_EVEX_L_XD_KZ, /* 4965 */
  IC_EVEX_L_XD_KZ, /* 4966 */
  IC_EVEX_L_XD_KZ, /* 4967 */
  IC_EVEX_L_W_KZ, /* 4968 */
  IC_EVEX_L_W_KZ, /* 4969 */
  IC_EVEX_L_W_XS_KZ, /* 4970 */
  IC_EVEX_L_W_XS_KZ, /* 4971 */
  IC_EVEX_L_W_XD_KZ, /* 4972 */
  IC_EVEX_L_W_XD_KZ, /* 4973 */
  IC_EVEX_L_W_XD_KZ, /* 4974 */
  IC_EVEX_L_W_XD_KZ, /* 4975 */
  IC_EVEX_L_OPSIZE_KZ, /* 4976 */
  IC_EVEX_L_OPSIZE_KZ, /* 4977 */
  IC_EVEX_L_OPSIZE_KZ, /* 4978 */
  IC_EVEX_L_OPSIZE_KZ, /* 4979 */
  IC_EVEX_L_OPSIZE_KZ, /* 4980 */
  IC_EVEX_L_OPSIZE_KZ, /* 4981 */
  IC_EVEX_L_OPSIZE_KZ, /* 4982 */
  IC_EVEX_L_OPSIZE_KZ, /* 4983 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4984 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4985 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4986 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4987 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4988 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4989 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4990 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 4991 */
  IC_EVEX_L_KZ, /* 4992 */
  IC_EVEX_L_KZ, /* 4993 */
  IC_EVEX_L_XS_KZ, /* 4994 */
  IC_EVEX_L_XS_KZ, /* 4995 */
  IC_EVEX_L_XD_KZ, /* 4996 */
  IC_EVEX_L_XD_KZ, /* 4997 */
  IC_EVEX_L_XD_KZ, /* 4998 */
  IC_EVEX_L_XD_KZ, /* 4999 */
  IC_EVEX_L_W_KZ, /* 5000 */
  IC_EVEX_L_W_KZ, /* 5001 */
  IC_EVEX_L_W_XS_KZ, /* 5002 */
  IC_EVEX_L_W_XS_KZ, /* 5003 */
  IC_EVEX_L_W_XD_KZ, /* 5004 */
  IC_EVEX_L_W_XD_KZ, /* 5005 */
  IC_EVEX_L_W_XD_KZ, /* 5006 */
  IC_EVEX_L_W_XD_KZ, /* 5007 */
  IC_EVEX_L_OPSIZE_KZ, /* 5008 */
  IC_EVEX_L_OPSIZE_KZ, /* 5009 */
  IC_EVEX_L_OPSIZE_KZ, /* 5010 */
  IC_EVEX_L_OPSIZE_KZ, /* 5011 */
  IC_EVEX_L_OPSIZE_KZ, /* 5012 */
  IC_EVEX_L_OPSIZE_KZ, /* 5013 */
  IC_EVEX_L_OPSIZE_KZ, /* 5014 */
  IC_EVEX_L_OPSIZE_KZ, /* 5015 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5016 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5017 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5018 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5019 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5020 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5021 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5022 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5023 */
  IC_EVEX_L_KZ, /* 5024 */
  IC_EVEX_L_KZ, /* 5025 */
  IC_EVEX_L_XS_KZ, /* 5026 */
  IC_EVEX_L_XS_KZ, /* 5027 */
  IC_EVEX_L_XD_KZ, /* 5028 */
  IC_EVEX_L_XD_KZ, /* 5029 */
  IC_EVEX_L_XD_KZ, /* 5030 */
  IC_EVEX_L_XD_KZ, /* 5031 */
  IC_EVEX_L_W_KZ, /* 5032 */
  IC_EVEX_L_W_KZ, /* 5033 */
  IC_EVEX_L_W_XS_KZ, /* 5034 */
  IC_EVEX_L_W_XS_KZ, /* 5035 */
  IC_EVEX_L_W_XD_KZ, /* 5036 */
  IC_EVEX_L_W_XD_KZ, /* 5037 */
  IC_EVEX_L_W_XD_KZ, /* 5038 */
  IC_EVEX_L_W_XD_KZ, /* 5039 */
  IC_EVEX_L_OPSIZE_KZ, /* 5040 */
  IC_EVEX_L_OPSIZE_KZ, /* 5041 */
  IC_EVEX_L_OPSIZE_KZ, /* 5042 */
  IC_EVEX_L_OPSIZE_KZ, /* 5043 */
  IC_EVEX_L_OPSIZE_KZ, /* 5044 */
  IC_EVEX_L_OPSIZE_KZ, /* 5045 */
  IC_EVEX_L_OPSIZE_KZ, /* 5046 */
  IC_EVEX_L_OPSIZE_KZ, /* 5047 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5048 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5049 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5050 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5051 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5052 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5053 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5054 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5055 */
  IC_EVEX_L_KZ, /* 5056 */
  IC_EVEX_L_KZ, /* 5057 */
  IC_EVEX_L_XS_KZ, /* 5058 */
  IC_EVEX_L_XS_KZ, /* 5059 */
  IC_EVEX_L_XD_KZ, /* 5060 */
  IC_EVEX_L_XD_KZ, /* 5061 */
  IC_EVEX_L_XD_KZ, /* 5062 */
  IC_EVEX_L_XD_KZ, /* 5063 */
  IC_EVEX_L_W_KZ, /* 5064 */
  IC_EVEX_L_W_KZ, /* 5065 */
  IC_EVEX_L_W_XS_KZ, /* 5066 */
  IC_EVEX_L_W_XS_KZ, /* 5067 */
  IC_EVEX_L_W_XD_KZ, /* 5068 */
  IC_EVEX_L_W_XD_KZ, /* 5069 */
  IC_EVEX_L_W_XD_KZ, /* 5070 */
  IC_EVEX_L_W_XD_KZ, /* 5071 */
  IC_EVEX_L_OPSIZE_KZ, /* 5072 */
  IC_EVEX_L_OPSIZE_KZ, /* 5073 */
  IC_EVEX_L_OPSIZE_KZ, /* 5074 */
  IC_EVEX_L_OPSIZE_KZ, /* 5075 */
  IC_EVEX_L_OPSIZE_KZ, /* 5076 */
  IC_EVEX_L_OPSIZE_KZ, /* 5077 */
  IC_EVEX_L_OPSIZE_KZ, /* 5078 */
  IC_EVEX_L_OPSIZE_KZ, /* 5079 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5080 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5081 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5082 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5083 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5084 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5085 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5086 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5087 */
  IC_EVEX_L_KZ, /* 5088 */
  IC_EVEX_L_KZ, /* 5089 */
  IC_EVEX_L_XS_KZ, /* 5090 */
  IC_EVEX_L_XS_KZ, /* 5091 */
  IC_EVEX_L_XD_KZ, /* 5092 */
  IC_EVEX_L_XD_KZ, /* 5093 */
  IC_EVEX_L_XD_KZ, /* 5094 */
  IC_EVEX_L_XD_KZ, /* 5095 */
  IC_EVEX_L_W_KZ, /* 5096 */
  IC_EVEX_L_W_KZ, /* 5097 */
  IC_EVEX_L_W_XS_KZ, /* 5098 */
  IC_EVEX_L_W_XS_KZ, /* 5099 */
  IC_EVEX_L_W_XD_KZ, /* 5100 */
  IC_EVEX_L_W_XD_KZ, /* 5101 */
  IC_EVEX_L_W_XD_KZ, /* 5102 */
  IC_EVEX_L_W_XD_KZ, /* 5103 */
  IC_EVEX_L_OPSIZE_KZ, /* 5104 */
  IC_EVEX_L_OPSIZE_KZ, /* 5105 */
  IC_EVEX_L_OPSIZE_KZ, /* 5106 */
  IC_EVEX_L_OPSIZE_KZ, /* 5107 */
  IC_EVEX_L_OPSIZE_KZ, /* 5108 */
  IC_EVEX_L_OPSIZE_KZ, /* 5109 */
  IC_EVEX_L_OPSIZE_KZ, /* 5110 */
  IC_EVEX_L_OPSIZE_KZ, /* 5111 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5112 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5113 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5114 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5115 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5116 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5117 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5118 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 5119 */
  IC, /* 5120 */
  IC_64BIT, /* 5121 */
  IC_XS, /* 5122 */
  IC_64BIT_XS, /* 5123 */
  IC_XD, /* 5124 */
  IC_64BIT_XD, /* 5125 */
  IC_XS, /* 5126 */
  IC_64BIT_XS, /* 5127 */
  IC, /* 5128 */
  IC_64BIT_REXW, /* 5129 */
  IC_XS, /* 5130 */
  IC_64BIT_REXW_XS, /* 5131 */
  IC_XD, /* 5132 */
  IC_64BIT_REXW_XD, /* 5133 */
  IC_XS, /* 5134 */
  IC_64BIT_REXW_XS, /* 5135 */
  IC_OPSIZE, /* 5136 */
  IC_64BIT_OPSIZE, /* 5137 */
  IC_XS_OPSIZE, /* 5138 */
  IC_64BIT_XS_OPSIZE, /* 5139 */
  IC_XD_OPSIZE, /* 5140 */
  IC_64BIT_XD_OPSIZE, /* 5141 */
  IC_XS_OPSIZE, /* 5142 */
  IC_64BIT_XD_OPSIZE, /* 5143 */
  IC_OPSIZE, /* 5144 */
  IC_64BIT_REXW_OPSIZE, /* 5145 */
  IC_XS_OPSIZE, /* 5146 */
  IC_64BIT_REXW_XS, /* 5147 */
  IC_XD_OPSIZE, /* 5148 */
  IC_64BIT_REXW_XD, /* 5149 */
  IC_XS_OPSIZE, /* 5150 */
  IC_64BIT_REXW_XS, /* 5151 */
  IC_ADSIZE, /* 5152 */
  IC_64BIT_ADSIZE, /* 5153 */
  IC_XS, /* 5154 */
  IC_64BIT_XS, /* 5155 */
  IC_XD, /* 5156 */
  IC_64BIT_XD, /* 5157 */
  IC_XS, /* 5158 */
  IC_64BIT_XS, /* 5159 */
  IC_ADSIZE, /* 5160 */
  IC_64BIT_REXW_ADSIZE, /* 5161 */
  IC_XS, /* 5162 */
  IC_64BIT_REXW_XS, /* 5163 */
  IC_XD, /* 5164 */
  IC_64BIT_REXW_XD, /* 5165 */
  IC_XS, /* 5166 */
  IC_64BIT_REXW_XS, /* 5167 */
  IC_OPSIZE_ADSIZE, /* 5168 */
  IC_64BIT_OPSIZE_ADSIZE, /* 5169 */
  IC_XS_OPSIZE, /* 5170 */
  IC_64BIT_XS_OPSIZE, /* 5171 */
  IC_XD_OPSIZE, /* 5172 */
  IC_64BIT_XD_OPSIZE, /* 5173 */
  IC_XS_OPSIZE, /* 5174 */
  IC_64BIT_XD_OPSIZE, /* 5175 */
  IC_OPSIZE_ADSIZE, /* 5176 */
  IC_64BIT_REXW_OPSIZE, /* 5177 */
  IC_XS_OPSIZE, /* 5178 */
  IC_64BIT_REXW_XS, /* 5179 */
  IC_XD_OPSIZE, /* 5180 */
  IC_64BIT_REXW_XD, /* 5181 */
  IC_XS_OPSIZE, /* 5182 */
  IC_64BIT_REXW_XS, /* 5183 */
  IC_VEX, /* 5184 */
  IC_VEX, /* 5185 */
  IC_VEX_XS, /* 5186 */
  IC_VEX_XS, /* 5187 */
  IC_VEX_XD, /* 5188 */
  IC_VEX_XD, /* 5189 */
  IC_VEX_XD, /* 5190 */
  IC_VEX_XD, /* 5191 */
  IC_VEX_W, /* 5192 */
  IC_VEX_W, /* 5193 */
  IC_VEX_W_XS, /* 5194 */
  IC_VEX_W_XS, /* 5195 */
  IC_VEX_W_XD, /* 5196 */
  IC_VEX_W_XD, /* 5197 */
  IC_VEX_W_XD, /* 5198 */
  IC_VEX_W_XD, /* 5199 */
  IC_VEX_OPSIZE, /* 5200 */
  IC_VEX_OPSIZE, /* 5201 */
  IC_VEX_OPSIZE, /* 5202 */
  IC_VEX_OPSIZE, /* 5203 */
  IC_VEX_OPSIZE, /* 5204 */
  IC_VEX_OPSIZE, /* 5205 */
  IC_VEX_OPSIZE, /* 5206 */
  IC_VEX_OPSIZE, /* 5207 */
  IC_VEX_W_OPSIZE, /* 5208 */
  IC_VEX_W_OPSIZE, /* 5209 */
  IC_VEX_W_OPSIZE, /* 5210 */
  IC_VEX_W_OPSIZE, /* 5211 */
  IC_VEX_W_OPSIZE, /* 5212 */
  IC_VEX_W_OPSIZE, /* 5213 */
  IC_VEX_W_OPSIZE, /* 5214 */
  IC_VEX_W_OPSIZE, /* 5215 */
  IC_VEX, /* 5216 */
  IC_VEX, /* 5217 */
  IC_VEX_XS, /* 5218 */
  IC_VEX_XS, /* 5219 */
  IC_VEX_XD, /* 5220 */
  IC_VEX_XD, /* 5221 */
  IC_VEX_XD, /* 5222 */
  IC_VEX_XD, /* 5223 */
  IC_VEX_W, /* 5224 */
  IC_VEX_W, /* 5225 */
  IC_VEX_W_XS, /* 5226 */
  IC_VEX_W_XS, /* 5227 */
  IC_VEX_W_XD, /* 5228 */
  IC_VEX_W_XD, /* 5229 */
  IC_VEX_W_XD, /* 5230 */
  IC_VEX_W_XD, /* 5231 */
  IC_VEX_OPSIZE, /* 5232 */
  IC_VEX_OPSIZE, /* 5233 */
  IC_VEX_OPSIZE, /* 5234 */
  IC_VEX_OPSIZE, /* 5235 */
  IC_VEX_OPSIZE, /* 5236 */
  IC_VEX_OPSIZE, /* 5237 */
  IC_VEX_OPSIZE, /* 5238 */
  IC_VEX_OPSIZE, /* 5239 */
  IC_VEX_W_OPSIZE, /* 5240 */
  IC_VEX_W_OPSIZE, /* 5241 */
  IC_VEX_W_OPSIZE, /* 5242 */
  IC_VEX_W_OPSIZE, /* 5243 */
  IC_VEX_W_OPSIZE, /* 5244 */
  IC_VEX_W_OPSIZE, /* 5245 */
  IC_VEX_W_OPSIZE, /* 5246 */
  IC_VEX_W_OPSIZE, /* 5247 */
  IC_VEX_L, /* 5248 */
  IC_VEX_L, /* 5249 */
  IC_VEX_L_XS, /* 5250 */
  IC_VEX_L_XS, /* 5251 */
  IC_VEX_L_XD, /* 5252 */
  IC_VEX_L_XD, /* 5253 */
  IC_VEX_L_XD, /* 5254 */
  IC_VEX_L_XD, /* 5255 */
  IC_VEX_L_W, /* 5256 */
  IC_VEX_L_W, /* 5257 */
  IC_VEX_L_W_XS, /* 5258 */
  IC_VEX_L_W_XS, /* 5259 */
  IC_VEX_L_W_XD, /* 5260 */
  IC_VEX_L_W_XD, /* 5261 */
  IC_VEX_L_W_XD, /* 5262 */
  IC_VEX_L_W_XD, /* 5263 */
  IC_VEX_L_OPSIZE, /* 5264 */
  IC_VEX_L_OPSIZE, /* 5265 */
  IC_VEX_L_OPSIZE, /* 5266 */
  IC_VEX_L_OPSIZE, /* 5267 */
  IC_VEX_L_OPSIZE, /* 5268 */
  IC_VEX_L_OPSIZE, /* 5269 */
  IC_VEX_L_OPSIZE, /* 5270 */
  IC_VEX_L_OPSIZE, /* 5271 */
  IC_VEX_L_W_OPSIZE, /* 5272 */
  IC_VEX_L_W_OPSIZE, /* 5273 */
  IC_VEX_L_W_OPSIZE, /* 5274 */
  IC_VEX_L_W_OPSIZE, /* 5275 */
  IC_VEX_L_W_OPSIZE, /* 5276 */
  IC_VEX_L_W_OPSIZE, /* 5277 */
  IC_VEX_L_W_OPSIZE, /* 5278 */
  IC_VEX_L_W_OPSIZE, /* 5279 */
  IC_VEX_L, /* 5280 */
  IC_VEX_L, /* 5281 */
  IC_VEX_L_XS, /* 5282 */
  IC_VEX_L_XS, /* 5283 */
  IC_VEX_L_XD, /* 5284 */
  IC_VEX_L_XD, /* 5285 */
  IC_VEX_L_XD, /* 5286 */
  IC_VEX_L_XD, /* 5287 */
  IC_VEX_L_W, /* 5288 */
  IC_VEX_L_W, /* 5289 */
  IC_VEX_L_W_XS, /* 5290 */
  IC_VEX_L_W_XS, /* 5291 */
  IC_VEX_L_W_XD, /* 5292 */
  IC_VEX_L_W_XD, /* 5293 */
  IC_VEX_L_W_XD, /* 5294 */
  IC_VEX_L_W_XD, /* 5295 */
  IC_VEX_L_OPSIZE, /* 5296 */
  IC_VEX_L_OPSIZE, /* 5297 */
  IC_VEX_L_OPSIZE, /* 5298 */
  IC_VEX_L_OPSIZE, /* 5299 */
  IC_VEX_L_OPSIZE, /* 5300 */
  IC_VEX_L_OPSIZE, /* 5301 */
  IC_VEX_L_OPSIZE, /* 5302 */
  IC_VEX_L_OPSIZE, /* 5303 */
  IC_VEX_L_W_OPSIZE, /* 5304 */
  IC_VEX_L_W_OPSIZE, /* 5305 */
  IC_VEX_L_W_OPSIZE, /* 5306 */
  IC_VEX_L_W_OPSIZE, /* 5307 */
  IC_VEX_L_W_OPSIZE, /* 5308 */
  IC_VEX_L_W_OPSIZE, /* 5309 */
  IC_VEX_L_W_OPSIZE, /* 5310 */
  IC_VEX_L_W_OPSIZE, /* 5311 */
  IC_VEX_L, /* 5312 */
  IC_VEX_L, /* 5313 */
  IC_VEX_L_XS, /* 5314 */
  IC_VEX_L_XS, /* 5315 */
  IC_VEX_L_XD, /* 5316 */
  IC_VEX_L_XD, /* 5317 */
  IC_VEX_L_XD, /* 5318 */
  IC_VEX_L_XD, /* 5319 */
  IC_VEX_L_W, /* 5320 */
  IC_VEX_L_W, /* 5321 */
  IC_VEX_L_W_XS, /* 5322 */
  IC_VEX_L_W_XS, /* 5323 */
  IC_VEX_L_W_XD, /* 5324 */
  IC_VEX_L_W_XD, /* 5325 */
  IC_VEX_L_W_XD, /* 5326 */
  IC_VEX_L_W_XD, /* 5327 */
  IC_VEX_L_OPSIZE, /* 5328 */
  IC_VEX_L_OPSIZE, /* 5329 */
  IC_VEX_L_OPSIZE, /* 5330 */
  IC_VEX_L_OPSIZE, /* 5331 */
  IC_VEX_L_OPSIZE, /* 5332 */
  IC_VEX_L_OPSIZE, /* 5333 */
  IC_VEX_L_OPSIZE, /* 5334 */
  IC_VEX_L_OPSIZE, /* 5335 */
  IC_VEX_L_W_OPSIZE, /* 5336 */
  IC_VEX_L_W_OPSIZE, /* 5337 */
  IC_VEX_L_W_OPSIZE, /* 5338 */
  IC_VEX_L_W_OPSIZE, /* 5339 */
  IC_VEX_L_W_OPSIZE, /* 5340 */
  IC_VEX_L_W_OPSIZE, /* 5341 */
  IC_VEX_L_W_OPSIZE, /* 5342 */
  IC_VEX_L_W_OPSIZE, /* 5343 */
  IC_VEX_L, /* 5344 */
  IC_VEX_L, /* 5345 */
  IC_VEX_L_XS, /* 5346 */
  IC_VEX_L_XS, /* 5347 */
  IC_VEX_L_XD, /* 5348 */
  IC_VEX_L_XD, /* 5349 */
  IC_VEX_L_XD, /* 5350 */
  IC_VEX_L_XD, /* 5351 */
  IC_VEX_L_W, /* 5352 */
  IC_VEX_L_W, /* 5353 */
  IC_VEX_L_W_XS, /* 5354 */
  IC_VEX_L_W_XS, /* 5355 */
  IC_VEX_L_W_XD, /* 5356 */
  IC_VEX_L_W_XD, /* 5357 */
  IC_VEX_L_W_XD, /* 5358 */
  IC_VEX_L_W_XD, /* 5359 */
  IC_VEX_L_OPSIZE, /* 5360 */
  IC_VEX_L_OPSIZE, /* 5361 */
  IC_VEX_L_OPSIZE, /* 5362 */
  IC_VEX_L_OPSIZE, /* 5363 */
  IC_VEX_L_OPSIZE, /* 5364 */
  IC_VEX_L_OPSIZE, /* 5365 */
  IC_VEX_L_OPSIZE, /* 5366 */
  IC_VEX_L_OPSIZE, /* 5367 */
  IC_VEX_L_W_OPSIZE, /* 5368 */
  IC_VEX_L_W_OPSIZE, /* 5369 */
  IC_VEX_L_W_OPSIZE, /* 5370 */
  IC_VEX_L_W_OPSIZE, /* 5371 */
  IC_VEX_L_W_OPSIZE, /* 5372 */
  IC_VEX_L_W_OPSIZE, /* 5373 */
  IC_VEX_L_W_OPSIZE, /* 5374 */
  IC_VEX_L_W_OPSIZE, /* 5375 */
  IC_EVEX_L2_KZ, /* 5376 */
  IC_EVEX_L2_KZ, /* 5377 */
  IC_EVEX_L2_XS_KZ, /* 5378 */
  IC_EVEX_L2_XS_KZ, /* 5379 */
  IC_EVEX_L2_XD_KZ, /* 5380 */
  IC_EVEX_L2_XD_KZ, /* 5381 */
  IC_EVEX_L2_XD_KZ, /* 5382 */
  IC_EVEX_L2_XD_KZ, /* 5383 */
  IC_EVEX_L2_W_KZ, /* 5384 */
  IC_EVEX_L2_W_KZ, /* 5385 */
  IC_EVEX_L2_W_XS_KZ, /* 5386 */
  IC_EVEX_L2_W_XS_KZ, /* 5387 */
  IC_EVEX_L2_W_XD_KZ, /* 5388 */
  IC_EVEX_L2_W_XD_KZ, /* 5389 */
  IC_EVEX_L2_W_XD_KZ, /* 5390 */
  IC_EVEX_L2_W_XD_KZ, /* 5391 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5392 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5393 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5394 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5395 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5396 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5397 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5398 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5399 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5400 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5401 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5402 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5403 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5404 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5405 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5406 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5407 */
  IC_EVEX_L2_KZ, /* 5408 */
  IC_EVEX_L2_KZ, /* 5409 */
  IC_EVEX_L2_XS_KZ, /* 5410 */
  IC_EVEX_L2_XS_KZ, /* 5411 */
  IC_EVEX_L2_XD_KZ, /* 5412 */
  IC_EVEX_L2_XD_KZ, /* 5413 */
  IC_EVEX_L2_XD_KZ, /* 5414 */
  IC_EVEX_L2_XD_KZ, /* 5415 */
  IC_EVEX_L2_W_KZ, /* 5416 */
  IC_EVEX_L2_W_KZ, /* 5417 */
  IC_EVEX_L2_W_XS_KZ, /* 5418 */
  IC_EVEX_L2_W_XS_KZ, /* 5419 */
  IC_EVEX_L2_W_XD_KZ, /* 5420 */
  IC_EVEX_L2_W_XD_KZ, /* 5421 */
  IC_EVEX_L2_W_XD_KZ, /* 5422 */
  IC_EVEX_L2_W_XD_KZ, /* 5423 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5424 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5425 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5426 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5427 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5428 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5429 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5430 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5431 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5432 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5433 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5434 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5435 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5436 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5437 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5438 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5439 */
  IC_EVEX_L2_KZ, /* 5440 */
  IC_EVEX_L2_KZ, /* 5441 */
  IC_EVEX_L2_XS_KZ, /* 5442 */
  IC_EVEX_L2_XS_KZ, /* 5443 */
  IC_EVEX_L2_XD_KZ, /* 5444 */
  IC_EVEX_L2_XD_KZ, /* 5445 */
  IC_EVEX_L2_XD_KZ, /* 5446 */
  IC_EVEX_L2_XD_KZ, /* 5447 */
  IC_EVEX_L2_W_KZ, /* 5448 */
  IC_EVEX_L2_W_KZ, /* 5449 */
  IC_EVEX_L2_W_XS_KZ, /* 5450 */
  IC_EVEX_L2_W_XS_KZ, /* 5451 */
  IC_EVEX_L2_W_XD_KZ, /* 5452 */
  IC_EVEX_L2_W_XD_KZ, /* 5453 */
  IC_EVEX_L2_W_XD_KZ, /* 5454 */
  IC_EVEX_L2_W_XD_KZ, /* 5455 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5456 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5457 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5458 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5459 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5460 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5461 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5462 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5463 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5464 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5465 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5466 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5467 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5468 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5469 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5470 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5471 */
  IC_EVEX_L2_KZ, /* 5472 */
  IC_EVEX_L2_KZ, /* 5473 */
  IC_EVEX_L2_XS_KZ, /* 5474 */
  IC_EVEX_L2_XS_KZ, /* 5475 */
  IC_EVEX_L2_XD_KZ, /* 5476 */
  IC_EVEX_L2_XD_KZ, /* 5477 */
  IC_EVEX_L2_XD_KZ, /* 5478 */
  IC_EVEX_L2_XD_KZ, /* 5479 */
  IC_EVEX_L2_W_KZ, /* 5480 */
  IC_EVEX_L2_W_KZ, /* 5481 */
  IC_EVEX_L2_W_XS_KZ, /* 5482 */
  IC_EVEX_L2_W_XS_KZ, /* 5483 */
  IC_EVEX_L2_W_XD_KZ, /* 5484 */
  IC_EVEX_L2_W_XD_KZ, /* 5485 */
  IC_EVEX_L2_W_XD_KZ, /* 5486 */
  IC_EVEX_L2_W_XD_KZ, /* 5487 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5488 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5489 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5490 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5491 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5492 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5493 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5494 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5495 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5496 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5497 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5498 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5499 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5500 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5501 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5502 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5503 */
  IC_EVEX_L2_KZ, /* 5504 */
  IC_EVEX_L2_KZ, /* 5505 */
  IC_EVEX_L2_XS_KZ, /* 5506 */
  IC_EVEX_L2_XS_KZ, /* 5507 */
  IC_EVEX_L2_XD_KZ, /* 5508 */
  IC_EVEX_L2_XD_KZ, /* 5509 */
  IC_EVEX_L2_XD_KZ, /* 5510 */
  IC_EVEX_L2_XD_KZ, /* 5511 */
  IC_EVEX_L2_W_KZ, /* 5512 */
  IC_EVEX_L2_W_KZ, /* 5513 */
  IC_EVEX_L2_W_XS_KZ, /* 5514 */
  IC_EVEX_L2_W_XS_KZ, /* 5515 */
  IC_EVEX_L2_W_XD_KZ, /* 5516 */
  IC_EVEX_L2_W_XD_KZ, /* 5517 */
  IC_EVEX_L2_W_XD_KZ, /* 5518 */
  IC_EVEX_L2_W_XD_KZ, /* 5519 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5520 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5521 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5522 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5523 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5524 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5525 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5526 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5527 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5528 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5529 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5530 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5531 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5532 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5533 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5534 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5535 */
  IC_EVEX_L2_KZ, /* 5536 */
  IC_EVEX_L2_KZ, /* 5537 */
  IC_EVEX_L2_XS_KZ, /* 5538 */
  IC_EVEX_L2_XS_KZ, /* 5539 */
  IC_EVEX_L2_XD_KZ, /* 5540 */
  IC_EVEX_L2_XD_KZ, /* 5541 */
  IC_EVEX_L2_XD_KZ, /* 5542 */
  IC_EVEX_L2_XD_KZ, /* 5543 */
  IC_EVEX_L2_W_KZ, /* 5544 */
  IC_EVEX_L2_W_KZ, /* 5545 */
  IC_EVEX_L2_W_XS_KZ, /* 5546 */
  IC_EVEX_L2_W_XS_KZ, /* 5547 */
  IC_EVEX_L2_W_XD_KZ, /* 5548 */
  IC_EVEX_L2_W_XD_KZ, /* 5549 */
  IC_EVEX_L2_W_XD_KZ, /* 5550 */
  IC_EVEX_L2_W_XD_KZ, /* 5551 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5552 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5553 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5554 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5555 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5556 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5557 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5558 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5559 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5560 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5561 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5562 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5563 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5564 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5565 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5566 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5567 */
  IC_EVEX_L2_KZ, /* 5568 */
  IC_EVEX_L2_KZ, /* 5569 */
  IC_EVEX_L2_XS_KZ, /* 5570 */
  IC_EVEX_L2_XS_KZ, /* 5571 */
  IC_EVEX_L2_XD_KZ, /* 5572 */
  IC_EVEX_L2_XD_KZ, /* 5573 */
  IC_EVEX_L2_XD_KZ, /* 5574 */
  IC_EVEX_L2_XD_KZ, /* 5575 */
  IC_EVEX_L2_W_KZ, /* 5576 */
  IC_EVEX_L2_W_KZ, /* 5577 */
  IC_EVEX_L2_W_XS_KZ, /* 5578 */
  IC_EVEX_L2_W_XS_KZ, /* 5579 */
  IC_EVEX_L2_W_XD_KZ, /* 5580 */
  IC_EVEX_L2_W_XD_KZ, /* 5581 */
  IC_EVEX_L2_W_XD_KZ, /* 5582 */
  IC_EVEX_L2_W_XD_KZ, /* 5583 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5584 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5585 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5586 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5587 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5588 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5589 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5590 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5591 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5592 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5593 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5594 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5595 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5596 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5597 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5598 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5599 */
  IC_EVEX_L2_KZ, /* 5600 */
  IC_EVEX_L2_KZ, /* 5601 */
  IC_EVEX_L2_XS_KZ, /* 5602 */
  IC_EVEX_L2_XS_KZ, /* 5603 */
  IC_EVEX_L2_XD_KZ, /* 5604 */
  IC_EVEX_L2_XD_KZ, /* 5605 */
  IC_EVEX_L2_XD_KZ, /* 5606 */
  IC_EVEX_L2_XD_KZ, /* 5607 */
  IC_EVEX_L2_W_KZ, /* 5608 */
  IC_EVEX_L2_W_KZ, /* 5609 */
  IC_EVEX_L2_W_XS_KZ, /* 5610 */
  IC_EVEX_L2_W_XS_KZ, /* 5611 */
  IC_EVEX_L2_W_XD_KZ, /* 5612 */
  IC_EVEX_L2_W_XD_KZ, /* 5613 */
  IC_EVEX_L2_W_XD_KZ, /* 5614 */
  IC_EVEX_L2_W_XD_KZ, /* 5615 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5616 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5617 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5618 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5619 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5620 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5621 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5622 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5623 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5624 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5625 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5626 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5627 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5628 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5629 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5630 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5631 */
  IC, /* 5632 */
  IC_64BIT, /* 5633 */
  IC_XS, /* 5634 */
  IC_64BIT_XS, /* 5635 */
  IC_XD, /* 5636 */
  IC_64BIT_XD, /* 5637 */
  IC_XS, /* 5638 */
  IC_64BIT_XS, /* 5639 */
  IC, /* 5640 */
  IC_64BIT_REXW, /* 5641 */
  IC_XS, /* 5642 */
  IC_64BIT_REXW_XS, /* 5643 */
  IC_XD, /* 5644 */
  IC_64BIT_REXW_XD, /* 5645 */
  IC_XS, /* 5646 */
  IC_64BIT_REXW_XS, /* 5647 */
  IC_OPSIZE, /* 5648 */
  IC_64BIT_OPSIZE, /* 5649 */
  IC_XS_OPSIZE, /* 5650 */
  IC_64BIT_XS_OPSIZE, /* 5651 */
  IC_XD_OPSIZE, /* 5652 */
  IC_64BIT_XD_OPSIZE, /* 5653 */
  IC_XS_OPSIZE, /* 5654 */
  IC_64BIT_XD_OPSIZE, /* 5655 */
  IC_OPSIZE, /* 5656 */
  IC_64BIT_REXW_OPSIZE, /* 5657 */
  IC_XS_OPSIZE, /* 5658 */
  IC_64BIT_REXW_XS, /* 5659 */
  IC_XD_OPSIZE, /* 5660 */
  IC_64BIT_REXW_XD, /* 5661 */
  IC_XS_OPSIZE, /* 5662 */
  IC_64BIT_REXW_XS, /* 5663 */
  IC_ADSIZE, /* 5664 */
  IC_64BIT_ADSIZE, /* 5665 */
  IC_XS, /* 5666 */
  IC_64BIT_XS, /* 5667 */
  IC_XD, /* 5668 */
  IC_64BIT_XD, /* 5669 */
  IC_XS, /* 5670 */
  IC_64BIT_XS, /* 5671 */
  IC_ADSIZE, /* 5672 */
  IC_64BIT_REXW_ADSIZE, /* 5673 */
  IC_XS, /* 5674 */
  IC_64BIT_REXW_XS, /* 5675 */
  IC_XD, /* 5676 */
  IC_64BIT_REXW_XD, /* 5677 */
  IC_XS, /* 5678 */
  IC_64BIT_REXW_XS, /* 5679 */
  IC_OPSIZE_ADSIZE, /* 5680 */
  IC_64BIT_OPSIZE_ADSIZE, /* 5681 */
  IC_XS_OPSIZE, /* 5682 */
  IC_64BIT_XS_OPSIZE, /* 5683 */
  IC_XD_OPSIZE, /* 5684 */
  IC_64BIT_XD_OPSIZE, /* 5685 */
  IC_XS_OPSIZE, /* 5686 */
  IC_64BIT_XD_OPSIZE, /* 5687 */
  IC_OPSIZE_ADSIZE, /* 5688 */
  IC_64BIT_REXW_OPSIZE, /* 5689 */
  IC_XS_OPSIZE, /* 5690 */
  IC_64BIT_REXW_XS, /* 5691 */
  IC_XD_OPSIZE, /* 5692 */
  IC_64BIT_REXW_XD, /* 5693 */
  IC_XS_OPSIZE, /* 5694 */
  IC_64BIT_REXW_XS, /* 5695 */
  IC_VEX, /* 5696 */
  IC_VEX, /* 5697 */
  IC_VEX_XS, /* 5698 */
  IC_VEX_XS, /* 5699 */
  IC_VEX_XD, /* 5700 */
  IC_VEX_XD, /* 5701 */
  IC_VEX_XD, /* 5702 */
  IC_VEX_XD, /* 5703 */
  IC_VEX_W, /* 5704 */
  IC_VEX_W, /* 5705 */
  IC_VEX_W_XS, /* 5706 */
  IC_VEX_W_XS, /* 5707 */
  IC_VEX_W_XD, /* 5708 */
  IC_VEX_W_XD, /* 5709 */
  IC_VEX_W_XD, /* 5710 */
  IC_VEX_W_XD, /* 5711 */
  IC_VEX_OPSIZE, /* 5712 */
  IC_VEX_OPSIZE, /* 5713 */
  IC_VEX_OPSIZE, /* 5714 */
  IC_VEX_OPSIZE, /* 5715 */
  IC_VEX_OPSIZE, /* 5716 */
  IC_VEX_OPSIZE, /* 5717 */
  IC_VEX_OPSIZE, /* 5718 */
  IC_VEX_OPSIZE, /* 5719 */
  IC_VEX_W_OPSIZE, /* 5720 */
  IC_VEX_W_OPSIZE, /* 5721 */
  IC_VEX_W_OPSIZE, /* 5722 */
  IC_VEX_W_OPSIZE, /* 5723 */
  IC_VEX_W_OPSIZE, /* 5724 */
  IC_VEX_W_OPSIZE, /* 5725 */
  IC_VEX_W_OPSIZE, /* 5726 */
  IC_VEX_W_OPSIZE, /* 5727 */
  IC_VEX, /* 5728 */
  IC_VEX, /* 5729 */
  IC_VEX_XS, /* 5730 */
  IC_VEX_XS, /* 5731 */
  IC_VEX_XD, /* 5732 */
  IC_VEX_XD, /* 5733 */
  IC_VEX_XD, /* 5734 */
  IC_VEX_XD, /* 5735 */
  IC_VEX_W, /* 5736 */
  IC_VEX_W, /* 5737 */
  IC_VEX_W_XS, /* 5738 */
  IC_VEX_W_XS, /* 5739 */
  IC_VEX_W_XD, /* 5740 */
  IC_VEX_W_XD, /* 5741 */
  IC_VEX_W_XD, /* 5742 */
  IC_VEX_W_XD, /* 5743 */
  IC_VEX_OPSIZE, /* 5744 */
  IC_VEX_OPSIZE, /* 5745 */
  IC_VEX_OPSIZE, /* 5746 */
  IC_VEX_OPSIZE, /* 5747 */
  IC_VEX_OPSIZE, /* 5748 */
  IC_VEX_OPSIZE, /* 5749 */
  IC_VEX_OPSIZE, /* 5750 */
  IC_VEX_OPSIZE, /* 5751 */
  IC_VEX_W_OPSIZE, /* 5752 */
  IC_VEX_W_OPSIZE, /* 5753 */
  IC_VEX_W_OPSIZE, /* 5754 */
  IC_VEX_W_OPSIZE, /* 5755 */
  IC_VEX_W_OPSIZE, /* 5756 */
  IC_VEX_W_OPSIZE, /* 5757 */
  IC_VEX_W_OPSIZE, /* 5758 */
  IC_VEX_W_OPSIZE, /* 5759 */
  IC_VEX_L, /* 5760 */
  IC_VEX_L, /* 5761 */
  IC_VEX_L_XS, /* 5762 */
  IC_VEX_L_XS, /* 5763 */
  IC_VEX_L_XD, /* 5764 */
  IC_VEX_L_XD, /* 5765 */
  IC_VEX_L_XD, /* 5766 */
  IC_VEX_L_XD, /* 5767 */
  IC_VEX_L_W, /* 5768 */
  IC_VEX_L_W, /* 5769 */
  IC_VEX_L_W_XS, /* 5770 */
  IC_VEX_L_W_XS, /* 5771 */
  IC_VEX_L_W_XD, /* 5772 */
  IC_VEX_L_W_XD, /* 5773 */
  IC_VEX_L_W_XD, /* 5774 */
  IC_VEX_L_W_XD, /* 5775 */
  IC_VEX_L_OPSIZE, /* 5776 */
  IC_VEX_L_OPSIZE, /* 5777 */
  IC_VEX_L_OPSIZE, /* 5778 */
  IC_VEX_L_OPSIZE, /* 5779 */
  IC_VEX_L_OPSIZE, /* 5780 */
  IC_VEX_L_OPSIZE, /* 5781 */
  IC_VEX_L_OPSIZE, /* 5782 */
  IC_VEX_L_OPSIZE, /* 5783 */
  IC_VEX_L_W_OPSIZE, /* 5784 */
  IC_VEX_L_W_OPSIZE, /* 5785 */
  IC_VEX_L_W_OPSIZE, /* 5786 */
  IC_VEX_L_W_OPSIZE, /* 5787 */
  IC_VEX_L_W_OPSIZE, /* 5788 */
  IC_VEX_L_W_OPSIZE, /* 5789 */
  IC_VEX_L_W_OPSIZE, /* 5790 */
  IC_VEX_L_W_OPSIZE, /* 5791 */
  IC_VEX_L, /* 5792 */
  IC_VEX_L, /* 5793 */
  IC_VEX_L_XS, /* 5794 */
  IC_VEX_L_XS, /* 5795 */
  IC_VEX_L_XD, /* 5796 */
  IC_VEX_L_XD, /* 5797 */
  IC_VEX_L_XD, /* 5798 */
  IC_VEX_L_XD, /* 5799 */
  IC_VEX_L_W, /* 5800 */
  IC_VEX_L_W, /* 5801 */
  IC_VEX_L_W_XS, /* 5802 */
  IC_VEX_L_W_XS, /* 5803 */
  IC_VEX_L_W_XD, /* 5804 */
  IC_VEX_L_W_XD, /* 5805 */
  IC_VEX_L_W_XD, /* 5806 */
  IC_VEX_L_W_XD, /* 5807 */
  IC_VEX_L_OPSIZE, /* 5808 */
  IC_VEX_L_OPSIZE, /* 5809 */
  IC_VEX_L_OPSIZE, /* 5810 */
  IC_VEX_L_OPSIZE, /* 5811 */
  IC_VEX_L_OPSIZE, /* 5812 */
  IC_VEX_L_OPSIZE, /* 5813 */
  IC_VEX_L_OPSIZE, /* 5814 */
  IC_VEX_L_OPSIZE, /* 5815 */
  IC_VEX_L_W_OPSIZE, /* 5816 */
  IC_VEX_L_W_OPSIZE, /* 5817 */
  IC_VEX_L_W_OPSIZE, /* 5818 */
  IC_VEX_L_W_OPSIZE, /* 5819 */
  IC_VEX_L_W_OPSIZE, /* 5820 */
  IC_VEX_L_W_OPSIZE, /* 5821 */
  IC_VEX_L_W_OPSIZE, /* 5822 */
  IC_VEX_L_W_OPSIZE, /* 5823 */
  IC_VEX_L, /* 5824 */
  IC_VEX_L, /* 5825 */
  IC_VEX_L_XS, /* 5826 */
  IC_VEX_L_XS, /* 5827 */
  IC_VEX_L_XD, /* 5828 */
  IC_VEX_L_XD, /* 5829 */
  IC_VEX_L_XD, /* 5830 */
  IC_VEX_L_XD, /* 5831 */
  IC_VEX_L_W, /* 5832 */
  IC_VEX_L_W, /* 5833 */
  IC_VEX_L_W_XS, /* 5834 */
  IC_VEX_L_W_XS, /* 5835 */
  IC_VEX_L_W_XD, /* 5836 */
  IC_VEX_L_W_XD, /* 5837 */
  IC_VEX_L_W_XD, /* 5838 */
  IC_VEX_L_W_XD, /* 5839 */
  IC_VEX_L_OPSIZE, /* 5840 */
  IC_VEX_L_OPSIZE, /* 5841 */
  IC_VEX_L_OPSIZE, /* 5842 */
  IC_VEX_L_OPSIZE, /* 5843 */
  IC_VEX_L_OPSIZE, /* 5844 */
  IC_VEX_L_OPSIZE, /* 5845 */
  IC_VEX_L_OPSIZE, /* 5846 */
  IC_VEX_L_OPSIZE, /* 5847 */
  IC_VEX_L_W_OPSIZE, /* 5848 */
  IC_VEX_L_W_OPSIZE, /* 5849 */
  IC_VEX_L_W_OPSIZE, /* 5850 */
  IC_VEX_L_W_OPSIZE, /* 5851 */
  IC_VEX_L_W_OPSIZE, /* 5852 */
  IC_VEX_L_W_OPSIZE, /* 5853 */
  IC_VEX_L_W_OPSIZE, /* 5854 */
  IC_VEX_L_W_OPSIZE, /* 5855 */
  IC_VEX_L, /* 5856 */
  IC_VEX_L, /* 5857 */
  IC_VEX_L_XS, /* 5858 */
  IC_VEX_L_XS, /* 5859 */
  IC_VEX_L_XD, /* 5860 */
  IC_VEX_L_XD, /* 5861 */
  IC_VEX_L_XD, /* 5862 */
  IC_VEX_L_XD, /* 5863 */
  IC_VEX_L_W, /* 5864 */
  IC_VEX_L_W, /* 5865 */
  IC_VEX_L_W_XS, /* 5866 */
  IC_VEX_L_W_XS, /* 5867 */
  IC_VEX_L_W_XD, /* 5868 */
  IC_VEX_L_W_XD, /* 5869 */
  IC_VEX_L_W_XD, /* 5870 */
  IC_VEX_L_W_XD, /* 5871 */
  IC_VEX_L_OPSIZE, /* 5872 */
  IC_VEX_L_OPSIZE, /* 5873 */
  IC_VEX_L_OPSIZE, /* 5874 */
  IC_VEX_L_OPSIZE, /* 5875 */
  IC_VEX_L_OPSIZE, /* 5876 */
  IC_VEX_L_OPSIZE, /* 5877 */
  IC_VEX_L_OPSIZE, /* 5878 */
  IC_VEX_L_OPSIZE, /* 5879 */
  IC_VEX_L_W_OPSIZE, /* 5880 */
  IC_VEX_L_W_OPSIZE, /* 5881 */
  IC_VEX_L_W_OPSIZE, /* 5882 */
  IC_VEX_L_W_OPSIZE, /* 5883 */
  IC_VEX_L_W_OPSIZE, /* 5884 */
  IC_VEX_L_W_OPSIZE, /* 5885 */
  IC_VEX_L_W_OPSIZE, /* 5886 */
  IC_VEX_L_W_OPSIZE, /* 5887 */
  IC_EVEX_L2_KZ, /* 5888 */
  IC_EVEX_L2_KZ, /* 5889 */
  IC_EVEX_L2_XS_KZ, /* 5890 */
  IC_EVEX_L2_XS_KZ, /* 5891 */
  IC_EVEX_L2_XD_KZ, /* 5892 */
  IC_EVEX_L2_XD_KZ, /* 5893 */
  IC_EVEX_L2_XD_KZ, /* 5894 */
  IC_EVEX_L2_XD_KZ, /* 5895 */
  IC_EVEX_L2_W_KZ, /* 5896 */
  IC_EVEX_L2_W_KZ, /* 5897 */
  IC_EVEX_L2_W_XS_KZ, /* 5898 */
  IC_EVEX_L2_W_XS_KZ, /* 5899 */
  IC_EVEX_L2_W_XD_KZ, /* 5900 */
  IC_EVEX_L2_W_XD_KZ, /* 5901 */
  IC_EVEX_L2_W_XD_KZ, /* 5902 */
  IC_EVEX_L2_W_XD_KZ, /* 5903 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5904 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5905 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5906 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5907 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5908 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5909 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5910 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5911 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5912 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5913 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5914 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5915 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5916 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5917 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5918 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5919 */
  IC_EVEX_L2_KZ, /* 5920 */
  IC_EVEX_L2_KZ, /* 5921 */
  IC_EVEX_L2_XS_KZ, /* 5922 */
  IC_EVEX_L2_XS_KZ, /* 5923 */
  IC_EVEX_L2_XD_KZ, /* 5924 */
  IC_EVEX_L2_XD_KZ, /* 5925 */
  IC_EVEX_L2_XD_KZ, /* 5926 */
  IC_EVEX_L2_XD_KZ, /* 5927 */
  IC_EVEX_L2_W_KZ, /* 5928 */
  IC_EVEX_L2_W_KZ, /* 5929 */
  IC_EVEX_L2_W_XS_KZ, /* 5930 */
  IC_EVEX_L2_W_XS_KZ, /* 5931 */
  IC_EVEX_L2_W_XD_KZ, /* 5932 */
  IC_EVEX_L2_W_XD_KZ, /* 5933 */
  IC_EVEX_L2_W_XD_KZ, /* 5934 */
  IC_EVEX_L2_W_XD_KZ, /* 5935 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5936 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5937 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5938 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5939 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5940 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5941 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5942 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5943 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5944 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5945 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5946 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5947 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5948 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5949 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5950 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5951 */
  IC_EVEX_L2_KZ, /* 5952 */
  IC_EVEX_L2_KZ, /* 5953 */
  IC_EVEX_L2_XS_KZ, /* 5954 */
  IC_EVEX_L2_XS_KZ, /* 5955 */
  IC_EVEX_L2_XD_KZ, /* 5956 */
  IC_EVEX_L2_XD_KZ, /* 5957 */
  IC_EVEX_L2_XD_KZ, /* 5958 */
  IC_EVEX_L2_XD_KZ, /* 5959 */
  IC_EVEX_L2_W_KZ, /* 5960 */
  IC_EVEX_L2_W_KZ, /* 5961 */
  IC_EVEX_L2_W_XS_KZ, /* 5962 */
  IC_EVEX_L2_W_XS_KZ, /* 5963 */
  IC_EVEX_L2_W_XD_KZ, /* 5964 */
  IC_EVEX_L2_W_XD_KZ, /* 5965 */
  IC_EVEX_L2_W_XD_KZ, /* 5966 */
  IC_EVEX_L2_W_XD_KZ, /* 5967 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5968 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5969 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5970 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5971 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5972 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5973 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5974 */
  IC_EVEX_L2_OPSIZE_KZ, /* 5975 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5976 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5977 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5978 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5979 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5980 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5981 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5982 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 5983 */
  IC_EVEX_L2_KZ, /* 5984 */
  IC_EVEX_L2_KZ, /* 5985 */
  IC_EVEX_L2_XS_KZ, /* 5986 */
  IC_EVEX_L2_XS_KZ, /* 5987 */
  IC_EVEX_L2_XD_KZ, /* 5988 */
  IC_EVEX_L2_XD_KZ, /* 5989 */
  IC_EVEX_L2_XD_KZ, /* 5990 */
  IC_EVEX_L2_XD_KZ, /* 5991 */
  IC_EVEX_L2_W_KZ, /* 5992 */
  IC_EVEX_L2_W_KZ, /* 5993 */
  IC_EVEX_L2_W_XS_KZ, /* 5994 */
  IC_EVEX_L2_W_XS_KZ, /* 5995 */
  IC_EVEX_L2_W_XD_KZ, /* 5996 */
  IC_EVEX_L2_W_XD_KZ, /* 5997 */
  IC_EVEX_L2_W_XD_KZ, /* 5998 */
  IC_EVEX_L2_W_XD_KZ, /* 5999 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6000 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6001 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6002 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6003 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6004 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6005 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6006 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6007 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6008 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6009 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6010 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6011 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6012 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6013 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6014 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6015 */
  IC_EVEX_L2_KZ, /* 6016 */
  IC_EVEX_L2_KZ, /* 6017 */
  IC_EVEX_L2_XS_KZ, /* 6018 */
  IC_EVEX_L2_XS_KZ, /* 6019 */
  IC_EVEX_L2_XD_KZ, /* 6020 */
  IC_EVEX_L2_XD_KZ, /* 6021 */
  IC_EVEX_L2_XD_KZ, /* 6022 */
  IC_EVEX_L2_XD_KZ, /* 6023 */
  IC_EVEX_L2_W_KZ, /* 6024 */
  IC_EVEX_L2_W_KZ, /* 6025 */
  IC_EVEX_L2_W_XS_KZ, /* 6026 */
  IC_EVEX_L2_W_XS_KZ, /* 6027 */
  IC_EVEX_L2_W_XD_KZ, /* 6028 */
  IC_EVEX_L2_W_XD_KZ, /* 6029 */
  IC_EVEX_L2_W_XD_KZ, /* 6030 */
  IC_EVEX_L2_W_XD_KZ, /* 6031 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6032 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6033 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6034 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6035 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6036 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6037 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6038 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6039 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6040 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6041 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6042 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6043 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6044 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6045 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6046 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6047 */
  IC_EVEX_L2_KZ, /* 6048 */
  IC_EVEX_L2_KZ, /* 6049 */
  IC_EVEX_L2_XS_KZ, /* 6050 */
  IC_EVEX_L2_XS_KZ, /* 6051 */
  IC_EVEX_L2_XD_KZ, /* 6052 */
  IC_EVEX_L2_XD_KZ, /* 6053 */
  IC_EVEX_L2_XD_KZ, /* 6054 */
  IC_EVEX_L2_XD_KZ, /* 6055 */
  IC_EVEX_L2_W_KZ, /* 6056 */
  IC_EVEX_L2_W_KZ, /* 6057 */
  IC_EVEX_L2_W_XS_KZ, /* 6058 */
  IC_EVEX_L2_W_XS_KZ, /* 6059 */
  IC_EVEX_L2_W_XD_KZ, /* 6060 */
  IC_EVEX_L2_W_XD_KZ, /* 6061 */
  IC_EVEX_L2_W_XD_KZ, /* 6062 */
  IC_EVEX_L2_W_XD_KZ, /* 6063 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6064 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6065 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6066 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6067 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6068 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6069 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6070 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6071 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6072 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6073 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6074 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6075 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6076 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6077 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6078 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6079 */
  IC_EVEX_L2_KZ, /* 6080 */
  IC_EVEX_L2_KZ, /* 6081 */
  IC_EVEX_L2_XS_KZ, /* 6082 */
  IC_EVEX_L2_XS_KZ, /* 6083 */
  IC_EVEX_L2_XD_KZ, /* 6084 */
  IC_EVEX_L2_XD_KZ, /* 6085 */
  IC_EVEX_L2_XD_KZ, /* 6086 */
  IC_EVEX_L2_XD_KZ, /* 6087 */
  IC_EVEX_L2_W_KZ, /* 6088 */
  IC_EVEX_L2_W_KZ, /* 6089 */
  IC_EVEX_L2_W_XS_KZ, /* 6090 */
  IC_EVEX_L2_W_XS_KZ, /* 6091 */
  IC_EVEX_L2_W_XD_KZ, /* 6092 */
  IC_EVEX_L2_W_XD_KZ, /* 6093 */
  IC_EVEX_L2_W_XD_KZ, /* 6094 */
  IC_EVEX_L2_W_XD_KZ, /* 6095 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6096 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6097 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6098 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6099 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6100 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6101 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6102 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6103 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6104 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6105 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6106 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6107 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6108 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6109 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6110 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6111 */
  IC_EVEX_L2_KZ, /* 6112 */
  IC_EVEX_L2_KZ, /* 6113 */
  IC_EVEX_L2_XS_KZ, /* 6114 */
  IC_EVEX_L2_XS_KZ, /* 6115 */
  IC_EVEX_L2_XD_KZ, /* 6116 */
  IC_EVEX_L2_XD_KZ, /* 6117 */
  IC_EVEX_L2_XD_KZ, /* 6118 */
  IC_EVEX_L2_XD_KZ, /* 6119 */
  IC_EVEX_L2_W_KZ, /* 6120 */
  IC_EVEX_L2_W_KZ, /* 6121 */
  IC_EVEX_L2_W_XS_KZ, /* 6122 */
  IC_EVEX_L2_W_XS_KZ, /* 6123 */
  IC_EVEX_L2_W_XD_KZ, /* 6124 */
  IC_EVEX_L2_W_XD_KZ, /* 6125 */
  IC_EVEX_L2_W_XD_KZ, /* 6126 */
  IC_EVEX_L2_W_XD_KZ, /* 6127 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6128 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6129 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6130 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6131 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6132 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6133 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6134 */
  IC_EVEX_L2_OPSIZE_KZ, /* 6135 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6136 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6137 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6138 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6139 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6140 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6141 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6142 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 6143 */
  IC, /* 6144 */
  IC_64BIT, /* 6145 */
  IC_XS, /* 6146 */
  IC_64BIT_XS, /* 6147 */
  IC_XD, /* 6148 */
  IC_64BIT_XD, /* 6149 */
  IC_XS, /* 6150 */
  IC_64BIT_XS, /* 6151 */
  IC, /* 6152 */
  IC_64BIT_REXW, /* 6153 */
  IC_XS, /* 6154 */
  IC_64BIT_REXW_XS, /* 6155 */
  IC_XD, /* 6156 */
  IC_64BIT_REXW_XD, /* 6157 */
  IC_XS, /* 6158 */
  IC_64BIT_REXW_XS, /* 6159 */
  IC_OPSIZE, /* 6160 */
  IC_64BIT_OPSIZE, /* 6161 */
  IC_XS_OPSIZE, /* 6162 */
  IC_64BIT_XS_OPSIZE, /* 6163 */
  IC_XD_OPSIZE, /* 6164 */
  IC_64BIT_XD_OPSIZE, /* 6165 */
  IC_XS_OPSIZE, /* 6166 */
  IC_64BIT_XD_OPSIZE, /* 6167 */
  IC_OPSIZE, /* 6168 */
  IC_64BIT_REXW_OPSIZE, /* 6169 */
  IC_XS_OPSIZE, /* 6170 */
  IC_64BIT_REXW_XS, /* 6171 */
  IC_XD_OPSIZE, /* 6172 */
  IC_64BIT_REXW_XD, /* 6173 */
  IC_XS_OPSIZE, /* 6174 */
  IC_64BIT_REXW_XS, /* 6175 */
  IC_ADSIZE, /* 6176 */
  IC_64BIT_ADSIZE, /* 6177 */
  IC_XS, /* 6178 */
  IC_64BIT_XS, /* 6179 */
  IC_XD, /* 6180 */
  IC_64BIT_XD, /* 6181 */
  IC_XS, /* 6182 */
  IC_64BIT_XS, /* 6183 */
  IC_ADSIZE, /* 6184 */
  IC_64BIT_REXW_ADSIZE, /* 6185 */
  IC_XS, /* 6186 */
  IC_64BIT_REXW_XS, /* 6187 */
  IC_XD, /* 6188 */
  IC_64BIT_REXW_XD, /* 6189 */
  IC_XS, /* 6190 */
  IC_64BIT_REXW_XS, /* 6191 */
  IC_OPSIZE_ADSIZE, /* 6192 */
  IC_64BIT_OPSIZE_ADSIZE, /* 6193 */
  IC_XS_OPSIZE, /* 6194 */
  IC_64BIT_XS_OPSIZE, /* 6195 */
  IC_XD_OPSIZE, /* 6196 */
  IC_64BIT_XD_OPSIZE, /* 6197 */
  IC_XS_OPSIZE, /* 6198 */
  IC_64BIT_XD_OPSIZE, /* 6199 */
  IC_OPSIZE_ADSIZE, /* 6200 */
  IC_64BIT_REXW_OPSIZE, /* 6201 */
  IC_XS_OPSIZE, /* 6202 */
  IC_64BIT_REXW_XS, /* 6203 */
  IC_XD_OPSIZE, /* 6204 */
  IC_64BIT_REXW_XD, /* 6205 */
  IC_XS_OPSIZE, /* 6206 */
  IC_64BIT_REXW_XS, /* 6207 */
  IC_VEX, /* 6208 */
  IC_VEX, /* 6209 */
  IC_VEX_XS, /* 6210 */
  IC_VEX_XS, /* 6211 */
  IC_VEX_XD, /* 6212 */
  IC_VEX_XD, /* 6213 */
  IC_VEX_XD, /* 6214 */
  IC_VEX_XD, /* 6215 */
  IC_VEX_W, /* 6216 */
  IC_VEX_W, /* 6217 */
  IC_VEX_W_XS, /* 6218 */
  IC_VEX_W_XS, /* 6219 */
  IC_VEX_W_XD, /* 6220 */
  IC_VEX_W_XD, /* 6221 */
  IC_VEX_W_XD, /* 6222 */
  IC_VEX_W_XD, /* 6223 */
  IC_VEX_OPSIZE, /* 6224 */
  IC_VEX_OPSIZE, /* 6225 */
  IC_VEX_OPSIZE, /* 6226 */
  IC_VEX_OPSIZE, /* 6227 */
  IC_VEX_OPSIZE, /* 6228 */
  IC_VEX_OPSIZE, /* 6229 */
  IC_VEX_OPSIZE, /* 6230 */
  IC_VEX_OPSIZE, /* 6231 */
  IC_VEX_W_OPSIZE, /* 6232 */
  IC_VEX_W_OPSIZE, /* 6233 */
  IC_VEX_W_OPSIZE, /* 6234 */
  IC_VEX_W_OPSIZE, /* 6235 */
  IC_VEX_W_OPSIZE, /* 6236 */
  IC_VEX_W_OPSIZE, /* 6237 */
  IC_VEX_W_OPSIZE, /* 6238 */
  IC_VEX_W_OPSIZE, /* 6239 */
  IC_VEX, /* 6240 */
  IC_VEX, /* 6241 */
  IC_VEX_XS, /* 6242 */
  IC_VEX_XS, /* 6243 */
  IC_VEX_XD, /* 6244 */
  IC_VEX_XD, /* 6245 */
  IC_VEX_XD, /* 6246 */
  IC_VEX_XD, /* 6247 */
  IC_VEX_W, /* 6248 */
  IC_VEX_W, /* 6249 */
  IC_VEX_W_XS, /* 6250 */
  IC_VEX_W_XS, /* 6251 */
  IC_VEX_W_XD, /* 6252 */
  IC_VEX_W_XD, /* 6253 */
  IC_VEX_W_XD, /* 6254 */
  IC_VEX_W_XD, /* 6255 */
  IC_VEX_OPSIZE, /* 6256 */
  IC_VEX_OPSIZE, /* 6257 */
  IC_VEX_OPSIZE, /* 6258 */
  IC_VEX_OPSIZE, /* 6259 */
  IC_VEX_OPSIZE, /* 6260 */
  IC_VEX_OPSIZE, /* 6261 */
  IC_VEX_OPSIZE, /* 6262 */
  IC_VEX_OPSIZE, /* 6263 */
  IC_VEX_W_OPSIZE, /* 6264 */
  IC_VEX_W_OPSIZE, /* 6265 */
  IC_VEX_W_OPSIZE, /* 6266 */
  IC_VEX_W_OPSIZE, /* 6267 */
  IC_VEX_W_OPSIZE, /* 6268 */
  IC_VEX_W_OPSIZE, /* 6269 */
  IC_VEX_W_OPSIZE, /* 6270 */
  IC_VEX_W_OPSIZE, /* 6271 */
  IC_VEX_L, /* 6272 */
  IC_VEX_L, /* 6273 */
  IC_VEX_L_XS, /* 6274 */
  IC_VEX_L_XS, /* 6275 */
  IC_VEX_L_XD, /* 6276 */
  IC_VEX_L_XD, /* 6277 */
  IC_VEX_L_XD, /* 6278 */
  IC_VEX_L_XD, /* 6279 */
  IC_VEX_L_W, /* 6280 */
  IC_VEX_L_W, /* 6281 */
  IC_VEX_L_W_XS, /* 6282 */
  IC_VEX_L_W_XS, /* 6283 */
  IC_VEX_L_W_XD, /* 6284 */
  IC_VEX_L_W_XD, /* 6285 */
  IC_VEX_L_W_XD, /* 6286 */
  IC_VEX_L_W_XD, /* 6287 */
  IC_VEX_L_OPSIZE, /* 6288 */
  IC_VEX_L_OPSIZE, /* 6289 */
  IC_VEX_L_OPSIZE, /* 6290 */
  IC_VEX_L_OPSIZE, /* 6291 */
  IC_VEX_L_OPSIZE, /* 6292 */
  IC_VEX_L_OPSIZE, /* 6293 */
  IC_VEX_L_OPSIZE, /* 6294 */
  IC_VEX_L_OPSIZE, /* 6295 */
  IC_VEX_L_W_OPSIZE, /* 6296 */
  IC_VEX_L_W_OPSIZE, /* 6297 */
  IC_VEX_L_W_OPSIZE, /* 6298 */
  IC_VEX_L_W_OPSIZE, /* 6299 */
  IC_VEX_L_W_OPSIZE, /* 6300 */
  IC_VEX_L_W_OPSIZE, /* 6301 */
  IC_VEX_L_W_OPSIZE, /* 6302 */
  IC_VEX_L_W_OPSIZE, /* 6303 */
  IC_VEX_L, /* 6304 */
  IC_VEX_L, /* 6305 */
  IC_VEX_L_XS, /* 6306 */
  IC_VEX_L_XS, /* 6307 */
  IC_VEX_L_XD, /* 6308 */
  IC_VEX_L_XD, /* 6309 */
  IC_VEX_L_XD, /* 6310 */
  IC_VEX_L_XD, /* 6311 */
  IC_VEX_L_W, /* 6312 */
  IC_VEX_L_W, /* 6313 */
  IC_VEX_L_W_XS, /* 6314 */
  IC_VEX_L_W_XS, /* 6315 */
  IC_VEX_L_W_XD, /* 6316 */
  IC_VEX_L_W_XD, /* 6317 */
  IC_VEX_L_W_XD, /* 6318 */
  IC_VEX_L_W_XD, /* 6319 */
  IC_VEX_L_OPSIZE, /* 6320 */
  IC_VEX_L_OPSIZE, /* 6321 */
  IC_VEX_L_OPSIZE, /* 6322 */
  IC_VEX_L_OPSIZE, /* 6323 */
  IC_VEX_L_OPSIZE, /* 6324 */
  IC_VEX_L_OPSIZE, /* 6325 */
  IC_VEX_L_OPSIZE, /* 6326 */
  IC_VEX_L_OPSIZE, /* 6327 */
  IC_VEX_L_W_OPSIZE, /* 6328 */
  IC_VEX_L_W_OPSIZE, /* 6329 */
  IC_VEX_L_W_OPSIZE, /* 6330 */
  IC_VEX_L_W_OPSIZE, /* 6331 */
  IC_VEX_L_W_OPSIZE, /* 6332 */
  IC_VEX_L_W_OPSIZE, /* 6333 */
  IC_VEX_L_W_OPSIZE, /* 6334 */
  IC_VEX_L_W_OPSIZE, /* 6335 */
  IC_VEX_L, /* 6336 */
  IC_VEX_L, /* 6337 */
  IC_VEX_L_XS, /* 6338 */
  IC_VEX_L_XS, /* 6339 */
  IC_VEX_L_XD, /* 6340 */
  IC_VEX_L_XD, /* 6341 */
  IC_VEX_L_XD, /* 6342 */
  IC_VEX_L_XD, /* 6343 */
  IC_VEX_L_W, /* 6344 */
  IC_VEX_L_W, /* 6345 */
  IC_VEX_L_W_XS, /* 6346 */
  IC_VEX_L_W_XS, /* 6347 */
  IC_VEX_L_W_XD, /* 6348 */
  IC_VEX_L_W_XD, /* 6349 */
  IC_VEX_L_W_XD, /* 6350 */
  IC_VEX_L_W_XD, /* 6351 */
  IC_VEX_L_OPSIZE, /* 6352 */
  IC_VEX_L_OPSIZE, /* 6353 */
  IC_VEX_L_OPSIZE, /* 6354 */
  IC_VEX_L_OPSIZE, /* 6355 */
  IC_VEX_L_OPSIZE, /* 6356 */
  IC_VEX_L_OPSIZE, /* 6357 */
  IC_VEX_L_OPSIZE, /* 6358 */
  IC_VEX_L_OPSIZE, /* 6359 */
  IC_VEX_L_W_OPSIZE, /* 6360 */
  IC_VEX_L_W_OPSIZE, /* 6361 */
  IC_VEX_L_W_OPSIZE, /* 6362 */
  IC_VEX_L_W_OPSIZE, /* 6363 */
  IC_VEX_L_W_OPSIZE, /* 6364 */
  IC_VEX_L_W_OPSIZE, /* 6365 */
  IC_VEX_L_W_OPSIZE, /* 6366 */
  IC_VEX_L_W_OPSIZE, /* 6367 */
  IC_VEX_L, /* 6368 */
  IC_VEX_L, /* 6369 */
  IC_VEX_L_XS, /* 6370 */
  IC_VEX_L_XS, /* 6371 */
  IC_VEX_L_XD, /* 6372 */
  IC_VEX_L_XD, /* 6373 */
  IC_VEX_L_XD, /* 6374 */
  IC_VEX_L_XD, /* 6375 */
  IC_VEX_L_W, /* 6376 */
  IC_VEX_L_W, /* 6377 */
  IC_VEX_L_W_XS, /* 6378 */
  IC_VEX_L_W_XS, /* 6379 */
  IC_VEX_L_W_XD, /* 6380 */
  IC_VEX_L_W_XD, /* 6381 */
  IC_VEX_L_W_XD, /* 6382 */
  IC_VEX_L_W_XD, /* 6383 */
  IC_VEX_L_OPSIZE, /* 6384 */
  IC_VEX_L_OPSIZE, /* 6385 */
  IC_VEX_L_OPSIZE, /* 6386 */
  IC_VEX_L_OPSIZE, /* 6387 */
  IC_VEX_L_OPSIZE, /* 6388 */
  IC_VEX_L_OPSIZE, /* 6389 */
  IC_VEX_L_OPSIZE, /* 6390 */
  IC_VEX_L_OPSIZE, /* 6391 */
  IC_VEX_L_W_OPSIZE, /* 6392 */
  IC_VEX_L_W_OPSIZE, /* 6393 */
  IC_VEX_L_W_OPSIZE, /* 6394 */
  IC_VEX_L_W_OPSIZE, /* 6395 */
  IC_VEX_L_W_OPSIZE, /* 6396 */
  IC_VEX_L_W_OPSIZE, /* 6397 */
  IC_VEX_L_W_OPSIZE, /* 6398 */
  IC_VEX_L_W_OPSIZE, /* 6399 */
  IC_EVEX_KZ, /* 6400 */
  IC_EVEX_KZ, /* 6401 */
  IC_EVEX_XS_KZ, /* 6402 */
  IC_EVEX_XS_KZ, /* 6403 */
  IC_EVEX_XD_KZ, /* 6404 */
  IC_EVEX_XD_KZ, /* 6405 */
  IC_EVEX_XD_KZ, /* 6406 */
  IC_EVEX_XD_KZ, /* 6407 */
  IC_EVEX_W_KZ, /* 6408 */
  IC_EVEX_W_KZ, /* 6409 */
  IC_EVEX_W_XS_KZ, /* 6410 */
  IC_EVEX_W_XS_KZ, /* 6411 */
  IC_EVEX_W_XD_KZ, /* 6412 */
  IC_EVEX_W_XD_KZ, /* 6413 */
  IC_EVEX_W_XD_KZ, /* 6414 */
  IC_EVEX_W_XD_KZ, /* 6415 */
  IC_EVEX_OPSIZE_KZ, /* 6416 */
  IC_EVEX_OPSIZE_KZ, /* 6417 */
  IC_EVEX_OPSIZE_KZ, /* 6418 */
  IC_EVEX_OPSIZE_KZ, /* 6419 */
  IC_EVEX_OPSIZE_KZ, /* 6420 */
  IC_EVEX_OPSIZE_KZ, /* 6421 */
  IC_EVEX_OPSIZE_KZ, /* 6422 */
  IC_EVEX_OPSIZE_KZ, /* 6423 */
  IC_EVEX_W_OPSIZE_KZ, /* 6424 */
  IC_EVEX_W_OPSIZE_KZ, /* 6425 */
  IC_EVEX_W_OPSIZE_KZ, /* 6426 */
  IC_EVEX_W_OPSIZE_KZ, /* 6427 */
  IC_EVEX_W_OPSIZE_KZ, /* 6428 */
  IC_EVEX_W_OPSIZE_KZ, /* 6429 */
  IC_EVEX_W_OPSIZE_KZ, /* 6430 */
  IC_EVEX_W_OPSIZE_KZ, /* 6431 */
  IC_EVEX_KZ, /* 6432 */
  IC_EVEX_KZ, /* 6433 */
  IC_EVEX_XS_KZ, /* 6434 */
  IC_EVEX_XS_KZ, /* 6435 */
  IC_EVEX_XD_KZ, /* 6436 */
  IC_EVEX_XD_KZ, /* 6437 */
  IC_EVEX_XD_KZ, /* 6438 */
  IC_EVEX_XD_KZ, /* 6439 */
  IC_EVEX_W_KZ, /* 6440 */
  IC_EVEX_W_KZ, /* 6441 */
  IC_EVEX_W_XS_KZ, /* 6442 */
  IC_EVEX_W_XS_KZ, /* 6443 */
  IC_EVEX_W_XD_KZ, /* 6444 */
  IC_EVEX_W_XD_KZ, /* 6445 */
  IC_EVEX_W_XD_KZ, /* 6446 */
  IC_EVEX_W_XD_KZ, /* 6447 */
  IC_EVEX_OPSIZE_KZ, /* 6448 */
  IC_EVEX_OPSIZE_KZ, /* 6449 */
  IC_EVEX_OPSIZE_KZ, /* 6450 */
  IC_EVEX_OPSIZE_KZ, /* 6451 */
  IC_EVEX_OPSIZE_KZ, /* 6452 */
  IC_EVEX_OPSIZE_KZ, /* 6453 */
  IC_EVEX_OPSIZE_KZ, /* 6454 */
  IC_EVEX_OPSIZE_KZ, /* 6455 */
  IC_EVEX_W_OPSIZE_KZ, /* 6456 */
  IC_EVEX_W_OPSIZE_KZ, /* 6457 */
  IC_EVEX_W_OPSIZE_KZ, /* 6458 */
  IC_EVEX_W_OPSIZE_KZ, /* 6459 */
  IC_EVEX_W_OPSIZE_KZ, /* 6460 */
  IC_EVEX_W_OPSIZE_KZ, /* 6461 */
  IC_EVEX_W_OPSIZE_KZ, /* 6462 */
  IC_EVEX_W_OPSIZE_KZ, /* 6463 */
  IC_EVEX_KZ, /* 6464 */
  IC_EVEX_KZ, /* 6465 */
  IC_EVEX_XS_KZ, /* 6466 */
  IC_EVEX_XS_KZ, /* 6467 */
  IC_EVEX_XD_KZ, /* 6468 */
  IC_EVEX_XD_KZ, /* 6469 */
  IC_EVEX_XD_KZ, /* 6470 */
  IC_EVEX_XD_KZ, /* 6471 */
  IC_EVEX_W_KZ, /* 6472 */
  IC_EVEX_W_KZ, /* 6473 */
  IC_EVEX_W_XS_KZ, /* 6474 */
  IC_EVEX_W_XS_KZ, /* 6475 */
  IC_EVEX_W_XD_KZ, /* 6476 */
  IC_EVEX_W_XD_KZ, /* 6477 */
  IC_EVEX_W_XD_KZ, /* 6478 */
  IC_EVEX_W_XD_KZ, /* 6479 */
  IC_EVEX_OPSIZE_KZ, /* 6480 */
  IC_EVEX_OPSIZE_KZ, /* 6481 */
  IC_EVEX_OPSIZE_KZ, /* 6482 */
  IC_EVEX_OPSIZE_KZ, /* 6483 */
  IC_EVEX_OPSIZE_KZ, /* 6484 */
  IC_EVEX_OPSIZE_KZ, /* 6485 */
  IC_EVEX_OPSIZE_KZ, /* 6486 */
  IC_EVEX_OPSIZE_KZ, /* 6487 */
  IC_EVEX_W_OPSIZE_KZ, /* 6488 */
  IC_EVEX_W_OPSIZE_KZ, /* 6489 */
  IC_EVEX_W_OPSIZE_KZ, /* 6490 */
  IC_EVEX_W_OPSIZE_KZ, /* 6491 */
  IC_EVEX_W_OPSIZE_KZ, /* 6492 */
  IC_EVEX_W_OPSIZE_KZ, /* 6493 */
  IC_EVEX_W_OPSIZE_KZ, /* 6494 */
  IC_EVEX_W_OPSIZE_KZ, /* 6495 */
  IC_EVEX_KZ, /* 6496 */
  IC_EVEX_KZ, /* 6497 */
  IC_EVEX_XS_KZ, /* 6498 */
  IC_EVEX_XS_KZ, /* 6499 */
  IC_EVEX_XD_KZ, /* 6500 */
  IC_EVEX_XD_KZ, /* 6501 */
  IC_EVEX_XD_KZ, /* 6502 */
  IC_EVEX_XD_KZ, /* 6503 */
  IC_EVEX_W_KZ, /* 6504 */
  IC_EVEX_W_KZ, /* 6505 */
  IC_EVEX_W_XS_KZ, /* 6506 */
  IC_EVEX_W_XS_KZ, /* 6507 */
  IC_EVEX_W_XD_KZ, /* 6508 */
  IC_EVEX_W_XD_KZ, /* 6509 */
  IC_EVEX_W_XD_KZ, /* 6510 */
  IC_EVEX_W_XD_KZ, /* 6511 */
  IC_EVEX_OPSIZE_KZ, /* 6512 */
  IC_EVEX_OPSIZE_KZ, /* 6513 */
  IC_EVEX_OPSIZE_KZ, /* 6514 */
  IC_EVEX_OPSIZE_KZ, /* 6515 */
  IC_EVEX_OPSIZE_KZ, /* 6516 */
  IC_EVEX_OPSIZE_KZ, /* 6517 */
  IC_EVEX_OPSIZE_KZ, /* 6518 */
  IC_EVEX_OPSIZE_KZ, /* 6519 */
  IC_EVEX_W_OPSIZE_KZ, /* 6520 */
  IC_EVEX_W_OPSIZE_KZ, /* 6521 */
  IC_EVEX_W_OPSIZE_KZ, /* 6522 */
  IC_EVEX_W_OPSIZE_KZ, /* 6523 */
  IC_EVEX_W_OPSIZE_KZ, /* 6524 */
  IC_EVEX_W_OPSIZE_KZ, /* 6525 */
  IC_EVEX_W_OPSIZE_KZ, /* 6526 */
  IC_EVEX_W_OPSIZE_KZ, /* 6527 */
  IC_EVEX_KZ, /* 6528 */
  IC_EVEX_KZ, /* 6529 */
  IC_EVEX_XS_KZ, /* 6530 */
  IC_EVEX_XS_KZ, /* 6531 */
  IC_EVEX_XD_KZ, /* 6532 */
  IC_EVEX_XD_KZ, /* 6533 */
  IC_EVEX_XD_KZ, /* 6534 */
  IC_EVEX_XD_KZ, /* 6535 */
  IC_EVEX_W_KZ, /* 6536 */
  IC_EVEX_W_KZ, /* 6537 */
  IC_EVEX_W_XS_KZ, /* 6538 */
  IC_EVEX_W_XS_KZ, /* 6539 */
  IC_EVEX_W_XD_KZ, /* 6540 */
  IC_EVEX_W_XD_KZ, /* 6541 */
  IC_EVEX_W_XD_KZ, /* 6542 */
  IC_EVEX_W_XD_KZ, /* 6543 */
  IC_EVEX_OPSIZE_KZ, /* 6544 */
  IC_EVEX_OPSIZE_KZ, /* 6545 */
  IC_EVEX_OPSIZE_KZ, /* 6546 */
  IC_EVEX_OPSIZE_KZ, /* 6547 */
  IC_EVEX_OPSIZE_KZ, /* 6548 */
  IC_EVEX_OPSIZE_KZ, /* 6549 */
  IC_EVEX_OPSIZE_KZ, /* 6550 */
  IC_EVEX_OPSIZE_KZ, /* 6551 */
  IC_EVEX_W_OPSIZE_KZ, /* 6552 */
  IC_EVEX_W_OPSIZE_KZ, /* 6553 */
  IC_EVEX_W_OPSIZE_KZ, /* 6554 */
  IC_EVEX_W_OPSIZE_KZ, /* 6555 */
  IC_EVEX_W_OPSIZE_KZ, /* 6556 */
  IC_EVEX_W_OPSIZE_KZ, /* 6557 */
  IC_EVEX_W_OPSIZE_KZ, /* 6558 */
  IC_EVEX_W_OPSIZE_KZ, /* 6559 */
  IC_EVEX_KZ, /* 6560 */
  IC_EVEX_KZ, /* 6561 */
  IC_EVEX_XS_KZ, /* 6562 */
  IC_EVEX_XS_KZ, /* 6563 */
  IC_EVEX_XD_KZ, /* 6564 */
  IC_EVEX_XD_KZ, /* 6565 */
  IC_EVEX_XD_KZ, /* 6566 */
  IC_EVEX_XD_KZ, /* 6567 */
  IC_EVEX_W_KZ, /* 6568 */
  IC_EVEX_W_KZ, /* 6569 */
  IC_EVEX_W_XS_KZ, /* 6570 */
  IC_EVEX_W_XS_KZ, /* 6571 */
  IC_EVEX_W_XD_KZ, /* 6572 */
  IC_EVEX_W_XD_KZ, /* 6573 */
  IC_EVEX_W_XD_KZ, /* 6574 */
  IC_EVEX_W_XD_KZ, /* 6575 */
  IC_EVEX_OPSIZE_KZ, /* 6576 */
  IC_EVEX_OPSIZE_KZ, /* 6577 */
  IC_EVEX_OPSIZE_KZ, /* 6578 */
  IC_EVEX_OPSIZE_KZ, /* 6579 */
  IC_EVEX_OPSIZE_KZ, /* 6580 */
  IC_EVEX_OPSIZE_KZ, /* 6581 */
  IC_EVEX_OPSIZE_KZ, /* 6582 */
  IC_EVEX_OPSIZE_KZ, /* 6583 */
  IC_EVEX_W_OPSIZE_KZ, /* 6584 */
  IC_EVEX_W_OPSIZE_KZ, /* 6585 */
  IC_EVEX_W_OPSIZE_KZ, /* 6586 */
  IC_EVEX_W_OPSIZE_KZ, /* 6587 */
  IC_EVEX_W_OPSIZE_KZ, /* 6588 */
  IC_EVEX_W_OPSIZE_KZ, /* 6589 */
  IC_EVEX_W_OPSIZE_KZ, /* 6590 */
  IC_EVEX_W_OPSIZE_KZ, /* 6591 */
  IC_EVEX_KZ, /* 6592 */
  IC_EVEX_KZ, /* 6593 */
  IC_EVEX_XS_KZ, /* 6594 */
  IC_EVEX_XS_KZ, /* 6595 */
  IC_EVEX_XD_KZ, /* 6596 */
  IC_EVEX_XD_KZ, /* 6597 */
  IC_EVEX_XD_KZ, /* 6598 */
  IC_EVEX_XD_KZ, /* 6599 */
  IC_EVEX_W_KZ, /* 6600 */
  IC_EVEX_W_KZ, /* 6601 */
  IC_EVEX_W_XS_KZ, /* 6602 */
  IC_EVEX_W_XS_KZ, /* 6603 */
  IC_EVEX_W_XD_KZ, /* 6604 */
  IC_EVEX_W_XD_KZ, /* 6605 */
  IC_EVEX_W_XD_KZ, /* 6606 */
  IC_EVEX_W_XD_KZ, /* 6607 */
  IC_EVEX_OPSIZE_KZ, /* 6608 */
  IC_EVEX_OPSIZE_KZ, /* 6609 */
  IC_EVEX_OPSIZE_KZ, /* 6610 */
  IC_EVEX_OPSIZE_KZ, /* 6611 */
  IC_EVEX_OPSIZE_KZ, /* 6612 */
  IC_EVEX_OPSIZE_KZ, /* 6613 */
  IC_EVEX_OPSIZE_KZ, /* 6614 */
  IC_EVEX_OPSIZE_KZ, /* 6615 */
  IC_EVEX_W_OPSIZE_KZ, /* 6616 */
  IC_EVEX_W_OPSIZE_KZ, /* 6617 */
  IC_EVEX_W_OPSIZE_KZ, /* 6618 */
  IC_EVEX_W_OPSIZE_KZ, /* 6619 */
  IC_EVEX_W_OPSIZE_KZ, /* 6620 */
  IC_EVEX_W_OPSIZE_KZ, /* 6621 */
  IC_EVEX_W_OPSIZE_KZ, /* 6622 */
  IC_EVEX_W_OPSIZE_KZ, /* 6623 */
  IC_EVEX_KZ, /* 6624 */
  IC_EVEX_KZ, /* 6625 */
  IC_EVEX_XS_KZ, /* 6626 */
  IC_EVEX_XS_KZ, /* 6627 */
  IC_EVEX_XD_KZ, /* 6628 */
  IC_EVEX_XD_KZ, /* 6629 */
  IC_EVEX_XD_KZ, /* 6630 */
  IC_EVEX_XD_KZ, /* 6631 */
  IC_EVEX_W_KZ, /* 6632 */
  IC_EVEX_W_KZ, /* 6633 */
  IC_EVEX_W_XS_KZ, /* 6634 */
  IC_EVEX_W_XS_KZ, /* 6635 */
  IC_EVEX_W_XD_KZ, /* 6636 */
  IC_EVEX_W_XD_KZ, /* 6637 */
  IC_EVEX_W_XD_KZ, /* 6638 */
  IC_EVEX_W_XD_KZ, /* 6639 */
  IC_EVEX_OPSIZE_KZ, /* 6640 */
  IC_EVEX_OPSIZE_KZ, /* 6641 */
  IC_EVEX_OPSIZE_KZ, /* 6642 */
  IC_EVEX_OPSIZE_KZ, /* 6643 */
  IC_EVEX_OPSIZE_KZ, /* 6644 */
  IC_EVEX_OPSIZE_KZ, /* 6645 */
  IC_EVEX_OPSIZE_KZ, /* 6646 */
  IC_EVEX_OPSIZE_KZ, /* 6647 */
  IC_EVEX_W_OPSIZE_KZ, /* 6648 */
  IC_EVEX_W_OPSIZE_KZ, /* 6649 */
  IC_EVEX_W_OPSIZE_KZ, /* 6650 */
  IC_EVEX_W_OPSIZE_KZ, /* 6651 */
  IC_EVEX_W_OPSIZE_KZ, /* 6652 */
  IC_EVEX_W_OPSIZE_KZ, /* 6653 */
  IC_EVEX_W_OPSIZE_KZ, /* 6654 */
  IC_EVEX_W_OPSIZE_KZ, /* 6655 */
  IC, /* 6656 */
  IC_64BIT, /* 6657 */
  IC_XS, /* 6658 */
  IC_64BIT_XS, /* 6659 */
  IC_XD, /* 6660 */
  IC_64BIT_XD, /* 6661 */
  IC_XS, /* 6662 */
  IC_64BIT_XS, /* 6663 */
  IC, /* 6664 */
  IC_64BIT_REXW, /* 6665 */
  IC_XS, /* 6666 */
  IC_64BIT_REXW_XS, /* 6667 */
  IC_XD, /* 6668 */
  IC_64BIT_REXW_XD, /* 6669 */
  IC_XS, /* 6670 */
  IC_64BIT_REXW_XS, /* 6671 */
  IC_OPSIZE, /* 6672 */
  IC_64BIT_OPSIZE, /* 6673 */
  IC_XS_OPSIZE, /* 6674 */
  IC_64BIT_XS_OPSIZE, /* 6675 */
  IC_XD_OPSIZE, /* 6676 */
  IC_64BIT_XD_OPSIZE, /* 6677 */
  IC_XS_OPSIZE, /* 6678 */
  IC_64BIT_XD_OPSIZE, /* 6679 */
  IC_OPSIZE, /* 6680 */
  IC_64BIT_REXW_OPSIZE, /* 6681 */
  IC_XS_OPSIZE, /* 6682 */
  IC_64BIT_REXW_XS, /* 6683 */
  IC_XD_OPSIZE, /* 6684 */
  IC_64BIT_REXW_XD, /* 6685 */
  IC_XS_OPSIZE, /* 6686 */
  IC_64BIT_REXW_XS, /* 6687 */
  IC_ADSIZE, /* 6688 */
  IC_64BIT_ADSIZE, /* 6689 */
  IC_XS, /* 6690 */
  IC_64BIT_XS, /* 6691 */
  IC_XD, /* 6692 */
  IC_64BIT_XD, /* 6693 */
  IC_XS, /* 6694 */
  IC_64BIT_XS, /* 6695 */
  IC_ADSIZE, /* 6696 */
  IC_64BIT_REXW_ADSIZE, /* 6697 */
  IC_XS, /* 6698 */
  IC_64BIT_REXW_XS, /* 6699 */
  IC_XD, /* 6700 */
  IC_64BIT_REXW_XD, /* 6701 */
  IC_XS, /* 6702 */
  IC_64BIT_REXW_XS, /* 6703 */
  IC_OPSIZE_ADSIZE, /* 6704 */
  IC_64BIT_OPSIZE_ADSIZE, /* 6705 */
  IC_XS_OPSIZE, /* 6706 */
  IC_64BIT_XS_OPSIZE, /* 6707 */
  IC_XD_OPSIZE, /* 6708 */
  IC_64BIT_XD_OPSIZE, /* 6709 */
  IC_XS_OPSIZE, /* 6710 */
  IC_64BIT_XD_OPSIZE, /* 6711 */
  IC_OPSIZE_ADSIZE, /* 6712 */
  IC_64BIT_REXW_OPSIZE, /* 6713 */
  IC_XS_OPSIZE, /* 6714 */
  IC_64BIT_REXW_XS, /* 6715 */
  IC_XD_OPSIZE, /* 6716 */
  IC_64BIT_REXW_XD, /* 6717 */
  IC_XS_OPSIZE, /* 6718 */
  IC_64BIT_REXW_XS, /* 6719 */
  IC_VEX, /* 6720 */
  IC_VEX, /* 6721 */
  IC_VEX_XS, /* 6722 */
  IC_VEX_XS, /* 6723 */
  IC_VEX_XD, /* 6724 */
  IC_VEX_XD, /* 6725 */
  IC_VEX_XD, /* 6726 */
  IC_VEX_XD, /* 6727 */
  IC_VEX_W, /* 6728 */
  IC_VEX_W, /* 6729 */
  IC_VEX_W_XS, /* 6730 */
  IC_VEX_W_XS, /* 6731 */
  IC_VEX_W_XD, /* 6732 */
  IC_VEX_W_XD, /* 6733 */
  IC_VEX_W_XD, /* 6734 */
  IC_VEX_W_XD, /* 6735 */
  IC_VEX_OPSIZE, /* 6736 */
  IC_VEX_OPSIZE, /* 6737 */
  IC_VEX_OPSIZE, /* 6738 */
  IC_VEX_OPSIZE, /* 6739 */
  IC_VEX_OPSIZE, /* 6740 */
  IC_VEX_OPSIZE, /* 6741 */
  IC_VEX_OPSIZE, /* 6742 */
  IC_VEX_OPSIZE, /* 6743 */
  IC_VEX_W_OPSIZE, /* 6744 */
  IC_VEX_W_OPSIZE, /* 6745 */
  IC_VEX_W_OPSIZE, /* 6746 */
  IC_VEX_W_OPSIZE, /* 6747 */
  IC_VEX_W_OPSIZE, /* 6748 */
  IC_VEX_W_OPSIZE, /* 6749 */
  IC_VEX_W_OPSIZE, /* 6750 */
  IC_VEX_W_OPSIZE, /* 6751 */
  IC_VEX, /* 6752 */
  IC_VEX, /* 6753 */
  IC_VEX_XS, /* 6754 */
  IC_VEX_XS, /* 6755 */
  IC_VEX_XD, /* 6756 */
  IC_VEX_XD, /* 6757 */
  IC_VEX_XD, /* 6758 */
  IC_VEX_XD, /* 6759 */
  IC_VEX_W, /* 6760 */
  IC_VEX_W, /* 6761 */
  IC_VEX_W_XS, /* 6762 */
  IC_VEX_W_XS, /* 6763 */
  IC_VEX_W_XD, /* 6764 */
  IC_VEX_W_XD, /* 6765 */
  IC_VEX_W_XD, /* 6766 */
  IC_VEX_W_XD, /* 6767 */
  IC_VEX_OPSIZE, /* 6768 */
  IC_VEX_OPSIZE, /* 6769 */
  IC_VEX_OPSIZE, /* 6770 */
  IC_VEX_OPSIZE, /* 6771 */
  IC_VEX_OPSIZE, /* 6772 */
  IC_VEX_OPSIZE, /* 6773 */
  IC_VEX_OPSIZE, /* 6774 */
  IC_VEX_OPSIZE, /* 6775 */
  IC_VEX_W_OPSIZE, /* 6776 */
  IC_VEX_W_OPSIZE, /* 6777 */
  IC_VEX_W_OPSIZE, /* 6778 */
  IC_VEX_W_OPSIZE, /* 6779 */
  IC_VEX_W_OPSIZE, /* 6780 */
  IC_VEX_W_OPSIZE, /* 6781 */
  IC_VEX_W_OPSIZE, /* 6782 */
  IC_VEX_W_OPSIZE, /* 6783 */
  IC_VEX_L, /* 6784 */
  IC_VEX_L, /* 6785 */
  IC_VEX_L_XS, /* 6786 */
  IC_VEX_L_XS, /* 6787 */
  IC_VEX_L_XD, /* 6788 */
  IC_VEX_L_XD, /* 6789 */
  IC_VEX_L_XD, /* 6790 */
  IC_VEX_L_XD, /* 6791 */
  IC_VEX_L_W, /* 6792 */
  IC_VEX_L_W, /* 6793 */
  IC_VEX_L_W_XS, /* 6794 */
  IC_VEX_L_W_XS, /* 6795 */
  IC_VEX_L_W_XD, /* 6796 */
  IC_VEX_L_W_XD, /* 6797 */
  IC_VEX_L_W_XD, /* 6798 */
  IC_VEX_L_W_XD, /* 6799 */
  IC_VEX_L_OPSIZE, /* 6800 */
  IC_VEX_L_OPSIZE, /* 6801 */
  IC_VEX_L_OPSIZE, /* 6802 */
  IC_VEX_L_OPSIZE, /* 6803 */
  IC_VEX_L_OPSIZE, /* 6804 */
  IC_VEX_L_OPSIZE, /* 6805 */
  IC_VEX_L_OPSIZE, /* 6806 */
  IC_VEX_L_OPSIZE, /* 6807 */
  IC_VEX_L_W_OPSIZE, /* 6808 */
  IC_VEX_L_W_OPSIZE, /* 6809 */
  IC_VEX_L_W_OPSIZE, /* 6810 */
  IC_VEX_L_W_OPSIZE, /* 6811 */
  IC_VEX_L_W_OPSIZE, /* 6812 */
  IC_VEX_L_W_OPSIZE, /* 6813 */
  IC_VEX_L_W_OPSIZE, /* 6814 */
  IC_VEX_L_W_OPSIZE, /* 6815 */
  IC_VEX_L, /* 6816 */
  IC_VEX_L, /* 6817 */
  IC_VEX_L_XS, /* 6818 */
  IC_VEX_L_XS, /* 6819 */
  IC_VEX_L_XD, /* 6820 */
  IC_VEX_L_XD, /* 6821 */
  IC_VEX_L_XD, /* 6822 */
  IC_VEX_L_XD, /* 6823 */
  IC_VEX_L_W, /* 6824 */
  IC_VEX_L_W, /* 6825 */
  IC_VEX_L_W_XS, /* 6826 */
  IC_VEX_L_W_XS, /* 6827 */
  IC_VEX_L_W_XD, /* 6828 */
  IC_VEX_L_W_XD, /* 6829 */
  IC_VEX_L_W_XD, /* 6830 */
  IC_VEX_L_W_XD, /* 6831 */
  IC_VEX_L_OPSIZE, /* 6832 */
  IC_VEX_L_OPSIZE, /* 6833 */
  IC_VEX_L_OPSIZE, /* 6834 */
  IC_VEX_L_OPSIZE, /* 6835 */
  IC_VEX_L_OPSIZE, /* 6836 */
  IC_VEX_L_OPSIZE, /* 6837 */
  IC_VEX_L_OPSIZE, /* 6838 */
  IC_VEX_L_OPSIZE, /* 6839 */
  IC_VEX_L_W_OPSIZE, /* 6840 */
  IC_VEX_L_W_OPSIZE, /* 6841 */
  IC_VEX_L_W_OPSIZE, /* 6842 */
  IC_VEX_L_W_OPSIZE, /* 6843 */
  IC_VEX_L_W_OPSIZE, /* 6844 */
  IC_VEX_L_W_OPSIZE, /* 6845 */
  IC_VEX_L_W_OPSIZE, /* 6846 */
  IC_VEX_L_W_OPSIZE, /* 6847 */
  IC_VEX_L, /* 6848 */
  IC_VEX_L, /* 6849 */
  IC_VEX_L_XS, /* 6850 */
  IC_VEX_L_XS, /* 6851 */
  IC_VEX_L_XD, /* 6852 */
  IC_VEX_L_XD, /* 6853 */
  IC_VEX_L_XD, /* 6854 */
  IC_VEX_L_XD, /* 6855 */
  IC_VEX_L_W, /* 6856 */
  IC_VEX_L_W, /* 6857 */
  IC_VEX_L_W_XS, /* 6858 */
  IC_VEX_L_W_XS, /* 6859 */
  IC_VEX_L_W_XD, /* 6860 */
  IC_VEX_L_W_XD, /* 6861 */
  IC_VEX_L_W_XD, /* 6862 */
  IC_VEX_L_W_XD, /* 6863 */
  IC_VEX_L_OPSIZE, /* 6864 */
  IC_VEX_L_OPSIZE, /* 6865 */
  IC_VEX_L_OPSIZE, /* 6866 */
  IC_VEX_L_OPSIZE, /* 6867 */
  IC_VEX_L_OPSIZE, /* 6868 */
  IC_VEX_L_OPSIZE, /* 6869 */
  IC_VEX_L_OPSIZE, /* 6870 */
  IC_VEX_L_OPSIZE, /* 6871 */
  IC_VEX_L_W_OPSIZE, /* 6872 */
  IC_VEX_L_W_OPSIZE, /* 6873 */
  IC_VEX_L_W_OPSIZE, /* 6874 */
  IC_VEX_L_W_OPSIZE, /* 6875 */
  IC_VEX_L_W_OPSIZE, /* 6876 */
  IC_VEX_L_W_OPSIZE, /* 6877 */
  IC_VEX_L_W_OPSIZE, /* 6878 */
  IC_VEX_L_W_OPSIZE, /* 6879 */
  IC_VEX_L, /* 6880 */
  IC_VEX_L, /* 6881 */
  IC_VEX_L_XS, /* 6882 */
  IC_VEX_L_XS, /* 6883 */
  IC_VEX_L_XD, /* 6884 */
  IC_VEX_L_XD, /* 6885 */
  IC_VEX_L_XD, /* 6886 */
  IC_VEX_L_XD, /* 6887 */
  IC_VEX_L_W, /* 6888 */
  IC_VEX_L_W, /* 6889 */
  IC_VEX_L_W_XS, /* 6890 */
  IC_VEX_L_W_XS, /* 6891 */
  IC_VEX_L_W_XD, /* 6892 */
  IC_VEX_L_W_XD, /* 6893 */
  IC_VEX_L_W_XD, /* 6894 */
  IC_VEX_L_W_XD, /* 6895 */
  IC_VEX_L_OPSIZE, /* 6896 */
  IC_VEX_L_OPSIZE, /* 6897 */
  IC_VEX_L_OPSIZE, /* 6898 */
  IC_VEX_L_OPSIZE, /* 6899 */
  IC_VEX_L_OPSIZE, /* 6900 */
  IC_VEX_L_OPSIZE, /* 6901 */
  IC_VEX_L_OPSIZE, /* 6902 */
  IC_VEX_L_OPSIZE, /* 6903 */
  IC_VEX_L_W_OPSIZE, /* 6904 */
  IC_VEX_L_W_OPSIZE, /* 6905 */
  IC_VEX_L_W_OPSIZE, /* 6906 */
  IC_VEX_L_W_OPSIZE, /* 6907 */
  IC_VEX_L_W_OPSIZE, /* 6908 */
  IC_VEX_L_W_OPSIZE, /* 6909 */
  IC_VEX_L_W_OPSIZE, /* 6910 */
  IC_VEX_L_W_OPSIZE, /* 6911 */
  IC_EVEX_L_KZ, /* 6912 */
  IC_EVEX_L_KZ, /* 6913 */
  IC_EVEX_L_XS_KZ, /* 6914 */
  IC_EVEX_L_XS_KZ, /* 6915 */
  IC_EVEX_L_XD_KZ, /* 6916 */
  IC_EVEX_L_XD_KZ, /* 6917 */
  IC_EVEX_L_XD_KZ, /* 6918 */
  IC_EVEX_L_XD_KZ, /* 6919 */
  IC_EVEX_L_W_KZ, /* 6920 */
  IC_EVEX_L_W_KZ, /* 6921 */
  IC_EVEX_L_W_XS_KZ, /* 6922 */
  IC_EVEX_L_W_XS_KZ, /* 6923 */
  IC_EVEX_L_W_XD_KZ, /* 6924 */
  IC_EVEX_L_W_XD_KZ, /* 6925 */
  IC_EVEX_L_W_XD_KZ, /* 6926 */
  IC_EVEX_L_W_XD_KZ, /* 6927 */
  IC_EVEX_L_OPSIZE_KZ, /* 6928 */
  IC_EVEX_L_OPSIZE_KZ, /* 6929 */
  IC_EVEX_L_OPSIZE_KZ, /* 6930 */
  IC_EVEX_L_OPSIZE_KZ, /* 6931 */
  IC_EVEX_L_OPSIZE_KZ, /* 6932 */
  IC_EVEX_L_OPSIZE_KZ, /* 6933 */
  IC_EVEX_L_OPSIZE_KZ, /* 6934 */
  IC_EVEX_L_OPSIZE_KZ, /* 6935 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6936 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6937 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6938 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6939 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6940 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6941 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6942 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6943 */
  IC_EVEX_L_KZ, /* 6944 */
  IC_EVEX_L_KZ, /* 6945 */
  IC_EVEX_L_XS_KZ, /* 6946 */
  IC_EVEX_L_XS_KZ, /* 6947 */
  IC_EVEX_L_XD_KZ, /* 6948 */
  IC_EVEX_L_XD_KZ, /* 6949 */
  IC_EVEX_L_XD_KZ, /* 6950 */
  IC_EVEX_L_XD_KZ, /* 6951 */
  IC_EVEX_L_W_KZ, /* 6952 */
  IC_EVEX_L_W_KZ, /* 6953 */
  IC_EVEX_L_W_XS_KZ, /* 6954 */
  IC_EVEX_L_W_XS_KZ, /* 6955 */
  IC_EVEX_L_W_XD_KZ, /* 6956 */
  IC_EVEX_L_W_XD_KZ, /* 6957 */
  IC_EVEX_L_W_XD_KZ, /* 6958 */
  IC_EVEX_L_W_XD_KZ, /* 6959 */
  IC_EVEX_L_OPSIZE_KZ, /* 6960 */
  IC_EVEX_L_OPSIZE_KZ, /* 6961 */
  IC_EVEX_L_OPSIZE_KZ, /* 6962 */
  IC_EVEX_L_OPSIZE_KZ, /* 6963 */
  IC_EVEX_L_OPSIZE_KZ, /* 6964 */
  IC_EVEX_L_OPSIZE_KZ, /* 6965 */
  IC_EVEX_L_OPSIZE_KZ, /* 6966 */
  IC_EVEX_L_OPSIZE_KZ, /* 6967 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6968 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6969 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6970 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6971 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6972 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6973 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6974 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 6975 */
  IC_EVEX_L_KZ, /* 6976 */
  IC_EVEX_L_KZ, /* 6977 */
  IC_EVEX_L_XS_KZ, /* 6978 */
  IC_EVEX_L_XS_KZ, /* 6979 */
  IC_EVEX_L_XD_KZ, /* 6980 */
  IC_EVEX_L_XD_KZ, /* 6981 */
  IC_EVEX_L_XD_KZ, /* 6982 */
  IC_EVEX_L_XD_KZ, /* 6983 */
  IC_EVEX_L_W_KZ, /* 6984 */
  IC_EVEX_L_W_KZ, /* 6985 */
  IC_EVEX_L_W_XS_KZ, /* 6986 */
  IC_EVEX_L_W_XS_KZ, /* 6987 */
  IC_EVEX_L_W_XD_KZ, /* 6988 */
  IC_EVEX_L_W_XD_KZ, /* 6989 */
  IC_EVEX_L_W_XD_KZ, /* 6990 */
  IC_EVEX_L_W_XD_KZ, /* 6991 */
  IC_EVEX_L_OPSIZE_KZ, /* 6992 */
  IC_EVEX_L_OPSIZE_KZ, /* 6993 */
  IC_EVEX_L_OPSIZE_KZ, /* 6994 */
  IC_EVEX_L_OPSIZE_KZ, /* 6995 */
  IC_EVEX_L_OPSIZE_KZ, /* 6996 */
  IC_EVEX_L_OPSIZE_KZ, /* 6997 */
  IC_EVEX_L_OPSIZE_KZ, /* 6998 */
  IC_EVEX_L_OPSIZE_KZ, /* 6999 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7000 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7001 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7002 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7003 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7004 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7005 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7006 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7007 */
  IC_EVEX_L_KZ, /* 7008 */
  IC_EVEX_L_KZ, /* 7009 */
  IC_EVEX_L_XS_KZ, /* 7010 */
  IC_EVEX_L_XS_KZ, /* 7011 */
  IC_EVEX_L_XD_KZ, /* 7012 */
  IC_EVEX_L_XD_KZ, /* 7013 */
  IC_EVEX_L_XD_KZ, /* 7014 */
  IC_EVEX_L_XD_KZ, /* 7015 */
  IC_EVEX_L_W_KZ, /* 7016 */
  IC_EVEX_L_W_KZ, /* 7017 */
  IC_EVEX_L_W_XS_KZ, /* 7018 */
  IC_EVEX_L_W_XS_KZ, /* 7019 */
  IC_EVEX_L_W_XD_KZ, /* 7020 */
  IC_EVEX_L_W_XD_KZ, /* 7021 */
  IC_EVEX_L_W_XD_KZ, /* 7022 */
  IC_EVEX_L_W_XD_KZ, /* 7023 */
  IC_EVEX_L_OPSIZE_KZ, /* 7024 */
  IC_EVEX_L_OPSIZE_KZ, /* 7025 */
  IC_EVEX_L_OPSIZE_KZ, /* 7026 */
  IC_EVEX_L_OPSIZE_KZ, /* 7027 */
  IC_EVEX_L_OPSIZE_KZ, /* 7028 */
  IC_EVEX_L_OPSIZE_KZ, /* 7029 */
  IC_EVEX_L_OPSIZE_KZ, /* 7030 */
  IC_EVEX_L_OPSIZE_KZ, /* 7031 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7032 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7033 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7034 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7035 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7036 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7037 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7038 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7039 */
  IC_EVEX_L_KZ, /* 7040 */
  IC_EVEX_L_KZ, /* 7041 */
  IC_EVEX_L_XS_KZ, /* 7042 */
  IC_EVEX_L_XS_KZ, /* 7043 */
  IC_EVEX_L_XD_KZ, /* 7044 */
  IC_EVEX_L_XD_KZ, /* 7045 */
  IC_EVEX_L_XD_KZ, /* 7046 */
  IC_EVEX_L_XD_KZ, /* 7047 */
  IC_EVEX_L_W_KZ, /* 7048 */
  IC_EVEX_L_W_KZ, /* 7049 */
  IC_EVEX_L_W_XS_KZ, /* 7050 */
  IC_EVEX_L_W_XS_KZ, /* 7051 */
  IC_EVEX_L_W_XD_KZ, /* 7052 */
  IC_EVEX_L_W_XD_KZ, /* 7053 */
  IC_EVEX_L_W_XD_KZ, /* 7054 */
  IC_EVEX_L_W_XD_KZ, /* 7055 */
  IC_EVEX_L_OPSIZE_KZ, /* 7056 */
  IC_EVEX_L_OPSIZE_KZ, /* 7057 */
  IC_EVEX_L_OPSIZE_KZ, /* 7058 */
  IC_EVEX_L_OPSIZE_KZ, /* 7059 */
  IC_EVEX_L_OPSIZE_KZ, /* 7060 */
  IC_EVEX_L_OPSIZE_KZ, /* 7061 */
  IC_EVEX_L_OPSIZE_KZ, /* 7062 */
  IC_EVEX_L_OPSIZE_KZ, /* 7063 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7064 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7065 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7066 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7067 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7068 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7069 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7070 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7071 */
  IC_EVEX_L_KZ, /* 7072 */
  IC_EVEX_L_KZ, /* 7073 */
  IC_EVEX_L_XS_KZ, /* 7074 */
  IC_EVEX_L_XS_KZ, /* 7075 */
  IC_EVEX_L_XD_KZ, /* 7076 */
  IC_EVEX_L_XD_KZ, /* 7077 */
  IC_EVEX_L_XD_KZ, /* 7078 */
  IC_EVEX_L_XD_KZ, /* 7079 */
  IC_EVEX_L_W_KZ, /* 7080 */
  IC_EVEX_L_W_KZ, /* 7081 */
  IC_EVEX_L_W_XS_KZ, /* 7082 */
  IC_EVEX_L_W_XS_KZ, /* 7083 */
  IC_EVEX_L_W_XD_KZ, /* 7084 */
  IC_EVEX_L_W_XD_KZ, /* 7085 */
  IC_EVEX_L_W_XD_KZ, /* 7086 */
  IC_EVEX_L_W_XD_KZ, /* 7087 */
  IC_EVEX_L_OPSIZE_KZ, /* 7088 */
  IC_EVEX_L_OPSIZE_KZ, /* 7089 */
  IC_EVEX_L_OPSIZE_KZ, /* 7090 */
  IC_EVEX_L_OPSIZE_KZ, /* 7091 */
  IC_EVEX_L_OPSIZE_KZ, /* 7092 */
  IC_EVEX_L_OPSIZE_KZ, /* 7093 */
  IC_EVEX_L_OPSIZE_KZ, /* 7094 */
  IC_EVEX_L_OPSIZE_KZ, /* 7095 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7096 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7097 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7098 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7099 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7100 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7101 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7102 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7103 */
  IC_EVEX_L_KZ, /* 7104 */
  IC_EVEX_L_KZ, /* 7105 */
  IC_EVEX_L_XS_KZ, /* 7106 */
  IC_EVEX_L_XS_KZ, /* 7107 */
  IC_EVEX_L_XD_KZ, /* 7108 */
  IC_EVEX_L_XD_KZ, /* 7109 */
  IC_EVEX_L_XD_KZ, /* 7110 */
  IC_EVEX_L_XD_KZ, /* 7111 */
  IC_EVEX_L_W_KZ, /* 7112 */
  IC_EVEX_L_W_KZ, /* 7113 */
  IC_EVEX_L_W_XS_KZ, /* 7114 */
  IC_EVEX_L_W_XS_KZ, /* 7115 */
  IC_EVEX_L_W_XD_KZ, /* 7116 */
  IC_EVEX_L_W_XD_KZ, /* 7117 */
  IC_EVEX_L_W_XD_KZ, /* 7118 */
  IC_EVEX_L_W_XD_KZ, /* 7119 */
  IC_EVEX_L_OPSIZE_KZ, /* 7120 */
  IC_EVEX_L_OPSIZE_KZ, /* 7121 */
  IC_EVEX_L_OPSIZE_KZ, /* 7122 */
  IC_EVEX_L_OPSIZE_KZ, /* 7123 */
  IC_EVEX_L_OPSIZE_KZ, /* 7124 */
  IC_EVEX_L_OPSIZE_KZ, /* 7125 */
  IC_EVEX_L_OPSIZE_KZ, /* 7126 */
  IC_EVEX_L_OPSIZE_KZ, /* 7127 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7128 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7129 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7130 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7131 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7132 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7133 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7134 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7135 */
  IC_EVEX_L_KZ, /* 7136 */
  IC_EVEX_L_KZ, /* 7137 */
  IC_EVEX_L_XS_KZ, /* 7138 */
  IC_EVEX_L_XS_KZ, /* 7139 */
  IC_EVEX_L_XD_KZ, /* 7140 */
  IC_EVEX_L_XD_KZ, /* 7141 */
  IC_EVEX_L_XD_KZ, /* 7142 */
  IC_EVEX_L_XD_KZ, /* 7143 */
  IC_EVEX_L_W_KZ, /* 7144 */
  IC_EVEX_L_W_KZ, /* 7145 */
  IC_EVEX_L_W_XS_KZ, /* 7146 */
  IC_EVEX_L_W_XS_KZ, /* 7147 */
  IC_EVEX_L_W_XD_KZ, /* 7148 */
  IC_EVEX_L_W_XD_KZ, /* 7149 */
  IC_EVEX_L_W_XD_KZ, /* 7150 */
  IC_EVEX_L_W_XD_KZ, /* 7151 */
  IC_EVEX_L_OPSIZE_KZ, /* 7152 */
  IC_EVEX_L_OPSIZE_KZ, /* 7153 */
  IC_EVEX_L_OPSIZE_KZ, /* 7154 */
  IC_EVEX_L_OPSIZE_KZ, /* 7155 */
  IC_EVEX_L_OPSIZE_KZ, /* 7156 */
  IC_EVEX_L_OPSIZE_KZ, /* 7157 */
  IC_EVEX_L_OPSIZE_KZ, /* 7158 */
  IC_EVEX_L_OPSIZE_KZ, /* 7159 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7160 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7161 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7162 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7163 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7164 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7165 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7166 */
  IC_EVEX_L_W_OPSIZE_KZ, /* 7167 */
  IC, /* 7168 */
  IC_64BIT, /* 7169 */
  IC_XS, /* 7170 */
  IC_64BIT_XS, /* 7171 */
  IC_XD, /* 7172 */
  IC_64BIT_XD, /* 7173 */
  IC_XS, /* 7174 */
  IC_64BIT_XS, /* 7175 */
  IC, /* 7176 */
  IC_64BIT_REXW, /* 7177 */
  IC_XS, /* 7178 */
  IC_64BIT_REXW_XS, /* 7179 */
  IC_XD, /* 7180 */
  IC_64BIT_REXW_XD, /* 7181 */
  IC_XS, /* 7182 */
  IC_64BIT_REXW_XS, /* 7183 */
  IC_OPSIZE, /* 7184 */
  IC_64BIT_OPSIZE, /* 7185 */
  IC_XS_OPSIZE, /* 7186 */
  IC_64BIT_XS_OPSIZE, /* 7187 */
  IC_XD_OPSIZE, /* 7188 */
  IC_64BIT_XD_OPSIZE, /* 7189 */
  IC_XS_OPSIZE, /* 7190 */
  IC_64BIT_XD_OPSIZE, /* 7191 */
  IC_OPSIZE, /* 7192 */
  IC_64BIT_REXW_OPSIZE, /* 7193 */
  IC_XS_OPSIZE, /* 7194 */
  IC_64BIT_REXW_XS, /* 7195 */
  IC_XD_OPSIZE, /* 7196 */
  IC_64BIT_REXW_XD, /* 7197 */
  IC_XS_OPSIZE, /* 7198 */
  IC_64BIT_REXW_XS, /* 7199 */
  IC_ADSIZE, /* 7200 */
  IC_64BIT_ADSIZE, /* 7201 */
  IC_XS, /* 7202 */
  IC_64BIT_XS, /* 7203 */
  IC_XD, /* 7204 */
  IC_64BIT_XD, /* 7205 */
  IC_XS, /* 7206 */
  IC_64BIT_XS, /* 7207 */
  IC_ADSIZE, /* 7208 */
  IC_64BIT_REXW_ADSIZE, /* 7209 */
  IC_XS, /* 7210 */
  IC_64BIT_REXW_XS, /* 7211 */
  IC_XD, /* 7212 */
  IC_64BIT_REXW_XD, /* 7213 */
  IC_XS, /* 7214 */
  IC_64BIT_REXW_XS, /* 7215 */
  IC_OPSIZE_ADSIZE, /* 7216 */
  IC_64BIT_OPSIZE_ADSIZE, /* 7217 */
  IC_XS_OPSIZE, /* 7218 */
  IC_64BIT_XS_OPSIZE, /* 7219 */
  IC_XD_OPSIZE, /* 7220 */
  IC_64BIT_XD_OPSIZE, /* 7221 */
  IC_XS_OPSIZE, /* 7222 */
  IC_64BIT_XD_OPSIZE, /* 7223 */
  IC_OPSIZE_ADSIZE, /* 7224 */
  IC_64BIT_REXW_OPSIZE, /* 7225 */
  IC_XS_OPSIZE, /* 7226 */
  IC_64BIT_REXW_XS, /* 7227 */
  IC_XD_OPSIZE, /* 7228 */
  IC_64BIT_REXW_XD, /* 7229 */
  IC_XS_OPSIZE, /* 7230 */
  IC_64BIT_REXW_XS, /* 7231 */
  IC_VEX, /* 7232 */
  IC_VEX, /* 7233 */
  IC_VEX_XS, /* 7234 */
  IC_VEX_XS, /* 7235 */
  IC_VEX_XD, /* 7236 */
  IC_VEX_XD, /* 7237 */
  IC_VEX_XD, /* 7238 */
  IC_VEX_XD, /* 7239 */
  IC_VEX_W, /* 7240 */
  IC_VEX_W, /* 7241 */
  IC_VEX_W_XS, /* 7242 */
  IC_VEX_W_XS, /* 7243 */
  IC_VEX_W_XD, /* 7244 */
  IC_VEX_W_XD, /* 7245 */
  IC_VEX_W_XD, /* 7246 */
  IC_VEX_W_XD, /* 7247 */
  IC_VEX_OPSIZE, /* 7248 */
  IC_VEX_OPSIZE, /* 7249 */
  IC_VEX_OPSIZE, /* 7250 */
  IC_VEX_OPSIZE, /* 7251 */
  IC_VEX_OPSIZE, /* 7252 */
  IC_VEX_OPSIZE, /* 7253 */
  IC_VEX_OPSIZE, /* 7254 */
  IC_VEX_OPSIZE, /* 7255 */
  IC_VEX_W_OPSIZE, /* 7256 */
  IC_VEX_W_OPSIZE, /* 7257 */
  IC_VEX_W_OPSIZE, /* 7258 */
  IC_VEX_W_OPSIZE, /* 7259 */
  IC_VEX_W_OPSIZE, /* 7260 */
  IC_VEX_W_OPSIZE, /* 7261 */
  IC_VEX_W_OPSIZE, /* 7262 */
  IC_VEX_W_OPSIZE, /* 7263 */
  IC_VEX, /* 7264 */
  IC_VEX, /* 7265 */
  IC_VEX_XS, /* 7266 */
  IC_VEX_XS, /* 7267 */
  IC_VEX_XD, /* 7268 */
  IC_VEX_XD, /* 7269 */
  IC_VEX_XD, /* 7270 */
  IC_VEX_XD, /* 7271 */
  IC_VEX_W, /* 7272 */
  IC_VEX_W, /* 7273 */
  IC_VEX_W_XS, /* 7274 */
  IC_VEX_W_XS, /* 7275 */
  IC_VEX_W_XD, /* 7276 */
  IC_VEX_W_XD, /* 7277 */
  IC_VEX_W_XD, /* 7278 */
  IC_VEX_W_XD, /* 7279 */
  IC_VEX_OPSIZE, /* 7280 */
  IC_VEX_OPSIZE, /* 7281 */
  IC_VEX_OPSIZE, /* 7282 */
  IC_VEX_OPSIZE, /* 7283 */
  IC_VEX_OPSIZE, /* 7284 */
  IC_VEX_OPSIZE, /* 7285 */
  IC_VEX_OPSIZE, /* 7286 */
  IC_VEX_OPSIZE, /* 7287 */
  IC_VEX_W_OPSIZE, /* 7288 */
  IC_VEX_W_OPSIZE, /* 7289 */
  IC_VEX_W_OPSIZE, /* 7290 */
  IC_VEX_W_OPSIZE, /* 7291 */
  IC_VEX_W_OPSIZE, /* 7292 */
  IC_VEX_W_OPSIZE, /* 7293 */
  IC_VEX_W_OPSIZE, /* 7294 */
  IC_VEX_W_OPSIZE, /* 7295 */
  IC_VEX_L, /* 7296 */
  IC_VEX_L, /* 7297 */
  IC_VEX_L_XS, /* 7298 */
  IC_VEX_L_XS, /* 7299 */
  IC_VEX_L_XD, /* 7300 */
  IC_VEX_L_XD, /* 7301 */
  IC_VEX_L_XD, /* 7302 */
  IC_VEX_L_XD, /* 7303 */
  IC_VEX_L_W, /* 7304 */
  IC_VEX_L_W, /* 7305 */
  IC_VEX_L_W_XS, /* 7306 */
  IC_VEX_L_W_XS, /* 7307 */
  IC_VEX_L_W_XD, /* 7308 */
  IC_VEX_L_W_XD, /* 7309 */
  IC_VEX_L_W_XD, /* 7310 */
  IC_VEX_L_W_XD, /* 7311 */
  IC_VEX_L_OPSIZE, /* 7312 */
  IC_VEX_L_OPSIZE, /* 7313 */
  IC_VEX_L_OPSIZE, /* 7314 */
  IC_VEX_L_OPSIZE, /* 7315 */
  IC_VEX_L_OPSIZE, /* 7316 */
  IC_VEX_L_OPSIZE, /* 7317 */
  IC_VEX_L_OPSIZE, /* 7318 */
  IC_VEX_L_OPSIZE, /* 7319 */
  IC_VEX_L_W_OPSIZE, /* 7320 */
  IC_VEX_L_W_OPSIZE, /* 7321 */
  IC_VEX_L_W_OPSIZE, /* 7322 */
  IC_VEX_L_W_OPSIZE, /* 7323 */
  IC_VEX_L_W_OPSIZE, /* 7324 */
  IC_VEX_L_W_OPSIZE, /* 7325 */
  IC_VEX_L_W_OPSIZE, /* 7326 */
  IC_VEX_L_W_OPSIZE, /* 7327 */
  IC_VEX_L, /* 7328 */
  IC_VEX_L, /* 7329 */
  IC_VEX_L_XS, /* 7330 */
  IC_VEX_L_XS, /* 7331 */
  IC_VEX_L_XD, /* 7332 */
  IC_VEX_L_XD, /* 7333 */
  IC_VEX_L_XD, /* 7334 */
  IC_VEX_L_XD, /* 7335 */
  IC_VEX_L_W, /* 7336 */
  IC_VEX_L_W, /* 7337 */
  IC_VEX_L_W_XS, /* 7338 */
  IC_VEX_L_W_XS, /* 7339 */
  IC_VEX_L_W_XD, /* 7340 */
  IC_VEX_L_W_XD, /* 7341 */
  IC_VEX_L_W_XD, /* 7342 */
  IC_VEX_L_W_XD, /* 7343 */
  IC_VEX_L_OPSIZE, /* 7344 */
  IC_VEX_L_OPSIZE, /* 7345 */
  IC_VEX_L_OPSIZE, /* 7346 */
  IC_VEX_L_OPSIZE, /* 7347 */
  IC_VEX_L_OPSIZE, /* 7348 */
  IC_VEX_L_OPSIZE, /* 7349 */
  IC_VEX_L_OPSIZE, /* 7350 */
  IC_VEX_L_OPSIZE, /* 7351 */
  IC_VEX_L_W_OPSIZE, /* 7352 */
  IC_VEX_L_W_OPSIZE, /* 7353 */
  IC_VEX_L_W_OPSIZE, /* 7354 */
  IC_VEX_L_W_OPSIZE, /* 7355 */
  IC_VEX_L_W_OPSIZE, /* 7356 */
  IC_VEX_L_W_OPSIZE, /* 7357 */
  IC_VEX_L_W_OPSIZE, /* 7358 */
  IC_VEX_L_W_OPSIZE, /* 7359 */
  IC_VEX_L, /* 7360 */
  IC_VEX_L, /* 7361 */
  IC_VEX_L_XS, /* 7362 */
  IC_VEX_L_XS, /* 7363 */
  IC_VEX_L_XD, /* 7364 */
  IC_VEX_L_XD, /* 7365 */
  IC_VEX_L_XD, /* 7366 */
  IC_VEX_L_XD, /* 7367 */
  IC_VEX_L_W, /* 7368 */
  IC_VEX_L_W, /* 7369 */
  IC_VEX_L_W_XS, /* 7370 */
  IC_VEX_L_W_XS, /* 7371 */
  IC_VEX_L_W_XD, /* 7372 */
  IC_VEX_L_W_XD, /* 7373 */
  IC_VEX_L_W_XD, /* 7374 */
  IC_VEX_L_W_XD, /* 7375 */
  IC_VEX_L_OPSIZE, /* 7376 */
  IC_VEX_L_OPSIZE, /* 7377 */
  IC_VEX_L_OPSIZE, /* 7378 */
  IC_VEX_L_OPSIZE, /* 7379 */
  IC_VEX_L_OPSIZE, /* 7380 */
  IC_VEX_L_OPSIZE, /* 7381 */
  IC_VEX_L_OPSIZE, /* 7382 */
  IC_VEX_L_OPSIZE, /* 7383 */
  IC_VEX_L_W_OPSIZE, /* 7384 */
  IC_VEX_L_W_OPSIZE, /* 7385 */
  IC_VEX_L_W_OPSIZE, /* 7386 */
  IC_VEX_L_W_OPSIZE, /* 7387 */
  IC_VEX_L_W_OPSIZE, /* 7388 */
  IC_VEX_L_W_OPSIZE, /* 7389 */
  IC_VEX_L_W_OPSIZE, /* 7390 */
  IC_VEX_L_W_OPSIZE, /* 7391 */
  IC_VEX_L, /* 7392 */
  IC_VEX_L, /* 7393 */
  IC_VEX_L_XS, /* 7394 */
  IC_VEX_L_XS, /* 7395 */
  IC_VEX_L_XD, /* 7396 */
  IC_VEX_L_XD, /* 7397 */
  IC_VEX_L_XD, /* 7398 */
  IC_VEX_L_XD, /* 7399 */
  IC_VEX_L_W, /* 7400 */
  IC_VEX_L_W, /* 7401 */
  IC_VEX_L_W_XS, /* 7402 */
  IC_VEX_L_W_XS, /* 7403 */
  IC_VEX_L_W_XD, /* 7404 */
  IC_VEX_L_W_XD, /* 7405 */
  IC_VEX_L_W_XD, /* 7406 */
  IC_VEX_L_W_XD, /* 7407 */
  IC_VEX_L_OPSIZE, /* 7408 */
  IC_VEX_L_OPSIZE, /* 7409 */
  IC_VEX_L_OPSIZE, /* 7410 */
  IC_VEX_L_OPSIZE, /* 7411 */
  IC_VEX_L_OPSIZE, /* 7412 */
  IC_VEX_L_OPSIZE, /* 7413 */
  IC_VEX_L_OPSIZE, /* 7414 */
  IC_VEX_L_OPSIZE, /* 7415 */
  IC_VEX_L_W_OPSIZE, /* 7416 */
  IC_VEX_L_W_OPSIZE, /* 7417 */
  IC_VEX_L_W_OPSIZE, /* 7418 */
  IC_VEX_L_W_OPSIZE, /* 7419 */
  IC_VEX_L_W_OPSIZE, /* 7420 */
  IC_VEX_L_W_OPSIZE, /* 7421 */
  IC_VEX_L_W_OPSIZE, /* 7422 */
  IC_VEX_L_W_OPSIZE, /* 7423 */
  IC_EVEX_L2_KZ, /* 7424 */
  IC_EVEX_L2_KZ, /* 7425 */
  IC_EVEX_L2_XS_KZ, /* 7426 */
  IC_EVEX_L2_XS_KZ, /* 7427 */
  IC_EVEX_L2_XD_KZ, /* 7428 */
  IC_EVEX_L2_XD_KZ, /* 7429 */
  IC_EVEX_L2_XD_KZ, /* 7430 */
  IC_EVEX_L2_XD_KZ, /* 7431 */
  IC_EVEX_L2_W_KZ, /* 7432 */
  IC_EVEX_L2_W_KZ, /* 7433 */
  IC_EVEX_L2_W_XS_KZ, /* 7434 */
  IC_EVEX_L2_W_XS_KZ, /* 7435 */
  IC_EVEX_L2_W_XD_KZ, /* 7436 */
  IC_EVEX_L2_W_XD_KZ, /* 7437 */
  IC_EVEX_L2_W_XD_KZ, /* 7438 */
  IC_EVEX_L2_W_XD_KZ, /* 7439 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7440 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7441 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7442 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7443 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7444 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7445 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7446 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7447 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7448 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7449 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7450 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7451 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7452 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7453 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7454 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7455 */
  IC_EVEX_L2_KZ, /* 7456 */
  IC_EVEX_L2_KZ, /* 7457 */
  IC_EVEX_L2_XS_KZ, /* 7458 */
  IC_EVEX_L2_XS_KZ, /* 7459 */
  IC_EVEX_L2_XD_KZ, /* 7460 */
  IC_EVEX_L2_XD_KZ, /* 7461 */
  IC_EVEX_L2_XD_KZ, /* 7462 */
  IC_EVEX_L2_XD_KZ, /* 7463 */
  IC_EVEX_L2_W_KZ, /* 7464 */
  IC_EVEX_L2_W_KZ, /* 7465 */
  IC_EVEX_L2_W_XS_KZ, /* 7466 */
  IC_EVEX_L2_W_XS_KZ, /* 7467 */
  IC_EVEX_L2_W_XD_KZ, /* 7468 */
  IC_EVEX_L2_W_XD_KZ, /* 7469 */
  IC_EVEX_L2_W_XD_KZ, /* 7470 */
  IC_EVEX_L2_W_XD_KZ, /* 7471 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7472 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7473 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7474 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7475 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7476 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7477 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7478 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7479 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7480 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7481 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7482 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7483 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7484 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7485 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7486 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7487 */
  IC_EVEX_L2_KZ, /* 7488 */
  IC_EVEX_L2_KZ, /* 7489 */
  IC_EVEX_L2_XS_KZ, /* 7490 */
  IC_EVEX_L2_XS_KZ, /* 7491 */
  IC_EVEX_L2_XD_KZ, /* 7492 */
  IC_EVEX_L2_XD_KZ, /* 7493 */
  IC_EVEX_L2_XD_KZ, /* 7494 */
  IC_EVEX_L2_XD_KZ, /* 7495 */
  IC_EVEX_L2_W_KZ, /* 7496 */
  IC_EVEX_L2_W_KZ, /* 7497 */
  IC_EVEX_L2_W_XS_KZ, /* 7498 */
  IC_EVEX_L2_W_XS_KZ, /* 7499 */
  IC_EVEX_L2_W_XD_KZ, /* 7500 */
  IC_EVEX_L2_W_XD_KZ, /* 7501 */
  IC_EVEX_L2_W_XD_KZ, /* 7502 */
  IC_EVEX_L2_W_XD_KZ, /* 7503 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7504 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7505 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7506 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7507 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7508 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7509 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7510 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7511 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7512 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7513 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7514 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7515 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7516 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7517 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7518 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7519 */
  IC_EVEX_L2_KZ, /* 7520 */
  IC_EVEX_L2_KZ, /* 7521 */
  IC_EVEX_L2_XS_KZ, /* 7522 */
  IC_EVEX_L2_XS_KZ, /* 7523 */
  IC_EVEX_L2_XD_KZ, /* 7524 */
  IC_EVEX_L2_XD_KZ, /* 7525 */
  IC_EVEX_L2_XD_KZ, /* 7526 */
  IC_EVEX_L2_XD_KZ, /* 7527 */
  IC_EVEX_L2_W_KZ, /* 7528 */
  IC_EVEX_L2_W_KZ, /* 7529 */
  IC_EVEX_L2_W_XS_KZ, /* 7530 */
  IC_EVEX_L2_W_XS_KZ, /* 7531 */
  IC_EVEX_L2_W_XD_KZ, /* 7532 */
  IC_EVEX_L2_W_XD_KZ, /* 7533 */
  IC_EVEX_L2_W_XD_KZ, /* 7534 */
  IC_EVEX_L2_W_XD_KZ, /* 7535 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7536 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7537 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7538 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7539 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7540 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7541 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7542 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7543 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7544 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7545 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7546 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7547 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7548 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7549 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7550 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7551 */
  IC_EVEX_L2_KZ, /* 7552 */
  IC_EVEX_L2_KZ, /* 7553 */
  IC_EVEX_L2_XS_KZ, /* 7554 */
  IC_EVEX_L2_XS_KZ, /* 7555 */
  IC_EVEX_L2_XD_KZ, /* 7556 */
  IC_EVEX_L2_XD_KZ, /* 7557 */
  IC_EVEX_L2_XD_KZ, /* 7558 */
  IC_EVEX_L2_XD_KZ, /* 7559 */
  IC_EVEX_L2_W_KZ, /* 7560 */
  IC_EVEX_L2_W_KZ, /* 7561 */
  IC_EVEX_L2_W_XS_KZ, /* 7562 */
  IC_EVEX_L2_W_XS_KZ, /* 7563 */
  IC_EVEX_L2_W_XD_KZ, /* 7564 */
  IC_EVEX_L2_W_XD_KZ, /* 7565 */
  IC_EVEX_L2_W_XD_KZ, /* 7566 */
  IC_EVEX_L2_W_XD_KZ, /* 7567 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7568 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7569 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7570 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7571 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7572 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7573 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7574 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7575 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7576 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7577 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7578 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7579 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7580 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7581 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7582 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7583 */
  IC_EVEX_L2_KZ, /* 7584 */
  IC_EVEX_L2_KZ, /* 7585 */
  IC_EVEX_L2_XS_KZ, /* 7586 */
  IC_EVEX_L2_XS_KZ, /* 7587 */
  IC_EVEX_L2_XD_KZ, /* 7588 */
  IC_EVEX_L2_XD_KZ, /* 7589 */
  IC_EVEX_L2_XD_KZ, /* 7590 */
  IC_EVEX_L2_XD_KZ, /* 7591 */
  IC_EVEX_L2_W_KZ, /* 7592 */
  IC_EVEX_L2_W_KZ, /* 7593 */
  IC_EVEX_L2_W_XS_KZ, /* 7594 */
  IC_EVEX_L2_W_XS_KZ, /* 7595 */
  IC_EVEX_L2_W_XD_KZ, /* 7596 */
  IC_EVEX_L2_W_XD_KZ, /* 7597 */
  IC_EVEX_L2_W_XD_KZ, /* 7598 */
  IC_EVEX_L2_W_XD_KZ, /* 7599 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7600 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7601 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7602 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7603 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7604 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7605 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7606 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7607 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7608 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7609 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7610 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7611 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7612 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7613 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7614 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7615 */
  IC_EVEX_L2_KZ, /* 7616 */
  IC_EVEX_L2_KZ, /* 7617 */
  IC_EVEX_L2_XS_KZ, /* 7618 */
  IC_EVEX_L2_XS_KZ, /* 7619 */
  IC_EVEX_L2_XD_KZ, /* 7620 */
  IC_EVEX_L2_XD_KZ, /* 7621 */
  IC_EVEX_L2_XD_KZ, /* 7622 */
  IC_EVEX_L2_XD_KZ, /* 7623 */
  IC_EVEX_L2_W_KZ, /* 7624 */
  IC_EVEX_L2_W_KZ, /* 7625 */
  IC_EVEX_L2_W_XS_KZ, /* 7626 */
  IC_EVEX_L2_W_XS_KZ, /* 7627 */
  IC_EVEX_L2_W_XD_KZ, /* 7628 */
  IC_EVEX_L2_W_XD_KZ, /* 7629 */
  IC_EVEX_L2_W_XD_KZ, /* 7630 */
  IC_EVEX_L2_W_XD_KZ, /* 7631 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7632 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7633 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7634 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7635 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7636 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7637 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7638 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7639 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7640 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7641 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7642 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7643 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7644 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7645 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7646 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7647 */
  IC_EVEX_L2_KZ, /* 7648 */
  IC_EVEX_L2_KZ, /* 7649 */
  IC_EVEX_L2_XS_KZ, /* 7650 */
  IC_EVEX_L2_XS_KZ, /* 7651 */
  IC_EVEX_L2_XD_KZ, /* 7652 */
  IC_EVEX_L2_XD_KZ, /* 7653 */
  IC_EVEX_L2_XD_KZ, /* 7654 */
  IC_EVEX_L2_XD_KZ, /* 7655 */
  IC_EVEX_L2_W_KZ, /* 7656 */
  IC_EVEX_L2_W_KZ, /* 7657 */
  IC_EVEX_L2_W_XS_KZ, /* 7658 */
  IC_EVEX_L2_W_XS_KZ, /* 7659 */
  IC_EVEX_L2_W_XD_KZ, /* 7660 */
  IC_EVEX_L2_W_XD_KZ, /* 7661 */
  IC_EVEX_L2_W_XD_KZ, /* 7662 */
  IC_EVEX_L2_W_XD_KZ, /* 7663 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7664 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7665 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7666 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7667 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7668 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7669 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7670 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7671 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7672 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7673 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7674 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7675 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7676 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7677 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7678 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7679 */
  IC, /* 7680 */
  IC_64BIT, /* 7681 */
  IC_XS, /* 7682 */
  IC_64BIT_XS, /* 7683 */
  IC_XD, /* 7684 */
  IC_64BIT_XD, /* 7685 */
  IC_XS, /* 7686 */
  IC_64BIT_XS, /* 7687 */
  IC, /* 7688 */
  IC_64BIT_REXW, /* 7689 */
  IC_XS, /* 7690 */
  IC_64BIT_REXW_XS, /* 7691 */
  IC_XD, /* 7692 */
  IC_64BIT_REXW_XD, /* 7693 */
  IC_XS, /* 7694 */
  IC_64BIT_REXW_XS, /* 7695 */
  IC_OPSIZE, /* 7696 */
  IC_64BIT_OPSIZE, /* 7697 */
  IC_XS_OPSIZE, /* 7698 */
  IC_64BIT_XS_OPSIZE, /* 7699 */
  IC_XD_OPSIZE, /* 7700 */
  IC_64BIT_XD_OPSIZE, /* 7701 */
  IC_XS_OPSIZE, /* 7702 */
  IC_64BIT_XD_OPSIZE, /* 7703 */
  IC_OPSIZE, /* 7704 */
  IC_64BIT_REXW_OPSIZE, /* 7705 */
  IC_XS_OPSIZE, /* 7706 */
  IC_64BIT_REXW_XS, /* 7707 */
  IC_XD_OPSIZE, /* 7708 */
  IC_64BIT_REXW_XD, /* 7709 */
  IC_XS_OPSIZE, /* 7710 */
  IC_64BIT_REXW_XS, /* 7711 */
  IC_ADSIZE, /* 7712 */
  IC_64BIT_ADSIZE, /* 7713 */
  IC_XS, /* 7714 */
  IC_64BIT_XS, /* 7715 */
  IC_XD, /* 7716 */
  IC_64BIT_XD, /* 7717 */
  IC_XS, /* 7718 */
  IC_64BIT_XS, /* 7719 */
  IC_ADSIZE, /* 7720 */
  IC_64BIT_REXW_ADSIZE, /* 7721 */
  IC_XS, /* 7722 */
  IC_64BIT_REXW_XS, /* 7723 */
  IC_XD, /* 7724 */
  IC_64BIT_REXW_XD, /* 7725 */
  IC_XS, /* 7726 */
  IC_64BIT_REXW_XS, /* 7727 */
  IC_OPSIZE_ADSIZE, /* 7728 */
  IC_64BIT_OPSIZE_ADSIZE, /* 7729 */
  IC_XS_OPSIZE, /* 7730 */
  IC_64BIT_XS_OPSIZE, /* 7731 */
  IC_XD_OPSIZE, /* 7732 */
  IC_64BIT_XD_OPSIZE, /* 7733 */
  IC_XS_OPSIZE, /* 7734 */
  IC_64BIT_XD_OPSIZE, /* 7735 */
  IC_OPSIZE_ADSIZE, /* 7736 */
  IC_64BIT_REXW_OPSIZE, /* 7737 */
  IC_XS_OPSIZE, /* 7738 */
  IC_64BIT_REXW_XS, /* 7739 */
  IC_XD_OPSIZE, /* 7740 */
  IC_64BIT_REXW_XD, /* 7741 */
  IC_XS_OPSIZE, /* 7742 */
  IC_64BIT_REXW_XS, /* 7743 */
  IC_VEX, /* 7744 */
  IC_VEX, /* 7745 */
  IC_VEX_XS, /* 7746 */
  IC_VEX_XS, /* 7747 */
  IC_VEX_XD, /* 7748 */
  IC_VEX_XD, /* 7749 */
  IC_VEX_XD, /* 7750 */
  IC_VEX_XD, /* 7751 */
  IC_VEX_W, /* 7752 */
  IC_VEX_W, /* 7753 */
  IC_VEX_W_XS, /* 7754 */
  IC_VEX_W_XS, /* 7755 */
  IC_VEX_W_XD, /* 7756 */
  IC_VEX_W_XD, /* 7757 */
  IC_VEX_W_XD, /* 7758 */
  IC_VEX_W_XD, /* 7759 */
  IC_VEX_OPSIZE, /* 7760 */
  IC_VEX_OPSIZE, /* 7761 */
  IC_VEX_OPSIZE, /* 7762 */
  IC_VEX_OPSIZE, /* 7763 */
  IC_VEX_OPSIZE, /* 7764 */
  IC_VEX_OPSIZE, /* 7765 */
  IC_VEX_OPSIZE, /* 7766 */
  IC_VEX_OPSIZE, /* 7767 */
  IC_VEX_W_OPSIZE, /* 7768 */
  IC_VEX_W_OPSIZE, /* 7769 */
  IC_VEX_W_OPSIZE, /* 7770 */
  IC_VEX_W_OPSIZE, /* 7771 */
  IC_VEX_W_OPSIZE, /* 7772 */
  IC_VEX_W_OPSIZE, /* 7773 */
  IC_VEX_W_OPSIZE, /* 7774 */
  IC_VEX_W_OPSIZE, /* 7775 */
  IC_VEX, /* 7776 */
  IC_VEX, /* 7777 */
  IC_VEX_XS, /* 7778 */
  IC_VEX_XS, /* 7779 */
  IC_VEX_XD, /* 7780 */
  IC_VEX_XD, /* 7781 */
  IC_VEX_XD, /* 7782 */
  IC_VEX_XD, /* 7783 */
  IC_VEX_W, /* 7784 */
  IC_VEX_W, /* 7785 */
  IC_VEX_W_XS, /* 7786 */
  IC_VEX_W_XS, /* 7787 */
  IC_VEX_W_XD, /* 7788 */
  IC_VEX_W_XD, /* 7789 */
  IC_VEX_W_XD, /* 7790 */
  IC_VEX_W_XD, /* 7791 */
  IC_VEX_OPSIZE, /* 7792 */
  IC_VEX_OPSIZE, /* 7793 */
  IC_VEX_OPSIZE, /* 7794 */
  IC_VEX_OPSIZE, /* 7795 */
  IC_VEX_OPSIZE, /* 7796 */
  IC_VEX_OPSIZE, /* 7797 */
  IC_VEX_OPSIZE, /* 7798 */
  IC_VEX_OPSIZE, /* 7799 */
  IC_VEX_W_OPSIZE, /* 7800 */
  IC_VEX_W_OPSIZE, /* 7801 */
  IC_VEX_W_OPSIZE, /* 7802 */
  IC_VEX_W_OPSIZE, /* 7803 */
  IC_VEX_W_OPSIZE, /* 7804 */
  IC_VEX_W_OPSIZE, /* 7805 */
  IC_VEX_W_OPSIZE, /* 7806 */
  IC_VEX_W_OPSIZE, /* 7807 */
  IC_VEX_L, /* 7808 */
  IC_VEX_L, /* 7809 */
  IC_VEX_L_XS, /* 7810 */
  IC_VEX_L_XS, /* 7811 */
  IC_VEX_L_XD, /* 7812 */
  IC_VEX_L_XD, /* 7813 */
  IC_VEX_L_XD, /* 7814 */
  IC_VEX_L_XD, /* 7815 */
  IC_VEX_L_W, /* 7816 */
  IC_VEX_L_W, /* 7817 */
  IC_VEX_L_W_XS, /* 7818 */
  IC_VEX_L_W_XS, /* 7819 */
  IC_VEX_L_W_XD, /* 7820 */
  IC_VEX_L_W_XD, /* 7821 */
  IC_VEX_L_W_XD, /* 7822 */
  IC_VEX_L_W_XD, /* 7823 */
  IC_VEX_L_OPSIZE, /* 7824 */
  IC_VEX_L_OPSIZE, /* 7825 */
  IC_VEX_L_OPSIZE, /* 7826 */
  IC_VEX_L_OPSIZE, /* 7827 */
  IC_VEX_L_OPSIZE, /* 7828 */
  IC_VEX_L_OPSIZE, /* 7829 */
  IC_VEX_L_OPSIZE, /* 7830 */
  IC_VEX_L_OPSIZE, /* 7831 */
  IC_VEX_L_W_OPSIZE, /* 7832 */
  IC_VEX_L_W_OPSIZE, /* 7833 */
  IC_VEX_L_W_OPSIZE, /* 7834 */
  IC_VEX_L_W_OPSIZE, /* 7835 */
  IC_VEX_L_W_OPSIZE, /* 7836 */
  IC_VEX_L_W_OPSIZE, /* 7837 */
  IC_VEX_L_W_OPSIZE, /* 7838 */
  IC_VEX_L_W_OPSIZE, /* 7839 */
  IC_VEX_L, /* 7840 */
  IC_VEX_L, /* 7841 */
  IC_VEX_L_XS, /* 7842 */
  IC_VEX_L_XS, /* 7843 */
  IC_VEX_L_XD, /* 7844 */
  IC_VEX_L_XD, /* 7845 */
  IC_VEX_L_XD, /* 7846 */
  IC_VEX_L_XD, /* 7847 */
  IC_VEX_L_W, /* 7848 */
  IC_VEX_L_W, /* 7849 */
  IC_VEX_L_W_XS, /* 7850 */
  IC_VEX_L_W_XS, /* 7851 */
  IC_VEX_L_W_XD, /* 7852 */
  IC_VEX_L_W_XD, /* 7853 */
  IC_VEX_L_W_XD, /* 7854 */
  IC_VEX_L_W_XD, /* 7855 */
  IC_VEX_L_OPSIZE, /* 7856 */
  IC_VEX_L_OPSIZE, /* 7857 */
  IC_VEX_L_OPSIZE, /* 7858 */
  IC_VEX_L_OPSIZE, /* 7859 */
  IC_VEX_L_OPSIZE, /* 7860 */
  IC_VEX_L_OPSIZE, /* 7861 */
  IC_VEX_L_OPSIZE, /* 7862 */
  IC_VEX_L_OPSIZE, /* 7863 */
  IC_VEX_L_W_OPSIZE, /* 7864 */
  IC_VEX_L_W_OPSIZE, /* 7865 */
  IC_VEX_L_W_OPSIZE, /* 7866 */
  IC_VEX_L_W_OPSIZE, /* 7867 */
  IC_VEX_L_W_OPSIZE, /* 7868 */
  IC_VEX_L_W_OPSIZE, /* 7869 */
  IC_VEX_L_W_OPSIZE, /* 7870 */
  IC_VEX_L_W_OPSIZE, /* 7871 */
  IC_VEX_L, /* 7872 */
  IC_VEX_L, /* 7873 */
  IC_VEX_L_XS, /* 7874 */
  IC_VEX_L_XS, /* 7875 */
  IC_VEX_L_XD, /* 7876 */
  IC_VEX_L_XD, /* 7877 */
  IC_VEX_L_XD, /* 7878 */
  IC_VEX_L_XD, /* 7879 */
  IC_VEX_L_W, /* 7880 */
  IC_VEX_L_W, /* 7881 */
  IC_VEX_L_W_XS, /* 7882 */
  IC_VEX_L_W_XS, /* 7883 */
  IC_VEX_L_W_XD, /* 7884 */
  IC_VEX_L_W_XD, /* 7885 */
  IC_VEX_L_W_XD, /* 7886 */
  IC_VEX_L_W_XD, /* 7887 */
  IC_VEX_L_OPSIZE, /* 7888 */
  IC_VEX_L_OPSIZE, /* 7889 */
  IC_VEX_L_OPSIZE, /* 7890 */
  IC_VEX_L_OPSIZE, /* 7891 */
  IC_VEX_L_OPSIZE, /* 7892 */
  IC_VEX_L_OPSIZE, /* 7893 */
  IC_VEX_L_OPSIZE, /* 7894 */
  IC_VEX_L_OPSIZE, /* 7895 */
  IC_VEX_L_W_OPSIZE, /* 7896 */
  IC_VEX_L_W_OPSIZE, /* 7897 */
  IC_VEX_L_W_OPSIZE, /* 7898 */
  IC_VEX_L_W_OPSIZE, /* 7899 */
  IC_VEX_L_W_OPSIZE, /* 7900 */
  IC_VEX_L_W_OPSIZE, /* 7901 */
  IC_VEX_L_W_OPSIZE, /* 7902 */
  IC_VEX_L_W_OPSIZE, /* 7903 */
  IC_VEX_L, /* 7904 */
  IC_VEX_L, /* 7905 */
  IC_VEX_L_XS, /* 7906 */
  IC_VEX_L_XS, /* 7907 */
  IC_VEX_L_XD, /* 7908 */
  IC_VEX_L_XD, /* 7909 */
  IC_VEX_L_XD, /* 7910 */
  IC_VEX_L_XD, /* 7911 */
  IC_VEX_L_W, /* 7912 */
  IC_VEX_L_W, /* 7913 */
  IC_VEX_L_W_XS, /* 7914 */
  IC_VEX_L_W_XS, /* 7915 */
  IC_VEX_L_W_XD, /* 7916 */
  IC_VEX_L_W_XD, /* 7917 */
  IC_VEX_L_W_XD, /* 7918 */
  IC_VEX_L_W_XD, /* 7919 */
  IC_VEX_L_OPSIZE, /* 7920 */
  IC_VEX_L_OPSIZE, /* 7921 */
  IC_VEX_L_OPSIZE, /* 7922 */
  IC_VEX_L_OPSIZE, /* 7923 */
  IC_VEX_L_OPSIZE, /* 7924 */
  IC_VEX_L_OPSIZE, /* 7925 */
  IC_VEX_L_OPSIZE, /* 7926 */
  IC_VEX_L_OPSIZE, /* 7927 */
  IC_VEX_L_W_OPSIZE, /* 7928 */
  IC_VEX_L_W_OPSIZE, /* 7929 */
  IC_VEX_L_W_OPSIZE, /* 7930 */
  IC_VEX_L_W_OPSIZE, /* 7931 */
  IC_VEX_L_W_OPSIZE, /* 7932 */
  IC_VEX_L_W_OPSIZE, /* 7933 */
  IC_VEX_L_W_OPSIZE, /* 7934 */
  IC_VEX_L_W_OPSIZE, /* 7935 */
  IC_EVEX_L2_KZ, /* 7936 */
  IC_EVEX_L2_KZ, /* 7937 */
  IC_EVEX_L2_XS_KZ, /* 7938 */
  IC_EVEX_L2_XS_KZ, /* 7939 */
  IC_EVEX_L2_XD_KZ, /* 7940 */
  IC_EVEX_L2_XD_KZ, /* 7941 */
  IC_EVEX_L2_XD_KZ, /* 7942 */
  IC_EVEX_L2_XD_KZ, /* 7943 */
  IC_EVEX_L2_W_KZ, /* 7944 */
  IC_EVEX_L2_W_KZ, /* 7945 */
  IC_EVEX_L2_W_XS_KZ, /* 7946 */
  IC_EVEX_L2_W_XS_KZ, /* 7947 */
  IC_EVEX_L2_W_XD_KZ, /* 7948 */
  IC_EVEX_L2_W_XD_KZ, /* 7949 */
  IC_EVEX_L2_W_XD_KZ, /* 7950 */
  IC_EVEX_L2_W_XD_KZ, /* 7951 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7952 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7953 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7954 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7955 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7956 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7957 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7958 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7959 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7960 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7961 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7962 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7963 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7964 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7965 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7966 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7967 */
  IC_EVEX_L2_KZ, /* 7968 */
  IC_EVEX_L2_KZ, /* 7969 */
  IC_EVEX_L2_XS_KZ, /* 7970 */
  IC_EVEX_L2_XS_KZ, /* 7971 */
  IC_EVEX_L2_XD_KZ, /* 7972 */
  IC_EVEX_L2_XD_KZ, /* 7973 */
  IC_EVEX_L2_XD_KZ, /* 7974 */
  IC_EVEX_L2_XD_KZ, /* 7975 */
  IC_EVEX_L2_W_KZ, /* 7976 */
  IC_EVEX_L2_W_KZ, /* 7977 */
  IC_EVEX_L2_W_XS_KZ, /* 7978 */
  IC_EVEX_L2_W_XS_KZ, /* 7979 */
  IC_EVEX_L2_W_XD_KZ, /* 7980 */
  IC_EVEX_L2_W_XD_KZ, /* 7981 */
  IC_EVEX_L2_W_XD_KZ, /* 7982 */
  IC_EVEX_L2_W_XD_KZ, /* 7983 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7984 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7985 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7986 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7987 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7988 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7989 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7990 */
  IC_EVEX_L2_OPSIZE_KZ, /* 7991 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7992 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7993 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7994 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7995 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7996 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7997 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7998 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 7999 */
  IC_EVEX_L2_KZ, /* 8000 */
  IC_EVEX_L2_KZ, /* 8001 */
  IC_EVEX_L2_XS_KZ, /* 8002 */
  IC_EVEX_L2_XS_KZ, /* 8003 */
  IC_EVEX_L2_XD_KZ, /* 8004 */
  IC_EVEX_L2_XD_KZ, /* 8005 */
  IC_EVEX_L2_XD_KZ, /* 8006 */
  IC_EVEX_L2_XD_KZ, /* 8007 */
  IC_EVEX_L2_W_KZ, /* 8008 */
  IC_EVEX_L2_W_KZ, /* 8009 */
  IC_EVEX_L2_W_XS_KZ, /* 8010 */
  IC_EVEX_L2_W_XS_KZ, /* 8011 */
  IC_EVEX_L2_W_XD_KZ, /* 8012 */
  IC_EVEX_L2_W_XD_KZ, /* 8013 */
  IC_EVEX_L2_W_XD_KZ, /* 8014 */
  IC_EVEX_L2_W_XD_KZ, /* 8015 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8016 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8017 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8018 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8019 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8020 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8021 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8022 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8023 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8024 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8025 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8026 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8027 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8028 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8029 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8030 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8031 */
  IC_EVEX_L2_KZ, /* 8032 */
  IC_EVEX_L2_KZ, /* 8033 */
  IC_EVEX_L2_XS_KZ, /* 8034 */
  IC_EVEX_L2_XS_KZ, /* 8035 */
  IC_EVEX_L2_XD_KZ, /* 8036 */
  IC_EVEX_L2_XD_KZ, /* 8037 */
  IC_EVEX_L2_XD_KZ, /* 8038 */
  IC_EVEX_L2_XD_KZ, /* 8039 */
  IC_EVEX_L2_W_KZ, /* 8040 */
  IC_EVEX_L2_W_KZ, /* 8041 */
  IC_EVEX_L2_W_XS_KZ, /* 8042 */
  IC_EVEX_L2_W_XS_KZ, /* 8043 */
  IC_EVEX_L2_W_XD_KZ, /* 8044 */
  IC_EVEX_L2_W_XD_KZ, /* 8045 */
  IC_EVEX_L2_W_XD_KZ, /* 8046 */
  IC_EVEX_L2_W_XD_KZ, /* 8047 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8048 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8049 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8050 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8051 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8052 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8053 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8054 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8055 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8056 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8057 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8058 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8059 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8060 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8061 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8062 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8063 */
  IC_EVEX_L2_KZ, /* 8064 */
  IC_EVEX_L2_KZ, /* 8065 */
  IC_EVEX_L2_XS_KZ, /* 8066 */
  IC_EVEX_L2_XS_KZ, /* 8067 */
  IC_EVEX_L2_XD_KZ, /* 8068 */
  IC_EVEX_L2_XD_KZ, /* 8069 */
  IC_EVEX_L2_XD_KZ, /* 8070 */
  IC_EVEX_L2_XD_KZ, /* 8071 */
  IC_EVEX_L2_W_KZ, /* 8072 */
  IC_EVEX_L2_W_KZ, /* 8073 */
  IC_EVEX_L2_W_XS_KZ, /* 8074 */
  IC_EVEX_L2_W_XS_KZ, /* 8075 */
  IC_EVEX_L2_W_XD_KZ, /* 8076 */
  IC_EVEX_L2_W_XD_KZ, /* 8077 */
  IC_EVEX_L2_W_XD_KZ, /* 8078 */
  IC_EVEX_L2_W_XD_KZ, /* 8079 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8080 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8081 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8082 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8083 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8084 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8085 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8086 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8087 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8088 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8089 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8090 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8091 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8092 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8093 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8094 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8095 */
  IC_EVEX_L2_KZ, /* 8096 */
  IC_EVEX_L2_KZ, /* 8097 */
  IC_EVEX_L2_XS_KZ, /* 8098 */
  IC_EVEX_L2_XS_KZ, /* 8099 */
  IC_EVEX_L2_XD_KZ, /* 8100 */
  IC_EVEX_L2_XD_KZ, /* 8101 */
  IC_EVEX_L2_XD_KZ, /* 8102 */
  IC_EVEX_L2_XD_KZ, /* 8103 */
  IC_EVEX_L2_W_KZ, /* 8104 */
  IC_EVEX_L2_W_KZ, /* 8105 */
  IC_EVEX_L2_W_XS_KZ, /* 8106 */
  IC_EVEX_L2_W_XS_KZ, /* 8107 */
  IC_EVEX_L2_W_XD_KZ, /* 8108 */
  IC_EVEX_L2_W_XD_KZ, /* 8109 */
  IC_EVEX_L2_W_XD_KZ, /* 8110 */
  IC_EVEX_L2_W_XD_KZ, /* 8111 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8112 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8113 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8114 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8115 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8116 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8117 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8118 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8119 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8120 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8121 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8122 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8123 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8124 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8125 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8126 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8127 */
  IC_EVEX_L2_KZ, /* 8128 */
  IC_EVEX_L2_KZ, /* 8129 */
  IC_EVEX_L2_XS_KZ, /* 8130 */
  IC_EVEX_L2_XS_KZ, /* 8131 */
  IC_EVEX_L2_XD_KZ, /* 8132 */
  IC_EVEX_L2_XD_KZ, /* 8133 */
  IC_EVEX_L2_XD_KZ, /* 8134 */
  IC_EVEX_L2_XD_KZ, /* 8135 */
  IC_EVEX_L2_W_KZ, /* 8136 */
  IC_EVEX_L2_W_KZ, /* 8137 */
  IC_EVEX_L2_W_XS_KZ, /* 8138 */
  IC_EVEX_L2_W_XS_KZ, /* 8139 */
  IC_EVEX_L2_W_XD_KZ, /* 8140 */
  IC_EVEX_L2_W_XD_KZ, /* 8141 */
  IC_EVEX_L2_W_XD_KZ, /* 8142 */
  IC_EVEX_L2_W_XD_KZ, /* 8143 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8144 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8145 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8146 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8147 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8148 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8149 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8150 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8151 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8152 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8153 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8154 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8155 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8156 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8157 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8158 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8159 */
  IC_EVEX_L2_KZ, /* 8160 */
  IC_EVEX_L2_KZ, /* 8161 */
  IC_EVEX_L2_XS_KZ, /* 8162 */
  IC_EVEX_L2_XS_KZ, /* 8163 */
  IC_EVEX_L2_XD_KZ, /* 8164 */
  IC_EVEX_L2_XD_KZ, /* 8165 */
  IC_EVEX_L2_XD_KZ, /* 8166 */
  IC_EVEX_L2_XD_KZ, /* 8167 */
  IC_EVEX_L2_W_KZ, /* 8168 */
  IC_EVEX_L2_W_KZ, /* 8169 */
  IC_EVEX_L2_W_XS_KZ, /* 8170 */
  IC_EVEX_L2_W_XS_KZ, /* 8171 */
  IC_EVEX_L2_W_XD_KZ, /* 8172 */
  IC_EVEX_L2_W_XD_KZ, /* 8173 */
  IC_EVEX_L2_W_XD_KZ, /* 8174 */
  IC_EVEX_L2_W_XD_KZ, /* 8175 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8176 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8177 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8178 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8179 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8180 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8181 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8182 */
  IC_EVEX_L2_OPSIZE_KZ, /* 8183 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8184 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8185 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8186 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8187 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8188 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8189 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8190 */
  IC_EVEX_L2_W_OPSIZE_KZ, /* 8191 */
  IC, /* 8192 */
  IC_64BIT, /* 8193 */
  IC_XS, /* 8194 */
  IC_64BIT_XS, /* 8195 */
  IC_XD, /* 8196 */
  IC_64BIT_XD, /* 8197 */
  IC_XS, /* 8198 */
  IC_64BIT_XS, /* 8199 */
  IC, /* 8200 */
  IC_64BIT_REXW, /* 8201 */
  IC_XS, /* 8202 */
  IC_64BIT_REXW_XS, /* 8203 */
  IC_XD, /* 8204 */
  IC_64BIT_REXW_XD, /* 8205 */
  IC_XS, /* 8206 */
  IC_64BIT_REXW_XS, /* 8207 */
  IC_OPSIZE, /* 8208 */
  IC_64BIT_OPSIZE, /* 8209 */
  IC_XS_OPSIZE, /* 8210 */
  IC_64BIT_XS_OPSIZE, /* 8211 */
  IC_XD_OPSIZE, /* 8212 */
  IC_64BIT_XD_OPSIZE, /* 8213 */
  IC_XS_OPSIZE, /* 8214 */
  IC_64BIT_XD_OPSIZE, /* 8215 */
  IC_OPSIZE, /* 8216 */
  IC_64BIT_REXW_OPSIZE, /* 8217 */
  IC_XS_OPSIZE, /* 8218 */
  IC_64BIT_REXW_XS, /* 8219 */
  IC_XD_OPSIZE, /* 8220 */
  IC_64BIT_REXW_XD, /* 8221 */
  IC_XS_OPSIZE, /* 8222 */
  IC_64BIT_REXW_XS, /* 8223 */
  IC_ADSIZE, /* 8224 */
  IC_64BIT_ADSIZE, /* 8225 */
  IC_XS, /* 8226 */
  IC_64BIT_XS, /* 8227 */
  IC_XD, /* 8228 */
  IC_64BIT_XD, /* 8229 */
  IC_XS, /* 8230 */
  IC_64BIT_XS, /* 8231 */
  IC_ADSIZE, /* 8232 */
  IC_64BIT_REXW_ADSIZE, /* 8233 */
  IC_XS, /* 8234 */
  IC_64BIT_REXW_XS, /* 8235 */
  IC_XD, /* 8236 */
  IC_64BIT_REXW_XD, /* 8237 */
  IC_XS, /* 8238 */
  IC_64BIT_REXW_XS, /* 8239 */
  IC_OPSIZE_ADSIZE, /* 8240 */
  IC_64BIT_OPSIZE_ADSIZE, /* 8241 */
  IC_XS_OPSIZE, /* 8242 */
  IC_64BIT_XS_OPSIZE, /* 8243 */
  IC_XD_OPSIZE, /* 8244 */
  IC_64BIT_XD_OPSIZE, /* 8245 */
  IC_XS_OPSIZE, /* 8246 */
  IC_64BIT_XD_OPSIZE, /* 8247 */
  IC_OPSIZE_ADSIZE, /* 8248 */
  IC_64BIT_REXW_OPSIZE, /* 8249 */
  IC_XS_OPSIZE, /* 8250 */
  IC_64BIT_REXW_XS, /* 8251 */
  IC_XD_OPSIZE, /* 8252 */
  IC_64BIT_REXW_XD, /* 8253 */
  IC_XS_OPSIZE, /* 8254 */
  IC_64BIT_REXW_XS, /* 8255 */
  IC_VEX, /* 8256 */
  IC_VEX, /* 8257 */
  IC_VEX_XS, /* 8258 */
  IC_VEX_XS, /* 8259 */
  IC_VEX_XD, /* 8260 */
  IC_VEX_XD, /* 8261 */
  IC_VEX_XD, /* 8262 */
  IC_VEX_XD, /* 8263 */
  IC_VEX_W, /* 8264 */
  IC_VEX_W, /* 8265 */
  IC_VEX_W_XS, /* 8266 */
  IC_VEX_W_XS, /* 8267 */
  IC_VEX_W_XD, /* 8268 */
  IC_VEX_W_XD, /* 8269 */
  IC_VEX_W_XD, /* 8270 */
  IC_VEX_W_XD, /* 8271 */
  IC_VEX_OPSIZE, /* 8272 */
  IC_VEX_OPSIZE, /* 8273 */
  IC_VEX_OPSIZE, /* 8274 */
  IC_VEX_OPSIZE, /* 8275 */
  IC_VEX_OPSIZE, /* 8276 */
  IC_VEX_OPSIZE, /* 8277 */
  IC_VEX_OPSIZE, /* 8278 */
  IC_VEX_OPSIZE, /* 8279 */
  IC_VEX_W_OPSIZE, /* 8280 */
  IC_VEX_W_OPSIZE, /* 8281 */
  IC_VEX_W_OPSIZE, /* 8282 */
  IC_VEX_W_OPSIZE, /* 8283 */
  IC_VEX_W_OPSIZE, /* 8284 */
  IC_VEX_W_OPSIZE, /* 8285 */
  IC_VEX_W_OPSIZE, /* 8286 */
  IC_VEX_W_OPSIZE, /* 8287 */
  IC_VEX, /* 8288 */
  IC_VEX, /* 8289 */
  IC_VEX_XS, /* 8290 */
  IC_VEX_XS, /* 8291 */
  IC_VEX_XD, /* 8292 */
  IC_VEX_XD, /* 8293 */
  IC_VEX_XD, /* 8294 */
  IC_VEX_XD, /* 8295 */
  IC_VEX_W, /* 8296 */
  IC_VEX_W, /* 8297 */
  IC_VEX_W_XS, /* 8298 */
  IC_VEX_W_XS, /* 8299 */
  IC_VEX_W_XD, /* 8300 */
  IC_VEX_W_XD, /* 8301 */
  IC_VEX_W_XD, /* 8302 */
  IC_VEX_W_XD, /* 8303 */
  IC_VEX_OPSIZE, /* 8304 */
  IC_VEX_OPSIZE, /* 8305 */
  IC_VEX_OPSIZE, /* 8306 */
  IC_VEX_OPSIZE, /* 8307 */
  IC_VEX_OPSIZE, /* 8308 */
  IC_VEX_OPSIZE, /* 8309 */
  IC_VEX_OPSIZE, /* 8310 */
  IC_VEX_OPSIZE, /* 8311 */
  IC_VEX_W_OPSIZE, /* 8312 */
  IC_VEX_W_OPSIZE, /* 8313 */
  IC_VEX_W_OPSIZE, /* 8314 */
  IC_VEX_W_OPSIZE, /* 8315 */
  IC_VEX_W_OPSIZE, /* 8316 */
  IC_VEX_W_OPSIZE, /* 8317 */
  IC_VEX_W_OPSIZE, /* 8318 */
  IC_VEX_W_OPSIZE, /* 8319 */
  IC_VEX_L, /* 8320 */
  IC_VEX_L, /* 8321 */
  IC_VEX_L_XS, /* 8322 */
  IC_VEX_L_XS, /* 8323 */
  IC_VEX_L_XD, /* 8324 */
  IC_VEX_L_XD, /* 8325 */
  IC_VEX_L_XD, /* 8326 */
  IC_VEX_L_XD, /* 8327 */
  IC_VEX_L_W, /* 8328 */
  IC_VEX_L_W, /* 8329 */
  IC_VEX_L_W_XS, /* 8330 */
  IC_VEX_L_W_XS, /* 8331 */
  IC_VEX_L_W_XD, /* 8332 */
  IC_VEX_L_W_XD, /* 8333 */
  IC_VEX_L_W_XD, /* 8334 */
  IC_VEX_L_W_XD, /* 8335 */
  IC_VEX_L_OPSIZE, /* 8336 */
  IC_VEX_L_OPSIZE, /* 8337 */
  IC_VEX_L_OPSIZE, /* 8338 */
  IC_VEX_L_OPSIZE, /* 8339 */
  IC_VEX_L_OPSIZE, /* 8340 */
  IC_VEX_L_OPSIZE, /* 8341 */
  IC_VEX_L_OPSIZE, /* 8342 */
  IC_VEX_L_OPSIZE, /* 8343 */
  IC_VEX_L_W_OPSIZE, /* 8344 */
  IC_VEX_L_W_OPSIZE, /* 8345 */
  IC_VEX_L_W_OPSIZE, /* 8346 */
  IC_VEX_L_W_OPSIZE, /* 8347 */
  IC_VEX_L_W_OPSIZE, /* 8348 */
  IC_VEX_L_W_OPSIZE, /* 8349 */
  IC_VEX_L_W_OPSIZE, /* 8350 */
  IC_VEX_L_W_OPSIZE, /* 8351 */
  IC_VEX_L, /* 8352 */
  IC_VEX_L, /* 8353 */
  IC_VEX_L_XS, /* 8354 */
  IC_VEX_L_XS, /* 8355 */
  IC_VEX_L_XD, /* 8356 */
  IC_VEX_L_XD, /* 8357 */
  IC_VEX_L_XD, /* 8358 */
  IC_VEX_L_XD, /* 8359 */
  IC_VEX_L_W, /* 8360 */
  IC_VEX_L_W, /* 8361 */
  IC_VEX_L_W_XS, /* 8362 */
  IC_VEX_L_W_XS, /* 8363 */
  IC_VEX_L_W_XD, /* 8364 */
  IC_VEX_L_W_XD, /* 8365 */
  IC_VEX_L_W_XD, /* 8366 */
  IC_VEX_L_W_XD, /* 8367 */
  IC_VEX_L_OPSIZE, /* 8368 */
  IC_VEX_L_OPSIZE, /* 8369 */
  IC_VEX_L_OPSIZE, /* 8370 */
  IC_VEX_L_OPSIZE, /* 8371 */
  IC_VEX_L_OPSIZE, /* 8372 */
  IC_VEX_L_OPSIZE, /* 8373 */
  IC_VEX_L_OPSIZE, /* 8374 */
  IC_VEX_L_OPSIZE, /* 8375 */
  IC_VEX_L_W_OPSIZE, /* 8376 */
  IC_VEX_L_W_OPSIZE, /* 8377 */
  IC_VEX_L_W_OPSIZE, /* 8378 */
  IC_VEX_L_W_OPSIZE, /* 8379 */
  IC_VEX_L_W_OPSIZE, /* 8380 */
  IC_VEX_L_W_OPSIZE, /* 8381 */
  IC_VEX_L_W_OPSIZE, /* 8382 */
  IC_VEX_L_W_OPSIZE, /* 8383 */
  IC_VEX_L, /* 8384 */
  IC_VEX_L, /* 8385 */
  IC_VEX_L_XS, /* 8386 */
  IC_VEX_L_XS, /* 8387 */
  IC_VEX_L_XD, /* 8388 */
  IC_VEX_L_XD, /* 8389 */
  IC_VEX_L_XD, /* 8390 */
  IC_VEX_L_XD, /* 8391 */
  IC_VEX_L_W, /* 8392 */
  IC_VEX_L_W, /* 8393 */
  IC_VEX_L_W_XS, /* 8394 */
  IC_VEX_L_W_XS, /* 8395 */
  IC_VEX_L_W_XD, /* 8396 */
  IC_VEX_L_W_XD, /* 8397 */
  IC_VEX_L_W_XD, /* 8398 */
  IC_VEX_L_W_XD, /* 8399 */
  IC_VEX_L_OPSIZE, /* 8400 */
  IC_VEX_L_OPSIZE, /* 8401 */
  IC_VEX_L_OPSIZE, /* 8402 */
  IC_VEX_L_OPSIZE, /* 8403 */
  IC_VEX_L_OPSIZE, /* 8404 */
  IC_VEX_L_OPSIZE, /* 8405 */
  IC_VEX_L_OPSIZE, /* 8406 */
  IC_VEX_L_OPSIZE, /* 8407 */
  IC_VEX_L_W_OPSIZE, /* 8408 */
  IC_VEX_L_W_OPSIZE, /* 8409 */
  IC_VEX_L_W_OPSIZE, /* 8410 */
  IC_VEX_L_W_OPSIZE, /* 8411 */
  IC_VEX_L_W_OPSIZE, /* 8412 */
  IC_VEX_L_W_OPSIZE, /* 8413 */
  IC_VEX_L_W_OPSIZE, /* 8414 */
  IC_VEX_L_W_OPSIZE, /* 8415 */
  IC_VEX_L, /* 8416 */
  IC_VEX_L, /* 8417 */
  IC_VEX_L_XS, /* 8418 */
  IC_VEX_L_XS, /* 8419 */
  IC_VEX_L_XD, /* 8420 */
  IC_VEX_L_XD, /* 8421 */
  IC_VEX_L_XD, /* 8422 */
  IC_VEX_L_XD, /* 8423 */
  IC_VEX_L_W, /* 8424 */
  IC_VEX_L_W, /* 8425 */
  IC_VEX_L_W_XS, /* 8426 */
  IC_VEX_L_W_XS, /* 8427 */
  IC_VEX_L_W_XD, /* 8428 */
  IC_VEX_L_W_XD, /* 8429 */
  IC_VEX_L_W_XD, /* 8430 */
  IC_VEX_L_W_XD, /* 8431 */
  IC_VEX_L_OPSIZE, /* 8432 */
  IC_VEX_L_OPSIZE, /* 8433 */
  IC_VEX_L_OPSIZE, /* 8434 */
  IC_VEX_L_OPSIZE, /* 8435 */
  IC_VEX_L_OPSIZE, /* 8436 */
  IC_VEX_L_OPSIZE, /* 8437 */
  IC_VEX_L_OPSIZE, /* 8438 */
  IC_VEX_L_OPSIZE, /* 8439 */
  IC_VEX_L_W_OPSIZE, /* 8440 */
  IC_VEX_L_W_OPSIZE, /* 8441 */
  IC_VEX_L_W_OPSIZE, /* 8442 */
  IC_VEX_L_W_OPSIZE, /* 8443 */
  IC_VEX_L_W_OPSIZE, /* 8444 */
  IC_VEX_L_W_OPSIZE, /* 8445 */
  IC_VEX_L_W_OPSIZE, /* 8446 */
  IC_VEX_L_W_OPSIZE, /* 8447 */
  IC_EVEX_B, /* 8448 */
  IC_EVEX_B, /* 8449 */
  IC_EVEX_XS_B, /* 8450 */
  IC_EVEX_XS_B, /* 8451 */
  IC_EVEX_XD_B, /* 8452 */
  IC_EVEX_XD_B, /* 8453 */
  IC_EVEX_XD_B, /* 8454 */
  IC_EVEX_XD_B, /* 8455 */
  IC_EVEX_W_B, /* 8456 */
  IC_EVEX_W_B, /* 8457 */
  IC_EVEX_W_XS_B, /* 8458 */
  IC_EVEX_W_XS_B, /* 8459 */
  IC_EVEX_W_XD_B, /* 8460 */
  IC_EVEX_W_XD_B, /* 8461 */
  IC_EVEX_W_XD_B, /* 8462 */
  IC_EVEX_W_XD_B, /* 8463 */
  IC_EVEX_OPSIZE_B, /* 8464 */
  IC_EVEX_OPSIZE_B, /* 8465 */
  IC_EVEX_OPSIZE_B, /* 8466 */
  IC_EVEX_OPSIZE_B, /* 8467 */
  IC_EVEX_OPSIZE_B, /* 8468 */
  IC_EVEX_OPSIZE_B, /* 8469 */
  IC_EVEX_OPSIZE_B, /* 8470 */
  IC_EVEX_OPSIZE_B, /* 8471 */
  IC_EVEX_W_OPSIZE_B, /* 8472 */
  IC_EVEX_W_OPSIZE_B, /* 8473 */
  IC_EVEX_W_OPSIZE_B, /* 8474 */
  IC_EVEX_W_OPSIZE_B, /* 8475 */
  IC_EVEX_W_OPSIZE_B, /* 8476 */
  IC_EVEX_W_OPSIZE_B, /* 8477 */
  IC_EVEX_W_OPSIZE_B, /* 8478 */
  IC_EVEX_W_OPSIZE_B, /* 8479 */
  IC_EVEX_B, /* 8480 */
  IC_EVEX_B, /* 8481 */
  IC_EVEX_XS_B, /* 8482 */
  IC_EVEX_XS_B, /* 8483 */
  IC_EVEX_XD_B, /* 8484 */
  IC_EVEX_XD_B, /* 8485 */
  IC_EVEX_XD_B, /* 8486 */
  IC_EVEX_XD_B, /* 8487 */
  IC_EVEX_W_B, /* 8488 */
  IC_EVEX_W_B, /* 8489 */
  IC_EVEX_W_XS_B, /* 8490 */
  IC_EVEX_W_XS_B, /* 8491 */
  IC_EVEX_W_XD_B, /* 8492 */
  IC_EVEX_W_XD_B, /* 8493 */
  IC_EVEX_W_XD_B, /* 8494 */
  IC_EVEX_W_XD_B, /* 8495 */
  IC_EVEX_OPSIZE_B, /* 8496 */
  IC_EVEX_OPSIZE_B, /* 8497 */
  IC_EVEX_OPSIZE_B, /* 8498 */
  IC_EVEX_OPSIZE_B, /* 8499 */
  IC_EVEX_OPSIZE_B, /* 8500 */
  IC_EVEX_OPSIZE_B, /* 8501 */
  IC_EVEX_OPSIZE_B, /* 8502 */
  IC_EVEX_OPSIZE_B, /* 8503 */
  IC_EVEX_W_OPSIZE_B, /* 8504 */
  IC_EVEX_W_OPSIZE_B, /* 8505 */
  IC_EVEX_W_OPSIZE_B, /* 8506 */
  IC_EVEX_W_OPSIZE_B, /* 8507 */
  IC_EVEX_W_OPSIZE_B, /* 8508 */
  IC_EVEX_W_OPSIZE_B, /* 8509 */
  IC_EVEX_W_OPSIZE_B, /* 8510 */
  IC_EVEX_W_OPSIZE_B, /* 8511 */
  IC_EVEX_B, /* 8512 */
  IC_EVEX_B, /* 8513 */
  IC_EVEX_XS_B, /* 8514 */
  IC_EVEX_XS_B, /* 8515 */
  IC_EVEX_XD_B, /* 8516 */
  IC_EVEX_XD_B, /* 8517 */
  IC_EVEX_XD_B, /* 8518 */
  IC_EVEX_XD_B, /* 8519 */
  IC_EVEX_W_B, /* 8520 */
  IC_EVEX_W_B, /* 8521 */
  IC_EVEX_W_XS_B, /* 8522 */
  IC_EVEX_W_XS_B, /* 8523 */
  IC_EVEX_W_XD_B, /* 8524 */
  IC_EVEX_W_XD_B, /* 8525 */
  IC_EVEX_W_XD_B, /* 8526 */
  IC_EVEX_W_XD_B, /* 8527 */
  IC_EVEX_OPSIZE_B, /* 8528 */
  IC_EVEX_OPSIZE_B, /* 8529 */
  IC_EVEX_OPSIZE_B, /* 8530 */
  IC_EVEX_OPSIZE_B, /* 8531 */
  IC_EVEX_OPSIZE_B, /* 8532 */
  IC_EVEX_OPSIZE_B, /* 8533 */
  IC_EVEX_OPSIZE_B, /* 8534 */
  IC_EVEX_OPSIZE_B, /* 8535 */
  IC_EVEX_W_OPSIZE_B, /* 8536 */
  IC_EVEX_W_OPSIZE_B, /* 8537 */
  IC_EVEX_W_OPSIZE_B, /* 8538 */
  IC_EVEX_W_OPSIZE_B, /* 8539 */
  IC_EVEX_W_OPSIZE_B, /* 8540 */
  IC_EVEX_W_OPSIZE_B, /* 8541 */
  IC_EVEX_W_OPSIZE_B, /* 8542 */
  IC_EVEX_W_OPSIZE_B, /* 8543 */
  IC_EVEX_B, /* 8544 */
  IC_EVEX_B, /* 8545 */
  IC_EVEX_XS_B, /* 8546 */
  IC_EVEX_XS_B, /* 8547 */
  IC_EVEX_XD_B, /* 8548 */
  IC_EVEX_XD_B, /* 8549 */
  IC_EVEX_XD_B, /* 8550 */
  IC_EVEX_XD_B, /* 8551 */
  IC_EVEX_W_B, /* 8552 */
  IC_EVEX_W_B, /* 8553 */
  IC_EVEX_W_XS_B, /* 8554 */
  IC_EVEX_W_XS_B, /* 8555 */
  IC_EVEX_W_XD_B, /* 8556 */
  IC_EVEX_W_XD_B, /* 8557 */
  IC_EVEX_W_XD_B, /* 8558 */
  IC_EVEX_W_XD_B, /* 8559 */
  IC_EVEX_OPSIZE_B, /* 8560 */
  IC_EVEX_OPSIZE_B, /* 8561 */
  IC_EVEX_OPSIZE_B, /* 8562 */
  IC_EVEX_OPSIZE_B, /* 8563 */
  IC_EVEX_OPSIZE_B, /* 8564 */
  IC_EVEX_OPSIZE_B, /* 8565 */
  IC_EVEX_OPSIZE_B, /* 8566 */
  IC_EVEX_OPSIZE_B, /* 8567 */
  IC_EVEX_W_OPSIZE_B, /* 8568 */
  IC_EVEX_W_OPSIZE_B, /* 8569 */
  IC_EVEX_W_OPSIZE_B, /* 8570 */
  IC_EVEX_W_OPSIZE_B, /* 8571 */
  IC_EVEX_W_OPSIZE_B, /* 8572 */
  IC_EVEX_W_OPSIZE_B, /* 8573 */
  IC_EVEX_W_OPSIZE_B, /* 8574 */
  IC_EVEX_W_OPSIZE_B, /* 8575 */
  IC_EVEX_B, /* 8576 */
  IC_EVEX_B, /* 8577 */
  IC_EVEX_XS_B, /* 8578 */
  IC_EVEX_XS_B, /* 8579 */
  IC_EVEX_XD_B, /* 8580 */
  IC_EVEX_XD_B, /* 8581 */
  IC_EVEX_XD_B, /* 8582 */
  IC_EVEX_XD_B, /* 8583 */
  IC_EVEX_W_B, /* 8584 */
  IC_EVEX_W_B, /* 8585 */
  IC_EVEX_W_XS_B, /* 8586 */
  IC_EVEX_W_XS_B, /* 8587 */
  IC_EVEX_W_XD_B, /* 8588 */
  IC_EVEX_W_XD_B, /* 8589 */
  IC_EVEX_W_XD_B, /* 8590 */
  IC_EVEX_W_XD_B, /* 8591 */
  IC_EVEX_OPSIZE_B, /* 8592 */
  IC_EVEX_OPSIZE_B, /* 8593 */
  IC_EVEX_OPSIZE_B, /* 8594 */
  IC_EVEX_OPSIZE_B, /* 8595 */
  IC_EVEX_OPSIZE_B, /* 8596 */
  IC_EVEX_OPSIZE_B, /* 8597 */
  IC_EVEX_OPSIZE_B, /* 8598 */
  IC_EVEX_OPSIZE_B, /* 8599 */
  IC_EVEX_W_OPSIZE_B, /* 8600 */
  IC_EVEX_W_OPSIZE_B, /* 8601 */
  IC_EVEX_W_OPSIZE_B, /* 8602 */
  IC_EVEX_W_OPSIZE_B, /* 8603 */
  IC_EVEX_W_OPSIZE_B, /* 8604 */
  IC_EVEX_W_OPSIZE_B, /* 8605 */
  IC_EVEX_W_OPSIZE_B, /* 8606 */
  IC_EVEX_W_OPSIZE_B, /* 8607 */
  IC_EVEX_B, /* 8608 */
  IC_EVEX_B, /* 8609 */
  IC_EVEX_XS_B, /* 8610 */
  IC_EVEX_XS_B, /* 8611 */
  IC_EVEX_XD_B, /* 8612 */
  IC_EVEX_XD_B, /* 8613 */
  IC_EVEX_XD_B, /* 8614 */
  IC_EVEX_XD_B, /* 8615 */
  IC_EVEX_W_B, /* 8616 */
  IC_EVEX_W_B, /* 8617 */
  IC_EVEX_W_XS_B, /* 8618 */
  IC_EVEX_W_XS_B, /* 8619 */
  IC_EVEX_W_XD_B, /* 8620 */
  IC_EVEX_W_XD_B, /* 8621 */
  IC_EVEX_W_XD_B, /* 8622 */
  IC_EVEX_W_XD_B, /* 8623 */
  IC_EVEX_OPSIZE_B, /* 8624 */
  IC_EVEX_OPSIZE_B, /* 8625 */
  IC_EVEX_OPSIZE_B, /* 8626 */
  IC_EVEX_OPSIZE_B, /* 8627 */
  IC_EVEX_OPSIZE_B, /* 8628 */
  IC_EVEX_OPSIZE_B, /* 8629 */
  IC_EVEX_OPSIZE_B, /* 8630 */
  IC_EVEX_OPSIZE_B, /* 8631 */
  IC_EVEX_W_OPSIZE_B, /* 8632 */
  IC_EVEX_W_OPSIZE_B, /* 8633 */
  IC_EVEX_W_OPSIZE_B, /* 8634 */
  IC_EVEX_W_OPSIZE_B, /* 8635 */
  IC_EVEX_W_OPSIZE_B, /* 8636 */
  IC_EVEX_W_OPSIZE_B, /* 8637 */
  IC_EVEX_W_OPSIZE_B, /* 8638 */
  IC_EVEX_W_OPSIZE_B, /* 8639 */
  IC_EVEX_B, /* 8640 */
  IC_EVEX_B, /* 8641 */
  IC_EVEX_XS_B, /* 8642 */
  IC_EVEX_XS_B, /* 8643 */
  IC_EVEX_XD_B, /* 8644 */
  IC_EVEX_XD_B, /* 8645 */
  IC_EVEX_XD_B, /* 8646 */
  IC_EVEX_XD_B, /* 8647 */
  IC_EVEX_W_B, /* 8648 */
  IC_EVEX_W_B, /* 8649 */
  IC_EVEX_W_XS_B, /* 8650 */
  IC_EVEX_W_XS_B, /* 8651 */
  IC_EVEX_W_XD_B, /* 8652 */
  IC_EVEX_W_XD_B, /* 8653 */
  IC_EVEX_W_XD_B, /* 8654 */
  IC_EVEX_W_XD_B, /* 8655 */
  IC_EVEX_OPSIZE_B, /* 8656 */
  IC_EVEX_OPSIZE_B, /* 8657 */
  IC_EVEX_OPSIZE_B, /* 8658 */
  IC_EVEX_OPSIZE_B, /* 8659 */
  IC_EVEX_OPSIZE_B, /* 8660 */
  IC_EVEX_OPSIZE_B, /* 8661 */
  IC_EVEX_OPSIZE_B, /* 8662 */
  IC_EVEX_OPSIZE_B, /* 8663 */
  IC_EVEX_W_OPSIZE_B, /* 8664 */
  IC_EVEX_W_OPSIZE_B, /* 8665 */
  IC_EVEX_W_OPSIZE_B, /* 8666 */
  IC_EVEX_W_OPSIZE_B, /* 8667 */
  IC_EVEX_W_OPSIZE_B, /* 8668 */
  IC_EVEX_W_OPSIZE_B, /* 8669 */
  IC_EVEX_W_OPSIZE_B, /* 8670 */
  IC_EVEX_W_OPSIZE_B, /* 8671 */
  IC_EVEX_B, /* 8672 */
  IC_EVEX_B, /* 8673 */
  IC_EVEX_XS_B, /* 8674 */
  IC_EVEX_XS_B, /* 8675 */
  IC_EVEX_XD_B, /* 8676 */
  IC_EVEX_XD_B, /* 8677 */
  IC_EVEX_XD_B, /* 8678 */
  IC_EVEX_XD_B, /* 8679 */
  IC_EVEX_W_B, /* 8680 */
  IC_EVEX_W_B, /* 8681 */
  IC_EVEX_W_XS_B, /* 8682 */
  IC_EVEX_W_XS_B, /* 8683 */
  IC_EVEX_W_XD_B, /* 8684 */
  IC_EVEX_W_XD_B, /* 8685 */
  IC_EVEX_W_XD_B, /* 8686 */
  IC_EVEX_W_XD_B, /* 8687 */
  IC_EVEX_OPSIZE_B, /* 8688 */
  IC_EVEX_OPSIZE_B, /* 8689 */
  IC_EVEX_OPSIZE_B, /* 8690 */
  IC_EVEX_OPSIZE_B, /* 8691 */
  IC_EVEX_OPSIZE_B, /* 8692 */
  IC_EVEX_OPSIZE_B, /* 8693 */
  IC_EVEX_OPSIZE_B, /* 8694 */
  IC_EVEX_OPSIZE_B, /* 8695 */
  IC_EVEX_W_OPSIZE_B, /* 8696 */
  IC_EVEX_W_OPSIZE_B, /* 8697 */
  IC_EVEX_W_OPSIZE_B, /* 8698 */
  IC_EVEX_W_OPSIZE_B, /* 8699 */
  IC_EVEX_W_OPSIZE_B, /* 8700 */
  IC_EVEX_W_OPSIZE_B, /* 8701 */
  IC_EVEX_W_OPSIZE_B, /* 8702 */
  IC_EVEX_W_OPSIZE_B, /* 8703 */
  IC, /* 8704 */
  IC_64BIT, /* 8705 */
  IC_XS, /* 8706 */
  IC_64BIT_XS, /* 8707 */
  IC_XD, /* 8708 */
  IC_64BIT_XD, /* 8709 */
  IC_XS, /* 8710 */
  IC_64BIT_XS, /* 8711 */
  IC, /* 8712 */
  IC_64BIT_REXW, /* 8713 */
  IC_XS, /* 8714 */
  IC_64BIT_REXW_XS, /* 8715 */
  IC_XD, /* 8716 */
  IC_64BIT_REXW_XD, /* 8717 */
  IC_XS, /* 8718 */
  IC_64BIT_REXW_XS, /* 8719 */
  IC_OPSIZE, /* 8720 */
  IC_64BIT_OPSIZE, /* 8721 */
  IC_XS_OPSIZE, /* 8722 */
  IC_64BIT_XS_OPSIZE, /* 8723 */
  IC_XD_OPSIZE, /* 8724 */
  IC_64BIT_XD_OPSIZE, /* 8725 */
  IC_XS_OPSIZE, /* 8726 */
  IC_64BIT_XD_OPSIZE, /* 8727 */
  IC_OPSIZE, /* 8728 */
  IC_64BIT_REXW_OPSIZE, /* 8729 */
  IC_XS_OPSIZE, /* 8730 */
  IC_64BIT_REXW_XS, /* 8731 */
  IC_XD_OPSIZE, /* 8732 */
  IC_64BIT_REXW_XD, /* 8733 */
  IC_XS_OPSIZE, /* 8734 */
  IC_64BIT_REXW_XS, /* 8735 */
  IC_ADSIZE, /* 8736 */
  IC_64BIT_ADSIZE, /* 8737 */
  IC_XS, /* 8738 */
  IC_64BIT_XS, /* 8739 */
  IC_XD, /* 8740 */
  IC_64BIT_XD, /* 8741 */
  IC_XS, /* 8742 */
  IC_64BIT_XS, /* 8743 */
  IC_ADSIZE, /* 8744 */
  IC_64BIT_REXW_ADSIZE, /* 8745 */
  IC_XS, /* 8746 */
  IC_64BIT_REXW_XS, /* 8747 */
  IC_XD, /* 8748 */
  IC_64BIT_REXW_XD, /* 8749 */
  IC_XS, /* 8750 */
  IC_64BIT_REXW_XS, /* 8751 */
  IC_OPSIZE_ADSIZE, /* 8752 */
  IC_64BIT_OPSIZE_ADSIZE, /* 8753 */
  IC_XS_OPSIZE, /* 8754 */
  IC_64BIT_XS_OPSIZE, /* 8755 */
  IC_XD_OPSIZE, /* 8756 */
  IC_64BIT_XD_OPSIZE, /* 8757 */
  IC_XS_OPSIZE, /* 8758 */
  IC_64BIT_XD_OPSIZE, /* 8759 */
  IC_OPSIZE_ADSIZE, /* 8760 */
  IC_64BIT_REXW_OPSIZE, /* 8761 */
  IC_XS_OPSIZE, /* 8762 */
  IC_64BIT_REXW_XS, /* 8763 */
  IC_XD_OPSIZE, /* 8764 */
  IC_64BIT_REXW_XD, /* 8765 */
  IC_XS_OPSIZE, /* 8766 */
  IC_64BIT_REXW_XS, /* 8767 */
  IC_VEX, /* 8768 */
  IC_VEX, /* 8769 */
  IC_VEX_XS, /* 8770 */
  IC_VEX_XS, /* 8771 */
  IC_VEX_XD, /* 8772 */
  IC_VEX_XD, /* 8773 */
  IC_VEX_XD, /* 8774 */
  IC_VEX_XD, /* 8775 */
  IC_VEX_W, /* 8776 */
  IC_VEX_W, /* 8777 */
  IC_VEX_W_XS, /* 8778 */
  IC_VEX_W_XS, /* 8779 */
  IC_VEX_W_XD, /* 8780 */
  IC_VEX_W_XD, /* 8781 */
  IC_VEX_W_XD, /* 8782 */
  IC_VEX_W_XD, /* 8783 */
  IC_VEX_OPSIZE, /* 8784 */
  IC_VEX_OPSIZE, /* 8785 */
  IC_VEX_OPSIZE, /* 8786 */
  IC_VEX_OPSIZE, /* 8787 */
  IC_VEX_OPSIZE, /* 8788 */
  IC_VEX_OPSIZE, /* 8789 */
  IC_VEX_OPSIZE, /* 8790 */
  IC_VEX_OPSIZE, /* 8791 */
  IC_VEX_W_OPSIZE, /* 8792 */
  IC_VEX_W_OPSIZE, /* 8793 */
  IC_VEX_W_OPSIZE, /* 8794 */
  IC_VEX_W_OPSIZE, /* 8795 */
  IC_VEX_W_OPSIZE, /* 8796 */
  IC_VEX_W_OPSIZE, /* 8797 */
  IC_VEX_W_OPSIZE, /* 8798 */
  IC_VEX_W_OPSIZE, /* 8799 */
  IC_VEX, /* 8800 */
  IC_VEX, /* 8801 */
  IC_VEX_XS, /* 8802 */
  IC_VEX_XS, /* 8803 */
  IC_VEX_XD, /* 8804 */
  IC_VEX_XD, /* 8805 */
  IC_VEX_XD, /* 8806 */
  IC_VEX_XD, /* 8807 */
  IC_VEX_W, /* 8808 */
  IC_VEX_W, /* 8809 */
  IC_VEX_W_XS, /* 8810 */
  IC_VEX_W_XS, /* 8811 */
  IC_VEX_W_XD, /* 8812 */
  IC_VEX_W_XD, /* 8813 */
  IC_VEX_W_XD, /* 8814 */
  IC_VEX_W_XD, /* 8815 */
  IC_VEX_OPSIZE, /* 8816 */
  IC_VEX_OPSIZE, /* 8817 */
  IC_VEX_OPSIZE, /* 8818 */
  IC_VEX_OPSIZE, /* 8819 */
  IC_VEX_OPSIZE, /* 8820 */
  IC_VEX_OPSIZE, /* 8821 */
  IC_VEX_OPSIZE, /* 8822 */
  IC_VEX_OPSIZE, /* 8823 */
  IC_VEX_W_OPSIZE, /* 8824 */
  IC_VEX_W_OPSIZE, /* 8825 */
  IC_VEX_W_OPSIZE, /* 8826 */
  IC_VEX_W_OPSIZE, /* 8827 */
  IC_VEX_W_OPSIZE, /* 8828 */
  IC_VEX_W_OPSIZE, /* 8829 */
  IC_VEX_W_OPSIZE, /* 8830 */
  IC_VEX_W_OPSIZE, /* 8831 */
  IC_VEX_L, /* 8832 */
  IC_VEX_L, /* 8833 */
  IC_VEX_L_XS, /* 8834 */
  IC_VEX_L_XS, /* 8835 */
  IC_VEX_L_XD, /* 8836 */
  IC_VEX_L_XD, /* 8837 */
  IC_VEX_L_XD, /* 8838 */
  IC_VEX_L_XD, /* 8839 */
  IC_VEX_L_W, /* 8840 */
  IC_VEX_L_W, /* 8841 */
  IC_VEX_L_W_XS, /* 8842 */
  IC_VEX_L_W_XS, /* 8843 */
  IC_VEX_L_W_XD, /* 8844 */
  IC_VEX_L_W_XD, /* 8845 */
  IC_VEX_L_W_XD, /* 8846 */
  IC_VEX_L_W_XD, /* 8847 */
  IC_VEX_L_OPSIZE, /* 8848 */
  IC_VEX_L_OPSIZE, /* 8849 */
  IC_VEX_L_OPSIZE, /* 8850 */
  IC_VEX_L_OPSIZE, /* 8851 */
  IC_VEX_L_OPSIZE, /* 8852 */
  IC_VEX_L_OPSIZE, /* 8853 */
  IC_VEX_L_OPSIZE, /* 8854 */
  IC_VEX_L_OPSIZE, /* 8855 */
  IC_VEX_L_W_OPSIZE, /* 8856 */
  IC_VEX_L_W_OPSIZE, /* 8857 */
  IC_VEX_L_W_OPSIZE, /* 8858 */
  IC_VEX_L_W_OPSIZE, /* 8859 */
  IC_VEX_L_W_OPSIZE, /* 8860 */
  IC_VEX_L_W_OPSIZE, /* 8861 */
  IC_VEX_L_W_OPSIZE, /* 8862 */
  IC_VEX_L_W_OPSIZE, /* 8863 */
  IC_VEX_L, /* 8864 */
  IC_VEX_L, /* 8865 */
  IC_VEX_L_XS, /* 8866 */
  IC_VEX_L_XS, /* 8867 */
  IC_VEX_L_XD, /* 8868 */
  IC_VEX_L_XD, /* 8869 */
  IC_VEX_L_XD, /* 8870 */
  IC_VEX_L_XD, /* 8871 */
  IC_VEX_L_W, /* 8872 */
  IC_VEX_L_W, /* 8873 */
  IC_VEX_L_W_XS, /* 8874 */
  IC_VEX_L_W_XS, /* 8875 */
  IC_VEX_L_W_XD, /* 8876 */
  IC_VEX_L_W_XD, /* 8877 */
  IC_VEX_L_W_XD, /* 8878 */
  IC_VEX_L_W_XD, /* 8879 */
  IC_VEX_L_OPSIZE, /* 8880 */
  IC_VEX_L_OPSIZE, /* 8881 */
  IC_VEX_L_OPSIZE, /* 8882 */
  IC_VEX_L_OPSIZE, /* 8883 */
  IC_VEX_L_OPSIZE, /* 8884 */
  IC_VEX_L_OPSIZE, /* 8885 */
  IC_VEX_L_OPSIZE, /* 8886 */
  IC_VEX_L_OPSIZE, /* 8887 */
  IC_VEX_L_W_OPSIZE, /* 8888 */
  IC_VEX_L_W_OPSIZE, /* 8889 */
  IC_VEX_L_W_OPSIZE, /* 8890 */
  IC_VEX_L_W_OPSIZE, /* 8891 */
  IC_VEX_L_W_OPSIZE, /* 8892 */
  IC_VEX_L_W_OPSIZE, /* 8893 */
  IC_VEX_L_W_OPSIZE, /* 8894 */
  IC_VEX_L_W_OPSIZE, /* 8895 */
  IC_VEX_L, /* 8896 */
  IC_VEX_L, /* 8897 */
  IC_VEX_L_XS, /* 8898 */
  IC_VEX_L_XS, /* 8899 */
  IC_VEX_L_XD, /* 8900 */
  IC_VEX_L_XD, /* 8901 */
  IC_VEX_L_XD, /* 8902 */
  IC_VEX_L_XD, /* 8903 */
  IC_VEX_L_W, /* 8904 */
  IC_VEX_L_W, /* 8905 */
  IC_VEX_L_W_XS, /* 8906 */
  IC_VEX_L_W_XS, /* 8907 */
  IC_VEX_L_W_XD, /* 8908 */
  IC_VEX_L_W_XD, /* 8909 */
  IC_VEX_L_W_XD, /* 8910 */
  IC_VEX_L_W_XD, /* 8911 */
  IC_VEX_L_OPSIZE, /* 8912 */
  IC_VEX_L_OPSIZE, /* 8913 */
  IC_VEX_L_OPSIZE, /* 8914 */
  IC_VEX_L_OPSIZE, /* 8915 */
  IC_VEX_L_OPSIZE, /* 8916 */
  IC_VEX_L_OPSIZE, /* 8917 */
  IC_VEX_L_OPSIZE, /* 8918 */
  IC_VEX_L_OPSIZE, /* 8919 */
  IC_VEX_L_W_OPSIZE, /* 8920 */
  IC_VEX_L_W_OPSIZE, /* 8921 */
  IC_VEX_L_W_OPSIZE, /* 8922 */
  IC_VEX_L_W_OPSIZE, /* 8923 */
  IC_VEX_L_W_OPSIZE, /* 8924 */
  IC_VEX_L_W_OPSIZE, /* 8925 */
  IC_VEX_L_W_OPSIZE, /* 8926 */
  IC_VEX_L_W_OPSIZE, /* 8927 */
  IC_VEX_L, /* 8928 */
  IC_VEX_L, /* 8929 */
  IC_VEX_L_XS, /* 8930 */
  IC_VEX_L_XS, /* 8931 */
  IC_VEX_L_XD, /* 8932 */
  IC_VEX_L_XD, /* 8933 */
  IC_VEX_L_XD, /* 8934 */
  IC_VEX_L_XD, /* 8935 */
  IC_VEX_L_W, /* 8936 */
  IC_VEX_L_W, /* 8937 */
  IC_VEX_L_W_XS, /* 8938 */
  IC_VEX_L_W_XS, /* 8939 */
  IC_VEX_L_W_XD, /* 8940 */
  IC_VEX_L_W_XD, /* 8941 */
  IC_VEX_L_W_XD, /* 8942 */
  IC_VEX_L_W_XD, /* 8943 */
  IC_VEX_L_OPSIZE, /* 8944 */
  IC_VEX_L_OPSIZE, /* 8945 */
  IC_VEX_L_OPSIZE, /* 8946 */
  IC_VEX_L_OPSIZE, /* 8947 */
  IC_VEX_L_OPSIZE, /* 8948 */
  IC_VEX_L_OPSIZE, /* 8949 */
  IC_VEX_L_OPSIZE, /* 8950 */
  IC_VEX_L_OPSIZE, /* 8951 */
  IC_VEX_L_W_OPSIZE, /* 8952 */
  IC_VEX_L_W_OPSIZE, /* 8953 */
  IC_VEX_L_W_OPSIZE, /* 8954 */
  IC_VEX_L_W_OPSIZE, /* 8955 */
  IC_VEX_L_W_OPSIZE, /* 8956 */
  IC_VEX_L_W_OPSIZE, /* 8957 */
  IC_VEX_L_W_OPSIZE, /* 8958 */
  IC_VEX_L_W_OPSIZE, /* 8959 */
  IC_EVEX_L_B, /* 8960 */
  IC_EVEX_L_B, /* 8961 */
  IC_EVEX_L_XS_B, /* 8962 */
  IC_EVEX_L_XS_B, /* 8963 */
  IC_EVEX_L_XD_B, /* 8964 */
  IC_EVEX_L_XD_B, /* 8965 */
  IC_EVEX_L_XD_B, /* 8966 */
  IC_EVEX_L_XD_B, /* 8967 */
  IC_EVEX_L_W_B, /* 8968 */
  IC_EVEX_L_W_B, /* 8969 */
  IC_EVEX_L_W_XS_B, /* 8970 */
  IC_EVEX_L_W_XS_B, /* 8971 */
  IC_EVEX_L_W_XD_B, /* 8972 */
  IC_EVEX_L_W_XD_B, /* 8973 */
  IC_EVEX_L_W_XD_B, /* 8974 */
  IC_EVEX_L_W_XD_B, /* 8975 */
  IC_EVEX_L_OPSIZE_B, /* 8976 */
  IC_EVEX_L_OPSIZE_B, /* 8977 */
  IC_EVEX_L_OPSIZE_B, /* 8978 */
  IC_EVEX_L_OPSIZE_B, /* 8979 */
  IC_EVEX_L_OPSIZE_B, /* 8980 */
  IC_EVEX_L_OPSIZE_B, /* 8981 */
  IC_EVEX_L_OPSIZE_B, /* 8982 */
  IC_EVEX_L_OPSIZE_B, /* 8983 */
  IC_EVEX_L_W_OPSIZE_B, /* 8984 */
  IC_EVEX_L_W_OPSIZE_B, /* 8985 */
  IC_EVEX_L_W_OPSIZE_B, /* 8986 */
  IC_EVEX_L_W_OPSIZE_B, /* 8987 */
  IC_EVEX_L_W_OPSIZE_B, /* 8988 */
  IC_EVEX_L_W_OPSIZE_B, /* 8989 */
  IC_EVEX_L_W_OPSIZE_B, /* 8990 */
  IC_EVEX_L_W_OPSIZE_B, /* 8991 */
  IC_EVEX_L_B, /* 8992 */
  IC_EVEX_L_B, /* 8993 */
  IC_EVEX_L_XS_B, /* 8994 */
  IC_EVEX_L_XS_B, /* 8995 */
  IC_EVEX_L_XD_B, /* 8996 */
  IC_EVEX_L_XD_B, /* 8997 */
  IC_EVEX_L_XD_B, /* 8998 */
  IC_EVEX_L_XD_B, /* 8999 */
  IC_EVEX_L_W_B, /* 9000 */
  IC_EVEX_L_W_B, /* 9001 */
  IC_EVEX_L_W_XS_B, /* 9002 */
  IC_EVEX_L_W_XS_B, /* 9003 */
  IC_EVEX_L_W_XD_B, /* 9004 */
  IC_EVEX_L_W_XD_B, /* 9005 */
  IC_EVEX_L_W_XD_B, /* 9006 */
  IC_EVEX_L_W_XD_B, /* 9007 */
  IC_EVEX_L_OPSIZE_B, /* 9008 */
  IC_EVEX_L_OPSIZE_B, /* 9009 */
  IC_EVEX_L_OPSIZE_B, /* 9010 */
  IC_EVEX_L_OPSIZE_B, /* 9011 */
  IC_EVEX_L_OPSIZE_B, /* 9012 */
  IC_EVEX_L_OPSIZE_B, /* 9013 */
  IC_EVEX_L_OPSIZE_B, /* 9014 */
  IC_EVEX_L_OPSIZE_B, /* 9015 */
  IC_EVEX_L_W_OPSIZE_B, /* 9016 */
  IC_EVEX_L_W_OPSIZE_B, /* 9017 */
  IC_EVEX_L_W_OPSIZE_B, /* 9018 */
  IC_EVEX_L_W_OPSIZE_B, /* 9019 */
  IC_EVEX_L_W_OPSIZE_B, /* 9020 */
  IC_EVEX_L_W_OPSIZE_B, /* 9021 */
  IC_EVEX_L_W_OPSIZE_B, /* 9022 */
  IC_EVEX_L_W_OPSIZE_B, /* 9023 */
  IC_EVEX_L_B, /* 9024 */
  IC_EVEX_L_B, /* 9025 */
  IC_EVEX_L_XS_B, /* 9026 */
  IC_EVEX_L_XS_B, /* 9027 */
  IC_EVEX_L_XD_B, /* 9028 */
  IC_EVEX_L_XD_B, /* 9029 */
  IC_EVEX_L_XD_B, /* 9030 */
  IC_EVEX_L_XD_B, /* 9031 */
  IC_EVEX_L_W_B, /* 9032 */
  IC_EVEX_L_W_B, /* 9033 */
  IC_EVEX_L_W_XS_B, /* 9034 */
  IC_EVEX_L_W_XS_B, /* 9035 */
  IC_EVEX_L_W_XD_B, /* 9036 */
  IC_EVEX_L_W_XD_B, /* 9037 */
  IC_EVEX_L_W_XD_B, /* 9038 */
  IC_EVEX_L_W_XD_B, /* 9039 */
  IC_EVEX_L_OPSIZE_B, /* 9040 */
  IC_EVEX_L_OPSIZE_B, /* 9041 */
  IC_EVEX_L_OPSIZE_B, /* 9042 */
  IC_EVEX_L_OPSIZE_B, /* 9043 */
  IC_EVEX_L_OPSIZE_B, /* 9044 */
  IC_EVEX_L_OPSIZE_B, /* 9045 */
  IC_EVEX_L_OPSIZE_B, /* 9046 */
  IC_EVEX_L_OPSIZE_B, /* 9047 */
  IC_EVEX_L_W_OPSIZE_B, /* 9048 */
  IC_EVEX_L_W_OPSIZE_B, /* 9049 */
  IC_EVEX_L_W_OPSIZE_B, /* 9050 */
  IC_EVEX_L_W_OPSIZE_B, /* 9051 */
  IC_EVEX_L_W_OPSIZE_B, /* 9052 */
  IC_EVEX_L_W_OPSIZE_B, /* 9053 */
  IC_EVEX_L_W_OPSIZE_B, /* 9054 */
  IC_EVEX_L_W_OPSIZE_B, /* 9055 */
  IC_EVEX_L_B, /* 9056 */
  IC_EVEX_L_B, /* 9057 */
  IC_EVEX_L_XS_B, /* 9058 */
  IC_EVEX_L_XS_B, /* 9059 */
  IC_EVEX_L_XD_B, /* 9060 */
  IC_EVEX_L_XD_B, /* 9061 */
  IC_EVEX_L_XD_B, /* 9062 */
  IC_EVEX_L_XD_B, /* 9063 */
  IC_EVEX_L_W_B, /* 9064 */
  IC_EVEX_L_W_B, /* 9065 */
  IC_EVEX_L_W_XS_B, /* 9066 */
  IC_EVEX_L_W_XS_B, /* 9067 */
  IC_EVEX_L_W_XD_B, /* 9068 */
  IC_EVEX_L_W_XD_B, /* 9069 */
  IC_EVEX_L_W_XD_B, /* 9070 */
  IC_EVEX_L_W_XD_B, /* 9071 */
  IC_EVEX_L_OPSIZE_B, /* 9072 */
  IC_EVEX_L_OPSIZE_B, /* 9073 */
  IC_EVEX_L_OPSIZE_B, /* 9074 */
  IC_EVEX_L_OPSIZE_B, /* 9075 */
  IC_EVEX_L_OPSIZE_B, /* 9076 */
  IC_EVEX_L_OPSIZE_B, /* 9077 */
  IC_EVEX_L_OPSIZE_B, /* 9078 */
  IC_EVEX_L_OPSIZE_B, /* 9079 */
  IC_EVEX_L_W_OPSIZE_B, /* 9080 */
  IC_EVEX_L_W_OPSIZE_B, /* 9081 */
  IC_EVEX_L_W_OPSIZE_B, /* 9082 */
  IC_EVEX_L_W_OPSIZE_B, /* 9083 */
  IC_EVEX_L_W_OPSIZE_B, /* 9084 */
  IC_EVEX_L_W_OPSIZE_B, /* 9085 */
  IC_EVEX_L_W_OPSIZE_B, /* 9086 */
  IC_EVEX_L_W_OPSIZE_B, /* 9087 */
  IC_EVEX_L_B, /* 9088 */
  IC_EVEX_L_B, /* 9089 */
  IC_EVEX_L_XS_B, /* 9090 */
  IC_EVEX_L_XS_B, /* 9091 */
  IC_EVEX_L_XD_B, /* 9092 */
  IC_EVEX_L_XD_B, /* 9093 */
  IC_EVEX_L_XD_B, /* 9094 */
  IC_EVEX_L_XD_B, /* 9095 */
  IC_EVEX_L_W_B, /* 9096 */
  IC_EVEX_L_W_B, /* 9097 */
  IC_EVEX_L_W_XS_B, /* 9098 */
  IC_EVEX_L_W_XS_B, /* 9099 */
  IC_EVEX_L_W_XD_B, /* 9100 */
  IC_EVEX_L_W_XD_B, /* 9101 */
  IC_EVEX_L_W_XD_B, /* 9102 */
  IC_EVEX_L_W_XD_B, /* 9103 */
  IC_EVEX_L_OPSIZE_B, /* 9104 */
  IC_EVEX_L_OPSIZE_B, /* 9105 */
  IC_EVEX_L_OPSIZE_B, /* 9106 */
  IC_EVEX_L_OPSIZE_B, /* 9107 */
  IC_EVEX_L_OPSIZE_B, /* 9108 */
  IC_EVEX_L_OPSIZE_B, /* 9109 */
  IC_EVEX_L_OPSIZE_B, /* 9110 */
  IC_EVEX_L_OPSIZE_B, /* 9111 */
  IC_EVEX_L_W_OPSIZE_B, /* 9112 */
  IC_EVEX_L_W_OPSIZE_B, /* 9113 */
  IC_EVEX_L_W_OPSIZE_B, /* 9114 */
  IC_EVEX_L_W_OPSIZE_B, /* 9115 */
  IC_EVEX_L_W_OPSIZE_B, /* 9116 */
  IC_EVEX_L_W_OPSIZE_B, /* 9117 */
  IC_EVEX_L_W_OPSIZE_B, /* 9118 */
  IC_EVEX_L_W_OPSIZE_B, /* 9119 */
  IC_EVEX_L_B, /* 9120 */
  IC_EVEX_L_B, /* 9121 */
  IC_EVEX_L_XS_B, /* 9122 */
  IC_EVEX_L_XS_B, /* 9123 */
  IC_EVEX_L_XD_B, /* 9124 */
  IC_EVEX_L_XD_B, /* 9125 */
  IC_EVEX_L_XD_B, /* 9126 */
  IC_EVEX_L_XD_B, /* 9127 */
  IC_EVEX_L_W_B, /* 9128 */
  IC_EVEX_L_W_B, /* 9129 */
  IC_EVEX_L_W_XS_B, /* 9130 */
  IC_EVEX_L_W_XS_B, /* 9131 */
  IC_EVEX_L_W_XD_B, /* 9132 */
  IC_EVEX_L_W_XD_B, /* 9133 */
  IC_EVEX_L_W_XD_B, /* 9134 */
  IC_EVEX_L_W_XD_B, /* 9135 */
  IC_EVEX_L_OPSIZE_B, /* 9136 */
  IC_EVEX_L_OPSIZE_B, /* 9137 */
  IC_EVEX_L_OPSIZE_B, /* 9138 */
  IC_EVEX_L_OPSIZE_B, /* 9139 */
  IC_EVEX_L_OPSIZE_B, /* 9140 */
  IC_EVEX_L_OPSIZE_B, /* 9141 */
  IC_EVEX_L_OPSIZE_B, /* 9142 */
  IC_EVEX_L_OPSIZE_B, /* 9143 */
  IC_EVEX_L_W_OPSIZE_B, /* 9144 */
  IC_EVEX_L_W_OPSIZE_B, /* 9145 */
  IC_EVEX_L_W_OPSIZE_B, /* 9146 */
  IC_EVEX_L_W_OPSIZE_B, /* 9147 */
  IC_EVEX_L_W_OPSIZE_B, /* 9148 */
  IC_EVEX_L_W_OPSIZE_B, /* 9149 */
  IC_EVEX_L_W_OPSIZE_B, /* 9150 */
  IC_EVEX_L_W_OPSIZE_B, /* 9151 */
  IC_EVEX_L_B, /* 9152 */
  IC_EVEX_L_B, /* 9153 */
  IC_EVEX_L_XS_B, /* 9154 */
  IC_EVEX_L_XS_B, /* 9155 */
  IC_EVEX_L_XD_B, /* 9156 */
  IC_EVEX_L_XD_B, /* 9157 */
  IC_EVEX_L_XD_B, /* 9158 */
  IC_EVEX_L_XD_B, /* 9159 */
  IC_EVEX_L_W_B, /* 9160 */
  IC_EVEX_L_W_B, /* 9161 */
  IC_EVEX_L_W_XS_B, /* 9162 */
  IC_EVEX_L_W_XS_B, /* 9163 */
  IC_EVEX_L_W_XD_B, /* 9164 */
  IC_EVEX_L_W_XD_B, /* 9165 */
  IC_EVEX_L_W_XD_B, /* 9166 */
  IC_EVEX_L_W_XD_B, /* 9167 */
  IC_EVEX_L_OPSIZE_B, /* 9168 */
  IC_EVEX_L_OPSIZE_B, /* 9169 */
  IC_EVEX_L_OPSIZE_B, /* 9170 */
  IC_EVEX_L_OPSIZE_B, /* 9171 */
  IC_EVEX_L_OPSIZE_B, /* 9172 */
  IC_EVEX_L_OPSIZE_B, /* 9173 */
  IC_EVEX_L_OPSIZE_B, /* 9174 */
  IC_EVEX_L_OPSIZE_B, /* 9175 */
  IC_EVEX_L_W_OPSIZE_B, /* 9176 */
  IC_EVEX_L_W_OPSIZE_B, /* 9177 */
  IC_EVEX_L_W_OPSIZE_B, /* 9178 */
  IC_EVEX_L_W_OPSIZE_B, /* 9179 */
  IC_EVEX_L_W_OPSIZE_B, /* 9180 */
  IC_EVEX_L_W_OPSIZE_B, /* 9181 */
  IC_EVEX_L_W_OPSIZE_B, /* 9182 */
  IC_EVEX_L_W_OPSIZE_B, /* 9183 */
  IC_EVEX_L_B, /* 9184 */
  IC_EVEX_L_B, /* 9185 */
  IC_EVEX_L_XS_B, /* 9186 */
  IC_EVEX_L_XS_B, /* 9187 */
  IC_EVEX_L_XD_B, /* 9188 */
  IC_EVEX_L_XD_B, /* 9189 */
  IC_EVEX_L_XD_B, /* 9190 */
  IC_EVEX_L_XD_B, /* 9191 */
  IC_EVEX_L_W_B, /* 9192 */
  IC_EVEX_L_W_B, /* 9193 */
  IC_EVEX_L_W_XS_B, /* 9194 */
  IC_EVEX_L_W_XS_B, /* 9195 */
  IC_EVEX_L_W_XD_B, /* 9196 */
  IC_EVEX_L_W_XD_B, /* 9197 */
  IC_EVEX_L_W_XD_B, /* 9198 */
  IC_EVEX_L_W_XD_B, /* 9199 */
  IC_EVEX_L_OPSIZE_B, /* 9200 */
  IC_EVEX_L_OPSIZE_B, /* 9201 */
  IC_EVEX_L_OPSIZE_B, /* 9202 */
  IC_EVEX_L_OPSIZE_B, /* 9203 */
  IC_EVEX_L_OPSIZE_B, /* 9204 */
  IC_EVEX_L_OPSIZE_B, /* 9205 */
  IC_EVEX_L_OPSIZE_B, /* 9206 */
  IC_EVEX_L_OPSIZE_B, /* 9207 */
  IC_EVEX_L_W_OPSIZE_B, /* 9208 */
  IC_EVEX_L_W_OPSIZE_B, /* 9209 */
  IC_EVEX_L_W_OPSIZE_B, /* 9210 */
  IC_EVEX_L_W_OPSIZE_B, /* 9211 */
  IC_EVEX_L_W_OPSIZE_B, /* 9212 */
  IC_EVEX_L_W_OPSIZE_B, /* 9213 */
  IC_EVEX_L_W_OPSIZE_B, /* 9214 */
  IC_EVEX_L_W_OPSIZE_B, /* 9215 */
  IC, /* 9216 */
  IC_64BIT, /* 9217 */
  IC_XS, /* 9218 */
  IC_64BIT_XS, /* 9219 */
  IC_XD, /* 9220 */
  IC_64BIT_XD, /* 9221 */
  IC_XS, /* 9222 */
  IC_64BIT_XS, /* 9223 */
  IC, /* 9224 */
  IC_64BIT_REXW, /* 9225 */
  IC_XS, /* 9226 */
  IC_64BIT_REXW_XS, /* 9227 */
  IC_XD, /* 9228 */
  IC_64BIT_REXW_XD, /* 9229 */
  IC_XS, /* 9230 */
  IC_64BIT_REXW_XS, /* 9231 */
  IC_OPSIZE, /* 9232 */
  IC_64BIT_OPSIZE, /* 9233 */
  IC_XS_OPSIZE, /* 9234 */
  IC_64BIT_XS_OPSIZE, /* 9235 */
  IC_XD_OPSIZE, /* 9236 */
  IC_64BIT_XD_OPSIZE, /* 9237 */
  IC_XS_OPSIZE, /* 9238 */
  IC_64BIT_XD_OPSIZE, /* 9239 */
  IC_OPSIZE, /* 9240 */
  IC_64BIT_REXW_OPSIZE, /* 9241 */
  IC_XS_OPSIZE, /* 9242 */
  IC_64BIT_REXW_XS, /* 9243 */
  IC_XD_OPSIZE, /* 9244 */
  IC_64BIT_REXW_XD, /* 9245 */
  IC_XS_OPSIZE, /* 9246 */
  IC_64BIT_REXW_XS, /* 9247 */
  IC_ADSIZE, /* 9248 */
  IC_64BIT_ADSIZE, /* 9249 */
  IC_XS, /* 9250 */
  IC_64BIT_XS, /* 9251 */
  IC_XD, /* 9252 */
  IC_64BIT_XD, /* 9253 */
  IC_XS, /* 9254 */
  IC_64BIT_XS, /* 9255 */
  IC_ADSIZE, /* 9256 */
  IC_64BIT_REXW_ADSIZE, /* 9257 */
  IC_XS, /* 9258 */
  IC_64BIT_REXW_XS, /* 9259 */
  IC_XD, /* 9260 */
  IC_64BIT_REXW_XD, /* 9261 */
  IC_XS, /* 9262 */
  IC_64BIT_REXW_XS, /* 9263 */
  IC_OPSIZE_ADSIZE, /* 9264 */
  IC_64BIT_OPSIZE_ADSIZE, /* 9265 */
  IC_XS_OPSIZE, /* 9266 */
  IC_64BIT_XS_OPSIZE, /* 9267 */
  IC_XD_OPSIZE, /* 9268 */
  IC_64BIT_XD_OPSIZE, /* 9269 */
  IC_XS_OPSIZE, /* 9270 */
  IC_64BIT_XD_OPSIZE, /* 9271 */
  IC_OPSIZE_ADSIZE, /* 9272 */
  IC_64BIT_REXW_OPSIZE, /* 9273 */
  IC_XS_OPSIZE, /* 9274 */
  IC_64BIT_REXW_XS, /* 9275 */
  IC_XD_OPSIZE, /* 9276 */
  IC_64BIT_REXW_XD, /* 9277 */
  IC_XS_OPSIZE, /* 9278 */
  IC_64BIT_REXW_XS, /* 9279 */
  IC_VEX, /* 9280 */
  IC_VEX, /* 9281 */
  IC_VEX_XS, /* 9282 */
  IC_VEX_XS, /* 9283 */
  IC_VEX_XD, /* 9284 */
  IC_VEX_XD, /* 9285 */
  IC_VEX_XD, /* 9286 */
  IC_VEX_XD, /* 9287 */
  IC_VEX_W, /* 9288 */
  IC_VEX_W, /* 9289 */
  IC_VEX_W_XS, /* 9290 */
  IC_VEX_W_XS, /* 9291 */
  IC_VEX_W_XD, /* 9292 */
  IC_VEX_W_XD, /* 9293 */
  IC_VEX_W_XD, /* 9294 */
  IC_VEX_W_XD, /* 9295 */
  IC_VEX_OPSIZE, /* 9296 */
  IC_VEX_OPSIZE, /* 9297 */
  IC_VEX_OPSIZE, /* 9298 */
  IC_VEX_OPSIZE, /* 9299 */
  IC_VEX_OPSIZE, /* 9300 */
  IC_VEX_OPSIZE, /* 9301 */
  IC_VEX_OPSIZE, /* 9302 */
  IC_VEX_OPSIZE, /* 9303 */
  IC_VEX_W_OPSIZE, /* 9304 */
  IC_VEX_W_OPSIZE, /* 9305 */
  IC_VEX_W_OPSIZE, /* 9306 */
  IC_VEX_W_OPSIZE, /* 9307 */
  IC_VEX_W_OPSIZE, /* 9308 */
  IC_VEX_W_OPSIZE, /* 9309 */
  IC_VEX_W_OPSIZE, /* 9310 */
  IC_VEX_W_OPSIZE, /* 9311 */
  IC_VEX, /* 9312 */
  IC_VEX, /* 9313 */
  IC_VEX_XS, /* 9314 */
  IC_VEX_XS, /* 9315 */
  IC_VEX_XD, /* 9316 */
  IC_VEX_XD, /* 9317 */
  IC_VEX_XD, /* 9318 */
  IC_VEX_XD, /* 9319 */
  IC_VEX_W, /* 9320 */
  IC_VEX_W, /* 9321 */
  IC_VEX_W_XS, /* 9322 */
  IC_VEX_W_XS, /* 9323 */
  IC_VEX_W_XD, /* 9324 */
  IC_VEX_W_XD, /* 9325 */
  IC_VEX_W_XD, /* 9326 */
  IC_VEX_W_XD, /* 9327 */
  IC_VEX_OPSIZE, /* 9328 */
  IC_VEX_OPSIZE, /* 9329 */
  IC_VEX_OPSIZE, /* 9330 */
  IC_VEX_OPSIZE, /* 9331 */
  IC_VEX_OPSIZE, /* 9332 */
  IC_VEX_OPSIZE, /* 9333 */
  IC_VEX_OPSIZE, /* 9334 */
  IC_VEX_OPSIZE, /* 9335 */
  IC_VEX_W_OPSIZE, /* 9336 */
  IC_VEX_W_OPSIZE, /* 9337 */
  IC_VEX_W_OPSIZE, /* 9338 */
  IC_VEX_W_OPSIZE, /* 9339 */
  IC_VEX_W_OPSIZE, /* 9340 */
  IC_VEX_W_OPSIZE, /* 9341 */
  IC_VEX_W_OPSIZE, /* 9342 */
  IC_VEX_W_OPSIZE, /* 9343 */
  IC_VEX_L, /* 9344 */
  IC_VEX_L, /* 9345 */
  IC_VEX_L_XS, /* 9346 */
  IC_VEX_L_XS, /* 9347 */
  IC_VEX_L_XD, /* 9348 */
  IC_VEX_L_XD, /* 9349 */
  IC_VEX_L_XD, /* 9350 */
  IC_VEX_L_XD, /* 9351 */
  IC_VEX_L_W, /* 9352 */
  IC_VEX_L_W, /* 9353 */
  IC_VEX_L_W_XS, /* 9354 */
  IC_VEX_L_W_XS, /* 9355 */
  IC_VEX_L_W_XD, /* 9356 */
  IC_VEX_L_W_XD, /* 9357 */
  IC_VEX_L_W_XD, /* 9358 */
  IC_VEX_L_W_XD, /* 9359 */
  IC_VEX_L_OPSIZE, /* 9360 */
  IC_VEX_L_OPSIZE, /* 9361 */
  IC_VEX_L_OPSIZE, /* 9362 */
  IC_VEX_L_OPSIZE, /* 9363 */
  IC_VEX_L_OPSIZE, /* 9364 */
  IC_VEX_L_OPSIZE, /* 9365 */
  IC_VEX_L_OPSIZE, /* 9366 */
  IC_VEX_L_OPSIZE, /* 9367 */
  IC_VEX_L_W_OPSIZE, /* 9368 */
  IC_VEX_L_W_OPSIZE, /* 9369 */
  IC_VEX_L_W_OPSIZE, /* 9370 */
  IC_VEX_L_W_OPSIZE, /* 9371 */
  IC_VEX_L_W_OPSIZE, /* 9372 */
  IC_VEX_L_W_OPSIZE, /* 9373 */
  IC_VEX_L_W_OPSIZE, /* 9374 */
  IC_VEX_L_W_OPSIZE, /* 9375 */
  IC_VEX_L, /* 9376 */
  IC_VEX_L, /* 9377 */
  IC_VEX_L_XS, /* 9378 */
  IC_VEX_L_XS, /* 9379 */
  IC_VEX_L_XD, /* 9380 */
  IC_VEX_L_XD, /* 9381 */
  IC_VEX_L_XD, /* 9382 */
  IC_VEX_L_XD, /* 9383 */
  IC_VEX_L_W, /* 9384 */
  IC_VEX_L_W, /* 9385 */
  IC_VEX_L_W_XS, /* 9386 */
  IC_VEX_L_W_XS, /* 9387 */
  IC_VEX_L_W_XD, /* 9388 */
  IC_VEX_L_W_XD, /* 9389 */
  IC_VEX_L_W_XD, /* 9390 */
  IC_VEX_L_W_XD, /* 9391 */
  IC_VEX_L_OPSIZE, /* 9392 */
  IC_VEX_L_OPSIZE, /* 9393 */
  IC_VEX_L_OPSIZE, /* 9394 */
  IC_VEX_L_OPSIZE, /* 9395 */
  IC_VEX_L_OPSIZE, /* 9396 */
  IC_VEX_L_OPSIZE, /* 9397 */
  IC_VEX_L_OPSIZE, /* 9398 */
  IC_VEX_L_OPSIZE, /* 9399 */
  IC_VEX_L_W_OPSIZE, /* 9400 */
  IC_VEX_L_W_OPSIZE, /* 9401 */
  IC_VEX_L_W_OPSIZE, /* 9402 */
  IC_VEX_L_W_OPSIZE, /* 9403 */
  IC_VEX_L_W_OPSIZE, /* 9404 */
  IC_VEX_L_W_OPSIZE, /* 9405 */
  IC_VEX_L_W_OPSIZE, /* 9406 */
  IC_VEX_L_W_OPSIZE, /* 9407 */
  IC_VEX_L, /* 9408 */
  IC_VEX_L, /* 9409 */
  IC_VEX_L_XS, /* 9410 */
  IC_VEX_L_XS, /* 9411 */
  IC_VEX_L_XD, /* 9412 */
  IC_VEX_L_XD, /* 9413 */
  IC_VEX_L_XD, /* 9414 */
  IC_VEX_L_XD, /* 9415 */
  IC_VEX_L_W, /* 9416 */
  IC_VEX_L_W, /* 9417 */
  IC_VEX_L_W_XS, /* 9418 */
  IC_VEX_L_W_XS, /* 9419 */
  IC_VEX_L_W_XD, /* 9420 */
  IC_VEX_L_W_XD, /* 9421 */
  IC_VEX_L_W_XD, /* 9422 */
  IC_VEX_L_W_XD, /* 9423 */
  IC_VEX_L_OPSIZE, /* 9424 */
  IC_VEX_L_OPSIZE, /* 9425 */
  IC_VEX_L_OPSIZE, /* 9426 */
  IC_VEX_L_OPSIZE, /* 9427 */
  IC_VEX_L_OPSIZE, /* 9428 */
  IC_VEX_L_OPSIZE, /* 9429 */
  IC_VEX_L_OPSIZE, /* 9430 */
  IC_VEX_L_OPSIZE, /* 9431 */
  IC_VEX_L_W_OPSIZE, /* 9432 */
  IC_VEX_L_W_OPSIZE, /* 9433 */
  IC_VEX_L_W_OPSIZE, /* 9434 */
  IC_VEX_L_W_OPSIZE, /* 9435 */
  IC_VEX_L_W_OPSIZE, /* 9436 */
  IC_VEX_L_W_OPSIZE, /* 9437 */
  IC_VEX_L_W_OPSIZE, /* 9438 */
  IC_VEX_L_W_OPSIZE, /* 9439 */
  IC_VEX_L, /* 9440 */
  IC_VEX_L, /* 9441 */
  IC_VEX_L_XS, /* 9442 */
  IC_VEX_L_XS, /* 9443 */
  IC_VEX_L_XD, /* 9444 */
  IC_VEX_L_XD, /* 9445 */
  IC_VEX_L_XD, /* 9446 */
  IC_VEX_L_XD, /* 9447 */
  IC_VEX_L_W, /* 9448 */
  IC_VEX_L_W, /* 9449 */
  IC_VEX_L_W_XS, /* 9450 */
  IC_VEX_L_W_XS, /* 9451 */
  IC_VEX_L_W_XD, /* 9452 */
  IC_VEX_L_W_XD, /* 9453 */
  IC_VEX_L_W_XD, /* 9454 */
  IC_VEX_L_W_XD, /* 9455 */
  IC_VEX_L_OPSIZE, /* 9456 */
  IC_VEX_L_OPSIZE, /* 9457 */
  IC_VEX_L_OPSIZE, /* 9458 */
  IC_VEX_L_OPSIZE, /* 9459 */
  IC_VEX_L_OPSIZE, /* 9460 */
  IC_VEX_L_OPSIZE, /* 9461 */
  IC_VEX_L_OPSIZE, /* 9462 */
  IC_VEX_L_OPSIZE, /* 9463 */
  IC_VEX_L_W_OPSIZE, /* 9464 */
  IC_VEX_L_W_OPSIZE, /* 9465 */
  IC_VEX_L_W_OPSIZE, /* 9466 */
  IC_VEX_L_W_OPSIZE, /* 9467 */
  IC_VEX_L_W_OPSIZE, /* 9468 */
  IC_VEX_L_W_OPSIZE, /* 9469 */
  IC_VEX_L_W_OPSIZE, /* 9470 */
  IC_VEX_L_W_OPSIZE, /* 9471 */
  IC_EVEX_L2_B, /* 9472 */
  IC_EVEX_L2_B, /* 9473 */
  IC_EVEX_L2_XS_B, /* 9474 */
  IC_EVEX_L2_XS_B, /* 9475 */
  IC_EVEX_L2_XD_B, /* 9476 */
  IC_EVEX_L2_XD_B, /* 9477 */
  IC_EVEX_L2_XD_B, /* 9478 */
  IC_EVEX_L2_XD_B, /* 9479 */
  IC_EVEX_L2_W_B, /* 9480 */
  IC_EVEX_L2_W_B, /* 9481 */
  IC_EVEX_L2_W_XS_B, /* 9482 */
  IC_EVEX_L2_W_XS_B, /* 9483 */
  IC_EVEX_L2_W_XD_B, /* 9484 */
  IC_EVEX_L2_W_XD_B, /* 9485 */
  IC_EVEX_L2_W_XD_B, /* 9486 */
  IC_EVEX_L2_W_XD_B, /* 9487 */
  IC_EVEX_L2_OPSIZE_B, /* 9488 */
  IC_EVEX_L2_OPSIZE_B, /* 9489 */
  IC_EVEX_L2_OPSIZE_B, /* 9490 */
  IC_EVEX_L2_OPSIZE_B, /* 9491 */
  IC_EVEX_L2_OPSIZE_B, /* 9492 */
  IC_EVEX_L2_OPSIZE_B, /* 9493 */
  IC_EVEX_L2_OPSIZE_B, /* 9494 */
  IC_EVEX_L2_OPSIZE_B, /* 9495 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9496 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9497 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9498 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9499 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9500 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9501 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9502 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9503 */
  IC_EVEX_L2_B, /* 9504 */
  IC_EVEX_L2_B, /* 9505 */
  IC_EVEX_L2_XS_B, /* 9506 */
  IC_EVEX_L2_XS_B, /* 9507 */
  IC_EVEX_L2_XD_B, /* 9508 */
  IC_EVEX_L2_XD_B, /* 9509 */
  IC_EVEX_L2_XD_B, /* 9510 */
  IC_EVEX_L2_XD_B, /* 9511 */
  IC_EVEX_L2_W_B, /* 9512 */
  IC_EVEX_L2_W_B, /* 9513 */
  IC_EVEX_L2_W_XS_B, /* 9514 */
  IC_EVEX_L2_W_XS_B, /* 9515 */
  IC_EVEX_L2_W_XD_B, /* 9516 */
  IC_EVEX_L2_W_XD_B, /* 9517 */
  IC_EVEX_L2_W_XD_B, /* 9518 */
  IC_EVEX_L2_W_XD_B, /* 9519 */
  IC_EVEX_L2_OPSIZE_B, /* 9520 */
  IC_EVEX_L2_OPSIZE_B, /* 9521 */
  IC_EVEX_L2_OPSIZE_B, /* 9522 */
  IC_EVEX_L2_OPSIZE_B, /* 9523 */
  IC_EVEX_L2_OPSIZE_B, /* 9524 */
  IC_EVEX_L2_OPSIZE_B, /* 9525 */
  IC_EVEX_L2_OPSIZE_B, /* 9526 */
  IC_EVEX_L2_OPSIZE_B, /* 9527 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9528 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9529 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9530 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9531 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9532 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9533 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9534 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9535 */
  IC_EVEX_L2_B, /* 9536 */
  IC_EVEX_L2_B, /* 9537 */
  IC_EVEX_L2_XS_B, /* 9538 */
  IC_EVEX_L2_XS_B, /* 9539 */
  IC_EVEX_L2_XD_B, /* 9540 */
  IC_EVEX_L2_XD_B, /* 9541 */
  IC_EVEX_L2_XD_B, /* 9542 */
  IC_EVEX_L2_XD_B, /* 9543 */
  IC_EVEX_L2_W_B, /* 9544 */
  IC_EVEX_L2_W_B, /* 9545 */
  IC_EVEX_L2_W_XS_B, /* 9546 */
  IC_EVEX_L2_W_XS_B, /* 9547 */
  IC_EVEX_L2_W_XD_B, /* 9548 */
  IC_EVEX_L2_W_XD_B, /* 9549 */
  IC_EVEX_L2_W_XD_B, /* 9550 */
  IC_EVEX_L2_W_XD_B, /* 9551 */
  IC_EVEX_L2_OPSIZE_B, /* 9552 */
  IC_EVEX_L2_OPSIZE_B, /* 9553 */
  IC_EVEX_L2_OPSIZE_B, /* 9554 */
  IC_EVEX_L2_OPSIZE_B, /* 9555 */
  IC_EVEX_L2_OPSIZE_B, /* 9556 */
  IC_EVEX_L2_OPSIZE_B, /* 9557 */
  IC_EVEX_L2_OPSIZE_B, /* 9558 */
  IC_EVEX_L2_OPSIZE_B, /* 9559 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9560 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9561 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9562 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9563 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9564 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9565 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9566 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9567 */
  IC_EVEX_L2_B, /* 9568 */
  IC_EVEX_L2_B, /* 9569 */
  IC_EVEX_L2_XS_B, /* 9570 */
  IC_EVEX_L2_XS_B, /* 9571 */
  IC_EVEX_L2_XD_B, /* 9572 */
  IC_EVEX_L2_XD_B, /* 9573 */
  IC_EVEX_L2_XD_B, /* 9574 */
  IC_EVEX_L2_XD_B, /* 9575 */
  IC_EVEX_L2_W_B, /* 9576 */
  IC_EVEX_L2_W_B, /* 9577 */
  IC_EVEX_L2_W_XS_B, /* 9578 */
  IC_EVEX_L2_W_XS_B, /* 9579 */
  IC_EVEX_L2_W_XD_B, /* 9580 */
  IC_EVEX_L2_W_XD_B, /* 9581 */
  IC_EVEX_L2_W_XD_B, /* 9582 */
  IC_EVEX_L2_W_XD_B, /* 9583 */
  IC_EVEX_L2_OPSIZE_B, /* 9584 */
  IC_EVEX_L2_OPSIZE_B, /* 9585 */
  IC_EVEX_L2_OPSIZE_B, /* 9586 */
  IC_EVEX_L2_OPSIZE_B, /* 9587 */
  IC_EVEX_L2_OPSIZE_B, /* 9588 */
  IC_EVEX_L2_OPSIZE_B, /* 9589 */
  IC_EVEX_L2_OPSIZE_B, /* 9590 */
  IC_EVEX_L2_OPSIZE_B, /* 9591 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9592 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9593 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9594 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9595 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9596 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9597 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9598 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9599 */
  IC_EVEX_L2_B, /* 9600 */
  IC_EVEX_L2_B, /* 9601 */
  IC_EVEX_L2_XS_B, /* 9602 */
  IC_EVEX_L2_XS_B, /* 9603 */
  IC_EVEX_L2_XD_B, /* 9604 */
  IC_EVEX_L2_XD_B, /* 9605 */
  IC_EVEX_L2_XD_B, /* 9606 */
  IC_EVEX_L2_XD_B, /* 9607 */
  IC_EVEX_L2_W_B, /* 9608 */
  IC_EVEX_L2_W_B, /* 9609 */
  IC_EVEX_L2_W_XS_B, /* 9610 */
  IC_EVEX_L2_W_XS_B, /* 9611 */
  IC_EVEX_L2_W_XD_B, /* 9612 */
  IC_EVEX_L2_W_XD_B, /* 9613 */
  IC_EVEX_L2_W_XD_B, /* 9614 */
  IC_EVEX_L2_W_XD_B, /* 9615 */
  IC_EVEX_L2_OPSIZE_B, /* 9616 */
  IC_EVEX_L2_OPSIZE_B, /* 9617 */
  IC_EVEX_L2_OPSIZE_B, /* 9618 */
  IC_EVEX_L2_OPSIZE_B, /* 9619 */
  IC_EVEX_L2_OPSIZE_B, /* 9620 */
  IC_EVEX_L2_OPSIZE_B, /* 9621 */
  IC_EVEX_L2_OPSIZE_B, /* 9622 */
  IC_EVEX_L2_OPSIZE_B, /* 9623 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9624 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9625 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9626 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9627 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9628 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9629 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9630 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9631 */
  IC_EVEX_L2_B, /* 9632 */
  IC_EVEX_L2_B, /* 9633 */
  IC_EVEX_L2_XS_B, /* 9634 */
  IC_EVEX_L2_XS_B, /* 9635 */
  IC_EVEX_L2_XD_B, /* 9636 */
  IC_EVEX_L2_XD_B, /* 9637 */
  IC_EVEX_L2_XD_B, /* 9638 */
  IC_EVEX_L2_XD_B, /* 9639 */
  IC_EVEX_L2_W_B, /* 9640 */
  IC_EVEX_L2_W_B, /* 9641 */
  IC_EVEX_L2_W_XS_B, /* 9642 */
  IC_EVEX_L2_W_XS_B, /* 9643 */
  IC_EVEX_L2_W_XD_B, /* 9644 */
  IC_EVEX_L2_W_XD_B, /* 9645 */
  IC_EVEX_L2_W_XD_B, /* 9646 */
  IC_EVEX_L2_W_XD_B, /* 9647 */
  IC_EVEX_L2_OPSIZE_B, /* 9648 */
  IC_EVEX_L2_OPSIZE_B, /* 9649 */
  IC_EVEX_L2_OPSIZE_B, /* 9650 */
  IC_EVEX_L2_OPSIZE_B, /* 9651 */
  IC_EVEX_L2_OPSIZE_B, /* 9652 */
  IC_EVEX_L2_OPSIZE_B, /* 9653 */
  IC_EVEX_L2_OPSIZE_B, /* 9654 */
  IC_EVEX_L2_OPSIZE_B, /* 9655 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9656 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9657 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9658 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9659 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9660 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9661 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9662 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9663 */
  IC_EVEX_L2_B, /* 9664 */
  IC_EVEX_L2_B, /* 9665 */
  IC_EVEX_L2_XS_B, /* 9666 */
  IC_EVEX_L2_XS_B, /* 9667 */
  IC_EVEX_L2_XD_B, /* 9668 */
  IC_EVEX_L2_XD_B, /* 9669 */
  IC_EVEX_L2_XD_B, /* 9670 */
  IC_EVEX_L2_XD_B, /* 9671 */
  IC_EVEX_L2_W_B, /* 9672 */
  IC_EVEX_L2_W_B, /* 9673 */
  IC_EVEX_L2_W_XS_B, /* 9674 */
  IC_EVEX_L2_W_XS_B, /* 9675 */
  IC_EVEX_L2_W_XD_B, /* 9676 */
  IC_EVEX_L2_W_XD_B, /* 9677 */
  IC_EVEX_L2_W_XD_B, /* 9678 */
  IC_EVEX_L2_W_XD_B, /* 9679 */
  IC_EVEX_L2_OPSIZE_B, /* 9680 */
  IC_EVEX_L2_OPSIZE_B, /* 9681 */
  IC_EVEX_L2_OPSIZE_B, /* 9682 */
  IC_EVEX_L2_OPSIZE_B, /* 9683 */
  IC_EVEX_L2_OPSIZE_B, /* 9684 */
  IC_EVEX_L2_OPSIZE_B, /* 9685 */
  IC_EVEX_L2_OPSIZE_B, /* 9686 */
  IC_EVEX_L2_OPSIZE_B, /* 9687 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9688 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9689 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9690 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9691 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9692 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9693 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9694 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9695 */
  IC_EVEX_L2_B, /* 9696 */
  IC_EVEX_L2_B, /* 9697 */
  IC_EVEX_L2_XS_B, /* 9698 */
  IC_EVEX_L2_XS_B, /* 9699 */
  IC_EVEX_L2_XD_B, /* 9700 */
  IC_EVEX_L2_XD_B, /* 9701 */
  IC_EVEX_L2_XD_B, /* 9702 */
  IC_EVEX_L2_XD_B, /* 9703 */
  IC_EVEX_L2_W_B, /* 9704 */
  IC_EVEX_L2_W_B, /* 9705 */
  IC_EVEX_L2_W_XS_B, /* 9706 */
  IC_EVEX_L2_W_XS_B, /* 9707 */
  IC_EVEX_L2_W_XD_B, /* 9708 */
  IC_EVEX_L2_W_XD_B, /* 9709 */
  IC_EVEX_L2_W_XD_B, /* 9710 */
  IC_EVEX_L2_W_XD_B, /* 9711 */
  IC_EVEX_L2_OPSIZE_B, /* 9712 */
  IC_EVEX_L2_OPSIZE_B, /* 9713 */
  IC_EVEX_L2_OPSIZE_B, /* 9714 */
  IC_EVEX_L2_OPSIZE_B, /* 9715 */
  IC_EVEX_L2_OPSIZE_B, /* 9716 */
  IC_EVEX_L2_OPSIZE_B, /* 9717 */
  IC_EVEX_L2_OPSIZE_B, /* 9718 */
  IC_EVEX_L2_OPSIZE_B, /* 9719 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9720 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9721 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9722 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9723 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9724 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9725 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9726 */
  IC_EVEX_L2_W_OPSIZE_B, /* 9727 */
  IC, /* 9728 */
  IC_64BIT, /* 9729 */
  IC_XS, /* 9730 */
  IC_64BIT_XS, /* 9731 */
  IC_XD, /* 9732 */
  IC_64BIT_XD, /* 9733 */
  IC_XS, /* 9734 */
  IC_64BIT_XS, /* 9735 */
  IC, /* 9736 */
  IC_64BIT_REXW, /* 9737 */
  IC_XS, /* 9738 */
  IC_64BIT_REXW_XS, /* 9739 */
  IC_XD, /* 9740 */
  IC_64BIT_REXW_XD, /* 9741 */
  IC_XS, /* 9742 */
  IC_64BIT_REXW_XS, /* 9743 */
  IC_OPSIZE, /* 9744 */
  IC_64BIT_OPSIZE, /* 9745 */
  IC_XS_OPSIZE, /* 9746 */
  IC_64BIT_XS_OPSIZE, /* 9747 */
  IC_XD_OPSIZE, /* 9748 */
  IC_64BIT_XD_OPSIZE, /* 9749 */
  IC_XS_OPSIZE, /* 9750 */
  IC_64BIT_XD_OPSIZE, /* 9751 */
  IC_OPSIZE, /* 9752 */
  IC_64BIT_REXW_OPSIZE, /* 9753 */
  IC_XS_OPSIZE, /* 9754 */
  IC_64BIT_REXW_XS, /* 9755 */
  IC_XD_OPSIZE, /* 9756 */
  IC_64BIT_REXW_XD, /* 9757 */
  IC_XS_OPSIZE, /* 9758 */
  IC_64BIT_REXW_XS, /* 9759 */
  IC_ADSIZE, /* 9760 */
  IC_64BIT_ADSIZE, /* 9761 */
  IC_XS, /* 9762 */
  IC_64BIT_XS, /* 9763 */
  IC_XD, /* 9764 */
  IC_64BIT_XD, /* 9765 */
  IC_XS, /* 9766 */
  IC_64BIT_XS, /* 9767 */
  IC_ADSIZE, /* 9768 */
  IC_64BIT_REXW_ADSIZE, /* 9769 */
  IC_XS, /* 9770 */
  IC_64BIT_REXW_XS, /* 9771 */
  IC_XD, /* 9772 */
  IC_64BIT_REXW_XD, /* 9773 */
  IC_XS, /* 9774 */
  IC_64BIT_REXW_XS, /* 9775 */
  IC_OPSIZE_ADSIZE, /* 9776 */
  IC_64BIT_OPSIZE_ADSIZE, /* 9777 */
  IC_XS_OPSIZE, /* 9778 */
  IC_64BIT_XS_OPSIZE, /* 9779 */
  IC_XD_OPSIZE, /* 9780 */
  IC_64BIT_XD_OPSIZE, /* 9781 */
  IC_XS_OPSIZE, /* 9782 */
  IC_64BIT_XD_OPSIZE, /* 9783 */
  IC_OPSIZE_ADSIZE, /* 9784 */
  IC_64BIT_REXW_OPSIZE, /* 9785 */
  IC_XS_OPSIZE, /* 9786 */
  IC_64BIT_REXW_XS, /* 9787 */
  IC_XD_OPSIZE, /* 9788 */
  IC_64BIT_REXW_XD, /* 9789 */
  IC_XS_OPSIZE, /* 9790 */
  IC_64BIT_REXW_XS, /* 9791 */
  IC_VEX, /* 9792 */
  IC_VEX, /* 9793 */
  IC_VEX_XS, /* 9794 */
  IC_VEX_XS, /* 9795 */
  IC_VEX_XD, /* 9796 */
  IC_VEX_XD, /* 9797 */
  IC_VEX_XD, /* 9798 */
  IC_VEX_XD, /* 9799 */
  IC_VEX_W, /* 9800 */
  IC_VEX_W, /* 9801 */
  IC_VEX_W_XS, /* 9802 */
  IC_VEX_W_XS, /* 9803 */
  IC_VEX_W_XD, /* 9804 */
  IC_VEX_W_XD, /* 9805 */
  IC_VEX_W_XD, /* 9806 */
  IC_VEX_W_XD, /* 9807 */
  IC_VEX_OPSIZE, /* 9808 */
  IC_VEX_OPSIZE, /* 9809 */
  IC_VEX_OPSIZE, /* 9810 */
  IC_VEX_OPSIZE, /* 9811 */
  IC_VEX_OPSIZE, /* 9812 */
  IC_VEX_OPSIZE, /* 9813 */
  IC_VEX_OPSIZE, /* 9814 */
  IC_VEX_OPSIZE, /* 9815 */
  IC_VEX_W_OPSIZE, /* 9816 */
  IC_VEX_W_OPSIZE, /* 9817 */
  IC_VEX_W_OPSIZE, /* 9818 */
  IC_VEX_W_OPSIZE, /* 9819 */
  IC_VEX_W_OPSIZE, /* 9820 */
  IC_VEX_W_OPSIZE, /* 9821 */
  IC_VEX_W_OPSIZE, /* 9822 */
  IC_VEX_W_OPSIZE, /* 9823 */
  IC_VEX, /* 9824 */
  IC_VEX, /* 9825 */
  IC_VEX_XS, /* 9826 */
  IC_VEX_XS, /* 9827 */
  IC_VEX_XD, /* 9828 */
  IC_VEX_XD, /* 9829 */
  IC_VEX_XD, /* 9830 */
  IC_VEX_XD, /* 9831 */
  IC_VEX_W, /* 9832 */
  IC_VEX_W, /* 9833 */
  IC_VEX_W_XS, /* 9834 */
  IC_VEX_W_XS, /* 9835 */
  IC_VEX_W_XD, /* 9836 */
  IC_VEX_W_XD, /* 9837 */
  IC_VEX_W_XD, /* 9838 */
  IC_VEX_W_XD, /* 9839 */
  IC_VEX_OPSIZE, /* 9840 */
  IC_VEX_OPSIZE, /* 9841 */
  IC_VEX_OPSIZE, /* 9842 */
  IC_VEX_OPSIZE, /* 9843 */
  IC_VEX_OPSIZE, /* 9844 */
  IC_VEX_OPSIZE, /* 9845 */
  IC_VEX_OPSIZE, /* 9846 */
  IC_VEX_OPSIZE, /* 9847 */
  IC_VEX_W_OPSIZE, /* 9848 */
  IC_VEX_W_OPSIZE, /* 9849 */
  IC_VEX_W_OPSIZE, /* 9850 */
  IC_VEX_W_OPSIZE, /* 9851 */
  IC_VEX_W_OPSIZE, /* 9852 */
  IC_VEX_W_OPSIZE, /* 9853 */
  IC_VEX_W_OPSIZE, /* 9854 */
  IC_VEX_W_OPSIZE, /* 9855 */
  IC_VEX_L, /* 9856 */
  IC_VEX_L, /* 9857 */
  IC_VEX_L_XS, /* 9858 */
  IC_VEX_L_XS, /* 9859 */
  IC_VEX_L_XD, /* 9860 */
  IC_VEX_L_XD, /* 9861 */
  IC_VEX_L_XD, /* 9862 */
  IC_VEX_L_XD, /* 9863 */
  IC_VEX_L_W, /* 9864 */
  IC_VEX_L_W, /* 9865 */
  IC_VEX_L_W_XS, /* 9866 */
  IC_VEX_L_W_XS, /* 9867 */
  IC_VEX_L_W_XD, /* 9868 */
  IC_VEX_L_W_XD, /* 9869 */
  IC_VEX_L_W_XD, /* 9870 */
  IC_VEX_L_W_XD, /* 9871 */
  IC_VEX_L_OPSIZE, /* 9872 */
  IC_VEX_L_OPSIZE, /* 9873 */
  IC_VEX_L_OPSIZE, /* 9874 */
  IC_VEX_L_OPSIZE, /* 9875 */
  IC_VEX_L_OPSIZE, /* 9876 */
  IC_VEX_L_OPSIZE, /* 9877 */
  IC_VEX_L_OPSIZE, /* 9878 */
  IC_VEX_L_OPSIZE, /* 9879 */
  IC_VEX_L_W_OPSIZE, /* 9880 */
  IC_VEX_L_W_OPSIZE, /* 9881 */
  IC_VEX_L_W_OPSIZE, /* 9882 */
  IC_VEX_L_W_OPSIZE, /* 9883 */
  IC_VEX_L_W_OPSIZE, /* 9884 */
  IC_VEX_L_W_OPSIZE, /* 9885 */
  IC_VEX_L_W_OPSIZE, /* 9886 */
  IC_VEX_L_W_OPSIZE, /* 9887 */
  IC_VEX_L, /* 9888 */
  IC_VEX_L, /* 9889 */
  IC_VEX_L_XS, /* 9890 */
  IC_VEX_L_XS, /* 9891 */
  IC_VEX_L_XD, /* 9892 */
  IC_VEX_L_XD, /* 9893 */
  IC_VEX_L_XD, /* 9894 */
  IC_VEX_L_XD, /* 9895 */
  IC_VEX_L_W, /* 9896 */
  IC_VEX_L_W, /* 9897 */
  IC_VEX_L_W_XS, /* 9898 */
  IC_VEX_L_W_XS, /* 9899 */
  IC_VEX_L_W_XD, /* 9900 */
  IC_VEX_L_W_XD, /* 9901 */
  IC_VEX_L_W_XD, /* 9902 */
  IC_VEX_L_W_XD, /* 9903 */
  IC_VEX_L_OPSIZE, /* 9904 */
  IC_VEX_L_OPSIZE, /* 9905 */
  IC_VEX_L_OPSIZE, /* 9906 */
  IC_VEX_L_OPSIZE, /* 9907 */
  IC_VEX_L_OPSIZE, /* 9908 */
  IC_VEX_L_OPSIZE, /* 9909 */
  IC_VEX_L_OPSIZE, /* 9910 */
  IC_VEX_L_OPSIZE, /* 9911 */
  IC_VEX_L_W_OPSIZE, /* 9912 */
  IC_VEX_L_W_OPSIZE, /* 9913 */
  IC_VEX_L_W_OPSIZE, /* 9914 */
  IC_VEX_L_W_OPSIZE, /* 9915 */
  IC_VEX_L_W_OPSIZE, /* 9916 */
  IC_VEX_L_W_OPSIZE, /* 9917 */
  IC_VEX_L_W_OPSIZE, /* 9918 */
  IC_VEX_L_W_OPSIZE, /* 9919 */
  IC_VEX_L, /* 9920 */
  IC_VEX_L, /* 9921 */
  IC_VEX_L_XS, /* 9922 */
  IC_VEX_L_XS, /* 9923 */
  IC_VEX_L_XD, /* 9924 */
  IC_VEX_L_XD, /* 9925 */
  IC_VEX_L_XD, /* 9926 */
  IC_VEX_L_XD, /* 9927 */
  IC_VEX_L_W, /* 9928 */
  IC_VEX_L_W, /* 9929 */
  IC_VEX_L_W_XS, /* 9930 */
  IC_VEX_L_W_XS, /* 9931 */
  IC_VEX_L_W_XD, /* 9932 */
  IC_VEX_L_W_XD, /* 9933 */
  IC_VEX_L_W_XD, /* 9934 */
  IC_VEX_L_W_XD, /* 9935 */
  IC_VEX_L_OPSIZE, /* 9936 */
  IC_VEX_L_OPSIZE, /* 9937 */
  IC_VEX_L_OPSIZE, /* 9938 */
  IC_VEX_L_OPSIZE, /* 9939 */
  IC_VEX_L_OPSIZE, /* 9940 */
  IC_VEX_L_OPSIZE, /* 9941 */
  IC_VEX_L_OPSIZE, /* 9942 */
  IC_VEX_L_OPSIZE, /* 9943 */
  IC_VEX_L_W_OPSIZE, /* 9944 */
  IC_VEX_L_W_OPSIZE, /* 9945 */
  IC_VEX_L_W_OPSIZE, /* 9946 */
  IC_VEX_L_W_OPSIZE, /* 9947 */
  IC_VEX_L_W_OPSIZE, /* 9948 */
  IC_VEX_L_W_OPSIZE, /* 9949 */
  IC_VEX_L_W_OPSIZE, /* 9950 */
  IC_VEX_L_W_OPSIZE, /* 9951 */
  IC_VEX_L, /* 9952 */
  IC_VEX_L, /* 9953 */
  IC_VEX_L_XS, /* 9954 */
  IC_VEX_L_XS, /* 9955 */
  IC_VEX_L_XD, /* 9956 */
  IC_VEX_L_XD, /* 9957 */
  IC_VEX_L_XD, /* 9958 */
  IC_VEX_L_XD, /* 9959 */
  IC_VEX_L_W, /* 9960 */
  IC_VEX_L_W, /* 9961 */
  IC_VEX_L_W_XS, /* 9962 */
  IC_VEX_L_W_XS, /* 9963 */
  IC_VEX_L_W_XD, /* 9964 */
  IC_VEX_L_W_XD, /* 9965 */
  IC_VEX_L_W_XD, /* 9966 */
  IC_VEX_L_W_XD, /* 9967 */
  IC_VEX_L_OPSIZE, /* 9968 */
  IC_VEX_L_OPSIZE, /* 9969 */
  IC_VEX_L_OPSIZE, /* 9970 */
  IC_VEX_L_OPSIZE, /* 9971 */
  IC_VEX_L_OPSIZE, /* 9972 */
  IC_VEX_L_OPSIZE, /* 9973 */
  IC_VEX_L_OPSIZE, /* 9974 */
  IC_VEX_L_OPSIZE, /* 9975 */
  IC_VEX_L_W_OPSIZE, /* 9976 */
  IC_VEX_L_W_OPSIZE, /* 9977 */
  IC_VEX_L_W_OPSIZE, /* 9978 */
  IC_VEX_L_W_OPSIZE, /* 9979 */
  IC_VEX_L_W_OPSIZE, /* 9980 */
  IC_VEX_L_W_OPSIZE, /* 9981 */
  IC_VEX_L_W_OPSIZE, /* 9982 */
  IC_VEX_L_W_OPSIZE, /* 9983 */
  IC_EVEX_L2_B, /* 9984 */
  IC_EVEX_L2_B, /* 9985 */
  IC_EVEX_L2_XS_B, /* 9986 */
  IC_EVEX_L2_XS_B, /* 9987 */
  IC_EVEX_L2_XD_B, /* 9988 */
  IC_EVEX_L2_XD_B, /* 9989 */
  IC_EVEX_L2_XD_B, /* 9990 */
  IC_EVEX_L2_XD_B, /* 9991 */
  IC_EVEX_L2_W_B, /* 9992 */
  IC_EVEX_L2_W_B, /* 9993 */
  IC_EVEX_L2_W_XS_B, /* 9994 */
  IC_EVEX_L2_W_XS_B, /* 9995 */
  IC_EVEX_L2_W_XD_B, /* 9996 */
  IC_EVEX_L2_W_XD_B, /* 9997 */
  IC_EVEX_L2_W_XD_B, /* 9998 */
  IC_EVEX_L2_W_XD_B, /* 9999 */
  IC_EVEX_L2_OPSIZE_B, /* 10000 */
  IC_EVEX_L2_OPSIZE_B, /* 10001 */
  IC_EVEX_L2_OPSIZE_B, /* 10002 */
  IC_EVEX_L2_OPSIZE_B, /* 10003 */
  IC_EVEX_L2_OPSIZE_B, /* 10004 */
  IC_EVEX_L2_OPSIZE_B, /* 10005 */
  IC_EVEX_L2_OPSIZE_B, /* 10006 */
  IC_EVEX_L2_OPSIZE_B, /* 10007 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10008 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10009 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10010 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10011 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10012 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10013 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10014 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10015 */
  IC_EVEX_L2_B, /* 10016 */
  IC_EVEX_L2_B, /* 10017 */
  IC_EVEX_L2_XS_B, /* 10018 */
  IC_EVEX_L2_XS_B, /* 10019 */
  IC_EVEX_L2_XD_B, /* 10020 */
  IC_EVEX_L2_XD_B, /* 10021 */
  IC_EVEX_L2_XD_B, /* 10022 */
  IC_EVEX_L2_XD_B, /* 10023 */
  IC_EVEX_L2_W_B, /* 10024 */
  IC_EVEX_L2_W_B, /* 10025 */
  IC_EVEX_L2_W_XS_B, /* 10026 */
  IC_EVEX_L2_W_XS_B, /* 10027 */
  IC_EVEX_L2_W_XD_B, /* 10028 */
  IC_EVEX_L2_W_XD_B, /* 10029 */
  IC_EVEX_L2_W_XD_B, /* 10030 */
  IC_EVEX_L2_W_XD_B, /* 10031 */
  IC_EVEX_L2_OPSIZE_B, /* 10032 */
  IC_EVEX_L2_OPSIZE_B, /* 10033 */
  IC_EVEX_L2_OPSIZE_B, /* 10034 */
  IC_EVEX_L2_OPSIZE_B, /* 10035 */
  IC_EVEX_L2_OPSIZE_B, /* 10036 */
  IC_EVEX_L2_OPSIZE_B, /* 10037 */
  IC_EVEX_L2_OPSIZE_B, /* 10038 */
  IC_EVEX_L2_OPSIZE_B, /* 10039 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10040 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10041 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10042 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10043 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10044 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10045 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10046 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10047 */
  IC_EVEX_L2_B, /* 10048 */
  IC_EVEX_L2_B, /* 10049 */
  IC_EVEX_L2_XS_B, /* 10050 */
  IC_EVEX_L2_XS_B, /* 10051 */
  IC_EVEX_L2_XD_B, /* 10052 */
  IC_EVEX_L2_XD_B, /* 10053 */
  IC_EVEX_L2_XD_B, /* 10054 */
  IC_EVEX_L2_XD_B, /* 10055 */
  IC_EVEX_L2_W_B, /* 10056 */
  IC_EVEX_L2_W_B, /* 10057 */
  IC_EVEX_L2_W_XS_B, /* 10058 */
  IC_EVEX_L2_W_XS_B, /* 10059 */
  IC_EVEX_L2_W_XD_B, /* 10060 */
  IC_EVEX_L2_W_XD_B, /* 10061 */
  IC_EVEX_L2_W_XD_B, /* 10062 */
  IC_EVEX_L2_W_XD_B, /* 10063 */
  IC_EVEX_L2_OPSIZE_B, /* 10064 */
  IC_EVEX_L2_OPSIZE_B, /* 10065 */
  IC_EVEX_L2_OPSIZE_B, /* 10066 */
  IC_EVEX_L2_OPSIZE_B, /* 10067 */
  IC_EVEX_L2_OPSIZE_B, /* 10068 */
  IC_EVEX_L2_OPSIZE_B, /* 10069 */
  IC_EVEX_L2_OPSIZE_B, /* 10070 */
  IC_EVEX_L2_OPSIZE_B, /* 10071 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10072 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10073 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10074 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10075 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10076 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10077 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10078 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10079 */
  IC_EVEX_L2_B, /* 10080 */
  IC_EVEX_L2_B, /* 10081 */
  IC_EVEX_L2_XS_B, /* 10082 */
  IC_EVEX_L2_XS_B, /* 10083 */
  IC_EVEX_L2_XD_B, /* 10084 */
  IC_EVEX_L2_XD_B, /* 10085 */
  IC_EVEX_L2_XD_B, /* 10086 */
  IC_EVEX_L2_XD_B, /* 10087 */
  IC_EVEX_L2_W_B, /* 10088 */
  IC_EVEX_L2_W_B, /* 10089 */
  IC_EVEX_L2_W_XS_B, /* 10090 */
  IC_EVEX_L2_W_XS_B, /* 10091 */
  IC_EVEX_L2_W_XD_B, /* 10092 */
  IC_EVEX_L2_W_XD_B, /* 10093 */
  IC_EVEX_L2_W_XD_B, /* 10094 */
  IC_EVEX_L2_W_XD_B, /* 10095 */
  IC_EVEX_L2_OPSIZE_B, /* 10096 */
  IC_EVEX_L2_OPSIZE_B, /* 10097 */
  IC_EVEX_L2_OPSIZE_B, /* 10098 */
  IC_EVEX_L2_OPSIZE_B, /* 10099 */
  IC_EVEX_L2_OPSIZE_B, /* 10100 */
  IC_EVEX_L2_OPSIZE_B, /* 10101 */
  IC_EVEX_L2_OPSIZE_B, /* 10102 */
  IC_EVEX_L2_OPSIZE_B, /* 10103 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10104 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10105 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10106 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10107 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10108 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10109 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10110 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10111 */
  IC_EVEX_L2_B, /* 10112 */
  IC_EVEX_L2_B, /* 10113 */
  IC_EVEX_L2_XS_B, /* 10114 */
  IC_EVEX_L2_XS_B, /* 10115 */
  IC_EVEX_L2_XD_B, /* 10116 */
  IC_EVEX_L2_XD_B, /* 10117 */
  IC_EVEX_L2_XD_B, /* 10118 */
  IC_EVEX_L2_XD_B, /* 10119 */
  IC_EVEX_L2_W_B, /* 10120 */
  IC_EVEX_L2_W_B, /* 10121 */
  IC_EVEX_L2_W_XS_B, /* 10122 */
  IC_EVEX_L2_W_XS_B, /* 10123 */
  IC_EVEX_L2_W_XD_B, /* 10124 */
  IC_EVEX_L2_W_XD_B, /* 10125 */
  IC_EVEX_L2_W_XD_B, /* 10126 */
  IC_EVEX_L2_W_XD_B, /* 10127 */
  IC_EVEX_L2_OPSIZE_B, /* 10128 */
  IC_EVEX_L2_OPSIZE_B, /* 10129 */
  IC_EVEX_L2_OPSIZE_B, /* 10130 */
  IC_EVEX_L2_OPSIZE_B, /* 10131 */
  IC_EVEX_L2_OPSIZE_B, /* 10132 */
  IC_EVEX_L2_OPSIZE_B, /* 10133 */
  IC_EVEX_L2_OPSIZE_B, /* 10134 */
  IC_EVEX_L2_OPSIZE_B, /* 10135 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10136 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10137 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10138 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10139 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10140 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10141 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10142 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10143 */
  IC_EVEX_L2_B, /* 10144 */
  IC_EVEX_L2_B, /* 10145 */
  IC_EVEX_L2_XS_B, /* 10146 */
  IC_EVEX_L2_XS_B, /* 10147 */
  IC_EVEX_L2_XD_B, /* 10148 */
  IC_EVEX_L2_XD_B, /* 10149 */
  IC_EVEX_L2_XD_B, /* 10150 */
  IC_EVEX_L2_XD_B, /* 10151 */
  IC_EVEX_L2_W_B, /* 10152 */
  IC_EVEX_L2_W_B, /* 10153 */
  IC_EVEX_L2_W_XS_B, /* 10154 */
  IC_EVEX_L2_W_XS_B, /* 10155 */
  IC_EVEX_L2_W_XD_B, /* 10156 */
  IC_EVEX_L2_W_XD_B, /* 10157 */
  IC_EVEX_L2_W_XD_B, /* 10158 */
  IC_EVEX_L2_W_XD_B, /* 10159 */
  IC_EVEX_L2_OPSIZE_B, /* 10160 */
  IC_EVEX_L2_OPSIZE_B, /* 10161 */
  IC_EVEX_L2_OPSIZE_B, /* 10162 */
  IC_EVEX_L2_OPSIZE_B, /* 10163 */
  IC_EVEX_L2_OPSIZE_B, /* 10164 */
  IC_EVEX_L2_OPSIZE_B, /* 10165 */
  IC_EVEX_L2_OPSIZE_B, /* 10166 */
  IC_EVEX_L2_OPSIZE_B, /* 10167 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10168 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10169 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10170 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10171 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10172 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10173 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10174 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10175 */
  IC_EVEX_L2_B, /* 10176 */
  IC_EVEX_L2_B, /* 10177 */
  IC_EVEX_L2_XS_B, /* 10178 */
  IC_EVEX_L2_XS_B, /* 10179 */
  IC_EVEX_L2_XD_B, /* 10180 */
  IC_EVEX_L2_XD_B, /* 10181 */
  IC_EVEX_L2_XD_B, /* 10182 */
  IC_EVEX_L2_XD_B, /* 10183 */
  IC_EVEX_L2_W_B, /* 10184 */
  IC_EVEX_L2_W_B, /* 10185 */
  IC_EVEX_L2_W_XS_B, /* 10186 */
  IC_EVEX_L2_W_XS_B, /* 10187 */
  IC_EVEX_L2_W_XD_B, /* 10188 */
  IC_EVEX_L2_W_XD_B, /* 10189 */
  IC_EVEX_L2_W_XD_B, /* 10190 */
  IC_EVEX_L2_W_XD_B, /* 10191 */
  IC_EVEX_L2_OPSIZE_B, /* 10192 */
  IC_EVEX_L2_OPSIZE_B, /* 10193 */
  IC_EVEX_L2_OPSIZE_B, /* 10194 */
  IC_EVEX_L2_OPSIZE_B, /* 10195 */
  IC_EVEX_L2_OPSIZE_B, /* 10196 */
  IC_EVEX_L2_OPSIZE_B, /* 10197 */
  IC_EVEX_L2_OPSIZE_B, /* 10198 */
  IC_EVEX_L2_OPSIZE_B, /* 10199 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10200 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10201 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10202 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10203 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10204 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10205 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10206 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10207 */
  IC_EVEX_L2_B, /* 10208 */
  IC_EVEX_L2_B, /* 10209 */
  IC_EVEX_L2_XS_B, /* 10210 */
  IC_EVEX_L2_XS_B, /* 10211 */
  IC_EVEX_L2_XD_B, /* 10212 */
  IC_EVEX_L2_XD_B, /* 10213 */
  IC_EVEX_L2_XD_B, /* 10214 */
  IC_EVEX_L2_XD_B, /* 10215 */
  IC_EVEX_L2_W_B, /* 10216 */
  IC_EVEX_L2_W_B, /* 10217 */
  IC_EVEX_L2_W_XS_B, /* 10218 */
  IC_EVEX_L2_W_XS_B, /* 10219 */
  IC_EVEX_L2_W_XD_B, /* 10220 */
  IC_EVEX_L2_W_XD_B, /* 10221 */
  IC_EVEX_L2_W_XD_B, /* 10222 */
  IC_EVEX_L2_W_XD_B, /* 10223 */
  IC_EVEX_L2_OPSIZE_B, /* 10224 */
  IC_EVEX_L2_OPSIZE_B, /* 10225 */
  IC_EVEX_L2_OPSIZE_B, /* 10226 */
  IC_EVEX_L2_OPSIZE_B, /* 10227 */
  IC_EVEX_L2_OPSIZE_B, /* 10228 */
  IC_EVEX_L2_OPSIZE_B, /* 10229 */
  IC_EVEX_L2_OPSIZE_B, /* 10230 */
  IC_EVEX_L2_OPSIZE_B, /* 10231 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10232 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10233 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10234 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10235 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10236 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10237 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10238 */
  IC_EVEX_L2_W_OPSIZE_B, /* 10239 */
  IC, /* 10240 */
  IC_64BIT, /* 10241 */
  IC_XS, /* 10242 */
  IC_64BIT_XS, /* 10243 */
  IC_XD, /* 10244 */
  IC_64BIT_XD, /* 10245 */
  IC_XS, /* 10246 */
  IC_64BIT_XS, /* 10247 */
  IC, /* 10248 */
  IC_64BIT_REXW, /* 10249 */
  IC_XS, /* 10250 */
  IC_64BIT_REXW_XS, /* 10251 */
  IC_XD, /* 10252 */
  IC_64BIT_REXW_XD, /* 10253 */
  IC_XS, /* 10254 */
  IC_64BIT_REXW_XS, /* 10255 */
  IC_OPSIZE, /* 10256 */
  IC_64BIT_OPSIZE, /* 10257 */
  IC_XS_OPSIZE, /* 10258 */
  IC_64BIT_XS_OPSIZE, /* 10259 */
  IC_XD_OPSIZE, /* 10260 */
  IC_64BIT_XD_OPSIZE, /* 10261 */
  IC_XS_OPSIZE, /* 10262 */
  IC_64BIT_XD_OPSIZE, /* 10263 */
  IC_OPSIZE, /* 10264 */
  IC_64BIT_REXW_OPSIZE, /* 10265 */
  IC_XS_OPSIZE, /* 10266 */
  IC_64BIT_REXW_XS, /* 10267 */
  IC_XD_OPSIZE, /* 10268 */
  IC_64BIT_REXW_XD, /* 10269 */
  IC_XS_OPSIZE, /* 10270 */
  IC_64BIT_REXW_XS, /* 10271 */
  IC_ADSIZE, /* 10272 */
  IC_64BIT_ADSIZE, /* 10273 */
  IC_XS, /* 10274 */
  IC_64BIT_XS, /* 10275 */
  IC_XD, /* 10276 */
  IC_64BIT_XD, /* 10277 */
  IC_XS, /* 10278 */
  IC_64BIT_XS, /* 10279 */
  IC_ADSIZE, /* 10280 */
  IC_64BIT_REXW_ADSIZE, /* 10281 */
  IC_XS, /* 10282 */
  IC_64BIT_REXW_XS, /* 10283 */
  IC_XD, /* 10284 */
  IC_64BIT_REXW_XD, /* 10285 */
  IC_XS, /* 10286 */
  IC_64BIT_REXW_XS, /* 10287 */
  IC_OPSIZE_ADSIZE, /* 10288 */
  IC_64BIT_OPSIZE_ADSIZE, /* 10289 */
  IC_XS_OPSIZE, /* 10290 */
  IC_64BIT_XS_OPSIZE, /* 10291 */
  IC_XD_OPSIZE, /* 10292 */
  IC_64BIT_XD_OPSIZE, /* 10293 */
  IC_XS_OPSIZE, /* 10294 */
  IC_64BIT_XD_OPSIZE, /* 10295 */
  IC_OPSIZE_ADSIZE, /* 10296 */
  IC_64BIT_REXW_OPSIZE, /* 10297 */
  IC_XS_OPSIZE, /* 10298 */
  IC_64BIT_REXW_XS, /* 10299 */
  IC_XD_OPSIZE, /* 10300 */
  IC_64BIT_REXW_XD, /* 10301 */
  IC_XS_OPSIZE, /* 10302 */
  IC_64BIT_REXW_XS, /* 10303 */
  IC_VEX, /* 10304 */
  IC_VEX, /* 10305 */
  IC_VEX_XS, /* 10306 */
  IC_VEX_XS, /* 10307 */
  IC_VEX_XD, /* 10308 */
  IC_VEX_XD, /* 10309 */
  IC_VEX_XD, /* 10310 */
  IC_VEX_XD, /* 10311 */
  IC_VEX_W, /* 10312 */
  IC_VEX_W, /* 10313 */
  IC_VEX_W_XS, /* 10314 */
  IC_VEX_W_XS, /* 10315 */
  IC_VEX_W_XD, /* 10316 */
  IC_VEX_W_XD, /* 10317 */
  IC_VEX_W_XD, /* 10318 */
  IC_VEX_W_XD, /* 10319 */
  IC_VEX_OPSIZE, /* 10320 */
  IC_VEX_OPSIZE, /* 10321 */
  IC_VEX_OPSIZE, /* 10322 */
  IC_VEX_OPSIZE, /* 10323 */
  IC_VEX_OPSIZE, /* 10324 */
  IC_VEX_OPSIZE, /* 10325 */
  IC_VEX_OPSIZE, /* 10326 */
  IC_VEX_OPSIZE, /* 10327 */
  IC_VEX_W_OPSIZE, /* 10328 */
  IC_VEX_W_OPSIZE, /* 10329 */
  IC_VEX_W_OPSIZE, /* 10330 */
  IC_VEX_W_OPSIZE, /* 10331 */
  IC_VEX_W_OPSIZE, /* 10332 */
  IC_VEX_W_OPSIZE, /* 10333 */
  IC_VEX_W_OPSIZE, /* 10334 */
  IC_VEX_W_OPSIZE, /* 10335 */
  IC_VEX, /* 10336 */
  IC_VEX, /* 10337 */
  IC_VEX_XS, /* 10338 */
  IC_VEX_XS, /* 10339 */
  IC_VEX_XD, /* 10340 */
  IC_VEX_XD, /* 10341 */
  IC_VEX_XD, /* 10342 */
  IC_VEX_XD, /* 10343 */
  IC_VEX_W, /* 10344 */
  IC_VEX_W, /* 10345 */
  IC_VEX_W_XS, /* 10346 */
  IC_VEX_W_XS, /* 10347 */
  IC_VEX_W_XD, /* 10348 */
  IC_VEX_W_XD, /* 10349 */
  IC_VEX_W_XD, /* 10350 */
  IC_VEX_W_XD, /* 10351 */
  IC_VEX_OPSIZE, /* 10352 */
  IC_VEX_OPSIZE, /* 10353 */
  IC_VEX_OPSIZE, /* 10354 */
  IC_VEX_OPSIZE, /* 10355 */
  IC_VEX_OPSIZE, /* 10356 */
  IC_VEX_OPSIZE, /* 10357 */
  IC_VEX_OPSIZE, /* 10358 */
  IC_VEX_OPSIZE, /* 10359 */
  IC_VEX_W_OPSIZE, /* 10360 */
  IC_VEX_W_OPSIZE, /* 10361 */
  IC_VEX_W_OPSIZE, /* 10362 */
  IC_VEX_W_OPSIZE, /* 10363 */
  IC_VEX_W_OPSIZE, /* 10364 */
  IC_VEX_W_OPSIZE, /* 10365 */
  IC_VEX_W_OPSIZE, /* 10366 */
  IC_VEX_W_OPSIZE, /* 10367 */
  IC_VEX_L, /* 10368 */
  IC_VEX_L, /* 10369 */
  IC_VEX_L_XS, /* 10370 */
  IC_VEX_L_XS, /* 10371 */
  IC_VEX_L_XD, /* 10372 */
  IC_VEX_L_XD, /* 10373 */
  IC_VEX_L_XD, /* 10374 */
  IC_VEX_L_XD, /* 10375 */
  IC_VEX_L_W, /* 10376 */
  IC_VEX_L_W, /* 10377 */
  IC_VEX_L_W_XS, /* 10378 */
  IC_VEX_L_W_XS, /* 10379 */
  IC_VEX_L_W_XD, /* 10380 */
  IC_VEX_L_W_XD, /* 10381 */
  IC_VEX_L_W_XD, /* 10382 */
  IC_VEX_L_W_XD, /* 10383 */
  IC_VEX_L_OPSIZE, /* 10384 */
  IC_VEX_L_OPSIZE, /* 10385 */
  IC_VEX_L_OPSIZE, /* 10386 */
  IC_VEX_L_OPSIZE, /* 10387 */
  IC_VEX_L_OPSIZE, /* 10388 */
  IC_VEX_L_OPSIZE, /* 10389 */
  IC_VEX_L_OPSIZE, /* 10390 */
  IC_VEX_L_OPSIZE, /* 10391 */
  IC_VEX_L_W_OPSIZE, /* 10392 */
  IC_VEX_L_W_OPSIZE, /* 10393 */
  IC_VEX_L_W_OPSIZE, /* 10394 */
  IC_VEX_L_W_OPSIZE, /* 10395 */
  IC_VEX_L_W_OPSIZE, /* 10396 */
  IC_VEX_L_W_OPSIZE, /* 10397 */
  IC_VEX_L_W_OPSIZE, /* 10398 */
  IC_VEX_L_W_OPSIZE, /* 10399 */
  IC_VEX_L, /* 10400 */
  IC_VEX_L, /* 10401 */
  IC_VEX_L_XS, /* 10402 */
  IC_VEX_L_XS, /* 10403 */
  IC_VEX_L_XD, /* 10404 */
  IC_VEX_L_XD, /* 10405 */
  IC_VEX_L_XD, /* 10406 */
  IC_VEX_L_XD, /* 10407 */
  IC_VEX_L_W, /* 10408 */
  IC_VEX_L_W, /* 10409 */
  IC_VEX_L_W_XS, /* 10410 */
  IC_VEX_L_W_XS, /* 10411 */
  IC_VEX_L_W_XD, /* 10412 */
  IC_VEX_L_W_XD, /* 10413 */
  IC_VEX_L_W_XD, /* 10414 */
  IC_VEX_L_W_XD, /* 10415 */
  IC_VEX_L_OPSIZE, /* 10416 */
  IC_VEX_L_OPSIZE, /* 10417 */
  IC_VEX_L_OPSIZE, /* 10418 */
  IC_VEX_L_OPSIZE, /* 10419 */
  IC_VEX_L_OPSIZE, /* 10420 */
  IC_VEX_L_OPSIZE, /* 10421 */
  IC_VEX_L_OPSIZE, /* 10422 */
  IC_VEX_L_OPSIZE, /* 10423 */
  IC_VEX_L_W_OPSIZE, /* 10424 */
  IC_VEX_L_W_OPSIZE, /* 10425 */
  IC_VEX_L_W_OPSIZE, /* 10426 */
  IC_VEX_L_W_OPSIZE, /* 10427 */
  IC_VEX_L_W_OPSIZE, /* 10428 */
  IC_VEX_L_W_OPSIZE, /* 10429 */
  IC_VEX_L_W_OPSIZE, /* 10430 */
  IC_VEX_L_W_OPSIZE, /* 10431 */
  IC_VEX_L, /* 10432 */
  IC_VEX_L, /* 10433 */
  IC_VEX_L_XS, /* 10434 */
  IC_VEX_L_XS, /* 10435 */
  IC_VEX_L_XD, /* 10436 */
  IC_VEX_L_XD, /* 10437 */
  IC_VEX_L_XD, /* 10438 */
  IC_VEX_L_XD, /* 10439 */
  IC_VEX_L_W, /* 10440 */
  IC_VEX_L_W, /* 10441 */
  IC_VEX_L_W_XS, /* 10442 */
  IC_VEX_L_W_XS, /* 10443 */
  IC_VEX_L_W_XD, /* 10444 */
  IC_VEX_L_W_XD, /* 10445 */
  IC_VEX_L_W_XD, /* 10446 */
  IC_VEX_L_W_XD, /* 10447 */
  IC_VEX_L_OPSIZE, /* 10448 */
  IC_VEX_L_OPSIZE, /* 10449 */
  IC_VEX_L_OPSIZE, /* 10450 */
  IC_VEX_L_OPSIZE, /* 10451 */
  IC_VEX_L_OPSIZE, /* 10452 */
  IC_VEX_L_OPSIZE, /* 10453 */
  IC_VEX_L_OPSIZE, /* 10454 */
  IC_VEX_L_OPSIZE, /* 10455 */
  IC_VEX_L_W_OPSIZE, /* 10456 */
  IC_VEX_L_W_OPSIZE, /* 10457 */
  IC_VEX_L_W_OPSIZE, /* 10458 */
  IC_VEX_L_W_OPSIZE, /* 10459 */
  IC_VEX_L_W_OPSIZE, /* 10460 */
  IC_VEX_L_W_OPSIZE, /* 10461 */
  IC_VEX_L_W_OPSIZE, /* 10462 */
  IC_VEX_L_W_OPSIZE, /* 10463 */
  IC_VEX_L, /* 10464 */
  IC_VEX_L, /* 10465 */
  IC_VEX_L_XS, /* 10466 */
  IC_VEX_L_XS, /* 10467 */
  IC_VEX_L_XD, /* 10468 */
  IC_VEX_L_XD, /* 10469 */
  IC_VEX_L_XD, /* 10470 */
  IC_VEX_L_XD, /* 10471 */
  IC_VEX_L_W, /* 10472 */
  IC_VEX_L_W, /* 10473 */
  IC_VEX_L_W_XS, /* 10474 */
  IC_VEX_L_W_XS, /* 10475 */
  IC_VEX_L_W_XD, /* 10476 */
  IC_VEX_L_W_XD, /* 10477 */
  IC_VEX_L_W_XD, /* 10478 */
  IC_VEX_L_W_XD, /* 10479 */
  IC_VEX_L_OPSIZE, /* 10480 */
  IC_VEX_L_OPSIZE, /* 10481 */
  IC_VEX_L_OPSIZE, /* 10482 */
  IC_VEX_L_OPSIZE, /* 10483 */
  IC_VEX_L_OPSIZE, /* 10484 */
  IC_VEX_L_OPSIZE, /* 10485 */
  IC_VEX_L_OPSIZE, /* 10486 */
  IC_VEX_L_OPSIZE, /* 10487 */
  IC_VEX_L_W_OPSIZE, /* 10488 */
  IC_VEX_L_W_OPSIZE, /* 10489 */
  IC_VEX_L_W_OPSIZE, /* 10490 */
  IC_VEX_L_W_OPSIZE, /* 10491 */
  IC_VEX_L_W_OPSIZE, /* 10492 */
  IC_VEX_L_W_OPSIZE, /* 10493 */
  IC_VEX_L_W_OPSIZE, /* 10494 */
  IC_VEX_L_W_OPSIZE, /* 10495 */
  IC_EVEX_K_B, /* 10496 */
  IC_EVEX_K_B, /* 10497 */
  IC_EVEX_XS_K_B, /* 10498 */
  IC_EVEX_XS_K_B, /* 10499 */
  IC_EVEX_XD_K_B, /* 10500 */
  IC_EVEX_XD_K_B, /* 10501 */
  IC_EVEX_XD_K_B, /* 10502 */
  IC_EVEX_XD_K_B, /* 10503 */
  IC_EVEX_W_K_B, /* 10504 */
  IC_EVEX_W_K_B, /* 10505 */
  IC_EVEX_W_XS_K_B, /* 10506 */
  IC_EVEX_W_XS_K_B, /* 10507 */
  IC_EVEX_W_XD_K_B, /* 10508 */
  IC_EVEX_W_XD_K_B, /* 10509 */
  IC_EVEX_W_XD_K_B, /* 10510 */
  IC_EVEX_W_XD_K_B, /* 10511 */
  IC_EVEX_OPSIZE_K_B, /* 10512 */
  IC_EVEX_OPSIZE_K_B, /* 10513 */
  IC_EVEX_OPSIZE_K_B, /* 10514 */
  IC_EVEX_OPSIZE_K_B, /* 10515 */
  IC_EVEX_OPSIZE_K_B, /* 10516 */
  IC_EVEX_OPSIZE_K_B, /* 10517 */
  IC_EVEX_OPSIZE_K_B, /* 10518 */
  IC_EVEX_OPSIZE_K_B, /* 10519 */
  IC_EVEX_W_OPSIZE_K_B, /* 10520 */
  IC_EVEX_W_OPSIZE_K_B, /* 10521 */
  IC_EVEX_W_OPSIZE_K_B, /* 10522 */
  IC_EVEX_W_OPSIZE_K_B, /* 10523 */
  IC_EVEX_W_OPSIZE_K_B, /* 10524 */
  IC_EVEX_W_OPSIZE_K_B, /* 10525 */
  IC_EVEX_W_OPSIZE_K_B, /* 10526 */
  IC_EVEX_W_OPSIZE_K_B, /* 10527 */
  IC_EVEX_K_B, /* 10528 */
  IC_EVEX_K_B, /* 10529 */
  IC_EVEX_XS_K_B, /* 10530 */
  IC_EVEX_XS_K_B, /* 10531 */
  IC_EVEX_XD_K_B, /* 10532 */
  IC_EVEX_XD_K_B, /* 10533 */
  IC_EVEX_XD_K_B, /* 10534 */
  IC_EVEX_XD_K_B, /* 10535 */
  IC_EVEX_W_K_B, /* 10536 */
  IC_EVEX_W_K_B, /* 10537 */
  IC_EVEX_W_XS_K_B, /* 10538 */
  IC_EVEX_W_XS_K_B, /* 10539 */
  IC_EVEX_W_XD_K_B, /* 10540 */
  IC_EVEX_W_XD_K_B, /* 10541 */
  IC_EVEX_W_XD_K_B, /* 10542 */
  IC_EVEX_W_XD_K_B, /* 10543 */
  IC_EVEX_OPSIZE_K_B, /* 10544 */
  IC_EVEX_OPSIZE_K_B, /* 10545 */
  IC_EVEX_OPSIZE_K_B, /* 10546 */
  IC_EVEX_OPSIZE_K_B, /* 10547 */
  IC_EVEX_OPSIZE_K_B, /* 10548 */
  IC_EVEX_OPSIZE_K_B, /* 10549 */
  IC_EVEX_OPSIZE_K_B, /* 10550 */
  IC_EVEX_OPSIZE_K_B, /* 10551 */
  IC_EVEX_W_OPSIZE_K_B, /* 10552 */
  IC_EVEX_W_OPSIZE_K_B, /* 10553 */
  IC_EVEX_W_OPSIZE_K_B, /* 10554 */
  IC_EVEX_W_OPSIZE_K_B, /* 10555 */
  IC_EVEX_W_OPSIZE_K_B, /* 10556 */
  IC_EVEX_W_OPSIZE_K_B, /* 10557 */
  IC_EVEX_W_OPSIZE_K_B, /* 10558 */
  IC_EVEX_W_OPSIZE_K_B, /* 10559 */
  IC_EVEX_K_B, /* 10560 */
  IC_EVEX_K_B, /* 10561 */
  IC_EVEX_XS_K_B, /* 10562 */
  IC_EVEX_XS_K_B, /* 10563 */
  IC_EVEX_XD_K_B, /* 10564 */
  IC_EVEX_XD_K_B, /* 10565 */
  IC_EVEX_XD_K_B, /* 10566 */
  IC_EVEX_XD_K_B, /* 10567 */
  IC_EVEX_W_K_B, /* 10568 */
  IC_EVEX_W_K_B, /* 10569 */
  IC_EVEX_W_XS_K_B, /* 10570 */
  IC_EVEX_W_XS_K_B, /* 10571 */
  IC_EVEX_W_XD_K_B, /* 10572 */
  IC_EVEX_W_XD_K_B, /* 10573 */
  IC_EVEX_W_XD_K_B, /* 10574 */
  IC_EVEX_W_XD_K_B, /* 10575 */
  IC_EVEX_OPSIZE_K_B, /* 10576 */
  IC_EVEX_OPSIZE_K_B, /* 10577 */
  IC_EVEX_OPSIZE_K_B, /* 10578 */
  IC_EVEX_OPSIZE_K_B, /* 10579 */
  IC_EVEX_OPSIZE_K_B, /* 10580 */
  IC_EVEX_OPSIZE_K_B, /* 10581 */
  IC_EVEX_OPSIZE_K_B, /* 10582 */
  IC_EVEX_OPSIZE_K_B, /* 10583 */
  IC_EVEX_W_OPSIZE_K_B, /* 10584 */
  IC_EVEX_W_OPSIZE_K_B, /* 10585 */
  IC_EVEX_W_OPSIZE_K_B, /* 10586 */
  IC_EVEX_W_OPSIZE_K_B, /* 10587 */
  IC_EVEX_W_OPSIZE_K_B, /* 10588 */
  IC_EVEX_W_OPSIZE_K_B, /* 10589 */
  IC_EVEX_W_OPSIZE_K_B, /* 10590 */
  IC_EVEX_W_OPSIZE_K_B, /* 10591 */
  IC_EVEX_K_B, /* 10592 */
  IC_EVEX_K_B, /* 10593 */
  IC_EVEX_XS_K_B, /* 10594 */
  IC_EVEX_XS_K_B, /* 10595 */
  IC_EVEX_XD_K_B, /* 10596 */
  IC_EVEX_XD_K_B, /* 10597 */
  IC_EVEX_XD_K_B, /* 10598 */
  IC_EVEX_XD_K_B, /* 10599 */
  IC_EVEX_W_K_B, /* 10600 */
  IC_EVEX_W_K_B, /* 10601 */
  IC_EVEX_W_XS_K_B, /* 10602 */
  IC_EVEX_W_XS_K_B, /* 10603 */
  IC_EVEX_W_XD_K_B, /* 10604 */
  IC_EVEX_W_XD_K_B, /* 10605 */
  IC_EVEX_W_XD_K_B, /* 10606 */
  IC_EVEX_W_XD_K_B, /* 10607 */
  IC_EVEX_OPSIZE_K_B, /* 10608 */
  IC_EVEX_OPSIZE_K_B, /* 10609 */
  IC_EVEX_OPSIZE_K_B, /* 10610 */
  IC_EVEX_OPSIZE_K_B, /* 10611 */
  IC_EVEX_OPSIZE_K_B, /* 10612 */
  IC_EVEX_OPSIZE_K_B, /* 10613 */
  IC_EVEX_OPSIZE_K_B, /* 10614 */
  IC_EVEX_OPSIZE_K_B, /* 10615 */
  IC_EVEX_W_OPSIZE_K_B, /* 10616 */
  IC_EVEX_W_OPSIZE_K_B, /* 10617 */
  IC_EVEX_W_OPSIZE_K_B, /* 10618 */
  IC_EVEX_W_OPSIZE_K_B, /* 10619 */
  IC_EVEX_W_OPSIZE_K_B, /* 10620 */
  IC_EVEX_W_OPSIZE_K_B, /* 10621 */
  IC_EVEX_W_OPSIZE_K_B, /* 10622 */
  IC_EVEX_W_OPSIZE_K_B, /* 10623 */
  IC_EVEX_K_B, /* 10624 */
  IC_EVEX_K_B, /* 10625 */
  IC_EVEX_XS_K_B, /* 10626 */
  IC_EVEX_XS_K_B, /* 10627 */
  IC_EVEX_XD_K_B, /* 10628 */
  IC_EVEX_XD_K_B, /* 10629 */
  IC_EVEX_XD_K_B, /* 10630 */
  IC_EVEX_XD_K_B, /* 10631 */
  IC_EVEX_W_K_B, /* 10632 */
  IC_EVEX_W_K_B, /* 10633 */
  IC_EVEX_W_XS_K_B, /* 10634 */
  IC_EVEX_W_XS_K_B, /* 10635 */
  IC_EVEX_W_XD_K_B, /* 10636 */
  IC_EVEX_W_XD_K_B, /* 10637 */
  IC_EVEX_W_XD_K_B, /* 10638 */
  IC_EVEX_W_XD_K_B, /* 10639 */
  IC_EVEX_OPSIZE_K_B, /* 10640 */
  IC_EVEX_OPSIZE_K_B, /* 10641 */
  IC_EVEX_OPSIZE_K_B, /* 10642 */
  IC_EVEX_OPSIZE_K_B, /* 10643 */
  IC_EVEX_OPSIZE_K_B, /* 10644 */
  IC_EVEX_OPSIZE_K_B, /* 10645 */
  IC_EVEX_OPSIZE_K_B, /* 10646 */
  IC_EVEX_OPSIZE_K_B, /* 10647 */
  IC_EVEX_W_OPSIZE_K_B, /* 10648 */
  IC_EVEX_W_OPSIZE_K_B, /* 10649 */
  IC_EVEX_W_OPSIZE_K_B, /* 10650 */
  IC_EVEX_W_OPSIZE_K_B, /* 10651 */
  IC_EVEX_W_OPSIZE_K_B, /* 10652 */
  IC_EVEX_W_OPSIZE_K_B, /* 10653 */
  IC_EVEX_W_OPSIZE_K_B, /* 10654 */
  IC_EVEX_W_OPSIZE_K_B, /* 10655 */
  IC_EVEX_K_B, /* 10656 */
  IC_EVEX_K_B, /* 10657 */
  IC_EVEX_XS_K_B, /* 10658 */
  IC_EVEX_XS_K_B, /* 10659 */
  IC_EVEX_XD_K_B, /* 10660 */
  IC_EVEX_XD_K_B, /* 10661 */
  IC_EVEX_XD_K_B, /* 10662 */
  IC_EVEX_XD_K_B, /* 10663 */
  IC_EVEX_W_K_B, /* 10664 */
  IC_EVEX_W_K_B, /* 10665 */
  IC_EVEX_W_XS_K_B, /* 10666 */
  IC_EVEX_W_XS_K_B, /* 10667 */
  IC_EVEX_W_XD_K_B, /* 10668 */
  IC_EVEX_W_XD_K_B, /* 10669 */
  IC_EVEX_W_XD_K_B, /* 10670 */
  IC_EVEX_W_XD_K_B, /* 10671 */
  IC_EVEX_OPSIZE_K_B, /* 10672 */
  IC_EVEX_OPSIZE_K_B, /* 10673 */
  IC_EVEX_OPSIZE_K_B, /* 10674 */
  IC_EVEX_OPSIZE_K_B, /* 10675 */
  IC_EVEX_OPSIZE_K_B, /* 10676 */
  IC_EVEX_OPSIZE_K_B, /* 10677 */
  IC_EVEX_OPSIZE_K_B, /* 10678 */
  IC_EVEX_OPSIZE_K_B, /* 10679 */
  IC_EVEX_W_OPSIZE_K_B, /* 10680 */
  IC_EVEX_W_OPSIZE_K_B, /* 10681 */
  IC_EVEX_W_OPSIZE_K_B, /* 10682 */
  IC_EVEX_W_OPSIZE_K_B, /* 10683 */
  IC_EVEX_W_OPSIZE_K_B, /* 10684 */
  IC_EVEX_W_OPSIZE_K_B, /* 10685 */
  IC_EVEX_W_OPSIZE_K_B, /* 10686 */
  IC_EVEX_W_OPSIZE_K_B, /* 10687 */
  IC_EVEX_K_B, /* 10688 */
  IC_EVEX_K_B, /* 10689 */
  IC_EVEX_XS_K_B, /* 10690 */
  IC_EVEX_XS_K_B, /* 10691 */
  IC_EVEX_XD_K_B, /* 10692 */
  IC_EVEX_XD_K_B, /* 10693 */
  IC_EVEX_XD_K_B, /* 10694 */
  IC_EVEX_XD_K_B, /* 10695 */
  IC_EVEX_W_K_B, /* 10696 */
  IC_EVEX_W_K_B, /* 10697 */
  IC_EVEX_W_XS_K_B, /* 10698 */
  IC_EVEX_W_XS_K_B, /* 10699 */
  IC_EVEX_W_XD_K_B, /* 10700 */
  IC_EVEX_W_XD_K_B, /* 10701 */
  IC_EVEX_W_XD_K_B, /* 10702 */
  IC_EVEX_W_XD_K_B, /* 10703 */
  IC_EVEX_OPSIZE_K_B, /* 10704 */
  IC_EVEX_OPSIZE_K_B, /* 10705 */
  IC_EVEX_OPSIZE_K_B, /* 10706 */
  IC_EVEX_OPSIZE_K_B, /* 10707 */
  IC_EVEX_OPSIZE_K_B, /* 10708 */
  IC_EVEX_OPSIZE_K_B, /* 10709 */
  IC_EVEX_OPSIZE_K_B, /* 10710 */
  IC_EVEX_OPSIZE_K_B, /* 10711 */
  IC_EVEX_W_OPSIZE_K_B, /* 10712 */
  IC_EVEX_W_OPSIZE_K_B, /* 10713 */
  IC_EVEX_W_OPSIZE_K_B, /* 10714 */
  IC_EVEX_W_OPSIZE_K_B, /* 10715 */
  IC_EVEX_W_OPSIZE_K_B, /* 10716 */
  IC_EVEX_W_OPSIZE_K_B, /* 10717 */
  IC_EVEX_W_OPSIZE_K_B, /* 10718 */
  IC_EVEX_W_OPSIZE_K_B, /* 10719 */
  IC_EVEX_K_B, /* 10720 */
  IC_EVEX_K_B, /* 10721 */
  IC_EVEX_XS_K_B, /* 10722 */
  IC_EVEX_XS_K_B, /* 10723 */
  IC_EVEX_XD_K_B, /* 10724 */
  IC_EVEX_XD_K_B, /* 10725 */
  IC_EVEX_XD_K_B, /* 10726 */
  IC_EVEX_XD_K_B, /* 10727 */
  IC_EVEX_W_K_B, /* 10728 */
  IC_EVEX_W_K_B, /* 10729 */
  IC_EVEX_W_XS_K_B, /* 10730 */
  IC_EVEX_W_XS_K_B, /* 10731 */
  IC_EVEX_W_XD_K_B, /* 10732 */
  IC_EVEX_W_XD_K_B, /* 10733 */
  IC_EVEX_W_XD_K_B, /* 10734 */
  IC_EVEX_W_XD_K_B, /* 10735 */
  IC_EVEX_OPSIZE_K_B, /* 10736 */
  IC_EVEX_OPSIZE_K_B, /* 10737 */
  IC_EVEX_OPSIZE_K_B, /* 10738 */
  IC_EVEX_OPSIZE_K_B, /* 10739 */
  IC_EVEX_OPSIZE_K_B, /* 10740 */
  IC_EVEX_OPSIZE_K_B, /* 10741 */
  IC_EVEX_OPSIZE_K_B, /* 10742 */
  IC_EVEX_OPSIZE_K_B, /* 10743 */
  IC_EVEX_W_OPSIZE_K_B, /* 10744 */
  IC_EVEX_W_OPSIZE_K_B, /* 10745 */
  IC_EVEX_W_OPSIZE_K_B, /* 10746 */
  IC_EVEX_W_OPSIZE_K_B, /* 10747 */
  IC_EVEX_W_OPSIZE_K_B, /* 10748 */
  IC_EVEX_W_OPSIZE_K_B, /* 10749 */
  IC_EVEX_W_OPSIZE_K_B, /* 10750 */
  IC_EVEX_W_OPSIZE_K_B, /* 10751 */
  IC, /* 10752 */
  IC_64BIT, /* 10753 */
  IC_XS, /* 10754 */
  IC_64BIT_XS, /* 10755 */
  IC_XD, /* 10756 */
  IC_64BIT_XD, /* 10757 */
  IC_XS, /* 10758 */
  IC_64BIT_XS, /* 10759 */
  IC, /* 10760 */
  IC_64BIT_REXW, /* 10761 */
  IC_XS, /* 10762 */
  IC_64BIT_REXW_XS, /* 10763 */
  IC_XD, /* 10764 */
  IC_64BIT_REXW_XD, /* 10765 */
  IC_XS, /* 10766 */
  IC_64BIT_REXW_XS, /* 10767 */
  IC_OPSIZE, /* 10768 */
  IC_64BIT_OPSIZE, /* 10769 */
  IC_XS_OPSIZE, /* 10770 */
  IC_64BIT_XS_OPSIZE, /* 10771 */
  IC_XD_OPSIZE, /* 10772 */
  IC_64BIT_XD_OPSIZE, /* 10773 */
  IC_XS_OPSIZE, /* 10774 */
  IC_64BIT_XD_OPSIZE, /* 10775 */
  IC_OPSIZE, /* 10776 */
  IC_64BIT_REXW_OPSIZE, /* 10777 */
  IC_XS_OPSIZE, /* 10778 */
  IC_64BIT_REXW_XS, /* 10779 */
  IC_XD_OPSIZE, /* 10780 */
  IC_64BIT_REXW_XD, /* 10781 */
  IC_XS_OPSIZE, /* 10782 */
  IC_64BIT_REXW_XS, /* 10783 */
  IC_ADSIZE, /* 10784 */
  IC_64BIT_ADSIZE, /* 10785 */
  IC_XS, /* 10786 */
  IC_64BIT_XS, /* 10787 */
  IC_XD, /* 10788 */
  IC_64BIT_XD, /* 10789 */
  IC_XS, /* 10790 */
  IC_64BIT_XS, /* 10791 */
  IC_ADSIZE, /* 10792 */
  IC_64BIT_REXW_ADSIZE, /* 10793 */
  IC_XS, /* 10794 */
  IC_64BIT_REXW_XS, /* 10795 */
  IC_XD, /* 10796 */
  IC_64BIT_REXW_XD, /* 10797 */
  IC_XS, /* 10798 */
  IC_64BIT_REXW_XS, /* 10799 */
  IC_OPSIZE_ADSIZE, /* 10800 */
  IC_64BIT_OPSIZE_ADSIZE, /* 10801 */
  IC_XS_OPSIZE, /* 10802 */
  IC_64BIT_XS_OPSIZE, /* 10803 */
  IC_XD_OPSIZE, /* 10804 */
  IC_64BIT_XD_OPSIZE, /* 10805 */
  IC_XS_OPSIZE, /* 10806 */
  IC_64BIT_XD_OPSIZE, /* 10807 */
  IC_OPSIZE_ADSIZE, /* 10808 */
  IC_64BIT_REXW_OPSIZE, /* 10809 */
  IC_XS_OPSIZE, /* 10810 */
  IC_64BIT_REXW_XS, /* 10811 */
  IC_XD_OPSIZE, /* 10812 */
  IC_64BIT_REXW_XD, /* 10813 */
  IC_XS_OPSIZE, /* 10814 */
  IC_64BIT_REXW_XS, /* 10815 */
  IC_VEX, /* 10816 */
  IC_VEX, /* 10817 */
  IC_VEX_XS, /* 10818 */
  IC_VEX_XS, /* 10819 */
  IC_VEX_XD, /* 10820 */
  IC_VEX_XD, /* 10821 */
  IC_VEX_XD, /* 10822 */
  IC_VEX_XD, /* 10823 */
  IC_VEX_W, /* 10824 */
  IC_VEX_W, /* 10825 */
  IC_VEX_W_XS, /* 10826 */
  IC_VEX_W_XS, /* 10827 */
  IC_VEX_W_XD, /* 10828 */
  IC_VEX_W_XD, /* 10829 */
  IC_VEX_W_XD, /* 10830 */
  IC_VEX_W_XD, /* 10831 */
  IC_VEX_OPSIZE, /* 10832 */
  IC_VEX_OPSIZE, /* 10833 */
  IC_VEX_OPSIZE, /* 10834 */
  IC_VEX_OPSIZE, /* 10835 */
  IC_VEX_OPSIZE, /* 10836 */
  IC_VEX_OPSIZE, /* 10837 */
  IC_VEX_OPSIZE, /* 10838 */
  IC_VEX_OPSIZE, /* 10839 */
  IC_VEX_W_OPSIZE, /* 10840 */
  IC_VEX_W_OPSIZE, /* 10841 */
  IC_VEX_W_OPSIZE, /* 10842 */
  IC_VEX_W_OPSIZE, /* 10843 */
  IC_VEX_W_OPSIZE, /* 10844 */
  IC_VEX_W_OPSIZE, /* 10845 */
  IC_VEX_W_OPSIZE, /* 10846 */
  IC_VEX_W_OPSIZE, /* 10847 */
  IC_VEX, /* 10848 */
  IC_VEX, /* 10849 */
  IC_VEX_XS, /* 10850 */
  IC_VEX_XS, /* 10851 */
  IC_VEX_XD, /* 10852 */
  IC_VEX_XD, /* 10853 */
  IC_VEX_XD, /* 10854 */
  IC_VEX_XD, /* 10855 */
  IC_VEX_W, /* 10856 */
  IC_VEX_W, /* 10857 */
  IC_VEX_W_XS, /* 10858 */
  IC_VEX_W_XS, /* 10859 */
  IC_VEX_W_XD, /* 10860 */
  IC_VEX_W_XD, /* 10861 */
  IC_VEX_W_XD, /* 10862 */
  IC_VEX_W_XD, /* 10863 */
  IC_VEX_OPSIZE, /* 10864 */
  IC_VEX_OPSIZE, /* 10865 */
  IC_VEX_OPSIZE, /* 10866 */
  IC_VEX_OPSIZE, /* 10867 */
  IC_VEX_OPSIZE, /* 10868 */
  IC_VEX_OPSIZE, /* 10869 */
  IC_VEX_OPSIZE, /* 10870 */
  IC_VEX_OPSIZE, /* 10871 */
  IC_VEX_W_OPSIZE, /* 10872 */
  IC_VEX_W_OPSIZE, /* 10873 */
  IC_VEX_W_OPSIZE, /* 10874 */
  IC_VEX_W_OPSIZE, /* 10875 */
  IC_VEX_W_OPSIZE, /* 10876 */
  IC_VEX_W_OPSIZE, /* 10877 */
  IC_VEX_W_OPSIZE, /* 10878 */
  IC_VEX_W_OPSIZE, /* 10879 */
  IC_VEX_L, /* 10880 */
  IC_VEX_L, /* 10881 */
  IC_VEX_L_XS, /* 10882 */
  IC_VEX_L_XS, /* 10883 */
  IC_VEX_L_XD, /* 10884 */
  IC_VEX_L_XD, /* 10885 */
  IC_VEX_L_XD, /* 10886 */
  IC_VEX_L_XD, /* 10887 */
  IC_VEX_L_W, /* 10888 */
  IC_VEX_L_W, /* 10889 */
  IC_VEX_L_W_XS, /* 10890 */
  IC_VEX_L_W_XS, /* 10891 */
  IC_VEX_L_W_XD, /* 10892 */
  IC_VEX_L_W_XD, /* 10893 */
  IC_VEX_L_W_XD, /* 10894 */
  IC_VEX_L_W_XD, /* 10895 */
  IC_VEX_L_OPSIZE, /* 10896 */
  IC_VEX_L_OPSIZE, /* 10897 */
  IC_VEX_L_OPSIZE, /* 10898 */
  IC_VEX_L_OPSIZE, /* 10899 */
  IC_VEX_L_OPSIZE, /* 10900 */
  IC_VEX_L_OPSIZE, /* 10901 */
  IC_VEX_L_OPSIZE, /* 10902 */
  IC_VEX_L_OPSIZE, /* 10903 */
  IC_VEX_L_W_OPSIZE, /* 10904 */
  IC_VEX_L_W_OPSIZE, /* 10905 */
  IC_VEX_L_W_OPSIZE, /* 10906 */
  IC_VEX_L_W_OPSIZE, /* 10907 */
  IC_VEX_L_W_OPSIZE, /* 10908 */
  IC_VEX_L_W_OPSIZE, /* 10909 */
  IC_VEX_L_W_OPSIZE, /* 10910 */
  IC_VEX_L_W_OPSIZE, /* 10911 */
  IC_VEX_L, /* 10912 */
  IC_VEX_L, /* 10913 */
  IC_VEX_L_XS, /* 10914 */
  IC_VEX_L_XS, /* 10915 */
  IC_VEX_L_XD, /* 10916 */
  IC_VEX_L_XD, /* 10917 */
  IC_VEX_L_XD, /* 10918 */
  IC_VEX_L_XD, /* 10919 */
  IC_VEX_L_W, /* 10920 */
  IC_VEX_L_W, /* 10921 */
  IC_VEX_L_W_XS, /* 10922 */
  IC_VEX_L_W_XS, /* 10923 */
  IC_VEX_L_W_XD, /* 10924 */
  IC_VEX_L_W_XD, /* 10925 */
  IC_VEX_L_W_XD, /* 10926 */
  IC_VEX_L_W_XD, /* 10927 */
  IC_VEX_L_OPSIZE, /* 10928 */
  IC_VEX_L_OPSIZE, /* 10929 */
  IC_VEX_L_OPSIZE, /* 10930 */
  IC_VEX_L_OPSIZE, /* 10931 */
  IC_VEX_L_OPSIZE, /* 10932 */
  IC_VEX_L_OPSIZE, /* 10933 */
  IC_VEX_L_OPSIZE, /* 10934 */
  IC_VEX_L_OPSIZE, /* 10935 */
  IC_VEX_L_W_OPSIZE, /* 10936 */
  IC_VEX_L_W_OPSIZE, /* 10937 */
  IC_VEX_L_W_OPSIZE, /* 10938 */
  IC_VEX_L_W_OPSIZE, /* 10939 */
  IC_VEX_L_W_OPSIZE, /* 10940 */
  IC_VEX_L_W_OPSIZE, /* 10941 */
  IC_VEX_L_W_OPSIZE, /* 10942 */
  IC_VEX_L_W_OPSIZE, /* 10943 */
  IC_VEX_L, /* 10944 */
  IC_VEX_L, /* 10945 */
  IC_VEX_L_XS, /* 10946 */
  IC_VEX_L_XS, /* 10947 */
  IC_VEX_L_XD, /* 10948 */
  IC_VEX_L_XD, /* 10949 */
  IC_VEX_L_XD, /* 10950 */
  IC_VEX_L_XD, /* 10951 */
  IC_VEX_L_W, /* 10952 */
  IC_VEX_L_W, /* 10953 */
  IC_VEX_L_W_XS, /* 10954 */
  IC_VEX_L_W_XS, /* 10955 */
  IC_VEX_L_W_XD, /* 10956 */
  IC_VEX_L_W_XD, /* 10957 */
  IC_VEX_L_W_XD, /* 10958 */
  IC_VEX_L_W_XD, /* 10959 */
  IC_VEX_L_OPSIZE, /* 10960 */
  IC_VEX_L_OPSIZE, /* 10961 */
  IC_VEX_L_OPSIZE, /* 10962 */
  IC_VEX_L_OPSIZE, /* 10963 */
  IC_VEX_L_OPSIZE, /* 10964 */
  IC_VEX_L_OPSIZE, /* 10965 */
  IC_VEX_L_OPSIZE, /* 10966 */
  IC_VEX_L_OPSIZE, /* 10967 */
  IC_VEX_L_W_OPSIZE, /* 10968 */
  IC_VEX_L_W_OPSIZE, /* 10969 */
  IC_VEX_L_W_OPSIZE, /* 10970 */
  IC_VEX_L_W_OPSIZE, /* 10971 */
  IC_VEX_L_W_OPSIZE, /* 10972 */
  IC_VEX_L_W_OPSIZE, /* 10973 */
  IC_VEX_L_W_OPSIZE, /* 10974 */
  IC_VEX_L_W_OPSIZE, /* 10975 */
  IC_VEX_L, /* 10976 */
  IC_VEX_L, /* 10977 */
  IC_VEX_L_XS, /* 10978 */
  IC_VEX_L_XS, /* 10979 */
  IC_VEX_L_XD, /* 10980 */
  IC_VEX_L_XD, /* 10981 */
  IC_VEX_L_XD, /* 10982 */
  IC_VEX_L_XD, /* 10983 */
  IC_VEX_L_W, /* 10984 */
  IC_VEX_L_W, /* 10985 */
  IC_VEX_L_W_XS, /* 10986 */
  IC_VEX_L_W_XS, /* 10987 */
  IC_VEX_L_W_XD, /* 10988 */
  IC_VEX_L_W_XD, /* 10989 */
  IC_VEX_L_W_XD, /* 10990 */
  IC_VEX_L_W_XD, /* 10991 */
  IC_VEX_L_OPSIZE, /* 10992 */
  IC_VEX_L_OPSIZE, /* 10993 */
  IC_VEX_L_OPSIZE, /* 10994 */
  IC_VEX_L_OPSIZE, /* 10995 */
  IC_VEX_L_OPSIZE, /* 10996 */
  IC_VEX_L_OPSIZE, /* 10997 */
  IC_VEX_L_OPSIZE, /* 10998 */
  IC_VEX_L_OPSIZE, /* 10999 */
  IC_VEX_L_W_OPSIZE, /* 11000 */
  IC_VEX_L_W_OPSIZE, /* 11001 */
  IC_VEX_L_W_OPSIZE, /* 11002 */
  IC_VEX_L_W_OPSIZE, /* 11003 */
  IC_VEX_L_W_OPSIZE, /* 11004 */
  IC_VEX_L_W_OPSIZE, /* 11005 */
  IC_VEX_L_W_OPSIZE, /* 11006 */
  IC_VEX_L_W_OPSIZE, /* 11007 */
  IC_EVEX_L_K_B, /* 11008 */
  IC_EVEX_L_K_B, /* 11009 */
  IC_EVEX_L_XS_K_B, /* 11010 */
  IC_EVEX_L_XS_K_B, /* 11011 */
  IC_EVEX_L_XD_K_B, /* 11012 */
  IC_EVEX_L_XD_K_B, /* 11013 */
  IC_EVEX_L_XD_K_B, /* 11014 */
  IC_EVEX_L_XD_K_B, /* 11015 */
  IC_EVEX_L_W_K_B, /* 11016 */
  IC_EVEX_L_W_K_B, /* 11017 */
  IC_EVEX_L_W_XS_K_B, /* 11018 */
  IC_EVEX_L_W_XS_K_B, /* 11019 */
  IC_EVEX_L_W_XD_K_B, /* 11020 */
  IC_EVEX_L_W_XD_K_B, /* 11021 */
  IC_EVEX_L_W_XD_K_B, /* 11022 */
  IC_EVEX_L_W_XD_K_B, /* 11023 */
  IC_EVEX_L_OPSIZE_K_B, /* 11024 */
  IC_EVEX_L_OPSIZE_K_B, /* 11025 */
  IC_EVEX_L_OPSIZE_K_B, /* 11026 */
  IC_EVEX_L_OPSIZE_K_B, /* 11027 */
  IC_EVEX_L_OPSIZE_K_B, /* 11028 */
  IC_EVEX_L_OPSIZE_K_B, /* 11029 */
  IC_EVEX_L_OPSIZE_K_B, /* 11030 */
  IC_EVEX_L_OPSIZE_K_B, /* 11031 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11032 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11033 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11034 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11035 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11036 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11037 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11038 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11039 */
  IC_EVEX_L_K_B, /* 11040 */
  IC_EVEX_L_K_B, /* 11041 */
  IC_EVEX_L_XS_K_B, /* 11042 */
  IC_EVEX_L_XS_K_B, /* 11043 */
  IC_EVEX_L_XD_K_B, /* 11044 */
  IC_EVEX_L_XD_K_B, /* 11045 */
  IC_EVEX_L_XD_K_B, /* 11046 */
  IC_EVEX_L_XD_K_B, /* 11047 */
  IC_EVEX_L_W_K_B, /* 11048 */
  IC_EVEX_L_W_K_B, /* 11049 */
  IC_EVEX_L_W_XS_K_B, /* 11050 */
  IC_EVEX_L_W_XS_K_B, /* 11051 */
  IC_EVEX_L_W_XD_K_B, /* 11052 */
  IC_EVEX_L_W_XD_K_B, /* 11053 */
  IC_EVEX_L_W_XD_K_B, /* 11054 */
  IC_EVEX_L_W_XD_K_B, /* 11055 */
  IC_EVEX_L_OPSIZE_K_B, /* 11056 */
  IC_EVEX_L_OPSIZE_K_B, /* 11057 */
  IC_EVEX_L_OPSIZE_K_B, /* 11058 */
  IC_EVEX_L_OPSIZE_K_B, /* 11059 */
  IC_EVEX_L_OPSIZE_K_B, /* 11060 */
  IC_EVEX_L_OPSIZE_K_B, /* 11061 */
  IC_EVEX_L_OPSIZE_K_B, /* 11062 */
  IC_EVEX_L_OPSIZE_K_B, /* 11063 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11064 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11065 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11066 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11067 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11068 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11069 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11070 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11071 */
  IC_EVEX_L_K_B, /* 11072 */
  IC_EVEX_L_K_B, /* 11073 */
  IC_EVEX_L_XS_K_B, /* 11074 */
  IC_EVEX_L_XS_K_B, /* 11075 */
  IC_EVEX_L_XD_K_B, /* 11076 */
  IC_EVEX_L_XD_K_B, /* 11077 */
  IC_EVEX_L_XD_K_B, /* 11078 */
  IC_EVEX_L_XD_K_B, /* 11079 */
  IC_EVEX_L_W_K_B, /* 11080 */
  IC_EVEX_L_W_K_B, /* 11081 */
  IC_EVEX_L_W_XS_K_B, /* 11082 */
  IC_EVEX_L_W_XS_K_B, /* 11083 */
  IC_EVEX_L_W_XD_K_B, /* 11084 */
  IC_EVEX_L_W_XD_K_B, /* 11085 */
  IC_EVEX_L_W_XD_K_B, /* 11086 */
  IC_EVEX_L_W_XD_K_B, /* 11087 */
  IC_EVEX_L_OPSIZE_K_B, /* 11088 */
  IC_EVEX_L_OPSIZE_K_B, /* 11089 */
  IC_EVEX_L_OPSIZE_K_B, /* 11090 */
  IC_EVEX_L_OPSIZE_K_B, /* 11091 */
  IC_EVEX_L_OPSIZE_K_B, /* 11092 */
  IC_EVEX_L_OPSIZE_K_B, /* 11093 */
  IC_EVEX_L_OPSIZE_K_B, /* 11094 */
  IC_EVEX_L_OPSIZE_K_B, /* 11095 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11096 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11097 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11098 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11099 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11100 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11101 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11102 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11103 */
  IC_EVEX_L_K_B, /* 11104 */
  IC_EVEX_L_K_B, /* 11105 */
  IC_EVEX_L_XS_K_B, /* 11106 */
  IC_EVEX_L_XS_K_B, /* 11107 */
  IC_EVEX_L_XD_K_B, /* 11108 */
  IC_EVEX_L_XD_K_B, /* 11109 */
  IC_EVEX_L_XD_K_B, /* 11110 */
  IC_EVEX_L_XD_K_B, /* 11111 */
  IC_EVEX_L_W_K_B, /* 11112 */
  IC_EVEX_L_W_K_B, /* 11113 */
  IC_EVEX_L_W_XS_K_B, /* 11114 */
  IC_EVEX_L_W_XS_K_B, /* 11115 */
  IC_EVEX_L_W_XD_K_B, /* 11116 */
  IC_EVEX_L_W_XD_K_B, /* 11117 */
  IC_EVEX_L_W_XD_K_B, /* 11118 */
  IC_EVEX_L_W_XD_K_B, /* 11119 */
  IC_EVEX_L_OPSIZE_K_B, /* 11120 */
  IC_EVEX_L_OPSIZE_K_B, /* 11121 */
  IC_EVEX_L_OPSIZE_K_B, /* 11122 */
  IC_EVEX_L_OPSIZE_K_B, /* 11123 */
  IC_EVEX_L_OPSIZE_K_B, /* 11124 */
  IC_EVEX_L_OPSIZE_K_B, /* 11125 */
  IC_EVEX_L_OPSIZE_K_B, /* 11126 */
  IC_EVEX_L_OPSIZE_K_B, /* 11127 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11128 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11129 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11130 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11131 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11132 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11133 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11134 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11135 */
  IC_EVEX_L_K_B, /* 11136 */
  IC_EVEX_L_K_B, /* 11137 */
  IC_EVEX_L_XS_K_B, /* 11138 */
  IC_EVEX_L_XS_K_B, /* 11139 */
  IC_EVEX_L_XD_K_B, /* 11140 */
  IC_EVEX_L_XD_K_B, /* 11141 */
  IC_EVEX_L_XD_K_B, /* 11142 */
  IC_EVEX_L_XD_K_B, /* 11143 */
  IC_EVEX_L_W_K_B, /* 11144 */
  IC_EVEX_L_W_K_B, /* 11145 */
  IC_EVEX_L_W_XS_K_B, /* 11146 */
  IC_EVEX_L_W_XS_K_B, /* 11147 */
  IC_EVEX_L_W_XD_K_B, /* 11148 */
  IC_EVEX_L_W_XD_K_B, /* 11149 */
  IC_EVEX_L_W_XD_K_B, /* 11150 */
  IC_EVEX_L_W_XD_K_B, /* 11151 */
  IC_EVEX_L_OPSIZE_K_B, /* 11152 */
  IC_EVEX_L_OPSIZE_K_B, /* 11153 */
  IC_EVEX_L_OPSIZE_K_B, /* 11154 */
  IC_EVEX_L_OPSIZE_K_B, /* 11155 */
  IC_EVEX_L_OPSIZE_K_B, /* 11156 */
  IC_EVEX_L_OPSIZE_K_B, /* 11157 */
  IC_EVEX_L_OPSIZE_K_B, /* 11158 */
  IC_EVEX_L_OPSIZE_K_B, /* 11159 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11160 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11161 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11162 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11163 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11164 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11165 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11166 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11167 */
  IC_EVEX_L_K_B, /* 11168 */
  IC_EVEX_L_K_B, /* 11169 */
  IC_EVEX_L_XS_K_B, /* 11170 */
  IC_EVEX_L_XS_K_B, /* 11171 */
  IC_EVEX_L_XD_K_B, /* 11172 */
  IC_EVEX_L_XD_K_B, /* 11173 */
  IC_EVEX_L_XD_K_B, /* 11174 */
  IC_EVEX_L_XD_K_B, /* 11175 */
  IC_EVEX_L_W_K_B, /* 11176 */
  IC_EVEX_L_W_K_B, /* 11177 */
  IC_EVEX_L_W_XS_K_B, /* 11178 */
  IC_EVEX_L_W_XS_K_B, /* 11179 */
  IC_EVEX_L_W_XD_K_B, /* 11180 */
  IC_EVEX_L_W_XD_K_B, /* 11181 */
  IC_EVEX_L_W_XD_K_B, /* 11182 */
  IC_EVEX_L_W_XD_K_B, /* 11183 */
  IC_EVEX_L_OPSIZE_K_B, /* 11184 */
  IC_EVEX_L_OPSIZE_K_B, /* 11185 */
  IC_EVEX_L_OPSIZE_K_B, /* 11186 */
  IC_EVEX_L_OPSIZE_K_B, /* 11187 */
  IC_EVEX_L_OPSIZE_K_B, /* 11188 */
  IC_EVEX_L_OPSIZE_K_B, /* 11189 */
  IC_EVEX_L_OPSIZE_K_B, /* 11190 */
  IC_EVEX_L_OPSIZE_K_B, /* 11191 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11192 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11193 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11194 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11195 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11196 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11197 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11198 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11199 */
  IC_EVEX_L_K_B, /* 11200 */
  IC_EVEX_L_K_B, /* 11201 */
  IC_EVEX_L_XS_K_B, /* 11202 */
  IC_EVEX_L_XS_K_B, /* 11203 */
  IC_EVEX_L_XD_K_B, /* 11204 */
  IC_EVEX_L_XD_K_B, /* 11205 */
  IC_EVEX_L_XD_K_B, /* 11206 */
  IC_EVEX_L_XD_K_B, /* 11207 */
  IC_EVEX_L_W_K_B, /* 11208 */
  IC_EVEX_L_W_K_B, /* 11209 */
  IC_EVEX_L_W_XS_K_B, /* 11210 */
  IC_EVEX_L_W_XS_K_B, /* 11211 */
  IC_EVEX_L_W_XD_K_B, /* 11212 */
  IC_EVEX_L_W_XD_K_B, /* 11213 */
  IC_EVEX_L_W_XD_K_B, /* 11214 */
  IC_EVEX_L_W_XD_K_B, /* 11215 */
  IC_EVEX_L_OPSIZE_K_B, /* 11216 */
  IC_EVEX_L_OPSIZE_K_B, /* 11217 */
  IC_EVEX_L_OPSIZE_K_B, /* 11218 */
  IC_EVEX_L_OPSIZE_K_B, /* 11219 */
  IC_EVEX_L_OPSIZE_K_B, /* 11220 */
  IC_EVEX_L_OPSIZE_K_B, /* 11221 */
  IC_EVEX_L_OPSIZE_K_B, /* 11222 */
  IC_EVEX_L_OPSIZE_K_B, /* 11223 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11224 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11225 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11226 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11227 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11228 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11229 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11230 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11231 */
  IC_EVEX_L_K_B, /* 11232 */
  IC_EVEX_L_K_B, /* 11233 */
  IC_EVEX_L_XS_K_B, /* 11234 */
  IC_EVEX_L_XS_K_B, /* 11235 */
  IC_EVEX_L_XD_K_B, /* 11236 */
  IC_EVEX_L_XD_K_B, /* 11237 */
  IC_EVEX_L_XD_K_B, /* 11238 */
  IC_EVEX_L_XD_K_B, /* 11239 */
  IC_EVEX_L_W_K_B, /* 11240 */
  IC_EVEX_L_W_K_B, /* 11241 */
  IC_EVEX_L_W_XS_K_B, /* 11242 */
  IC_EVEX_L_W_XS_K_B, /* 11243 */
  IC_EVEX_L_W_XD_K_B, /* 11244 */
  IC_EVEX_L_W_XD_K_B, /* 11245 */
  IC_EVEX_L_W_XD_K_B, /* 11246 */
  IC_EVEX_L_W_XD_K_B, /* 11247 */
  IC_EVEX_L_OPSIZE_K_B, /* 11248 */
  IC_EVEX_L_OPSIZE_K_B, /* 11249 */
  IC_EVEX_L_OPSIZE_K_B, /* 11250 */
  IC_EVEX_L_OPSIZE_K_B, /* 11251 */
  IC_EVEX_L_OPSIZE_K_B, /* 11252 */
  IC_EVEX_L_OPSIZE_K_B, /* 11253 */
  IC_EVEX_L_OPSIZE_K_B, /* 11254 */
  IC_EVEX_L_OPSIZE_K_B, /* 11255 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11256 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11257 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11258 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11259 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11260 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11261 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11262 */
  IC_EVEX_L_W_OPSIZE_K_B, /* 11263 */
  IC, /* 11264 */
  IC_64BIT, /* 11265 */
  IC_XS, /* 11266 */
  IC_64BIT_XS, /* 11267 */
  IC_XD, /* 11268 */
  IC_64BIT_XD, /* 11269 */
  IC_XS, /* 11270 */
  IC_64BIT_XS, /* 11271 */
  IC, /* 11272 */
  IC_64BIT_REXW, /* 11273 */
  IC_XS, /* 11274 */
  IC_64BIT_REXW_XS, /* 11275 */
  IC_XD, /* 11276 */
  IC_64BIT_REXW_XD, /* 11277 */
  IC_XS, /* 11278 */
  IC_64BIT_REXW_XS, /* 11279 */
  IC_OPSIZE, /* 11280 */
  IC_64BIT_OPSIZE, /* 11281 */
  IC_XS_OPSIZE, /* 11282 */
  IC_64BIT_XS_OPSIZE, /* 11283 */
  IC_XD_OPSIZE, /* 11284 */
  IC_64BIT_XD_OPSIZE, /* 11285 */
  IC_XS_OPSIZE, /* 11286 */
  IC_64BIT_XD_OPSIZE, /* 11287 */
  IC_OPSIZE, /* 11288 */
  IC_64BIT_REXW_OPSIZE, /* 11289 */
  IC_XS_OPSIZE, /* 11290 */
  IC_64BIT_REXW_XS, /* 11291 */
  IC_XD_OPSIZE, /* 11292 */
  IC_64BIT_REXW_XD, /* 11293 */
  IC_XS_OPSIZE, /* 11294 */
  IC_64BIT_REXW_XS, /* 11295 */
  IC_ADSIZE, /* 11296 */
  IC_64BIT_ADSIZE, /* 11297 */
  IC_XS, /* 11298 */
  IC_64BIT_XS, /* 11299 */
  IC_XD, /* 11300 */
  IC_64BIT_XD, /* 11301 */
  IC_XS, /* 11302 */
  IC_64BIT_XS, /* 11303 */
  IC_ADSIZE, /* 11304 */
  IC_64BIT_REXW_ADSIZE, /* 11305 */
  IC_XS, /* 11306 */
  IC_64BIT_REXW_XS, /* 11307 */
  IC_XD, /* 11308 */
  IC_64BIT_REXW_XD, /* 11309 */
  IC_XS, /* 11310 */
  IC_64BIT_REXW_XS, /* 11311 */
  IC_OPSIZE_ADSIZE, /* 11312 */
  IC_64BIT_OPSIZE_ADSIZE, /* 11313 */
  IC_XS_OPSIZE, /* 11314 */
  IC_64BIT_XS_OPSIZE, /* 11315 */
  IC_XD_OPSIZE, /* 11316 */
  IC_64BIT_XD_OPSIZE, /* 11317 */
  IC_XS_OPSIZE, /* 11318 */
  IC_64BIT_XD_OPSIZE, /* 11319 */
  IC_OPSIZE_ADSIZE, /* 11320 */
  IC_64BIT_REXW_OPSIZE, /* 11321 */
  IC_XS_OPSIZE, /* 11322 */
  IC_64BIT_REXW_XS, /* 11323 */
  IC_XD_OPSIZE, /* 11324 */
  IC_64BIT_REXW_XD, /* 11325 */
  IC_XS_OPSIZE, /* 11326 */
  IC_64BIT_REXW_XS, /* 11327 */
  IC_VEX, /* 11328 */
  IC_VEX, /* 11329 */
  IC_VEX_XS, /* 11330 */
  IC_VEX_XS, /* 11331 */
  IC_VEX_XD, /* 11332 */
  IC_VEX_XD, /* 11333 */
  IC_VEX_XD, /* 11334 */
  IC_VEX_XD, /* 11335 */
  IC_VEX_W, /* 11336 */
  IC_VEX_W, /* 11337 */
  IC_VEX_W_XS, /* 11338 */
  IC_VEX_W_XS, /* 11339 */
  IC_VEX_W_XD, /* 11340 */
  IC_VEX_W_XD, /* 11341 */
  IC_VEX_W_XD, /* 11342 */
  IC_VEX_W_XD, /* 11343 */
  IC_VEX_OPSIZE, /* 11344 */
  IC_VEX_OPSIZE, /* 11345 */
  IC_VEX_OPSIZE, /* 11346 */
  IC_VEX_OPSIZE, /* 11347 */
  IC_VEX_OPSIZE, /* 11348 */
  IC_VEX_OPSIZE, /* 11349 */
  IC_VEX_OPSIZE, /* 11350 */
  IC_VEX_OPSIZE, /* 11351 */
  IC_VEX_W_OPSIZE, /* 11352 */
  IC_VEX_W_OPSIZE, /* 11353 */
  IC_VEX_W_OPSIZE, /* 11354 */
  IC_VEX_W_OPSIZE, /* 11355 */
  IC_VEX_W_OPSIZE, /* 11356 */
  IC_VEX_W_OPSIZE, /* 11357 */
  IC_VEX_W_OPSIZE, /* 11358 */
  IC_VEX_W_OPSIZE, /* 11359 */
  IC_VEX, /* 11360 */
  IC_VEX, /* 11361 */
  IC_VEX_XS, /* 11362 */
  IC_VEX_XS, /* 11363 */
  IC_VEX_XD, /* 11364 */
  IC_VEX_XD, /* 11365 */
  IC_VEX_XD, /* 11366 */
  IC_VEX_XD, /* 11367 */
  IC_VEX_W, /* 11368 */
  IC_VEX_W, /* 11369 */
  IC_VEX_W_XS, /* 11370 */
  IC_VEX_W_XS, /* 11371 */
  IC_VEX_W_XD, /* 11372 */
  IC_VEX_W_XD, /* 11373 */
  IC_VEX_W_XD, /* 11374 */
  IC_VEX_W_XD, /* 11375 */
  IC_VEX_OPSIZE, /* 11376 */
  IC_VEX_OPSIZE, /* 11377 */
  IC_VEX_OPSIZE, /* 11378 */
  IC_VEX_OPSIZE, /* 11379 */
  IC_VEX_OPSIZE, /* 11380 */
  IC_VEX_OPSIZE, /* 11381 */
  IC_VEX_OPSIZE, /* 11382 */
  IC_VEX_OPSIZE, /* 11383 */
  IC_VEX_W_OPSIZE, /* 11384 */
  IC_VEX_W_OPSIZE, /* 11385 */
  IC_VEX_W_OPSIZE, /* 11386 */
  IC_VEX_W_OPSIZE, /* 11387 */
  IC_VEX_W_OPSIZE, /* 11388 */
  IC_VEX_W_OPSIZE, /* 11389 */
  IC_VEX_W_OPSIZE, /* 11390 */
  IC_VEX_W_OPSIZE, /* 11391 */
  IC_VEX_L, /* 11392 */
  IC_VEX_L, /* 11393 */
  IC_VEX_L_XS, /* 11394 */
  IC_VEX_L_XS, /* 11395 */
  IC_VEX_L_XD, /* 11396 */
  IC_VEX_L_XD, /* 11397 */
  IC_VEX_L_XD, /* 11398 */
  IC_VEX_L_XD, /* 11399 */
  IC_VEX_L_W, /* 11400 */
  IC_VEX_L_W, /* 11401 */
  IC_VEX_L_W_XS, /* 11402 */
  IC_VEX_L_W_XS, /* 11403 */
  IC_VEX_L_W_XD, /* 11404 */
  IC_VEX_L_W_XD, /* 11405 */
  IC_VEX_L_W_XD, /* 11406 */
  IC_VEX_L_W_XD, /* 11407 */
  IC_VEX_L_OPSIZE, /* 11408 */
  IC_VEX_L_OPSIZE, /* 11409 */
  IC_VEX_L_OPSIZE, /* 11410 */
  IC_VEX_L_OPSIZE, /* 11411 */
  IC_VEX_L_OPSIZE, /* 11412 */
  IC_VEX_L_OPSIZE, /* 11413 */
  IC_VEX_L_OPSIZE, /* 11414 */
  IC_VEX_L_OPSIZE, /* 11415 */
  IC_VEX_L_W_OPSIZE, /* 11416 */
  IC_VEX_L_W_OPSIZE, /* 11417 */
  IC_VEX_L_W_OPSIZE, /* 11418 */
  IC_VEX_L_W_OPSIZE, /* 11419 */
  IC_VEX_L_W_OPSIZE, /* 11420 */
  IC_VEX_L_W_OPSIZE, /* 11421 */
  IC_VEX_L_W_OPSIZE, /* 11422 */
  IC_VEX_L_W_OPSIZE, /* 11423 */
  IC_VEX_L, /* 11424 */
  IC_VEX_L, /* 11425 */
  IC_VEX_L_XS, /* 11426 */
  IC_VEX_L_XS, /* 11427 */
  IC_VEX_L_XD, /* 11428 */
  IC_VEX_L_XD, /* 11429 */
  IC_VEX_L_XD, /* 11430 */
  IC_VEX_L_XD, /* 11431 */
  IC_VEX_L_W, /* 11432 */
  IC_VEX_L_W, /* 11433 */
  IC_VEX_L_W_XS, /* 11434 */
  IC_VEX_L_W_XS, /* 11435 */
  IC_VEX_L_W_XD, /* 11436 */
  IC_VEX_L_W_XD, /* 11437 */
  IC_VEX_L_W_XD, /* 11438 */
  IC_VEX_L_W_XD, /* 11439 */
  IC_VEX_L_OPSIZE, /* 11440 */
  IC_VEX_L_OPSIZE, /* 11441 */
  IC_VEX_L_OPSIZE, /* 11442 */
  IC_VEX_L_OPSIZE, /* 11443 */
  IC_VEX_L_OPSIZE, /* 11444 */
  IC_VEX_L_OPSIZE, /* 11445 */
  IC_VEX_L_OPSIZE, /* 11446 */
  IC_VEX_L_OPSIZE, /* 11447 */
  IC_VEX_L_W_OPSIZE, /* 11448 */
  IC_VEX_L_W_OPSIZE, /* 11449 */
  IC_VEX_L_W_OPSIZE, /* 11450 */
  IC_VEX_L_W_OPSIZE, /* 11451 */
  IC_VEX_L_W_OPSIZE, /* 11452 */
  IC_VEX_L_W_OPSIZE, /* 11453 */
  IC_VEX_L_W_OPSIZE, /* 11454 */
  IC_VEX_L_W_OPSIZE, /* 11455 */
  IC_VEX_L, /* 11456 */
  IC_VEX_L, /* 11457 */
  IC_VEX_L_XS, /* 11458 */
  IC_VEX_L_XS, /* 11459 */
  IC_VEX_L_XD, /* 11460 */
  IC_VEX_L_XD, /* 11461 */
  IC_VEX_L_XD, /* 11462 */
  IC_VEX_L_XD, /* 11463 */
  IC_VEX_L_W, /* 11464 */
  IC_VEX_L_W, /* 11465 */
  IC_VEX_L_W_XS, /* 11466 */
  IC_VEX_L_W_XS, /* 11467 */
  IC_VEX_L_W_XD, /* 11468 */
  IC_VEX_L_W_XD, /* 11469 */
  IC_VEX_L_W_XD, /* 11470 */
  IC_VEX_L_W_XD, /* 11471 */
  IC_VEX_L_OPSIZE, /* 11472 */
  IC_VEX_L_OPSIZE, /* 11473 */
  IC_VEX_L_OPSIZE, /* 11474 */
  IC_VEX_L_OPSIZE, /* 11475 */
  IC_VEX_L_OPSIZE, /* 11476 */
  IC_VEX_L_OPSIZE, /* 11477 */
  IC_VEX_L_OPSIZE, /* 11478 */
  IC_VEX_L_OPSIZE, /* 11479 */
  IC_VEX_L_W_OPSIZE, /* 11480 */
  IC_VEX_L_W_OPSIZE, /* 11481 */
  IC_VEX_L_W_OPSIZE, /* 11482 */
  IC_VEX_L_W_OPSIZE, /* 11483 */
  IC_VEX_L_W_OPSIZE, /* 11484 */
  IC_VEX_L_W_OPSIZE, /* 11485 */
  IC_VEX_L_W_OPSIZE, /* 11486 */
  IC_VEX_L_W_OPSIZE, /* 11487 */
  IC_VEX_L, /* 11488 */
  IC_VEX_L, /* 11489 */
  IC_VEX_L_XS, /* 11490 */
  IC_VEX_L_XS, /* 11491 */
  IC_VEX_L_XD, /* 11492 */
  IC_VEX_L_XD, /* 11493 */
  IC_VEX_L_XD, /* 11494 */
  IC_VEX_L_XD, /* 11495 */
  IC_VEX_L_W, /* 11496 */
  IC_VEX_L_W, /* 11497 */
  IC_VEX_L_W_XS, /* 11498 */
  IC_VEX_L_W_XS, /* 11499 */
  IC_VEX_L_W_XD, /* 11500 */
  IC_VEX_L_W_XD, /* 11501 */
  IC_VEX_L_W_XD, /* 11502 */
  IC_VEX_L_W_XD, /* 11503 */
  IC_VEX_L_OPSIZE, /* 11504 */
  IC_VEX_L_OPSIZE, /* 11505 */
  IC_VEX_L_OPSIZE, /* 11506 */
  IC_VEX_L_OPSIZE, /* 11507 */
  IC_VEX_L_OPSIZE, /* 11508 */
  IC_VEX_L_OPSIZE, /* 11509 */
  IC_VEX_L_OPSIZE, /* 11510 */
  IC_VEX_L_OPSIZE, /* 11511 */
  IC_VEX_L_W_OPSIZE, /* 11512 */
  IC_VEX_L_W_OPSIZE, /* 11513 */
  IC_VEX_L_W_OPSIZE, /* 11514 */
  IC_VEX_L_W_OPSIZE, /* 11515 */
  IC_VEX_L_W_OPSIZE, /* 11516 */
  IC_VEX_L_W_OPSIZE, /* 11517 */
  IC_VEX_L_W_OPSIZE, /* 11518 */
  IC_VEX_L_W_OPSIZE, /* 11519 */
  IC_EVEX_L2_K_B, /* 11520 */
  IC_EVEX_L2_K_B, /* 11521 */
  IC_EVEX_L2_XS_K_B, /* 11522 */
  IC_EVEX_L2_XS_K_B, /* 11523 */
  IC_EVEX_L2_XD_K_B, /* 11524 */
  IC_EVEX_L2_XD_K_B, /* 11525 */
  IC_EVEX_L2_XD_K_B, /* 11526 */
  IC_EVEX_L2_XD_K_B, /* 11527 */
  IC_EVEX_L2_W_K_B, /* 11528 */
  IC_EVEX_L2_W_K_B, /* 11529 */
  IC_EVEX_L2_W_XS_K_B, /* 11530 */
  IC_EVEX_L2_W_XS_K_B, /* 11531 */
  IC_EVEX_L2_W_XD_K_B, /* 11532 */
  IC_EVEX_L2_W_XD_K_B, /* 11533 */
  IC_EVEX_L2_W_XD_K_B, /* 11534 */
  IC_EVEX_L2_W_XD_K_B, /* 11535 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11536 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11537 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11538 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11539 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11540 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11541 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11542 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11543 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11544 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11545 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11546 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11547 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11548 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11549 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11550 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11551 */
  IC_EVEX_L2_K_B, /* 11552 */
  IC_EVEX_L2_K_B, /* 11553 */
  IC_EVEX_L2_XS_K_B, /* 11554 */
  IC_EVEX_L2_XS_K_B, /* 11555 */
  IC_EVEX_L2_XD_K_B, /* 11556 */
  IC_EVEX_L2_XD_K_B, /* 11557 */
  IC_EVEX_L2_XD_K_B, /* 11558 */
  IC_EVEX_L2_XD_K_B, /* 11559 */
  IC_EVEX_L2_W_K_B, /* 11560 */
  IC_EVEX_L2_W_K_B, /* 11561 */
  IC_EVEX_L2_W_XS_K_B, /* 11562 */
  IC_EVEX_L2_W_XS_K_B, /* 11563 */
  IC_EVEX_L2_W_XD_K_B, /* 11564 */
  IC_EVEX_L2_W_XD_K_B, /* 11565 */
  IC_EVEX_L2_W_XD_K_B, /* 11566 */
  IC_EVEX_L2_W_XD_K_B, /* 11567 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11568 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11569 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11570 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11571 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11572 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11573 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11574 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11575 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11576 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11577 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11578 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11579 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11580 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11581 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11582 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11583 */
  IC_EVEX_L2_K_B, /* 11584 */
  IC_EVEX_L2_K_B, /* 11585 */
  IC_EVEX_L2_XS_K_B, /* 11586 */
  IC_EVEX_L2_XS_K_B, /* 11587 */
  IC_EVEX_L2_XD_K_B, /* 11588 */
  IC_EVEX_L2_XD_K_B, /* 11589 */
  IC_EVEX_L2_XD_K_B, /* 11590 */
  IC_EVEX_L2_XD_K_B, /* 11591 */
  IC_EVEX_L2_W_K_B, /* 11592 */
  IC_EVEX_L2_W_K_B, /* 11593 */
  IC_EVEX_L2_W_XS_K_B, /* 11594 */
  IC_EVEX_L2_W_XS_K_B, /* 11595 */
  IC_EVEX_L2_W_XD_K_B, /* 11596 */
  IC_EVEX_L2_W_XD_K_B, /* 11597 */
  IC_EVEX_L2_W_XD_K_B, /* 11598 */
  IC_EVEX_L2_W_XD_K_B, /* 11599 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11600 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11601 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11602 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11603 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11604 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11605 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11606 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11607 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11608 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11609 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11610 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11611 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11612 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11613 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11614 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11615 */
  IC_EVEX_L2_K_B, /* 11616 */
  IC_EVEX_L2_K_B, /* 11617 */
  IC_EVEX_L2_XS_K_B, /* 11618 */
  IC_EVEX_L2_XS_K_B, /* 11619 */
  IC_EVEX_L2_XD_K_B, /* 11620 */
  IC_EVEX_L2_XD_K_B, /* 11621 */
  IC_EVEX_L2_XD_K_B, /* 11622 */
  IC_EVEX_L2_XD_K_B, /* 11623 */
  IC_EVEX_L2_W_K_B, /* 11624 */
  IC_EVEX_L2_W_K_B, /* 11625 */
  IC_EVEX_L2_W_XS_K_B, /* 11626 */
  IC_EVEX_L2_W_XS_K_B, /* 11627 */
  IC_EVEX_L2_W_XD_K_B, /* 11628 */
  IC_EVEX_L2_W_XD_K_B, /* 11629 */
  IC_EVEX_L2_W_XD_K_B, /* 11630 */
  IC_EVEX_L2_W_XD_K_B, /* 11631 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11632 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11633 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11634 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11635 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11636 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11637 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11638 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11639 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11640 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11641 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11642 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11643 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11644 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11645 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11646 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11647 */
  IC_EVEX_L2_K_B, /* 11648 */
  IC_EVEX_L2_K_B, /* 11649 */
  IC_EVEX_L2_XS_K_B, /* 11650 */
  IC_EVEX_L2_XS_K_B, /* 11651 */
  IC_EVEX_L2_XD_K_B, /* 11652 */
  IC_EVEX_L2_XD_K_B, /* 11653 */
  IC_EVEX_L2_XD_K_B, /* 11654 */
  IC_EVEX_L2_XD_K_B, /* 11655 */
  IC_EVEX_L2_W_K_B, /* 11656 */
  IC_EVEX_L2_W_K_B, /* 11657 */
  IC_EVEX_L2_W_XS_K_B, /* 11658 */
  IC_EVEX_L2_W_XS_K_B, /* 11659 */
  IC_EVEX_L2_W_XD_K_B, /* 11660 */
  IC_EVEX_L2_W_XD_K_B, /* 11661 */
  IC_EVEX_L2_W_XD_K_B, /* 11662 */
  IC_EVEX_L2_W_XD_K_B, /* 11663 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11664 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11665 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11666 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11667 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11668 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11669 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11670 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11671 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11672 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11673 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11674 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11675 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11676 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11677 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11678 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11679 */
  IC_EVEX_L2_K_B, /* 11680 */
  IC_EVEX_L2_K_B, /* 11681 */
  IC_EVEX_L2_XS_K_B, /* 11682 */
  IC_EVEX_L2_XS_K_B, /* 11683 */
  IC_EVEX_L2_XD_K_B, /* 11684 */
  IC_EVEX_L2_XD_K_B, /* 11685 */
  IC_EVEX_L2_XD_K_B, /* 11686 */
  IC_EVEX_L2_XD_K_B, /* 11687 */
  IC_EVEX_L2_W_K_B, /* 11688 */
  IC_EVEX_L2_W_K_B, /* 11689 */
  IC_EVEX_L2_W_XS_K_B, /* 11690 */
  IC_EVEX_L2_W_XS_K_B, /* 11691 */
  IC_EVEX_L2_W_XD_K_B, /* 11692 */
  IC_EVEX_L2_W_XD_K_B, /* 11693 */
  IC_EVEX_L2_W_XD_K_B, /* 11694 */
  IC_EVEX_L2_W_XD_K_B, /* 11695 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11696 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11697 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11698 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11699 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11700 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11701 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11702 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11703 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11704 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11705 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11706 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11707 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11708 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11709 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11710 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11711 */
  IC_EVEX_L2_K_B, /* 11712 */
  IC_EVEX_L2_K_B, /* 11713 */
  IC_EVEX_L2_XS_K_B, /* 11714 */
  IC_EVEX_L2_XS_K_B, /* 11715 */
  IC_EVEX_L2_XD_K_B, /* 11716 */
  IC_EVEX_L2_XD_K_B, /* 11717 */
  IC_EVEX_L2_XD_K_B, /* 11718 */
  IC_EVEX_L2_XD_K_B, /* 11719 */
  IC_EVEX_L2_W_K_B, /* 11720 */
  IC_EVEX_L2_W_K_B, /* 11721 */
  IC_EVEX_L2_W_XS_K_B, /* 11722 */
  IC_EVEX_L2_W_XS_K_B, /* 11723 */
  IC_EVEX_L2_W_XD_K_B, /* 11724 */
  IC_EVEX_L2_W_XD_K_B, /* 11725 */
  IC_EVEX_L2_W_XD_K_B, /* 11726 */
  IC_EVEX_L2_W_XD_K_B, /* 11727 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11728 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11729 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11730 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11731 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11732 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11733 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11734 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11735 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11736 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11737 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11738 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11739 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11740 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11741 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11742 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11743 */
  IC_EVEX_L2_K_B, /* 11744 */
  IC_EVEX_L2_K_B, /* 11745 */
  IC_EVEX_L2_XS_K_B, /* 11746 */
  IC_EVEX_L2_XS_K_B, /* 11747 */
  IC_EVEX_L2_XD_K_B, /* 11748 */
  IC_EVEX_L2_XD_K_B, /* 11749 */
  IC_EVEX_L2_XD_K_B, /* 11750 */
  IC_EVEX_L2_XD_K_B, /* 11751 */
  IC_EVEX_L2_W_K_B, /* 11752 */
  IC_EVEX_L2_W_K_B, /* 11753 */
  IC_EVEX_L2_W_XS_K_B, /* 11754 */
  IC_EVEX_L2_W_XS_K_B, /* 11755 */
  IC_EVEX_L2_W_XD_K_B, /* 11756 */
  IC_EVEX_L2_W_XD_K_B, /* 11757 */
  IC_EVEX_L2_W_XD_K_B, /* 11758 */
  IC_EVEX_L2_W_XD_K_B, /* 11759 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11760 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11761 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11762 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11763 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11764 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11765 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11766 */
  IC_EVEX_L2_OPSIZE_K_B, /* 11767 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11768 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11769 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11770 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11771 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11772 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11773 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11774 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 11775 */
  IC, /* 11776 */
  IC_64BIT, /* 11777 */
  IC_XS, /* 11778 */
  IC_64BIT_XS, /* 11779 */
  IC_XD, /* 11780 */
  IC_64BIT_XD, /* 11781 */
  IC_XS, /* 11782 */
  IC_64BIT_XS, /* 11783 */
  IC, /* 11784 */
  IC_64BIT_REXW, /* 11785 */
  IC_XS, /* 11786 */
  IC_64BIT_REXW_XS, /* 11787 */
  IC_XD, /* 11788 */
  IC_64BIT_REXW_XD, /* 11789 */
  IC_XS, /* 11790 */
  IC_64BIT_REXW_XS, /* 11791 */
  IC_OPSIZE, /* 11792 */
  IC_64BIT_OPSIZE, /* 11793 */
  IC_XS_OPSIZE, /* 11794 */
  IC_64BIT_XS_OPSIZE, /* 11795 */
  IC_XD_OPSIZE, /* 11796 */
  IC_64BIT_XD_OPSIZE, /* 11797 */
  IC_XS_OPSIZE, /* 11798 */
  IC_64BIT_XD_OPSIZE, /* 11799 */
  IC_OPSIZE, /* 11800 */
  IC_64BIT_REXW_OPSIZE, /* 11801 */
  IC_XS_OPSIZE, /* 11802 */
  IC_64BIT_REXW_XS, /* 11803 */
  IC_XD_OPSIZE, /* 11804 */
  IC_64BIT_REXW_XD, /* 11805 */
  IC_XS_OPSIZE, /* 11806 */
  IC_64BIT_REXW_XS, /* 11807 */
  IC_ADSIZE, /* 11808 */
  IC_64BIT_ADSIZE, /* 11809 */
  IC_XS, /* 11810 */
  IC_64BIT_XS, /* 11811 */
  IC_XD, /* 11812 */
  IC_64BIT_XD, /* 11813 */
  IC_XS, /* 11814 */
  IC_64BIT_XS, /* 11815 */
  IC_ADSIZE, /* 11816 */
  IC_64BIT_REXW_ADSIZE, /* 11817 */
  IC_XS, /* 11818 */
  IC_64BIT_REXW_XS, /* 11819 */
  IC_XD, /* 11820 */
  IC_64BIT_REXW_XD, /* 11821 */
  IC_XS, /* 11822 */
  IC_64BIT_REXW_XS, /* 11823 */
  IC_OPSIZE_ADSIZE, /* 11824 */
  IC_64BIT_OPSIZE_ADSIZE, /* 11825 */
  IC_XS_OPSIZE, /* 11826 */
  IC_64BIT_XS_OPSIZE, /* 11827 */
  IC_XD_OPSIZE, /* 11828 */
  IC_64BIT_XD_OPSIZE, /* 11829 */
  IC_XS_OPSIZE, /* 11830 */
  IC_64BIT_XD_OPSIZE, /* 11831 */
  IC_OPSIZE_ADSIZE, /* 11832 */
  IC_64BIT_REXW_OPSIZE, /* 11833 */
  IC_XS_OPSIZE, /* 11834 */
  IC_64BIT_REXW_XS, /* 11835 */
  IC_XD_OPSIZE, /* 11836 */
  IC_64BIT_REXW_XD, /* 11837 */
  IC_XS_OPSIZE, /* 11838 */
  IC_64BIT_REXW_XS, /* 11839 */
  IC_VEX, /* 11840 */
  IC_VEX, /* 11841 */
  IC_VEX_XS, /* 11842 */
  IC_VEX_XS, /* 11843 */
  IC_VEX_XD, /* 11844 */
  IC_VEX_XD, /* 11845 */
  IC_VEX_XD, /* 11846 */
  IC_VEX_XD, /* 11847 */
  IC_VEX_W, /* 11848 */
  IC_VEX_W, /* 11849 */
  IC_VEX_W_XS, /* 11850 */
  IC_VEX_W_XS, /* 11851 */
  IC_VEX_W_XD, /* 11852 */
  IC_VEX_W_XD, /* 11853 */
  IC_VEX_W_XD, /* 11854 */
  IC_VEX_W_XD, /* 11855 */
  IC_VEX_OPSIZE, /* 11856 */
  IC_VEX_OPSIZE, /* 11857 */
  IC_VEX_OPSIZE, /* 11858 */
  IC_VEX_OPSIZE, /* 11859 */
  IC_VEX_OPSIZE, /* 11860 */
  IC_VEX_OPSIZE, /* 11861 */
  IC_VEX_OPSIZE, /* 11862 */
  IC_VEX_OPSIZE, /* 11863 */
  IC_VEX_W_OPSIZE, /* 11864 */
  IC_VEX_W_OPSIZE, /* 11865 */
  IC_VEX_W_OPSIZE, /* 11866 */
  IC_VEX_W_OPSIZE, /* 11867 */
  IC_VEX_W_OPSIZE, /* 11868 */
  IC_VEX_W_OPSIZE, /* 11869 */
  IC_VEX_W_OPSIZE, /* 11870 */
  IC_VEX_W_OPSIZE, /* 11871 */
  IC_VEX, /* 11872 */
  IC_VEX, /* 11873 */
  IC_VEX_XS, /* 11874 */
  IC_VEX_XS, /* 11875 */
  IC_VEX_XD, /* 11876 */
  IC_VEX_XD, /* 11877 */
  IC_VEX_XD, /* 11878 */
  IC_VEX_XD, /* 11879 */
  IC_VEX_W, /* 11880 */
  IC_VEX_W, /* 11881 */
  IC_VEX_W_XS, /* 11882 */
  IC_VEX_W_XS, /* 11883 */
  IC_VEX_W_XD, /* 11884 */
  IC_VEX_W_XD, /* 11885 */
  IC_VEX_W_XD, /* 11886 */
  IC_VEX_W_XD, /* 11887 */
  IC_VEX_OPSIZE, /* 11888 */
  IC_VEX_OPSIZE, /* 11889 */
  IC_VEX_OPSIZE, /* 11890 */
  IC_VEX_OPSIZE, /* 11891 */
  IC_VEX_OPSIZE, /* 11892 */
  IC_VEX_OPSIZE, /* 11893 */
  IC_VEX_OPSIZE, /* 11894 */
  IC_VEX_OPSIZE, /* 11895 */
  IC_VEX_W_OPSIZE, /* 11896 */
  IC_VEX_W_OPSIZE, /* 11897 */
  IC_VEX_W_OPSIZE, /* 11898 */
  IC_VEX_W_OPSIZE, /* 11899 */
  IC_VEX_W_OPSIZE, /* 11900 */
  IC_VEX_W_OPSIZE, /* 11901 */
  IC_VEX_W_OPSIZE, /* 11902 */
  IC_VEX_W_OPSIZE, /* 11903 */
  IC_VEX_L, /* 11904 */
  IC_VEX_L, /* 11905 */
  IC_VEX_L_XS, /* 11906 */
  IC_VEX_L_XS, /* 11907 */
  IC_VEX_L_XD, /* 11908 */
  IC_VEX_L_XD, /* 11909 */
  IC_VEX_L_XD, /* 11910 */
  IC_VEX_L_XD, /* 11911 */
  IC_VEX_L_W, /* 11912 */
  IC_VEX_L_W, /* 11913 */
  IC_VEX_L_W_XS, /* 11914 */
  IC_VEX_L_W_XS, /* 11915 */
  IC_VEX_L_W_XD, /* 11916 */
  IC_VEX_L_W_XD, /* 11917 */
  IC_VEX_L_W_XD, /* 11918 */
  IC_VEX_L_W_XD, /* 11919 */
  IC_VEX_L_OPSIZE, /* 11920 */
  IC_VEX_L_OPSIZE, /* 11921 */
  IC_VEX_L_OPSIZE, /* 11922 */
  IC_VEX_L_OPSIZE, /* 11923 */
  IC_VEX_L_OPSIZE, /* 11924 */
  IC_VEX_L_OPSIZE, /* 11925 */
  IC_VEX_L_OPSIZE, /* 11926 */
  IC_VEX_L_OPSIZE, /* 11927 */
  IC_VEX_L_W_OPSIZE, /* 11928 */
  IC_VEX_L_W_OPSIZE, /* 11929 */
  IC_VEX_L_W_OPSIZE, /* 11930 */
  IC_VEX_L_W_OPSIZE, /* 11931 */
  IC_VEX_L_W_OPSIZE, /* 11932 */
  IC_VEX_L_W_OPSIZE, /* 11933 */
  IC_VEX_L_W_OPSIZE, /* 11934 */
  IC_VEX_L_W_OPSIZE, /* 11935 */
  IC_VEX_L, /* 11936 */
  IC_VEX_L, /* 11937 */
  IC_VEX_L_XS, /* 11938 */
  IC_VEX_L_XS, /* 11939 */
  IC_VEX_L_XD, /* 11940 */
  IC_VEX_L_XD, /* 11941 */
  IC_VEX_L_XD, /* 11942 */
  IC_VEX_L_XD, /* 11943 */
  IC_VEX_L_W, /* 11944 */
  IC_VEX_L_W, /* 11945 */
  IC_VEX_L_W_XS, /* 11946 */
  IC_VEX_L_W_XS, /* 11947 */
  IC_VEX_L_W_XD, /* 11948 */
  IC_VEX_L_W_XD, /* 11949 */
  IC_VEX_L_W_XD, /* 11950 */
  IC_VEX_L_W_XD, /* 11951 */
  IC_VEX_L_OPSIZE, /* 11952 */
  IC_VEX_L_OPSIZE, /* 11953 */
  IC_VEX_L_OPSIZE, /* 11954 */
  IC_VEX_L_OPSIZE, /* 11955 */
  IC_VEX_L_OPSIZE, /* 11956 */
  IC_VEX_L_OPSIZE, /* 11957 */
  IC_VEX_L_OPSIZE, /* 11958 */
  IC_VEX_L_OPSIZE, /* 11959 */
  IC_VEX_L_W_OPSIZE, /* 11960 */
  IC_VEX_L_W_OPSIZE, /* 11961 */
  IC_VEX_L_W_OPSIZE, /* 11962 */
  IC_VEX_L_W_OPSIZE, /* 11963 */
  IC_VEX_L_W_OPSIZE, /* 11964 */
  IC_VEX_L_W_OPSIZE, /* 11965 */
  IC_VEX_L_W_OPSIZE, /* 11966 */
  IC_VEX_L_W_OPSIZE, /* 11967 */
  IC_VEX_L, /* 11968 */
  IC_VEX_L, /* 11969 */
  IC_VEX_L_XS, /* 11970 */
  IC_VEX_L_XS, /* 11971 */
  IC_VEX_L_XD, /* 11972 */
  IC_VEX_L_XD, /* 11973 */
  IC_VEX_L_XD, /* 11974 */
  IC_VEX_L_XD, /* 11975 */
  IC_VEX_L_W, /* 11976 */
  IC_VEX_L_W, /* 11977 */
  IC_VEX_L_W_XS, /* 11978 */
  IC_VEX_L_W_XS, /* 11979 */
  IC_VEX_L_W_XD, /* 11980 */
  IC_VEX_L_W_XD, /* 11981 */
  IC_VEX_L_W_XD, /* 11982 */
  IC_VEX_L_W_XD, /* 11983 */
  IC_VEX_L_OPSIZE, /* 11984 */
  IC_VEX_L_OPSIZE, /* 11985 */
  IC_VEX_L_OPSIZE, /* 11986 */
  IC_VEX_L_OPSIZE, /* 11987 */
  IC_VEX_L_OPSIZE, /* 11988 */
  IC_VEX_L_OPSIZE, /* 11989 */
  IC_VEX_L_OPSIZE, /* 11990 */
  IC_VEX_L_OPSIZE, /* 11991 */
  IC_VEX_L_W_OPSIZE, /* 11992 */
  IC_VEX_L_W_OPSIZE, /* 11993 */
  IC_VEX_L_W_OPSIZE, /* 11994 */
  IC_VEX_L_W_OPSIZE, /* 11995 */
  IC_VEX_L_W_OPSIZE, /* 11996 */
  IC_VEX_L_W_OPSIZE, /* 11997 */
  IC_VEX_L_W_OPSIZE, /* 11998 */
  IC_VEX_L_W_OPSIZE, /* 11999 */
  IC_VEX_L, /* 12000 */
  IC_VEX_L, /* 12001 */
  IC_VEX_L_XS, /* 12002 */
  IC_VEX_L_XS, /* 12003 */
  IC_VEX_L_XD, /* 12004 */
  IC_VEX_L_XD, /* 12005 */
  IC_VEX_L_XD, /* 12006 */
  IC_VEX_L_XD, /* 12007 */
  IC_VEX_L_W, /* 12008 */
  IC_VEX_L_W, /* 12009 */
  IC_VEX_L_W_XS, /* 12010 */
  IC_VEX_L_W_XS, /* 12011 */
  IC_VEX_L_W_XD, /* 12012 */
  IC_VEX_L_W_XD, /* 12013 */
  IC_VEX_L_W_XD, /* 12014 */
  IC_VEX_L_W_XD, /* 12015 */
  IC_VEX_L_OPSIZE, /* 12016 */
  IC_VEX_L_OPSIZE, /* 12017 */
  IC_VEX_L_OPSIZE, /* 12018 */
  IC_VEX_L_OPSIZE, /* 12019 */
  IC_VEX_L_OPSIZE, /* 12020 */
  IC_VEX_L_OPSIZE, /* 12021 */
  IC_VEX_L_OPSIZE, /* 12022 */
  IC_VEX_L_OPSIZE, /* 12023 */
  IC_VEX_L_W_OPSIZE, /* 12024 */
  IC_VEX_L_W_OPSIZE, /* 12025 */
  IC_VEX_L_W_OPSIZE, /* 12026 */
  IC_VEX_L_W_OPSIZE, /* 12027 */
  IC_VEX_L_W_OPSIZE, /* 12028 */
  IC_VEX_L_W_OPSIZE, /* 12029 */
  IC_VEX_L_W_OPSIZE, /* 12030 */
  IC_VEX_L_W_OPSIZE, /* 12031 */
  IC_EVEX_L2_K_B, /* 12032 */
  IC_EVEX_L2_K_B, /* 12033 */
  IC_EVEX_L2_XS_K_B, /* 12034 */
  IC_EVEX_L2_XS_K_B, /* 12035 */
  IC_EVEX_L2_XD_K_B, /* 12036 */
  IC_EVEX_L2_XD_K_B, /* 12037 */
  IC_EVEX_L2_XD_K_B, /* 12038 */
  IC_EVEX_L2_XD_K_B, /* 12039 */
  IC_EVEX_L2_W_K_B, /* 12040 */
  IC_EVEX_L2_W_K_B, /* 12041 */
  IC_EVEX_L2_W_XS_K_B, /* 12042 */
  IC_EVEX_L2_W_XS_K_B, /* 12043 */
  IC_EVEX_L2_W_XD_K_B, /* 12044 */
  IC_EVEX_L2_W_XD_K_B, /* 12045 */
  IC_EVEX_L2_W_XD_K_B, /* 12046 */
  IC_EVEX_L2_W_XD_K_B, /* 12047 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12048 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12049 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12050 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12051 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12052 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12053 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12054 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12055 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12056 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12057 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12058 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12059 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12060 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12061 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12062 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12063 */
  IC_EVEX_L2_K_B, /* 12064 */
  IC_EVEX_L2_K_B, /* 12065 */
  IC_EVEX_L2_XS_K_B, /* 12066 */
  IC_EVEX_L2_XS_K_B, /* 12067 */
  IC_EVEX_L2_XD_K_B, /* 12068 */
  IC_EVEX_L2_XD_K_B, /* 12069 */
  IC_EVEX_L2_XD_K_B, /* 12070 */
  IC_EVEX_L2_XD_K_B, /* 12071 */
  IC_EVEX_L2_W_K_B, /* 12072 */
  IC_EVEX_L2_W_K_B, /* 12073 */
  IC_EVEX_L2_W_XS_K_B, /* 12074 */
  IC_EVEX_L2_W_XS_K_B, /* 12075 */
  IC_EVEX_L2_W_XD_K_B, /* 12076 */
  IC_EVEX_L2_W_XD_K_B, /* 12077 */
  IC_EVEX_L2_W_XD_K_B, /* 12078 */
  IC_EVEX_L2_W_XD_K_B, /* 12079 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12080 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12081 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12082 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12083 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12084 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12085 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12086 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12087 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12088 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12089 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12090 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12091 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12092 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12093 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12094 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12095 */
  IC_EVEX_L2_K_B, /* 12096 */
  IC_EVEX_L2_K_B, /* 12097 */
  IC_EVEX_L2_XS_K_B, /* 12098 */
  IC_EVEX_L2_XS_K_B, /* 12099 */
  IC_EVEX_L2_XD_K_B, /* 12100 */
  IC_EVEX_L2_XD_K_B, /* 12101 */
  IC_EVEX_L2_XD_K_B, /* 12102 */
  IC_EVEX_L2_XD_K_B, /* 12103 */
  IC_EVEX_L2_W_K_B, /* 12104 */
  IC_EVEX_L2_W_K_B, /* 12105 */
  IC_EVEX_L2_W_XS_K_B, /* 12106 */
  IC_EVEX_L2_W_XS_K_B, /* 12107 */
  IC_EVEX_L2_W_XD_K_B, /* 12108 */
  IC_EVEX_L2_W_XD_K_B, /* 12109 */
  IC_EVEX_L2_W_XD_K_B, /* 12110 */
  IC_EVEX_L2_W_XD_K_B, /* 12111 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12112 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12113 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12114 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12115 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12116 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12117 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12118 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12119 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12120 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12121 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12122 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12123 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12124 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12125 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12126 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12127 */
  IC_EVEX_L2_K_B, /* 12128 */
  IC_EVEX_L2_K_B, /* 12129 */
  IC_EVEX_L2_XS_K_B, /* 12130 */
  IC_EVEX_L2_XS_K_B, /* 12131 */
  IC_EVEX_L2_XD_K_B, /* 12132 */
  IC_EVEX_L2_XD_K_B, /* 12133 */
  IC_EVEX_L2_XD_K_B, /* 12134 */
  IC_EVEX_L2_XD_K_B, /* 12135 */
  IC_EVEX_L2_W_K_B, /* 12136 */
  IC_EVEX_L2_W_K_B, /* 12137 */
  IC_EVEX_L2_W_XS_K_B, /* 12138 */
  IC_EVEX_L2_W_XS_K_B, /* 12139 */
  IC_EVEX_L2_W_XD_K_B, /* 12140 */
  IC_EVEX_L2_W_XD_K_B, /* 12141 */
  IC_EVEX_L2_W_XD_K_B, /* 12142 */
  IC_EVEX_L2_W_XD_K_B, /* 12143 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12144 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12145 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12146 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12147 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12148 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12149 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12150 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12151 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12152 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12153 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12154 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12155 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12156 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12157 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12158 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12159 */
  IC_EVEX_L2_K_B, /* 12160 */
  IC_EVEX_L2_K_B, /* 12161 */
  IC_EVEX_L2_XS_K_B, /* 12162 */
  IC_EVEX_L2_XS_K_B, /* 12163 */
  IC_EVEX_L2_XD_K_B, /* 12164 */
  IC_EVEX_L2_XD_K_B, /* 12165 */
  IC_EVEX_L2_XD_K_B, /* 12166 */
  IC_EVEX_L2_XD_K_B, /* 12167 */
  IC_EVEX_L2_W_K_B, /* 12168 */
  IC_EVEX_L2_W_K_B, /* 12169 */
  IC_EVEX_L2_W_XS_K_B, /* 12170 */
  IC_EVEX_L2_W_XS_K_B, /* 12171 */
  IC_EVEX_L2_W_XD_K_B, /* 12172 */
  IC_EVEX_L2_W_XD_K_B, /* 12173 */
  IC_EVEX_L2_W_XD_K_B, /* 12174 */
  IC_EVEX_L2_W_XD_K_B, /* 12175 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12176 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12177 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12178 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12179 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12180 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12181 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12182 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12183 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12184 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12185 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12186 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12187 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12188 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12189 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12190 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12191 */
  IC_EVEX_L2_K_B, /* 12192 */
  IC_EVEX_L2_K_B, /* 12193 */
  IC_EVEX_L2_XS_K_B, /* 12194 */
  IC_EVEX_L2_XS_K_B, /* 12195 */
  IC_EVEX_L2_XD_K_B, /* 12196 */
  IC_EVEX_L2_XD_K_B, /* 12197 */
  IC_EVEX_L2_XD_K_B, /* 12198 */
  IC_EVEX_L2_XD_K_B, /* 12199 */
  IC_EVEX_L2_W_K_B, /* 12200 */
  IC_EVEX_L2_W_K_B, /* 12201 */
  IC_EVEX_L2_W_XS_K_B, /* 12202 */
  IC_EVEX_L2_W_XS_K_B, /* 12203 */
  IC_EVEX_L2_W_XD_K_B, /* 12204 */
  IC_EVEX_L2_W_XD_K_B, /* 12205 */
  IC_EVEX_L2_W_XD_K_B, /* 12206 */
  IC_EVEX_L2_W_XD_K_B, /* 12207 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12208 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12209 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12210 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12211 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12212 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12213 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12214 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12215 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12216 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12217 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12218 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12219 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12220 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12221 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12222 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12223 */
  IC_EVEX_L2_K_B, /* 12224 */
  IC_EVEX_L2_K_B, /* 12225 */
  IC_EVEX_L2_XS_K_B, /* 12226 */
  IC_EVEX_L2_XS_K_B, /* 12227 */
  IC_EVEX_L2_XD_K_B, /* 12228 */
  IC_EVEX_L2_XD_K_B, /* 12229 */
  IC_EVEX_L2_XD_K_B, /* 12230 */
  IC_EVEX_L2_XD_K_B, /* 12231 */
  IC_EVEX_L2_W_K_B, /* 12232 */
  IC_EVEX_L2_W_K_B, /* 12233 */
  IC_EVEX_L2_W_XS_K_B, /* 12234 */
  IC_EVEX_L2_W_XS_K_B, /* 12235 */
  IC_EVEX_L2_W_XD_K_B, /* 12236 */
  IC_EVEX_L2_W_XD_K_B, /* 12237 */
  IC_EVEX_L2_W_XD_K_B, /* 12238 */
  IC_EVEX_L2_W_XD_K_B, /* 12239 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12240 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12241 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12242 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12243 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12244 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12245 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12246 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12247 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12248 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12249 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12250 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12251 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12252 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12253 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12254 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12255 */
  IC_EVEX_L2_K_B, /* 12256 */
  IC_EVEX_L2_K_B, /* 12257 */
  IC_EVEX_L2_XS_K_B, /* 12258 */
  IC_EVEX_L2_XS_K_B, /* 12259 */
  IC_EVEX_L2_XD_K_B, /* 12260 */
  IC_EVEX_L2_XD_K_B, /* 12261 */
  IC_EVEX_L2_XD_K_B, /* 12262 */
  IC_EVEX_L2_XD_K_B, /* 12263 */
  IC_EVEX_L2_W_K_B, /* 12264 */
  IC_EVEX_L2_W_K_B, /* 12265 */
  IC_EVEX_L2_W_XS_K_B, /* 12266 */
  IC_EVEX_L2_W_XS_K_B, /* 12267 */
  IC_EVEX_L2_W_XD_K_B, /* 12268 */
  IC_EVEX_L2_W_XD_K_B, /* 12269 */
  IC_EVEX_L2_W_XD_K_B, /* 12270 */
  IC_EVEX_L2_W_XD_K_B, /* 12271 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12272 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12273 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12274 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12275 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12276 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12277 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12278 */
  IC_EVEX_L2_OPSIZE_K_B, /* 12279 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12280 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12281 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12282 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12283 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12284 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12285 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12286 */
  IC_EVEX_L2_W_OPSIZE_K_B, /* 12287 */
  IC, /* 12288 */
  IC_64BIT, /* 12289 */
  IC_XS, /* 12290 */
  IC_64BIT_XS, /* 12291 */
  IC_XD, /* 12292 */
  IC_64BIT_XD, /* 12293 */
  IC_XS, /* 12294 */
  IC_64BIT_XS, /* 12295 */
  IC, /* 12296 */
  IC_64BIT_REXW, /* 12297 */
  IC_XS, /* 12298 */
  IC_64BIT_REXW_XS, /* 12299 */
  IC_XD, /* 12300 */
  IC_64BIT_REXW_XD, /* 12301 */
  IC_XS, /* 12302 */
  IC_64BIT_REXW_XS, /* 12303 */
  IC_OPSIZE, /* 12304 */
  IC_64BIT_OPSIZE, /* 12305 */
  IC_XS_OPSIZE, /* 12306 */
  IC_64BIT_XS_OPSIZE, /* 12307 */
  IC_XD_OPSIZE, /* 12308 */
  IC_64BIT_XD_OPSIZE, /* 12309 */
  IC_XS_OPSIZE, /* 12310 */
  IC_64BIT_XD_OPSIZE, /* 12311 */
  IC_OPSIZE, /* 12312 */
  IC_64BIT_REXW_OPSIZE, /* 12313 */
  IC_XS_OPSIZE, /* 12314 */
  IC_64BIT_REXW_XS, /* 12315 */
  IC_XD_OPSIZE, /* 12316 */
  IC_64BIT_REXW_XD, /* 12317 */
  IC_XS_OPSIZE, /* 12318 */
  IC_64BIT_REXW_XS, /* 12319 */
  IC_ADSIZE, /* 12320 */
  IC_64BIT_ADSIZE, /* 12321 */
  IC_XS, /* 12322 */
  IC_64BIT_XS, /* 12323 */
  IC_XD, /* 12324 */
  IC_64BIT_XD, /* 12325 */
  IC_XS, /* 12326 */
  IC_64BIT_XS, /* 12327 */
  IC_ADSIZE, /* 12328 */
  IC_64BIT_REXW_ADSIZE, /* 12329 */
  IC_XS, /* 12330 */
  IC_64BIT_REXW_XS, /* 12331 */
  IC_XD, /* 12332 */
  IC_64BIT_REXW_XD, /* 12333 */
  IC_XS, /* 12334 */
  IC_64BIT_REXW_XS, /* 12335 */
  IC_OPSIZE_ADSIZE, /* 12336 */
  IC_64BIT_OPSIZE_ADSIZE, /* 12337 */
  IC_XS_OPSIZE, /* 12338 */
  IC_64BIT_XS_OPSIZE, /* 12339 */
  IC_XD_OPSIZE, /* 12340 */
  IC_64BIT_XD_OPSIZE, /* 12341 */
  IC_XS_OPSIZE, /* 12342 */
  IC_64BIT_XD_OPSIZE, /* 12343 */
  IC_OPSIZE_ADSIZE, /* 12344 */
  IC_64BIT_REXW_OPSIZE, /* 12345 */
  IC_XS_OPSIZE, /* 12346 */
  IC_64BIT_REXW_XS, /* 12347 */
  IC_XD_OPSIZE, /* 12348 */
  IC_64BIT_REXW_XD, /* 12349 */
  IC_XS_OPSIZE, /* 12350 */
  IC_64BIT_REXW_XS, /* 12351 */
  IC_VEX, /* 12352 */
  IC_VEX, /* 12353 */
  IC_VEX_XS, /* 12354 */
  IC_VEX_XS, /* 12355 */
  IC_VEX_XD, /* 12356 */
  IC_VEX_XD, /* 12357 */
  IC_VEX_XD, /* 12358 */
  IC_VEX_XD, /* 12359 */
  IC_VEX_W, /* 12360 */
  IC_VEX_W, /* 12361 */
  IC_VEX_W_XS, /* 12362 */
  IC_VEX_W_XS, /* 12363 */
  IC_VEX_W_XD, /* 12364 */
  IC_VEX_W_XD, /* 12365 */
  IC_VEX_W_XD, /* 12366 */
  IC_VEX_W_XD, /* 12367 */
  IC_VEX_OPSIZE, /* 12368 */
  IC_VEX_OPSIZE, /* 12369 */
  IC_VEX_OPSIZE, /* 12370 */
  IC_VEX_OPSIZE, /* 12371 */
  IC_VEX_OPSIZE, /* 12372 */
  IC_VEX_OPSIZE, /* 12373 */
  IC_VEX_OPSIZE, /* 12374 */
  IC_VEX_OPSIZE, /* 12375 */
  IC_VEX_W_OPSIZE, /* 12376 */
  IC_VEX_W_OPSIZE, /* 12377 */
  IC_VEX_W_OPSIZE, /* 12378 */
  IC_VEX_W_OPSIZE, /* 12379 */
  IC_VEX_W_OPSIZE, /* 12380 */
  IC_VEX_W_OPSIZE, /* 12381 */
  IC_VEX_W_OPSIZE, /* 12382 */
  IC_VEX_W_OPSIZE, /* 12383 */
  IC_VEX, /* 12384 */
  IC_VEX, /* 12385 */
  IC_VEX_XS, /* 12386 */
  IC_VEX_XS, /* 12387 */
  IC_VEX_XD, /* 12388 */
  IC_VEX_XD, /* 12389 */
  IC_VEX_XD, /* 12390 */
  IC_VEX_XD, /* 12391 */
  IC_VEX_W, /* 12392 */
  IC_VEX_W, /* 12393 */
  IC_VEX_W_XS, /* 12394 */
  IC_VEX_W_XS, /* 12395 */
  IC_VEX_W_XD, /* 12396 */
  IC_VEX_W_XD, /* 12397 */
  IC_VEX_W_XD, /* 12398 */
  IC_VEX_W_XD, /* 12399 */
  IC_VEX_OPSIZE, /* 12400 */
  IC_VEX_OPSIZE, /* 12401 */
  IC_VEX_OPSIZE, /* 12402 */
  IC_VEX_OPSIZE, /* 12403 */
  IC_VEX_OPSIZE, /* 12404 */
  IC_VEX_OPSIZE, /* 12405 */
  IC_VEX_OPSIZE, /* 12406 */
  IC_VEX_OPSIZE, /* 12407 */
  IC_VEX_W_OPSIZE, /* 12408 */
  IC_VEX_W_OPSIZE, /* 12409 */
  IC_VEX_W_OPSIZE, /* 12410 */
  IC_VEX_W_OPSIZE, /* 12411 */
  IC_VEX_W_OPSIZE, /* 12412 */
  IC_VEX_W_OPSIZE, /* 12413 */
  IC_VEX_W_OPSIZE, /* 12414 */
  IC_VEX_W_OPSIZE, /* 12415 */
  IC_VEX_L, /* 12416 */
  IC_VEX_L, /* 12417 */
  IC_VEX_L_XS, /* 12418 */
  IC_VEX_L_XS, /* 12419 */
  IC_VEX_L_XD, /* 12420 */
  IC_VEX_L_XD, /* 12421 */
  IC_VEX_L_XD, /* 12422 */
  IC_VEX_L_XD, /* 12423 */
  IC_VEX_L_W, /* 12424 */
  IC_VEX_L_W, /* 12425 */
  IC_VEX_L_W_XS, /* 12426 */
  IC_VEX_L_W_XS, /* 12427 */
  IC_VEX_L_W_XD, /* 12428 */
  IC_VEX_L_W_XD, /* 12429 */
  IC_VEX_L_W_XD, /* 12430 */
  IC_VEX_L_W_XD, /* 12431 */
  IC_VEX_L_OPSIZE, /* 12432 */
  IC_VEX_L_OPSIZE, /* 12433 */
  IC_VEX_L_OPSIZE, /* 12434 */
  IC_VEX_L_OPSIZE, /* 12435 */
  IC_VEX_L_OPSIZE, /* 12436 */
  IC_VEX_L_OPSIZE, /* 12437 */
  IC_VEX_L_OPSIZE, /* 12438 */
  IC_VEX_L_OPSIZE, /* 12439 */
  IC_VEX_L_W_OPSIZE, /* 12440 */
  IC_VEX_L_W_OPSIZE, /* 12441 */
  IC_VEX_L_W_OPSIZE, /* 12442 */
  IC_VEX_L_W_OPSIZE, /* 12443 */
  IC_VEX_L_W_OPSIZE, /* 12444 */
  IC_VEX_L_W_OPSIZE, /* 12445 */
  IC_VEX_L_W_OPSIZE, /* 12446 */
  IC_VEX_L_W_OPSIZE, /* 12447 */
  IC_VEX_L, /* 12448 */
  IC_VEX_L, /* 12449 */
  IC_VEX_L_XS, /* 12450 */
  IC_VEX_L_XS, /* 12451 */
  IC_VEX_L_XD, /* 12452 */
  IC_VEX_L_XD, /* 12453 */
  IC_VEX_L_XD, /* 12454 */
  IC_VEX_L_XD, /* 12455 */
  IC_VEX_L_W, /* 12456 */
  IC_VEX_L_W, /* 12457 */
  IC_VEX_L_W_XS, /* 12458 */
  IC_VEX_L_W_XS, /* 12459 */
  IC_VEX_L_W_XD, /* 12460 */
  IC_VEX_L_W_XD, /* 12461 */
  IC_VEX_L_W_XD, /* 12462 */
  IC_VEX_L_W_XD, /* 12463 */
  IC_VEX_L_OPSIZE, /* 12464 */
  IC_VEX_L_OPSIZE, /* 12465 */
  IC_VEX_L_OPSIZE, /* 12466 */
  IC_VEX_L_OPSIZE, /* 12467 */
  IC_VEX_L_OPSIZE, /* 12468 */
  IC_VEX_L_OPSIZE, /* 12469 */
  IC_VEX_L_OPSIZE, /* 12470 */
  IC_VEX_L_OPSIZE, /* 12471 */
  IC_VEX_L_W_OPSIZE, /* 12472 */
  IC_VEX_L_W_OPSIZE, /* 12473 */
  IC_VEX_L_W_OPSIZE, /* 12474 */
  IC_VEX_L_W_OPSIZE, /* 12475 */
  IC_VEX_L_W_OPSIZE, /* 12476 */
  IC_VEX_L_W_OPSIZE, /* 12477 */
  IC_VEX_L_W_OPSIZE, /* 12478 */
  IC_VEX_L_W_OPSIZE, /* 12479 */
  IC_VEX_L, /* 12480 */
  IC_VEX_L, /* 12481 */
  IC_VEX_L_XS, /* 12482 */
  IC_VEX_L_XS, /* 12483 */
  IC_VEX_L_XD, /* 12484 */
  IC_VEX_L_XD, /* 12485 */
  IC_VEX_L_XD, /* 12486 */
  IC_VEX_L_XD, /* 12487 */
  IC_VEX_L_W, /* 12488 */
  IC_VEX_L_W, /* 12489 */
  IC_VEX_L_W_XS, /* 12490 */
  IC_VEX_L_W_XS, /* 12491 */
  IC_VEX_L_W_XD, /* 12492 */
  IC_VEX_L_W_XD, /* 12493 */
  IC_VEX_L_W_XD, /* 12494 */
  IC_VEX_L_W_XD, /* 12495 */
  IC_VEX_L_OPSIZE, /* 12496 */
  IC_VEX_L_OPSIZE, /* 12497 */
  IC_VEX_L_OPSIZE, /* 12498 */
  IC_VEX_L_OPSIZE, /* 12499 */
  IC_VEX_L_OPSIZE, /* 12500 */
  IC_VEX_L_OPSIZE, /* 12501 */
  IC_VEX_L_OPSIZE, /* 12502 */
  IC_VEX_L_OPSIZE, /* 12503 */
  IC_VEX_L_W_OPSIZE, /* 12504 */
  IC_VEX_L_W_OPSIZE, /* 12505 */
  IC_VEX_L_W_OPSIZE, /* 12506 */
  IC_VEX_L_W_OPSIZE, /* 12507 */
  IC_VEX_L_W_OPSIZE, /* 12508 */
  IC_VEX_L_W_OPSIZE, /* 12509 */
  IC_VEX_L_W_OPSIZE, /* 12510 */
  IC_VEX_L_W_OPSIZE, /* 12511 */
  IC_VEX_L, /* 12512 */
  IC_VEX_L, /* 12513 */
  IC_VEX_L_XS, /* 12514 */
  IC_VEX_L_XS, /* 12515 */
  IC_VEX_L_XD, /* 12516 */
  IC_VEX_L_XD, /* 12517 */
  IC_VEX_L_XD, /* 12518 */
  IC_VEX_L_XD, /* 12519 */
  IC_VEX_L_W, /* 12520 */
  IC_VEX_L_W, /* 12521 */
  IC_VEX_L_W_XS, /* 12522 */
  IC_VEX_L_W_XS, /* 12523 */
  IC_VEX_L_W_XD, /* 12524 */
  IC_VEX_L_W_XD, /* 12525 */
  IC_VEX_L_W_XD, /* 12526 */
  IC_VEX_L_W_XD, /* 12527 */
  IC_VEX_L_OPSIZE, /* 12528 */
  IC_VEX_L_OPSIZE, /* 12529 */
  IC_VEX_L_OPSIZE, /* 12530 */
  IC_VEX_L_OPSIZE, /* 12531 */
  IC_VEX_L_OPSIZE, /* 12532 */
  IC_VEX_L_OPSIZE, /* 12533 */
  IC_VEX_L_OPSIZE, /* 12534 */
  IC_VEX_L_OPSIZE, /* 12535 */
  IC_VEX_L_W_OPSIZE, /* 12536 */
  IC_VEX_L_W_OPSIZE, /* 12537 */
  IC_VEX_L_W_OPSIZE, /* 12538 */
  IC_VEX_L_W_OPSIZE, /* 12539 */
  IC_VEX_L_W_OPSIZE, /* 12540 */
  IC_VEX_L_W_OPSIZE, /* 12541 */
  IC_VEX_L_W_OPSIZE, /* 12542 */
  IC_VEX_L_W_OPSIZE, /* 12543 */
  IC_EVEX_KZ_B, /* 12544 */
  IC_EVEX_KZ_B, /* 12545 */
  IC_EVEX_XS_KZ_B, /* 12546 */
  IC_EVEX_XS_KZ_B, /* 12547 */
  IC_EVEX_XD_KZ_B, /* 12548 */
  IC_EVEX_XD_KZ_B, /* 12549 */
  IC_EVEX_XD_KZ_B, /* 12550 */
  IC_EVEX_XD_KZ_B, /* 12551 */
  IC_EVEX_W_KZ_B, /* 12552 */
  IC_EVEX_W_KZ_B, /* 12553 */
  IC_EVEX_W_XS_KZ_B, /* 12554 */
  IC_EVEX_W_XS_KZ_B, /* 12555 */
  IC_EVEX_W_XD_KZ_B, /* 12556 */
  IC_EVEX_W_XD_KZ_B, /* 12557 */
  IC_EVEX_W_XD_KZ_B, /* 12558 */
  IC_EVEX_W_XD_KZ_B, /* 12559 */
  IC_EVEX_OPSIZE_KZ_B, /* 12560 */
  IC_EVEX_OPSIZE_KZ_B, /* 12561 */
  IC_EVEX_OPSIZE_KZ_B, /* 12562 */
  IC_EVEX_OPSIZE_KZ_B, /* 12563 */
  IC_EVEX_OPSIZE_KZ_B, /* 12564 */
  IC_EVEX_OPSIZE_KZ_B, /* 12565 */
  IC_EVEX_OPSIZE_KZ_B, /* 12566 */
  IC_EVEX_OPSIZE_KZ_B, /* 12567 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12568 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12569 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12570 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12571 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12572 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12573 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12574 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12575 */
  IC_EVEX_KZ_B, /* 12576 */
  IC_EVEX_KZ_B, /* 12577 */
  IC_EVEX_XS_KZ_B, /* 12578 */
  IC_EVEX_XS_KZ_B, /* 12579 */
  IC_EVEX_XD_KZ_B, /* 12580 */
  IC_EVEX_XD_KZ_B, /* 12581 */
  IC_EVEX_XD_KZ_B, /* 12582 */
  IC_EVEX_XD_KZ_B, /* 12583 */
  IC_EVEX_W_KZ_B, /* 12584 */
  IC_EVEX_W_KZ_B, /* 12585 */
  IC_EVEX_W_XS_KZ_B, /* 12586 */
  IC_EVEX_W_XS_KZ_B, /* 12587 */
  IC_EVEX_W_XD_KZ_B, /* 12588 */
  IC_EVEX_W_XD_KZ_B, /* 12589 */
  IC_EVEX_W_XD_KZ_B, /* 12590 */
  IC_EVEX_W_XD_KZ_B, /* 12591 */
  IC_EVEX_OPSIZE_KZ_B, /* 12592 */
  IC_EVEX_OPSIZE_KZ_B, /* 12593 */
  IC_EVEX_OPSIZE_KZ_B, /* 12594 */
  IC_EVEX_OPSIZE_KZ_B, /* 12595 */
  IC_EVEX_OPSIZE_KZ_B, /* 12596 */
  IC_EVEX_OPSIZE_KZ_B, /* 12597 */
  IC_EVEX_OPSIZE_KZ_B, /* 12598 */
  IC_EVEX_OPSIZE_KZ_B, /* 12599 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12600 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12601 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12602 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12603 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12604 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12605 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12606 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12607 */
  IC_EVEX_KZ_B, /* 12608 */
  IC_EVEX_KZ_B, /* 12609 */
  IC_EVEX_XS_KZ_B, /* 12610 */
  IC_EVEX_XS_KZ_B, /* 12611 */
  IC_EVEX_XD_KZ_B, /* 12612 */
  IC_EVEX_XD_KZ_B, /* 12613 */
  IC_EVEX_XD_KZ_B, /* 12614 */
  IC_EVEX_XD_KZ_B, /* 12615 */
  IC_EVEX_W_KZ_B, /* 12616 */
  IC_EVEX_W_KZ_B, /* 12617 */
  IC_EVEX_W_XS_KZ_B, /* 12618 */
  IC_EVEX_W_XS_KZ_B, /* 12619 */
  IC_EVEX_W_XD_KZ_B, /* 12620 */
  IC_EVEX_W_XD_KZ_B, /* 12621 */
  IC_EVEX_W_XD_KZ_B, /* 12622 */
  IC_EVEX_W_XD_KZ_B, /* 12623 */
  IC_EVEX_OPSIZE_KZ_B, /* 12624 */
  IC_EVEX_OPSIZE_KZ_B, /* 12625 */
  IC_EVEX_OPSIZE_KZ_B, /* 12626 */
  IC_EVEX_OPSIZE_KZ_B, /* 12627 */
  IC_EVEX_OPSIZE_KZ_B, /* 12628 */
  IC_EVEX_OPSIZE_KZ_B, /* 12629 */
  IC_EVEX_OPSIZE_KZ_B, /* 12630 */
  IC_EVEX_OPSIZE_KZ_B, /* 12631 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12632 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12633 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12634 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12635 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12636 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12637 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12638 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12639 */
  IC_EVEX_KZ_B, /* 12640 */
  IC_EVEX_KZ_B, /* 12641 */
  IC_EVEX_XS_KZ_B, /* 12642 */
  IC_EVEX_XS_KZ_B, /* 12643 */
  IC_EVEX_XD_KZ_B, /* 12644 */
  IC_EVEX_XD_KZ_B, /* 12645 */
  IC_EVEX_XD_KZ_B, /* 12646 */
  IC_EVEX_XD_KZ_B, /* 12647 */
  IC_EVEX_W_KZ_B, /* 12648 */
  IC_EVEX_W_KZ_B, /* 12649 */
  IC_EVEX_W_XS_KZ_B, /* 12650 */
  IC_EVEX_W_XS_KZ_B, /* 12651 */
  IC_EVEX_W_XD_KZ_B, /* 12652 */
  IC_EVEX_W_XD_KZ_B, /* 12653 */
  IC_EVEX_W_XD_KZ_B, /* 12654 */
  IC_EVEX_W_XD_KZ_B, /* 12655 */
  IC_EVEX_OPSIZE_KZ_B, /* 12656 */
  IC_EVEX_OPSIZE_KZ_B, /* 12657 */
  IC_EVEX_OPSIZE_KZ_B, /* 12658 */
  IC_EVEX_OPSIZE_KZ_B, /* 12659 */
  IC_EVEX_OPSIZE_KZ_B, /* 12660 */
  IC_EVEX_OPSIZE_KZ_B, /* 12661 */
  IC_EVEX_OPSIZE_KZ_B, /* 12662 */
  IC_EVEX_OPSIZE_KZ_B, /* 12663 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12664 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12665 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12666 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12667 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12668 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12669 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12670 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12671 */
  IC_EVEX_KZ_B, /* 12672 */
  IC_EVEX_KZ_B, /* 12673 */
  IC_EVEX_XS_KZ_B, /* 12674 */
  IC_EVEX_XS_KZ_B, /* 12675 */
  IC_EVEX_XD_KZ_B, /* 12676 */
  IC_EVEX_XD_KZ_B, /* 12677 */
  IC_EVEX_XD_KZ_B, /* 12678 */
  IC_EVEX_XD_KZ_B, /* 12679 */
  IC_EVEX_W_KZ_B, /* 12680 */
  IC_EVEX_W_KZ_B, /* 12681 */
  IC_EVEX_W_XS_KZ_B, /* 12682 */
  IC_EVEX_W_XS_KZ_B, /* 12683 */
  IC_EVEX_W_XD_KZ_B, /* 12684 */
  IC_EVEX_W_XD_KZ_B, /* 12685 */
  IC_EVEX_W_XD_KZ_B, /* 12686 */
  IC_EVEX_W_XD_KZ_B, /* 12687 */
  IC_EVEX_OPSIZE_KZ_B, /* 12688 */
  IC_EVEX_OPSIZE_KZ_B, /* 12689 */
  IC_EVEX_OPSIZE_KZ_B, /* 12690 */
  IC_EVEX_OPSIZE_KZ_B, /* 12691 */
  IC_EVEX_OPSIZE_KZ_B, /* 12692 */
  IC_EVEX_OPSIZE_KZ_B, /* 12693 */
  IC_EVEX_OPSIZE_KZ_B, /* 12694 */
  IC_EVEX_OPSIZE_KZ_B, /* 12695 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12696 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12697 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12698 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12699 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12700 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12701 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12702 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12703 */
  IC_EVEX_KZ_B, /* 12704 */
  IC_EVEX_KZ_B, /* 12705 */
  IC_EVEX_XS_KZ_B, /* 12706 */
  IC_EVEX_XS_KZ_B, /* 12707 */
  IC_EVEX_XD_KZ_B, /* 12708 */
  IC_EVEX_XD_KZ_B, /* 12709 */
  IC_EVEX_XD_KZ_B, /* 12710 */
  IC_EVEX_XD_KZ_B, /* 12711 */
  IC_EVEX_W_KZ_B, /* 12712 */
  IC_EVEX_W_KZ_B, /* 12713 */
  IC_EVEX_W_XS_KZ_B, /* 12714 */
  IC_EVEX_W_XS_KZ_B, /* 12715 */
  IC_EVEX_W_XD_KZ_B, /* 12716 */
  IC_EVEX_W_XD_KZ_B, /* 12717 */
  IC_EVEX_W_XD_KZ_B, /* 12718 */
  IC_EVEX_W_XD_KZ_B, /* 12719 */
  IC_EVEX_OPSIZE_KZ_B, /* 12720 */
  IC_EVEX_OPSIZE_KZ_B, /* 12721 */
  IC_EVEX_OPSIZE_KZ_B, /* 12722 */
  IC_EVEX_OPSIZE_KZ_B, /* 12723 */
  IC_EVEX_OPSIZE_KZ_B, /* 12724 */
  IC_EVEX_OPSIZE_KZ_B, /* 12725 */
  IC_EVEX_OPSIZE_KZ_B, /* 12726 */
  IC_EVEX_OPSIZE_KZ_B, /* 12727 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12728 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12729 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12730 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12731 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12732 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12733 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12734 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12735 */
  IC_EVEX_KZ_B, /* 12736 */
  IC_EVEX_KZ_B, /* 12737 */
  IC_EVEX_XS_KZ_B, /* 12738 */
  IC_EVEX_XS_KZ_B, /* 12739 */
  IC_EVEX_XD_KZ_B, /* 12740 */
  IC_EVEX_XD_KZ_B, /* 12741 */
  IC_EVEX_XD_KZ_B, /* 12742 */
  IC_EVEX_XD_KZ_B, /* 12743 */
  IC_EVEX_W_KZ_B, /* 12744 */
  IC_EVEX_W_KZ_B, /* 12745 */
  IC_EVEX_W_XS_KZ_B, /* 12746 */
  IC_EVEX_W_XS_KZ_B, /* 12747 */
  IC_EVEX_W_XD_KZ_B, /* 12748 */
  IC_EVEX_W_XD_KZ_B, /* 12749 */
  IC_EVEX_W_XD_KZ_B, /* 12750 */
  IC_EVEX_W_XD_KZ_B, /* 12751 */
  IC_EVEX_OPSIZE_KZ_B, /* 12752 */
  IC_EVEX_OPSIZE_KZ_B, /* 12753 */
  IC_EVEX_OPSIZE_KZ_B, /* 12754 */
  IC_EVEX_OPSIZE_KZ_B, /* 12755 */
  IC_EVEX_OPSIZE_KZ_B, /* 12756 */
  IC_EVEX_OPSIZE_KZ_B, /* 12757 */
  IC_EVEX_OPSIZE_KZ_B, /* 12758 */
  IC_EVEX_OPSIZE_KZ_B, /* 12759 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12760 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12761 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12762 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12763 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12764 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12765 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12766 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12767 */
  IC_EVEX_KZ_B, /* 12768 */
  IC_EVEX_KZ_B, /* 12769 */
  IC_EVEX_XS_KZ_B, /* 12770 */
  IC_EVEX_XS_KZ_B, /* 12771 */
  IC_EVEX_XD_KZ_B, /* 12772 */
  IC_EVEX_XD_KZ_B, /* 12773 */
  IC_EVEX_XD_KZ_B, /* 12774 */
  IC_EVEX_XD_KZ_B, /* 12775 */
  IC_EVEX_W_KZ_B, /* 12776 */
  IC_EVEX_W_KZ_B, /* 12777 */
  IC_EVEX_W_XS_KZ_B, /* 12778 */
  IC_EVEX_W_XS_KZ_B, /* 12779 */
  IC_EVEX_W_XD_KZ_B, /* 12780 */
  IC_EVEX_W_XD_KZ_B, /* 12781 */
  IC_EVEX_W_XD_KZ_B, /* 12782 */
  IC_EVEX_W_XD_KZ_B, /* 12783 */
  IC_EVEX_OPSIZE_KZ_B, /* 12784 */
  IC_EVEX_OPSIZE_KZ_B, /* 12785 */
  IC_EVEX_OPSIZE_KZ_B, /* 12786 */
  IC_EVEX_OPSIZE_KZ_B, /* 12787 */
  IC_EVEX_OPSIZE_KZ_B, /* 12788 */
  IC_EVEX_OPSIZE_KZ_B, /* 12789 */
  IC_EVEX_OPSIZE_KZ_B, /* 12790 */
  IC_EVEX_OPSIZE_KZ_B, /* 12791 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12792 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12793 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12794 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12795 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12796 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12797 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12798 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 12799 */
  IC, /* 12800 */
  IC_64BIT, /* 12801 */
  IC_XS, /* 12802 */
  IC_64BIT_XS, /* 12803 */
  IC_XD, /* 12804 */
  IC_64BIT_XD, /* 12805 */
  IC_XS, /* 12806 */
  IC_64BIT_XS, /* 12807 */
  IC, /* 12808 */
  IC_64BIT_REXW, /* 12809 */
  IC_XS, /* 12810 */
  IC_64BIT_REXW_XS, /* 12811 */
  IC_XD, /* 12812 */
  IC_64BIT_REXW_XD, /* 12813 */
  IC_XS, /* 12814 */
  IC_64BIT_REXW_XS, /* 12815 */
  IC_OPSIZE, /* 12816 */
  IC_64BIT_OPSIZE, /* 12817 */
  IC_XS_OPSIZE, /* 12818 */
  IC_64BIT_XS_OPSIZE, /* 12819 */
  IC_XD_OPSIZE, /* 12820 */
  IC_64BIT_XD_OPSIZE, /* 12821 */
  IC_XS_OPSIZE, /* 12822 */
  IC_64BIT_XD_OPSIZE, /* 12823 */
  IC_OPSIZE, /* 12824 */
  IC_64BIT_REXW_OPSIZE, /* 12825 */
  IC_XS_OPSIZE, /* 12826 */
  IC_64BIT_REXW_XS, /* 12827 */
  IC_XD_OPSIZE, /* 12828 */
  IC_64BIT_REXW_XD, /* 12829 */
  IC_XS_OPSIZE, /* 12830 */
  IC_64BIT_REXW_XS, /* 12831 */
  IC_ADSIZE, /* 12832 */
  IC_64BIT_ADSIZE, /* 12833 */
  IC_XS, /* 12834 */
  IC_64BIT_XS, /* 12835 */
  IC_XD, /* 12836 */
  IC_64BIT_XD, /* 12837 */
  IC_XS, /* 12838 */
  IC_64BIT_XS, /* 12839 */
  IC_ADSIZE, /* 12840 */
  IC_64BIT_REXW_ADSIZE, /* 12841 */
  IC_XS, /* 12842 */
  IC_64BIT_REXW_XS, /* 12843 */
  IC_XD, /* 12844 */
  IC_64BIT_REXW_XD, /* 12845 */
  IC_XS, /* 12846 */
  IC_64BIT_REXW_XS, /* 12847 */
  IC_OPSIZE_ADSIZE, /* 12848 */
  IC_64BIT_OPSIZE_ADSIZE, /* 12849 */
  IC_XS_OPSIZE, /* 12850 */
  IC_64BIT_XS_OPSIZE, /* 12851 */
  IC_XD_OPSIZE, /* 12852 */
  IC_64BIT_XD_OPSIZE, /* 12853 */
  IC_XS_OPSIZE, /* 12854 */
  IC_64BIT_XD_OPSIZE, /* 12855 */
  IC_OPSIZE_ADSIZE, /* 12856 */
  IC_64BIT_REXW_OPSIZE, /* 12857 */
  IC_XS_OPSIZE, /* 12858 */
  IC_64BIT_REXW_XS, /* 12859 */
  IC_XD_OPSIZE, /* 12860 */
  IC_64BIT_REXW_XD, /* 12861 */
  IC_XS_OPSIZE, /* 12862 */
  IC_64BIT_REXW_XS, /* 12863 */
  IC_VEX, /* 12864 */
  IC_VEX, /* 12865 */
  IC_VEX_XS, /* 12866 */
  IC_VEX_XS, /* 12867 */
  IC_VEX_XD, /* 12868 */
  IC_VEX_XD, /* 12869 */
  IC_VEX_XD, /* 12870 */
  IC_VEX_XD, /* 12871 */
  IC_VEX_W, /* 12872 */
  IC_VEX_W, /* 12873 */
  IC_VEX_W_XS, /* 12874 */
  IC_VEX_W_XS, /* 12875 */
  IC_VEX_W_XD, /* 12876 */
  IC_VEX_W_XD, /* 12877 */
  IC_VEX_W_XD, /* 12878 */
  IC_VEX_W_XD, /* 12879 */
  IC_VEX_OPSIZE, /* 12880 */
  IC_VEX_OPSIZE, /* 12881 */
  IC_VEX_OPSIZE, /* 12882 */
  IC_VEX_OPSIZE, /* 12883 */
  IC_VEX_OPSIZE, /* 12884 */
  IC_VEX_OPSIZE, /* 12885 */
  IC_VEX_OPSIZE, /* 12886 */
  IC_VEX_OPSIZE, /* 12887 */
  IC_VEX_W_OPSIZE, /* 12888 */
  IC_VEX_W_OPSIZE, /* 12889 */
  IC_VEX_W_OPSIZE, /* 12890 */
  IC_VEX_W_OPSIZE, /* 12891 */
  IC_VEX_W_OPSIZE, /* 12892 */
  IC_VEX_W_OPSIZE, /* 12893 */
  IC_VEX_W_OPSIZE, /* 12894 */
  IC_VEX_W_OPSIZE, /* 12895 */
  IC_VEX, /* 12896 */
  IC_VEX, /* 12897 */
  IC_VEX_XS, /* 12898 */
  IC_VEX_XS, /* 12899 */
  IC_VEX_XD, /* 12900 */
  IC_VEX_XD, /* 12901 */
  IC_VEX_XD, /* 12902 */
  IC_VEX_XD, /* 12903 */
  IC_VEX_W, /* 12904 */
  IC_VEX_W, /* 12905 */
  IC_VEX_W_XS, /* 12906 */
  IC_VEX_W_XS, /* 12907 */
  IC_VEX_W_XD, /* 12908 */
  IC_VEX_W_XD, /* 12909 */
  IC_VEX_W_XD, /* 12910 */
  IC_VEX_W_XD, /* 12911 */
  IC_VEX_OPSIZE, /* 12912 */
  IC_VEX_OPSIZE, /* 12913 */
  IC_VEX_OPSIZE, /* 12914 */
  IC_VEX_OPSIZE, /* 12915 */
  IC_VEX_OPSIZE, /* 12916 */
  IC_VEX_OPSIZE, /* 12917 */
  IC_VEX_OPSIZE, /* 12918 */
  IC_VEX_OPSIZE, /* 12919 */
  IC_VEX_W_OPSIZE, /* 12920 */
  IC_VEX_W_OPSIZE, /* 12921 */
  IC_VEX_W_OPSIZE, /* 12922 */
  IC_VEX_W_OPSIZE, /* 12923 */
  IC_VEX_W_OPSIZE, /* 12924 */
  IC_VEX_W_OPSIZE, /* 12925 */
  IC_VEX_W_OPSIZE, /* 12926 */
  IC_VEX_W_OPSIZE, /* 12927 */
  IC_VEX_L, /* 12928 */
  IC_VEX_L, /* 12929 */
  IC_VEX_L_XS, /* 12930 */
  IC_VEX_L_XS, /* 12931 */
  IC_VEX_L_XD, /* 12932 */
  IC_VEX_L_XD, /* 12933 */
  IC_VEX_L_XD, /* 12934 */
  IC_VEX_L_XD, /* 12935 */
  IC_VEX_L_W, /* 12936 */
  IC_VEX_L_W, /* 12937 */
  IC_VEX_L_W_XS, /* 12938 */
  IC_VEX_L_W_XS, /* 12939 */
  IC_VEX_L_W_XD, /* 12940 */
  IC_VEX_L_W_XD, /* 12941 */
  IC_VEX_L_W_XD, /* 12942 */
  IC_VEX_L_W_XD, /* 12943 */
  IC_VEX_L_OPSIZE, /* 12944 */
  IC_VEX_L_OPSIZE, /* 12945 */
  IC_VEX_L_OPSIZE, /* 12946 */
  IC_VEX_L_OPSIZE, /* 12947 */
  IC_VEX_L_OPSIZE, /* 12948 */
  IC_VEX_L_OPSIZE, /* 12949 */
  IC_VEX_L_OPSIZE, /* 12950 */
  IC_VEX_L_OPSIZE, /* 12951 */
  IC_VEX_L_W_OPSIZE, /* 12952 */
  IC_VEX_L_W_OPSIZE, /* 12953 */
  IC_VEX_L_W_OPSIZE, /* 12954 */
  IC_VEX_L_W_OPSIZE, /* 12955 */
  IC_VEX_L_W_OPSIZE, /* 12956 */
  IC_VEX_L_W_OPSIZE, /* 12957 */
  IC_VEX_L_W_OPSIZE, /* 12958 */
  IC_VEX_L_W_OPSIZE, /* 12959 */
  IC_VEX_L, /* 12960 */
  IC_VEX_L, /* 12961 */
  IC_VEX_L_XS, /* 12962 */
  IC_VEX_L_XS, /* 12963 */
  IC_VEX_L_XD, /* 12964 */
  IC_VEX_L_XD, /* 12965 */
  IC_VEX_L_XD, /* 12966 */
  IC_VEX_L_XD, /* 12967 */
  IC_VEX_L_W, /* 12968 */
  IC_VEX_L_W, /* 12969 */
  IC_VEX_L_W_XS, /* 12970 */
  IC_VEX_L_W_XS, /* 12971 */
  IC_VEX_L_W_XD, /* 12972 */
  IC_VEX_L_W_XD, /* 12973 */
  IC_VEX_L_W_XD, /* 12974 */
  IC_VEX_L_W_XD, /* 12975 */
  IC_VEX_L_OPSIZE, /* 12976 */
  IC_VEX_L_OPSIZE, /* 12977 */
  IC_VEX_L_OPSIZE, /* 12978 */
  IC_VEX_L_OPSIZE, /* 12979 */
  IC_VEX_L_OPSIZE, /* 12980 */
  IC_VEX_L_OPSIZE, /* 12981 */
  IC_VEX_L_OPSIZE, /* 12982 */
  IC_VEX_L_OPSIZE, /* 12983 */
  IC_VEX_L_W_OPSIZE, /* 12984 */
  IC_VEX_L_W_OPSIZE, /* 12985 */
  IC_VEX_L_W_OPSIZE, /* 12986 */
  IC_VEX_L_W_OPSIZE, /* 12987 */
  IC_VEX_L_W_OPSIZE, /* 12988 */
  IC_VEX_L_W_OPSIZE, /* 12989 */
  IC_VEX_L_W_OPSIZE, /* 12990 */
  IC_VEX_L_W_OPSIZE, /* 12991 */
  IC_VEX_L, /* 12992 */
  IC_VEX_L, /* 12993 */
  IC_VEX_L_XS, /* 12994 */
  IC_VEX_L_XS, /* 12995 */
  IC_VEX_L_XD, /* 12996 */
  IC_VEX_L_XD, /* 12997 */
  IC_VEX_L_XD, /* 12998 */
  IC_VEX_L_XD, /* 12999 */
  IC_VEX_L_W, /* 13000 */
  IC_VEX_L_W, /* 13001 */
  IC_VEX_L_W_XS, /* 13002 */
  IC_VEX_L_W_XS, /* 13003 */
  IC_VEX_L_W_XD, /* 13004 */
  IC_VEX_L_W_XD, /* 13005 */
  IC_VEX_L_W_XD, /* 13006 */
  IC_VEX_L_W_XD, /* 13007 */
  IC_VEX_L_OPSIZE, /* 13008 */
  IC_VEX_L_OPSIZE, /* 13009 */
  IC_VEX_L_OPSIZE, /* 13010 */
  IC_VEX_L_OPSIZE, /* 13011 */
  IC_VEX_L_OPSIZE, /* 13012 */
  IC_VEX_L_OPSIZE, /* 13013 */
  IC_VEX_L_OPSIZE, /* 13014 */
  IC_VEX_L_OPSIZE, /* 13015 */
  IC_VEX_L_W_OPSIZE, /* 13016 */
  IC_VEX_L_W_OPSIZE, /* 13017 */
  IC_VEX_L_W_OPSIZE, /* 13018 */
  IC_VEX_L_W_OPSIZE, /* 13019 */
  IC_VEX_L_W_OPSIZE, /* 13020 */
  IC_VEX_L_W_OPSIZE, /* 13021 */
  IC_VEX_L_W_OPSIZE, /* 13022 */
  IC_VEX_L_W_OPSIZE, /* 13023 */
  IC_VEX_L, /* 13024 */
  IC_VEX_L, /* 13025 */
  IC_VEX_L_XS, /* 13026 */
  IC_VEX_L_XS, /* 13027 */
  IC_VEX_L_XD, /* 13028 */
  IC_VEX_L_XD, /* 13029 */
  IC_VEX_L_XD, /* 13030 */
  IC_VEX_L_XD, /* 13031 */
  IC_VEX_L_W, /* 13032 */
  IC_VEX_L_W, /* 13033 */
  IC_VEX_L_W_XS, /* 13034 */
  IC_VEX_L_W_XS, /* 13035 */
  IC_VEX_L_W_XD, /* 13036 */
  IC_VEX_L_W_XD, /* 13037 */
  IC_VEX_L_W_XD, /* 13038 */
  IC_VEX_L_W_XD, /* 13039 */
  IC_VEX_L_OPSIZE, /* 13040 */
  IC_VEX_L_OPSIZE, /* 13041 */
  IC_VEX_L_OPSIZE, /* 13042 */
  IC_VEX_L_OPSIZE, /* 13043 */
  IC_VEX_L_OPSIZE, /* 13044 */
  IC_VEX_L_OPSIZE, /* 13045 */
  IC_VEX_L_OPSIZE, /* 13046 */
  IC_VEX_L_OPSIZE, /* 13047 */
  IC_VEX_L_W_OPSIZE, /* 13048 */
  IC_VEX_L_W_OPSIZE, /* 13049 */
  IC_VEX_L_W_OPSIZE, /* 13050 */
  IC_VEX_L_W_OPSIZE, /* 13051 */
  IC_VEX_L_W_OPSIZE, /* 13052 */
  IC_VEX_L_W_OPSIZE, /* 13053 */
  IC_VEX_L_W_OPSIZE, /* 13054 */
  IC_VEX_L_W_OPSIZE, /* 13055 */
  IC_EVEX_L_KZ_B, /* 13056 */
  IC_EVEX_L_KZ_B, /* 13057 */
  IC_EVEX_L_XS_KZ_B, /* 13058 */
  IC_EVEX_L_XS_KZ_B, /* 13059 */
  IC_EVEX_L_XD_KZ_B, /* 13060 */
  IC_EVEX_L_XD_KZ_B, /* 13061 */
  IC_EVEX_L_XD_KZ_B, /* 13062 */
  IC_EVEX_L_XD_KZ_B, /* 13063 */
  IC_EVEX_L_W_KZ_B, /* 13064 */
  IC_EVEX_L_W_KZ_B, /* 13065 */
  IC_EVEX_L_W_XS_KZ_B, /* 13066 */
  IC_EVEX_L_W_XS_KZ_B, /* 13067 */
  IC_EVEX_L_W_XD_KZ_B, /* 13068 */
  IC_EVEX_L_W_XD_KZ_B, /* 13069 */
  IC_EVEX_L_W_XD_KZ_B, /* 13070 */
  IC_EVEX_L_W_XD_KZ_B, /* 13071 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13072 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13073 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13074 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13075 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13076 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13077 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13078 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13079 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13080 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13081 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13082 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13083 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13084 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13085 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13086 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13087 */
  IC_EVEX_L_KZ_B, /* 13088 */
  IC_EVEX_L_KZ_B, /* 13089 */
  IC_EVEX_L_XS_KZ_B, /* 13090 */
  IC_EVEX_L_XS_KZ_B, /* 13091 */
  IC_EVEX_L_XD_KZ_B, /* 13092 */
  IC_EVEX_L_XD_KZ_B, /* 13093 */
  IC_EVEX_L_XD_KZ_B, /* 13094 */
  IC_EVEX_L_XD_KZ_B, /* 13095 */
  IC_EVEX_L_W_KZ_B, /* 13096 */
  IC_EVEX_L_W_KZ_B, /* 13097 */
  IC_EVEX_L_W_XS_KZ_B, /* 13098 */
  IC_EVEX_L_W_XS_KZ_B, /* 13099 */
  IC_EVEX_L_W_XD_KZ_B, /* 13100 */
  IC_EVEX_L_W_XD_KZ_B, /* 13101 */
  IC_EVEX_L_W_XD_KZ_B, /* 13102 */
  IC_EVEX_L_W_XD_KZ_B, /* 13103 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13104 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13105 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13106 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13107 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13108 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13109 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13110 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13111 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13112 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13113 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13114 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13115 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13116 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13117 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13118 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13119 */
  IC_EVEX_L_KZ_B, /* 13120 */
  IC_EVEX_L_KZ_B, /* 13121 */
  IC_EVEX_L_XS_KZ_B, /* 13122 */
  IC_EVEX_L_XS_KZ_B, /* 13123 */
  IC_EVEX_L_XD_KZ_B, /* 13124 */
  IC_EVEX_L_XD_KZ_B, /* 13125 */
  IC_EVEX_L_XD_KZ_B, /* 13126 */
  IC_EVEX_L_XD_KZ_B, /* 13127 */
  IC_EVEX_L_W_KZ_B, /* 13128 */
  IC_EVEX_L_W_KZ_B, /* 13129 */
  IC_EVEX_L_W_XS_KZ_B, /* 13130 */
  IC_EVEX_L_W_XS_KZ_B, /* 13131 */
  IC_EVEX_L_W_XD_KZ_B, /* 13132 */
  IC_EVEX_L_W_XD_KZ_B, /* 13133 */
  IC_EVEX_L_W_XD_KZ_B, /* 13134 */
  IC_EVEX_L_W_XD_KZ_B, /* 13135 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13136 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13137 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13138 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13139 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13140 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13141 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13142 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13143 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13144 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13145 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13146 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13147 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13148 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13149 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13150 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13151 */
  IC_EVEX_L_KZ_B, /* 13152 */
  IC_EVEX_L_KZ_B, /* 13153 */
  IC_EVEX_L_XS_KZ_B, /* 13154 */
  IC_EVEX_L_XS_KZ_B, /* 13155 */
  IC_EVEX_L_XD_KZ_B, /* 13156 */
  IC_EVEX_L_XD_KZ_B, /* 13157 */
  IC_EVEX_L_XD_KZ_B, /* 13158 */
  IC_EVEX_L_XD_KZ_B, /* 13159 */
  IC_EVEX_L_W_KZ_B, /* 13160 */
  IC_EVEX_L_W_KZ_B, /* 13161 */
  IC_EVEX_L_W_XS_KZ_B, /* 13162 */
  IC_EVEX_L_W_XS_KZ_B, /* 13163 */
  IC_EVEX_L_W_XD_KZ_B, /* 13164 */
  IC_EVEX_L_W_XD_KZ_B, /* 13165 */
  IC_EVEX_L_W_XD_KZ_B, /* 13166 */
  IC_EVEX_L_W_XD_KZ_B, /* 13167 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13168 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13169 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13170 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13171 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13172 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13173 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13174 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13175 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13176 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13177 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13178 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13179 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13180 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13181 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13182 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13183 */
  IC_EVEX_L_KZ_B, /* 13184 */
  IC_EVEX_L_KZ_B, /* 13185 */
  IC_EVEX_L_XS_KZ_B, /* 13186 */
  IC_EVEX_L_XS_KZ_B, /* 13187 */
  IC_EVEX_L_XD_KZ_B, /* 13188 */
  IC_EVEX_L_XD_KZ_B, /* 13189 */
  IC_EVEX_L_XD_KZ_B, /* 13190 */
  IC_EVEX_L_XD_KZ_B, /* 13191 */
  IC_EVEX_L_W_KZ_B, /* 13192 */
  IC_EVEX_L_W_KZ_B, /* 13193 */
  IC_EVEX_L_W_XS_KZ_B, /* 13194 */
  IC_EVEX_L_W_XS_KZ_B, /* 13195 */
  IC_EVEX_L_W_XD_KZ_B, /* 13196 */
  IC_EVEX_L_W_XD_KZ_B, /* 13197 */
  IC_EVEX_L_W_XD_KZ_B, /* 13198 */
  IC_EVEX_L_W_XD_KZ_B, /* 13199 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13200 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13201 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13202 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13203 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13204 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13205 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13206 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13207 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13208 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13209 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13210 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13211 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13212 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13213 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13214 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13215 */
  IC_EVEX_L_KZ_B, /* 13216 */
  IC_EVEX_L_KZ_B, /* 13217 */
  IC_EVEX_L_XS_KZ_B, /* 13218 */
  IC_EVEX_L_XS_KZ_B, /* 13219 */
  IC_EVEX_L_XD_KZ_B, /* 13220 */
  IC_EVEX_L_XD_KZ_B, /* 13221 */
  IC_EVEX_L_XD_KZ_B, /* 13222 */
  IC_EVEX_L_XD_KZ_B, /* 13223 */
  IC_EVEX_L_W_KZ_B, /* 13224 */
  IC_EVEX_L_W_KZ_B, /* 13225 */
  IC_EVEX_L_W_XS_KZ_B, /* 13226 */
  IC_EVEX_L_W_XS_KZ_B, /* 13227 */
  IC_EVEX_L_W_XD_KZ_B, /* 13228 */
  IC_EVEX_L_W_XD_KZ_B, /* 13229 */
  IC_EVEX_L_W_XD_KZ_B, /* 13230 */
  IC_EVEX_L_W_XD_KZ_B, /* 13231 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13232 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13233 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13234 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13235 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13236 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13237 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13238 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13239 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13240 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13241 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13242 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13243 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13244 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13245 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13246 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13247 */
  IC_EVEX_L_KZ_B, /* 13248 */
  IC_EVEX_L_KZ_B, /* 13249 */
  IC_EVEX_L_XS_KZ_B, /* 13250 */
  IC_EVEX_L_XS_KZ_B, /* 13251 */
  IC_EVEX_L_XD_KZ_B, /* 13252 */
  IC_EVEX_L_XD_KZ_B, /* 13253 */
  IC_EVEX_L_XD_KZ_B, /* 13254 */
  IC_EVEX_L_XD_KZ_B, /* 13255 */
  IC_EVEX_L_W_KZ_B, /* 13256 */
  IC_EVEX_L_W_KZ_B, /* 13257 */
  IC_EVEX_L_W_XS_KZ_B, /* 13258 */
  IC_EVEX_L_W_XS_KZ_B, /* 13259 */
  IC_EVEX_L_W_XD_KZ_B, /* 13260 */
  IC_EVEX_L_W_XD_KZ_B, /* 13261 */
  IC_EVEX_L_W_XD_KZ_B, /* 13262 */
  IC_EVEX_L_W_XD_KZ_B, /* 13263 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13264 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13265 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13266 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13267 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13268 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13269 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13270 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13271 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13272 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13273 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13274 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13275 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13276 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13277 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13278 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13279 */
  IC_EVEX_L_KZ_B, /* 13280 */
  IC_EVEX_L_KZ_B, /* 13281 */
  IC_EVEX_L_XS_KZ_B, /* 13282 */
  IC_EVEX_L_XS_KZ_B, /* 13283 */
  IC_EVEX_L_XD_KZ_B, /* 13284 */
  IC_EVEX_L_XD_KZ_B, /* 13285 */
  IC_EVEX_L_XD_KZ_B, /* 13286 */
  IC_EVEX_L_XD_KZ_B, /* 13287 */
  IC_EVEX_L_W_KZ_B, /* 13288 */
  IC_EVEX_L_W_KZ_B, /* 13289 */
  IC_EVEX_L_W_XS_KZ_B, /* 13290 */
  IC_EVEX_L_W_XS_KZ_B, /* 13291 */
  IC_EVEX_L_W_XD_KZ_B, /* 13292 */
  IC_EVEX_L_W_XD_KZ_B, /* 13293 */
  IC_EVEX_L_W_XD_KZ_B, /* 13294 */
  IC_EVEX_L_W_XD_KZ_B, /* 13295 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13296 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13297 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13298 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13299 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13300 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13301 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13302 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 13303 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13304 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13305 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13306 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13307 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13308 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13309 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13310 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 13311 */
  IC, /* 13312 */
  IC_64BIT, /* 13313 */
  IC_XS, /* 13314 */
  IC_64BIT_XS, /* 13315 */
  IC_XD, /* 13316 */
  IC_64BIT_XD, /* 13317 */
  IC_XS, /* 13318 */
  IC_64BIT_XS, /* 13319 */
  IC, /* 13320 */
  IC_64BIT_REXW, /* 13321 */
  IC_XS, /* 13322 */
  IC_64BIT_REXW_XS, /* 13323 */
  IC_XD, /* 13324 */
  IC_64BIT_REXW_XD, /* 13325 */
  IC_XS, /* 13326 */
  IC_64BIT_REXW_XS, /* 13327 */
  IC_OPSIZE, /* 13328 */
  IC_64BIT_OPSIZE, /* 13329 */
  IC_XS_OPSIZE, /* 13330 */
  IC_64BIT_XS_OPSIZE, /* 13331 */
  IC_XD_OPSIZE, /* 13332 */
  IC_64BIT_XD_OPSIZE, /* 13333 */
  IC_XS_OPSIZE, /* 13334 */
  IC_64BIT_XD_OPSIZE, /* 13335 */
  IC_OPSIZE, /* 13336 */
  IC_64BIT_REXW_OPSIZE, /* 13337 */
  IC_XS_OPSIZE, /* 13338 */
  IC_64BIT_REXW_XS, /* 13339 */
  IC_XD_OPSIZE, /* 13340 */
  IC_64BIT_REXW_XD, /* 13341 */
  IC_XS_OPSIZE, /* 13342 */
  IC_64BIT_REXW_XS, /* 13343 */
  IC_ADSIZE, /* 13344 */
  IC_64BIT_ADSIZE, /* 13345 */
  IC_XS, /* 13346 */
  IC_64BIT_XS, /* 13347 */
  IC_XD, /* 13348 */
  IC_64BIT_XD, /* 13349 */
  IC_XS, /* 13350 */
  IC_64BIT_XS, /* 13351 */
  IC_ADSIZE, /* 13352 */
  IC_64BIT_REXW_ADSIZE, /* 13353 */
  IC_XS, /* 13354 */
  IC_64BIT_REXW_XS, /* 13355 */
  IC_XD, /* 13356 */
  IC_64BIT_REXW_XD, /* 13357 */
  IC_XS, /* 13358 */
  IC_64BIT_REXW_XS, /* 13359 */
  IC_OPSIZE_ADSIZE, /* 13360 */
  IC_64BIT_OPSIZE_ADSIZE, /* 13361 */
  IC_XS_OPSIZE, /* 13362 */
  IC_64BIT_XS_OPSIZE, /* 13363 */
  IC_XD_OPSIZE, /* 13364 */
  IC_64BIT_XD_OPSIZE, /* 13365 */
  IC_XS_OPSIZE, /* 13366 */
  IC_64BIT_XD_OPSIZE, /* 13367 */
  IC_OPSIZE_ADSIZE, /* 13368 */
  IC_64BIT_REXW_OPSIZE, /* 13369 */
  IC_XS_OPSIZE, /* 13370 */
  IC_64BIT_REXW_XS, /* 13371 */
  IC_XD_OPSIZE, /* 13372 */
  IC_64BIT_REXW_XD, /* 13373 */
  IC_XS_OPSIZE, /* 13374 */
  IC_64BIT_REXW_XS, /* 13375 */
  IC_VEX, /* 13376 */
  IC_VEX, /* 13377 */
  IC_VEX_XS, /* 13378 */
  IC_VEX_XS, /* 13379 */
  IC_VEX_XD, /* 13380 */
  IC_VEX_XD, /* 13381 */
  IC_VEX_XD, /* 13382 */
  IC_VEX_XD, /* 13383 */
  IC_VEX_W, /* 13384 */
  IC_VEX_W, /* 13385 */
  IC_VEX_W_XS, /* 13386 */
  IC_VEX_W_XS, /* 13387 */
  IC_VEX_W_XD, /* 13388 */
  IC_VEX_W_XD, /* 13389 */
  IC_VEX_W_XD, /* 13390 */
  IC_VEX_W_XD, /* 13391 */
  IC_VEX_OPSIZE, /* 13392 */
  IC_VEX_OPSIZE, /* 13393 */
  IC_VEX_OPSIZE, /* 13394 */
  IC_VEX_OPSIZE, /* 13395 */
  IC_VEX_OPSIZE, /* 13396 */
  IC_VEX_OPSIZE, /* 13397 */
  IC_VEX_OPSIZE, /* 13398 */
  IC_VEX_OPSIZE, /* 13399 */
  IC_VEX_W_OPSIZE, /* 13400 */
  IC_VEX_W_OPSIZE, /* 13401 */
  IC_VEX_W_OPSIZE, /* 13402 */
  IC_VEX_W_OPSIZE, /* 13403 */
  IC_VEX_W_OPSIZE, /* 13404 */
  IC_VEX_W_OPSIZE, /* 13405 */
  IC_VEX_W_OPSIZE, /* 13406 */
  IC_VEX_W_OPSIZE, /* 13407 */
  IC_VEX, /* 13408 */
  IC_VEX, /* 13409 */
  IC_VEX_XS, /* 13410 */
  IC_VEX_XS, /* 13411 */
  IC_VEX_XD, /* 13412 */
  IC_VEX_XD, /* 13413 */
  IC_VEX_XD, /* 13414 */
  IC_VEX_XD, /* 13415 */
  IC_VEX_W, /* 13416 */
  IC_VEX_W, /* 13417 */
  IC_VEX_W_XS, /* 13418 */
  IC_VEX_W_XS, /* 13419 */
  IC_VEX_W_XD, /* 13420 */
  IC_VEX_W_XD, /* 13421 */
  IC_VEX_W_XD, /* 13422 */
  IC_VEX_W_XD, /* 13423 */
  IC_VEX_OPSIZE, /* 13424 */
  IC_VEX_OPSIZE, /* 13425 */
  IC_VEX_OPSIZE, /* 13426 */
  IC_VEX_OPSIZE, /* 13427 */
  IC_VEX_OPSIZE, /* 13428 */
  IC_VEX_OPSIZE, /* 13429 */
  IC_VEX_OPSIZE, /* 13430 */
  IC_VEX_OPSIZE, /* 13431 */
  IC_VEX_W_OPSIZE, /* 13432 */
  IC_VEX_W_OPSIZE, /* 13433 */
  IC_VEX_W_OPSIZE, /* 13434 */
  IC_VEX_W_OPSIZE, /* 13435 */
  IC_VEX_W_OPSIZE, /* 13436 */
  IC_VEX_W_OPSIZE, /* 13437 */
  IC_VEX_W_OPSIZE, /* 13438 */
  IC_VEX_W_OPSIZE, /* 13439 */
  IC_VEX_L, /* 13440 */
  IC_VEX_L, /* 13441 */
  IC_VEX_L_XS, /* 13442 */
  IC_VEX_L_XS, /* 13443 */
  IC_VEX_L_XD, /* 13444 */
  IC_VEX_L_XD, /* 13445 */
  IC_VEX_L_XD, /* 13446 */
  IC_VEX_L_XD, /* 13447 */
  IC_VEX_L_W, /* 13448 */
  IC_VEX_L_W, /* 13449 */
  IC_VEX_L_W_XS, /* 13450 */
  IC_VEX_L_W_XS, /* 13451 */
  IC_VEX_L_W_XD, /* 13452 */
  IC_VEX_L_W_XD, /* 13453 */
  IC_VEX_L_W_XD, /* 13454 */
  IC_VEX_L_W_XD, /* 13455 */
  IC_VEX_L_OPSIZE, /* 13456 */
  IC_VEX_L_OPSIZE, /* 13457 */
  IC_VEX_L_OPSIZE, /* 13458 */
  IC_VEX_L_OPSIZE, /* 13459 */
  IC_VEX_L_OPSIZE, /* 13460 */
  IC_VEX_L_OPSIZE, /* 13461 */
  IC_VEX_L_OPSIZE, /* 13462 */
  IC_VEX_L_OPSIZE, /* 13463 */
  IC_VEX_L_W_OPSIZE, /* 13464 */
  IC_VEX_L_W_OPSIZE, /* 13465 */
  IC_VEX_L_W_OPSIZE, /* 13466 */
  IC_VEX_L_W_OPSIZE, /* 13467 */
  IC_VEX_L_W_OPSIZE, /* 13468 */
  IC_VEX_L_W_OPSIZE, /* 13469 */
  IC_VEX_L_W_OPSIZE, /* 13470 */
  IC_VEX_L_W_OPSIZE, /* 13471 */
  IC_VEX_L, /* 13472 */
  IC_VEX_L, /* 13473 */
  IC_VEX_L_XS, /* 13474 */
  IC_VEX_L_XS, /* 13475 */
  IC_VEX_L_XD, /* 13476 */
  IC_VEX_L_XD, /* 13477 */
  IC_VEX_L_XD, /* 13478 */
  IC_VEX_L_XD, /* 13479 */
  IC_VEX_L_W, /* 13480 */
  IC_VEX_L_W, /* 13481 */
  IC_VEX_L_W_XS, /* 13482 */
  IC_VEX_L_W_XS, /* 13483 */
  IC_VEX_L_W_XD, /* 13484 */
  IC_VEX_L_W_XD, /* 13485 */
  IC_VEX_L_W_XD, /* 13486 */
  IC_VEX_L_W_XD, /* 13487 */
  IC_VEX_L_OPSIZE, /* 13488 */
  IC_VEX_L_OPSIZE, /* 13489 */
  IC_VEX_L_OPSIZE, /* 13490 */
  IC_VEX_L_OPSIZE, /* 13491 */
  IC_VEX_L_OPSIZE, /* 13492 */
  IC_VEX_L_OPSIZE, /* 13493 */
  IC_VEX_L_OPSIZE, /* 13494 */
  IC_VEX_L_OPSIZE, /* 13495 */
  IC_VEX_L_W_OPSIZE, /* 13496 */
  IC_VEX_L_W_OPSIZE, /* 13497 */
  IC_VEX_L_W_OPSIZE, /* 13498 */
  IC_VEX_L_W_OPSIZE, /* 13499 */
  IC_VEX_L_W_OPSIZE, /* 13500 */
  IC_VEX_L_W_OPSIZE, /* 13501 */
  IC_VEX_L_W_OPSIZE, /* 13502 */
  IC_VEX_L_W_OPSIZE, /* 13503 */
  IC_VEX_L, /* 13504 */
  IC_VEX_L, /* 13505 */
  IC_VEX_L_XS, /* 13506 */
  IC_VEX_L_XS, /* 13507 */
  IC_VEX_L_XD, /* 13508 */
  IC_VEX_L_XD, /* 13509 */
  IC_VEX_L_XD, /* 13510 */
  IC_VEX_L_XD, /* 13511 */
  IC_VEX_L_W, /* 13512 */
  IC_VEX_L_W, /* 13513 */
  IC_VEX_L_W_XS, /* 13514 */
  IC_VEX_L_W_XS, /* 13515 */
  IC_VEX_L_W_XD, /* 13516 */
  IC_VEX_L_W_XD, /* 13517 */
  IC_VEX_L_W_XD, /* 13518 */
  IC_VEX_L_W_XD, /* 13519 */
  IC_VEX_L_OPSIZE, /* 13520 */
  IC_VEX_L_OPSIZE, /* 13521 */
  IC_VEX_L_OPSIZE, /* 13522 */
  IC_VEX_L_OPSIZE, /* 13523 */
  IC_VEX_L_OPSIZE, /* 13524 */
  IC_VEX_L_OPSIZE, /* 13525 */
  IC_VEX_L_OPSIZE, /* 13526 */
  IC_VEX_L_OPSIZE, /* 13527 */
  IC_VEX_L_W_OPSIZE, /* 13528 */
  IC_VEX_L_W_OPSIZE, /* 13529 */
  IC_VEX_L_W_OPSIZE, /* 13530 */
  IC_VEX_L_W_OPSIZE, /* 13531 */
  IC_VEX_L_W_OPSIZE, /* 13532 */
  IC_VEX_L_W_OPSIZE, /* 13533 */
  IC_VEX_L_W_OPSIZE, /* 13534 */
  IC_VEX_L_W_OPSIZE, /* 13535 */
  IC_VEX_L, /* 13536 */
  IC_VEX_L, /* 13537 */
  IC_VEX_L_XS, /* 13538 */
  IC_VEX_L_XS, /* 13539 */
  IC_VEX_L_XD, /* 13540 */
  IC_VEX_L_XD, /* 13541 */
  IC_VEX_L_XD, /* 13542 */
  IC_VEX_L_XD, /* 13543 */
  IC_VEX_L_W, /* 13544 */
  IC_VEX_L_W, /* 13545 */
  IC_VEX_L_W_XS, /* 13546 */
  IC_VEX_L_W_XS, /* 13547 */
  IC_VEX_L_W_XD, /* 13548 */
  IC_VEX_L_W_XD, /* 13549 */
  IC_VEX_L_W_XD, /* 13550 */
  IC_VEX_L_W_XD, /* 13551 */
  IC_VEX_L_OPSIZE, /* 13552 */
  IC_VEX_L_OPSIZE, /* 13553 */
  IC_VEX_L_OPSIZE, /* 13554 */
  IC_VEX_L_OPSIZE, /* 13555 */
  IC_VEX_L_OPSIZE, /* 13556 */
  IC_VEX_L_OPSIZE, /* 13557 */
  IC_VEX_L_OPSIZE, /* 13558 */
  IC_VEX_L_OPSIZE, /* 13559 */
  IC_VEX_L_W_OPSIZE, /* 13560 */
  IC_VEX_L_W_OPSIZE, /* 13561 */
  IC_VEX_L_W_OPSIZE, /* 13562 */
  IC_VEX_L_W_OPSIZE, /* 13563 */
  IC_VEX_L_W_OPSIZE, /* 13564 */
  IC_VEX_L_W_OPSIZE, /* 13565 */
  IC_VEX_L_W_OPSIZE, /* 13566 */
  IC_VEX_L_W_OPSIZE, /* 13567 */
  IC_EVEX_L2_KZ_B, /* 13568 */
  IC_EVEX_L2_KZ_B, /* 13569 */
  IC_EVEX_L2_XS_KZ_B, /* 13570 */
  IC_EVEX_L2_XS_KZ_B, /* 13571 */
  IC_EVEX_L2_XD_KZ_B, /* 13572 */
  IC_EVEX_L2_XD_KZ_B, /* 13573 */
  IC_EVEX_L2_XD_KZ_B, /* 13574 */
  IC_EVEX_L2_XD_KZ_B, /* 13575 */
  IC_EVEX_L2_W_KZ_B, /* 13576 */
  IC_EVEX_L2_W_KZ_B, /* 13577 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13578 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13579 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13580 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13581 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13582 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13583 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13584 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13585 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13586 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13587 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13588 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13589 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13590 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13591 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13592 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13593 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13594 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13595 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13596 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13597 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13598 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13599 */
  IC_EVEX_L2_KZ_B, /* 13600 */
  IC_EVEX_L2_KZ_B, /* 13601 */
  IC_EVEX_L2_XS_KZ_B, /* 13602 */
  IC_EVEX_L2_XS_KZ_B, /* 13603 */
  IC_EVEX_L2_XD_KZ_B, /* 13604 */
  IC_EVEX_L2_XD_KZ_B, /* 13605 */
  IC_EVEX_L2_XD_KZ_B, /* 13606 */
  IC_EVEX_L2_XD_KZ_B, /* 13607 */
  IC_EVEX_L2_W_KZ_B, /* 13608 */
  IC_EVEX_L2_W_KZ_B, /* 13609 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13610 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13611 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13612 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13613 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13614 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13615 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13616 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13617 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13618 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13619 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13620 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13621 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13622 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13623 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13624 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13625 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13626 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13627 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13628 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13629 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13630 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13631 */
  IC_EVEX_L2_KZ_B, /* 13632 */
  IC_EVEX_L2_KZ_B, /* 13633 */
  IC_EVEX_L2_XS_KZ_B, /* 13634 */
  IC_EVEX_L2_XS_KZ_B, /* 13635 */
  IC_EVEX_L2_XD_KZ_B, /* 13636 */
  IC_EVEX_L2_XD_KZ_B, /* 13637 */
  IC_EVEX_L2_XD_KZ_B, /* 13638 */
  IC_EVEX_L2_XD_KZ_B, /* 13639 */
  IC_EVEX_L2_W_KZ_B, /* 13640 */
  IC_EVEX_L2_W_KZ_B, /* 13641 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13642 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13643 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13644 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13645 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13646 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13647 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13648 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13649 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13650 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13651 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13652 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13653 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13654 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13655 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13656 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13657 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13658 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13659 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13660 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13661 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13662 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13663 */
  IC_EVEX_L2_KZ_B, /* 13664 */
  IC_EVEX_L2_KZ_B, /* 13665 */
  IC_EVEX_L2_XS_KZ_B, /* 13666 */
  IC_EVEX_L2_XS_KZ_B, /* 13667 */
  IC_EVEX_L2_XD_KZ_B, /* 13668 */
  IC_EVEX_L2_XD_KZ_B, /* 13669 */
  IC_EVEX_L2_XD_KZ_B, /* 13670 */
  IC_EVEX_L2_XD_KZ_B, /* 13671 */
  IC_EVEX_L2_W_KZ_B, /* 13672 */
  IC_EVEX_L2_W_KZ_B, /* 13673 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13674 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13675 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13676 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13677 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13678 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13679 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13680 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13681 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13682 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13683 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13684 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13685 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13686 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13687 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13688 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13689 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13690 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13691 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13692 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13693 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13694 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13695 */
  IC_EVEX_L2_KZ_B, /* 13696 */
  IC_EVEX_L2_KZ_B, /* 13697 */
  IC_EVEX_L2_XS_KZ_B, /* 13698 */
  IC_EVEX_L2_XS_KZ_B, /* 13699 */
  IC_EVEX_L2_XD_KZ_B, /* 13700 */
  IC_EVEX_L2_XD_KZ_B, /* 13701 */
  IC_EVEX_L2_XD_KZ_B, /* 13702 */
  IC_EVEX_L2_XD_KZ_B, /* 13703 */
  IC_EVEX_L2_W_KZ_B, /* 13704 */
  IC_EVEX_L2_W_KZ_B, /* 13705 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13706 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13707 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13708 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13709 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13710 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13711 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13712 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13713 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13714 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13715 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13716 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13717 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13718 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13719 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13720 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13721 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13722 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13723 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13724 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13725 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13726 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13727 */
  IC_EVEX_L2_KZ_B, /* 13728 */
  IC_EVEX_L2_KZ_B, /* 13729 */
  IC_EVEX_L2_XS_KZ_B, /* 13730 */
  IC_EVEX_L2_XS_KZ_B, /* 13731 */
  IC_EVEX_L2_XD_KZ_B, /* 13732 */
  IC_EVEX_L2_XD_KZ_B, /* 13733 */
  IC_EVEX_L2_XD_KZ_B, /* 13734 */
  IC_EVEX_L2_XD_KZ_B, /* 13735 */
  IC_EVEX_L2_W_KZ_B, /* 13736 */
  IC_EVEX_L2_W_KZ_B, /* 13737 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13738 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13739 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13740 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13741 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13742 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13743 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13744 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13745 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13746 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13747 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13748 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13749 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13750 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13751 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13752 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13753 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13754 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13755 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13756 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13757 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13758 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13759 */
  IC_EVEX_L2_KZ_B, /* 13760 */
  IC_EVEX_L2_KZ_B, /* 13761 */
  IC_EVEX_L2_XS_KZ_B, /* 13762 */
  IC_EVEX_L2_XS_KZ_B, /* 13763 */
  IC_EVEX_L2_XD_KZ_B, /* 13764 */
  IC_EVEX_L2_XD_KZ_B, /* 13765 */
  IC_EVEX_L2_XD_KZ_B, /* 13766 */
  IC_EVEX_L2_XD_KZ_B, /* 13767 */
  IC_EVEX_L2_W_KZ_B, /* 13768 */
  IC_EVEX_L2_W_KZ_B, /* 13769 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13770 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13771 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13772 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13773 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13774 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13775 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13776 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13777 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13778 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13779 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13780 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13781 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13782 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13783 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13784 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13785 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13786 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13787 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13788 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13789 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13790 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13791 */
  IC_EVEX_L2_KZ_B, /* 13792 */
  IC_EVEX_L2_KZ_B, /* 13793 */
  IC_EVEX_L2_XS_KZ_B, /* 13794 */
  IC_EVEX_L2_XS_KZ_B, /* 13795 */
  IC_EVEX_L2_XD_KZ_B, /* 13796 */
  IC_EVEX_L2_XD_KZ_B, /* 13797 */
  IC_EVEX_L2_XD_KZ_B, /* 13798 */
  IC_EVEX_L2_XD_KZ_B, /* 13799 */
  IC_EVEX_L2_W_KZ_B, /* 13800 */
  IC_EVEX_L2_W_KZ_B, /* 13801 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13802 */
  IC_EVEX_L2_W_XS_KZ_B, /* 13803 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13804 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13805 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13806 */
  IC_EVEX_L2_W_XD_KZ_B, /* 13807 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13808 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13809 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13810 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13811 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13812 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13813 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13814 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 13815 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13816 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13817 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13818 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13819 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13820 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13821 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13822 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 13823 */
  IC, /* 13824 */
  IC_64BIT, /* 13825 */
  IC_XS, /* 13826 */
  IC_64BIT_XS, /* 13827 */
  IC_XD, /* 13828 */
  IC_64BIT_XD, /* 13829 */
  IC_XS, /* 13830 */
  IC_64BIT_XS, /* 13831 */
  IC, /* 13832 */
  IC_64BIT_REXW, /* 13833 */
  IC_XS, /* 13834 */
  IC_64BIT_REXW_XS, /* 13835 */
  IC_XD, /* 13836 */
  IC_64BIT_REXW_XD, /* 13837 */
  IC_XS, /* 13838 */
  IC_64BIT_REXW_XS, /* 13839 */
  IC_OPSIZE, /* 13840 */
  IC_64BIT_OPSIZE, /* 13841 */
  IC_XS_OPSIZE, /* 13842 */
  IC_64BIT_XS_OPSIZE, /* 13843 */
  IC_XD_OPSIZE, /* 13844 */
  IC_64BIT_XD_OPSIZE, /* 13845 */
  IC_XS_OPSIZE, /* 13846 */
  IC_64BIT_XD_OPSIZE, /* 13847 */
  IC_OPSIZE, /* 13848 */
  IC_64BIT_REXW_OPSIZE, /* 13849 */
  IC_XS_OPSIZE, /* 13850 */
  IC_64BIT_REXW_XS, /* 13851 */
  IC_XD_OPSIZE, /* 13852 */
  IC_64BIT_REXW_XD, /* 13853 */
  IC_XS_OPSIZE, /* 13854 */
  IC_64BIT_REXW_XS, /* 13855 */
  IC_ADSIZE, /* 13856 */
  IC_64BIT_ADSIZE, /* 13857 */
  IC_XS, /* 13858 */
  IC_64BIT_XS, /* 13859 */
  IC_XD, /* 13860 */
  IC_64BIT_XD, /* 13861 */
  IC_XS, /* 13862 */
  IC_64BIT_XS, /* 13863 */
  IC_ADSIZE, /* 13864 */
  IC_64BIT_REXW_ADSIZE, /* 13865 */
  IC_XS, /* 13866 */
  IC_64BIT_REXW_XS, /* 13867 */
  IC_XD, /* 13868 */
  IC_64BIT_REXW_XD, /* 13869 */
  IC_XS, /* 13870 */
  IC_64BIT_REXW_XS, /* 13871 */
  IC_OPSIZE_ADSIZE, /* 13872 */
  IC_64BIT_OPSIZE_ADSIZE, /* 13873 */
  IC_XS_OPSIZE, /* 13874 */
  IC_64BIT_XS_OPSIZE, /* 13875 */
  IC_XD_OPSIZE, /* 13876 */
  IC_64BIT_XD_OPSIZE, /* 13877 */
  IC_XS_OPSIZE, /* 13878 */
  IC_64BIT_XD_OPSIZE, /* 13879 */
  IC_OPSIZE_ADSIZE, /* 13880 */
  IC_64BIT_REXW_OPSIZE, /* 13881 */
  IC_XS_OPSIZE, /* 13882 */
  IC_64BIT_REXW_XS, /* 13883 */
  IC_XD_OPSIZE, /* 13884 */
  IC_64BIT_REXW_XD, /* 13885 */
  IC_XS_OPSIZE, /* 13886 */
  IC_64BIT_REXW_XS, /* 13887 */
  IC_VEX, /* 13888 */
  IC_VEX, /* 13889 */
  IC_VEX_XS, /* 13890 */
  IC_VEX_XS, /* 13891 */
  IC_VEX_XD, /* 13892 */
  IC_VEX_XD, /* 13893 */
  IC_VEX_XD, /* 13894 */
  IC_VEX_XD, /* 13895 */
  IC_VEX_W, /* 13896 */
  IC_VEX_W, /* 13897 */
  IC_VEX_W_XS, /* 13898 */
  IC_VEX_W_XS, /* 13899 */
  IC_VEX_W_XD, /* 13900 */
  IC_VEX_W_XD, /* 13901 */
  IC_VEX_W_XD, /* 13902 */
  IC_VEX_W_XD, /* 13903 */
  IC_VEX_OPSIZE, /* 13904 */
  IC_VEX_OPSIZE, /* 13905 */
  IC_VEX_OPSIZE, /* 13906 */
  IC_VEX_OPSIZE, /* 13907 */
  IC_VEX_OPSIZE, /* 13908 */
  IC_VEX_OPSIZE, /* 13909 */
  IC_VEX_OPSIZE, /* 13910 */
  IC_VEX_OPSIZE, /* 13911 */
  IC_VEX_W_OPSIZE, /* 13912 */
  IC_VEX_W_OPSIZE, /* 13913 */
  IC_VEX_W_OPSIZE, /* 13914 */
  IC_VEX_W_OPSIZE, /* 13915 */
  IC_VEX_W_OPSIZE, /* 13916 */
  IC_VEX_W_OPSIZE, /* 13917 */
  IC_VEX_W_OPSIZE, /* 13918 */
  IC_VEX_W_OPSIZE, /* 13919 */
  IC_VEX, /* 13920 */
  IC_VEX, /* 13921 */
  IC_VEX_XS, /* 13922 */
  IC_VEX_XS, /* 13923 */
  IC_VEX_XD, /* 13924 */
  IC_VEX_XD, /* 13925 */
  IC_VEX_XD, /* 13926 */
  IC_VEX_XD, /* 13927 */
  IC_VEX_W, /* 13928 */
  IC_VEX_W, /* 13929 */
  IC_VEX_W_XS, /* 13930 */
  IC_VEX_W_XS, /* 13931 */
  IC_VEX_W_XD, /* 13932 */
  IC_VEX_W_XD, /* 13933 */
  IC_VEX_W_XD, /* 13934 */
  IC_VEX_W_XD, /* 13935 */
  IC_VEX_OPSIZE, /* 13936 */
  IC_VEX_OPSIZE, /* 13937 */
  IC_VEX_OPSIZE, /* 13938 */
  IC_VEX_OPSIZE, /* 13939 */
  IC_VEX_OPSIZE, /* 13940 */
  IC_VEX_OPSIZE, /* 13941 */
  IC_VEX_OPSIZE, /* 13942 */
  IC_VEX_OPSIZE, /* 13943 */
  IC_VEX_W_OPSIZE, /* 13944 */
  IC_VEX_W_OPSIZE, /* 13945 */
  IC_VEX_W_OPSIZE, /* 13946 */
  IC_VEX_W_OPSIZE, /* 13947 */
  IC_VEX_W_OPSIZE, /* 13948 */
  IC_VEX_W_OPSIZE, /* 13949 */
  IC_VEX_W_OPSIZE, /* 13950 */
  IC_VEX_W_OPSIZE, /* 13951 */
  IC_VEX_L, /* 13952 */
  IC_VEX_L, /* 13953 */
  IC_VEX_L_XS, /* 13954 */
  IC_VEX_L_XS, /* 13955 */
  IC_VEX_L_XD, /* 13956 */
  IC_VEX_L_XD, /* 13957 */
  IC_VEX_L_XD, /* 13958 */
  IC_VEX_L_XD, /* 13959 */
  IC_VEX_L_W, /* 13960 */
  IC_VEX_L_W, /* 13961 */
  IC_VEX_L_W_XS, /* 13962 */
  IC_VEX_L_W_XS, /* 13963 */
  IC_VEX_L_W_XD, /* 13964 */
  IC_VEX_L_W_XD, /* 13965 */
  IC_VEX_L_W_XD, /* 13966 */
  IC_VEX_L_W_XD, /* 13967 */
  IC_VEX_L_OPSIZE, /* 13968 */
  IC_VEX_L_OPSIZE, /* 13969 */
  IC_VEX_L_OPSIZE, /* 13970 */
  IC_VEX_L_OPSIZE, /* 13971 */
  IC_VEX_L_OPSIZE, /* 13972 */
  IC_VEX_L_OPSIZE, /* 13973 */
  IC_VEX_L_OPSIZE, /* 13974 */
  IC_VEX_L_OPSIZE, /* 13975 */
  IC_VEX_L_W_OPSIZE, /* 13976 */
  IC_VEX_L_W_OPSIZE, /* 13977 */
  IC_VEX_L_W_OPSIZE, /* 13978 */
  IC_VEX_L_W_OPSIZE, /* 13979 */
  IC_VEX_L_W_OPSIZE, /* 13980 */
  IC_VEX_L_W_OPSIZE, /* 13981 */
  IC_VEX_L_W_OPSIZE, /* 13982 */
  IC_VEX_L_W_OPSIZE, /* 13983 */
  IC_VEX_L, /* 13984 */
  IC_VEX_L, /* 13985 */
  IC_VEX_L_XS, /* 13986 */
  IC_VEX_L_XS, /* 13987 */
  IC_VEX_L_XD, /* 13988 */
  IC_VEX_L_XD, /* 13989 */
  IC_VEX_L_XD, /* 13990 */
  IC_VEX_L_XD, /* 13991 */
  IC_VEX_L_W, /* 13992 */
  IC_VEX_L_W, /* 13993 */
  IC_VEX_L_W_XS, /* 13994 */
  IC_VEX_L_W_XS, /* 13995 */
  IC_VEX_L_W_XD, /* 13996 */
  IC_VEX_L_W_XD, /* 13997 */
  IC_VEX_L_W_XD, /* 13998 */
  IC_VEX_L_W_XD, /* 13999 */
  IC_VEX_L_OPSIZE, /* 14000 */
  IC_VEX_L_OPSIZE, /* 14001 */
  IC_VEX_L_OPSIZE, /* 14002 */
  IC_VEX_L_OPSIZE, /* 14003 */
  IC_VEX_L_OPSIZE, /* 14004 */
  IC_VEX_L_OPSIZE, /* 14005 */
  IC_VEX_L_OPSIZE, /* 14006 */
  IC_VEX_L_OPSIZE, /* 14007 */
  IC_VEX_L_W_OPSIZE, /* 14008 */
  IC_VEX_L_W_OPSIZE, /* 14009 */
  IC_VEX_L_W_OPSIZE, /* 14010 */
  IC_VEX_L_W_OPSIZE, /* 14011 */
  IC_VEX_L_W_OPSIZE, /* 14012 */
  IC_VEX_L_W_OPSIZE, /* 14013 */
  IC_VEX_L_W_OPSIZE, /* 14014 */
  IC_VEX_L_W_OPSIZE, /* 14015 */
  IC_VEX_L, /* 14016 */
  IC_VEX_L, /* 14017 */
  IC_VEX_L_XS, /* 14018 */
  IC_VEX_L_XS, /* 14019 */
  IC_VEX_L_XD, /* 14020 */
  IC_VEX_L_XD, /* 14021 */
  IC_VEX_L_XD, /* 14022 */
  IC_VEX_L_XD, /* 14023 */
  IC_VEX_L_W, /* 14024 */
  IC_VEX_L_W, /* 14025 */
  IC_VEX_L_W_XS, /* 14026 */
  IC_VEX_L_W_XS, /* 14027 */
  IC_VEX_L_W_XD, /* 14028 */
  IC_VEX_L_W_XD, /* 14029 */
  IC_VEX_L_W_XD, /* 14030 */
  IC_VEX_L_W_XD, /* 14031 */
  IC_VEX_L_OPSIZE, /* 14032 */
  IC_VEX_L_OPSIZE, /* 14033 */
  IC_VEX_L_OPSIZE, /* 14034 */
  IC_VEX_L_OPSIZE, /* 14035 */
  IC_VEX_L_OPSIZE, /* 14036 */
  IC_VEX_L_OPSIZE, /* 14037 */
  IC_VEX_L_OPSIZE, /* 14038 */
  IC_VEX_L_OPSIZE, /* 14039 */
  IC_VEX_L_W_OPSIZE, /* 14040 */
  IC_VEX_L_W_OPSIZE, /* 14041 */
  IC_VEX_L_W_OPSIZE, /* 14042 */
  IC_VEX_L_W_OPSIZE, /* 14043 */
  IC_VEX_L_W_OPSIZE, /* 14044 */
  IC_VEX_L_W_OPSIZE, /* 14045 */
  IC_VEX_L_W_OPSIZE, /* 14046 */
  IC_VEX_L_W_OPSIZE, /* 14047 */
  IC_VEX_L, /* 14048 */
  IC_VEX_L, /* 14049 */
  IC_VEX_L_XS, /* 14050 */
  IC_VEX_L_XS, /* 14051 */
  IC_VEX_L_XD, /* 14052 */
  IC_VEX_L_XD, /* 14053 */
  IC_VEX_L_XD, /* 14054 */
  IC_VEX_L_XD, /* 14055 */
  IC_VEX_L_W, /* 14056 */
  IC_VEX_L_W, /* 14057 */
  IC_VEX_L_W_XS, /* 14058 */
  IC_VEX_L_W_XS, /* 14059 */
  IC_VEX_L_W_XD, /* 14060 */
  IC_VEX_L_W_XD, /* 14061 */
  IC_VEX_L_W_XD, /* 14062 */
  IC_VEX_L_W_XD, /* 14063 */
  IC_VEX_L_OPSIZE, /* 14064 */
  IC_VEX_L_OPSIZE, /* 14065 */
  IC_VEX_L_OPSIZE, /* 14066 */
  IC_VEX_L_OPSIZE, /* 14067 */
  IC_VEX_L_OPSIZE, /* 14068 */
  IC_VEX_L_OPSIZE, /* 14069 */
  IC_VEX_L_OPSIZE, /* 14070 */
  IC_VEX_L_OPSIZE, /* 14071 */
  IC_VEX_L_W_OPSIZE, /* 14072 */
  IC_VEX_L_W_OPSIZE, /* 14073 */
  IC_VEX_L_W_OPSIZE, /* 14074 */
  IC_VEX_L_W_OPSIZE, /* 14075 */
  IC_VEX_L_W_OPSIZE, /* 14076 */
  IC_VEX_L_W_OPSIZE, /* 14077 */
  IC_VEX_L_W_OPSIZE, /* 14078 */
  IC_VEX_L_W_OPSIZE, /* 14079 */
  IC_EVEX_L2_KZ_B, /* 14080 */
  IC_EVEX_L2_KZ_B, /* 14081 */
  IC_EVEX_L2_XS_KZ_B, /* 14082 */
  IC_EVEX_L2_XS_KZ_B, /* 14083 */
  IC_EVEX_L2_XD_KZ_B, /* 14084 */
  IC_EVEX_L2_XD_KZ_B, /* 14085 */
  IC_EVEX_L2_XD_KZ_B, /* 14086 */
  IC_EVEX_L2_XD_KZ_B, /* 14087 */
  IC_EVEX_L2_W_KZ_B, /* 14088 */
  IC_EVEX_L2_W_KZ_B, /* 14089 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14090 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14091 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14092 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14093 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14094 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14095 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14096 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14097 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14098 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14099 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14100 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14101 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14102 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14103 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14104 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14105 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14106 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14107 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14108 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14109 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14110 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14111 */
  IC_EVEX_L2_KZ_B, /* 14112 */
  IC_EVEX_L2_KZ_B, /* 14113 */
  IC_EVEX_L2_XS_KZ_B, /* 14114 */
  IC_EVEX_L2_XS_KZ_B, /* 14115 */
  IC_EVEX_L2_XD_KZ_B, /* 14116 */
  IC_EVEX_L2_XD_KZ_B, /* 14117 */
  IC_EVEX_L2_XD_KZ_B, /* 14118 */
  IC_EVEX_L2_XD_KZ_B, /* 14119 */
  IC_EVEX_L2_W_KZ_B, /* 14120 */
  IC_EVEX_L2_W_KZ_B, /* 14121 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14122 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14123 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14124 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14125 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14126 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14127 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14128 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14129 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14130 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14131 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14132 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14133 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14134 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14135 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14136 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14137 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14138 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14139 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14140 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14141 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14142 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14143 */
  IC_EVEX_L2_KZ_B, /* 14144 */
  IC_EVEX_L2_KZ_B, /* 14145 */
  IC_EVEX_L2_XS_KZ_B, /* 14146 */
  IC_EVEX_L2_XS_KZ_B, /* 14147 */
  IC_EVEX_L2_XD_KZ_B, /* 14148 */
  IC_EVEX_L2_XD_KZ_B, /* 14149 */
  IC_EVEX_L2_XD_KZ_B, /* 14150 */
  IC_EVEX_L2_XD_KZ_B, /* 14151 */
  IC_EVEX_L2_W_KZ_B, /* 14152 */
  IC_EVEX_L2_W_KZ_B, /* 14153 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14154 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14155 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14156 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14157 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14158 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14159 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14160 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14161 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14162 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14163 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14164 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14165 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14166 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14167 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14168 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14169 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14170 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14171 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14172 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14173 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14174 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14175 */
  IC_EVEX_L2_KZ_B, /* 14176 */
  IC_EVEX_L2_KZ_B, /* 14177 */
  IC_EVEX_L2_XS_KZ_B, /* 14178 */
  IC_EVEX_L2_XS_KZ_B, /* 14179 */
  IC_EVEX_L2_XD_KZ_B, /* 14180 */
  IC_EVEX_L2_XD_KZ_B, /* 14181 */
  IC_EVEX_L2_XD_KZ_B, /* 14182 */
  IC_EVEX_L2_XD_KZ_B, /* 14183 */
  IC_EVEX_L2_W_KZ_B, /* 14184 */
  IC_EVEX_L2_W_KZ_B, /* 14185 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14186 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14187 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14188 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14189 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14190 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14191 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14192 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14193 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14194 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14195 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14196 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14197 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14198 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14199 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14200 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14201 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14202 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14203 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14204 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14205 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14206 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14207 */
  IC_EVEX_L2_KZ_B, /* 14208 */
  IC_EVEX_L2_KZ_B, /* 14209 */
  IC_EVEX_L2_XS_KZ_B, /* 14210 */
  IC_EVEX_L2_XS_KZ_B, /* 14211 */
  IC_EVEX_L2_XD_KZ_B, /* 14212 */
  IC_EVEX_L2_XD_KZ_B, /* 14213 */
  IC_EVEX_L2_XD_KZ_B, /* 14214 */
  IC_EVEX_L2_XD_KZ_B, /* 14215 */
  IC_EVEX_L2_W_KZ_B, /* 14216 */
  IC_EVEX_L2_W_KZ_B, /* 14217 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14218 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14219 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14220 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14221 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14222 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14223 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14224 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14225 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14226 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14227 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14228 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14229 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14230 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14231 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14232 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14233 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14234 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14235 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14236 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14237 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14238 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14239 */
  IC_EVEX_L2_KZ_B, /* 14240 */
  IC_EVEX_L2_KZ_B, /* 14241 */
  IC_EVEX_L2_XS_KZ_B, /* 14242 */
  IC_EVEX_L2_XS_KZ_B, /* 14243 */
  IC_EVEX_L2_XD_KZ_B, /* 14244 */
  IC_EVEX_L2_XD_KZ_B, /* 14245 */
  IC_EVEX_L2_XD_KZ_B, /* 14246 */
  IC_EVEX_L2_XD_KZ_B, /* 14247 */
  IC_EVEX_L2_W_KZ_B, /* 14248 */
  IC_EVEX_L2_W_KZ_B, /* 14249 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14250 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14251 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14252 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14253 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14254 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14255 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14256 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14257 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14258 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14259 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14260 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14261 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14262 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14263 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14264 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14265 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14266 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14267 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14268 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14269 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14270 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14271 */
  IC_EVEX_L2_KZ_B, /* 14272 */
  IC_EVEX_L2_KZ_B, /* 14273 */
  IC_EVEX_L2_XS_KZ_B, /* 14274 */
  IC_EVEX_L2_XS_KZ_B, /* 14275 */
  IC_EVEX_L2_XD_KZ_B, /* 14276 */
  IC_EVEX_L2_XD_KZ_B, /* 14277 */
  IC_EVEX_L2_XD_KZ_B, /* 14278 */
  IC_EVEX_L2_XD_KZ_B, /* 14279 */
  IC_EVEX_L2_W_KZ_B, /* 14280 */
  IC_EVEX_L2_W_KZ_B, /* 14281 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14282 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14283 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14284 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14285 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14286 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14287 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14288 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14289 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14290 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14291 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14292 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14293 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14294 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14295 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14296 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14297 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14298 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14299 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14300 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14301 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14302 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14303 */
  IC_EVEX_L2_KZ_B, /* 14304 */
  IC_EVEX_L2_KZ_B, /* 14305 */
  IC_EVEX_L2_XS_KZ_B, /* 14306 */
  IC_EVEX_L2_XS_KZ_B, /* 14307 */
  IC_EVEX_L2_XD_KZ_B, /* 14308 */
  IC_EVEX_L2_XD_KZ_B, /* 14309 */
  IC_EVEX_L2_XD_KZ_B, /* 14310 */
  IC_EVEX_L2_XD_KZ_B, /* 14311 */
  IC_EVEX_L2_W_KZ_B, /* 14312 */
  IC_EVEX_L2_W_KZ_B, /* 14313 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14314 */
  IC_EVEX_L2_W_XS_KZ_B, /* 14315 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14316 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14317 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14318 */
  IC_EVEX_L2_W_XD_KZ_B, /* 14319 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14320 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14321 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14322 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14323 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14324 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14325 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14326 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 14327 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14328 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14329 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14330 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14331 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14332 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14333 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14334 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 14335 */
  IC, /* 14336 */
  IC_64BIT, /* 14337 */
  IC_XS, /* 14338 */
  IC_64BIT_XS, /* 14339 */
  IC_XD, /* 14340 */
  IC_64BIT_XD, /* 14341 */
  IC_XS, /* 14342 */
  IC_64BIT_XS, /* 14343 */
  IC, /* 14344 */
  IC_64BIT_REXW, /* 14345 */
  IC_XS, /* 14346 */
  IC_64BIT_REXW_XS, /* 14347 */
  IC_XD, /* 14348 */
  IC_64BIT_REXW_XD, /* 14349 */
  IC_XS, /* 14350 */
  IC_64BIT_REXW_XS, /* 14351 */
  IC_OPSIZE, /* 14352 */
  IC_64BIT_OPSIZE, /* 14353 */
  IC_XS_OPSIZE, /* 14354 */
  IC_64BIT_XS_OPSIZE, /* 14355 */
  IC_XD_OPSIZE, /* 14356 */
  IC_64BIT_XD_OPSIZE, /* 14357 */
  IC_XS_OPSIZE, /* 14358 */
  IC_64BIT_XD_OPSIZE, /* 14359 */
  IC_OPSIZE, /* 14360 */
  IC_64BIT_REXW_OPSIZE, /* 14361 */
  IC_XS_OPSIZE, /* 14362 */
  IC_64BIT_REXW_XS, /* 14363 */
  IC_XD_OPSIZE, /* 14364 */
  IC_64BIT_REXW_XD, /* 14365 */
  IC_XS_OPSIZE, /* 14366 */
  IC_64BIT_REXW_XS, /* 14367 */
  IC_ADSIZE, /* 14368 */
  IC_64BIT_ADSIZE, /* 14369 */
  IC_XS, /* 14370 */
  IC_64BIT_XS, /* 14371 */
  IC_XD, /* 14372 */
  IC_64BIT_XD, /* 14373 */
  IC_XS, /* 14374 */
  IC_64BIT_XS, /* 14375 */
  IC_ADSIZE, /* 14376 */
  IC_64BIT_REXW_ADSIZE, /* 14377 */
  IC_XS, /* 14378 */
  IC_64BIT_REXW_XS, /* 14379 */
  IC_XD, /* 14380 */
  IC_64BIT_REXW_XD, /* 14381 */
  IC_XS, /* 14382 */
  IC_64BIT_REXW_XS, /* 14383 */
  IC_OPSIZE_ADSIZE, /* 14384 */
  IC_64BIT_OPSIZE_ADSIZE, /* 14385 */
  IC_XS_OPSIZE, /* 14386 */
  IC_64BIT_XS_OPSIZE, /* 14387 */
  IC_XD_OPSIZE, /* 14388 */
  IC_64BIT_XD_OPSIZE, /* 14389 */
  IC_XS_OPSIZE, /* 14390 */
  IC_64BIT_XD_OPSIZE, /* 14391 */
  IC_OPSIZE_ADSIZE, /* 14392 */
  IC_64BIT_REXW_OPSIZE, /* 14393 */
  IC_XS_OPSIZE, /* 14394 */
  IC_64BIT_REXW_XS, /* 14395 */
  IC_XD_OPSIZE, /* 14396 */
  IC_64BIT_REXW_XD, /* 14397 */
  IC_XS_OPSIZE, /* 14398 */
  IC_64BIT_REXW_XS, /* 14399 */
  IC_VEX, /* 14400 */
  IC_VEX, /* 14401 */
  IC_VEX_XS, /* 14402 */
  IC_VEX_XS, /* 14403 */
  IC_VEX_XD, /* 14404 */
  IC_VEX_XD, /* 14405 */
  IC_VEX_XD, /* 14406 */
  IC_VEX_XD, /* 14407 */
  IC_VEX_W, /* 14408 */
  IC_VEX_W, /* 14409 */
  IC_VEX_W_XS, /* 14410 */
  IC_VEX_W_XS, /* 14411 */
  IC_VEX_W_XD, /* 14412 */
  IC_VEX_W_XD, /* 14413 */
  IC_VEX_W_XD, /* 14414 */
  IC_VEX_W_XD, /* 14415 */
  IC_VEX_OPSIZE, /* 14416 */
  IC_VEX_OPSIZE, /* 14417 */
  IC_VEX_OPSIZE, /* 14418 */
  IC_VEX_OPSIZE, /* 14419 */
  IC_VEX_OPSIZE, /* 14420 */
  IC_VEX_OPSIZE, /* 14421 */
  IC_VEX_OPSIZE, /* 14422 */
  IC_VEX_OPSIZE, /* 14423 */
  IC_VEX_W_OPSIZE, /* 14424 */
  IC_VEX_W_OPSIZE, /* 14425 */
  IC_VEX_W_OPSIZE, /* 14426 */
  IC_VEX_W_OPSIZE, /* 14427 */
  IC_VEX_W_OPSIZE, /* 14428 */
  IC_VEX_W_OPSIZE, /* 14429 */
  IC_VEX_W_OPSIZE, /* 14430 */
  IC_VEX_W_OPSIZE, /* 14431 */
  IC_VEX, /* 14432 */
  IC_VEX, /* 14433 */
  IC_VEX_XS, /* 14434 */
  IC_VEX_XS, /* 14435 */
  IC_VEX_XD, /* 14436 */
  IC_VEX_XD, /* 14437 */
  IC_VEX_XD, /* 14438 */
  IC_VEX_XD, /* 14439 */
  IC_VEX_W, /* 14440 */
  IC_VEX_W, /* 14441 */
  IC_VEX_W_XS, /* 14442 */
  IC_VEX_W_XS, /* 14443 */
  IC_VEX_W_XD, /* 14444 */
  IC_VEX_W_XD, /* 14445 */
  IC_VEX_W_XD, /* 14446 */
  IC_VEX_W_XD, /* 14447 */
  IC_VEX_OPSIZE, /* 14448 */
  IC_VEX_OPSIZE, /* 14449 */
  IC_VEX_OPSIZE, /* 14450 */
  IC_VEX_OPSIZE, /* 14451 */
  IC_VEX_OPSIZE, /* 14452 */
  IC_VEX_OPSIZE, /* 14453 */
  IC_VEX_OPSIZE, /* 14454 */
  IC_VEX_OPSIZE, /* 14455 */
  IC_VEX_W_OPSIZE, /* 14456 */
  IC_VEX_W_OPSIZE, /* 14457 */
  IC_VEX_W_OPSIZE, /* 14458 */
  IC_VEX_W_OPSIZE, /* 14459 */
  IC_VEX_W_OPSIZE, /* 14460 */
  IC_VEX_W_OPSIZE, /* 14461 */
  IC_VEX_W_OPSIZE, /* 14462 */
  IC_VEX_W_OPSIZE, /* 14463 */
  IC_VEX_L, /* 14464 */
  IC_VEX_L, /* 14465 */
  IC_VEX_L_XS, /* 14466 */
  IC_VEX_L_XS, /* 14467 */
  IC_VEX_L_XD, /* 14468 */
  IC_VEX_L_XD, /* 14469 */
  IC_VEX_L_XD, /* 14470 */
  IC_VEX_L_XD, /* 14471 */
  IC_VEX_L_W, /* 14472 */
  IC_VEX_L_W, /* 14473 */
  IC_VEX_L_W_XS, /* 14474 */
  IC_VEX_L_W_XS, /* 14475 */
  IC_VEX_L_W_XD, /* 14476 */
  IC_VEX_L_W_XD, /* 14477 */
  IC_VEX_L_W_XD, /* 14478 */
  IC_VEX_L_W_XD, /* 14479 */
  IC_VEX_L_OPSIZE, /* 14480 */
  IC_VEX_L_OPSIZE, /* 14481 */
  IC_VEX_L_OPSIZE, /* 14482 */
  IC_VEX_L_OPSIZE, /* 14483 */
  IC_VEX_L_OPSIZE, /* 14484 */
  IC_VEX_L_OPSIZE, /* 14485 */
  IC_VEX_L_OPSIZE, /* 14486 */
  IC_VEX_L_OPSIZE, /* 14487 */
  IC_VEX_L_W_OPSIZE, /* 14488 */
  IC_VEX_L_W_OPSIZE, /* 14489 */
  IC_VEX_L_W_OPSIZE, /* 14490 */
  IC_VEX_L_W_OPSIZE, /* 14491 */
  IC_VEX_L_W_OPSIZE, /* 14492 */
  IC_VEX_L_W_OPSIZE, /* 14493 */
  IC_VEX_L_W_OPSIZE, /* 14494 */
  IC_VEX_L_W_OPSIZE, /* 14495 */
  IC_VEX_L, /* 14496 */
  IC_VEX_L, /* 14497 */
  IC_VEX_L_XS, /* 14498 */
  IC_VEX_L_XS, /* 14499 */
  IC_VEX_L_XD, /* 14500 */
  IC_VEX_L_XD, /* 14501 */
  IC_VEX_L_XD, /* 14502 */
  IC_VEX_L_XD, /* 14503 */
  IC_VEX_L_W, /* 14504 */
  IC_VEX_L_W, /* 14505 */
  IC_VEX_L_W_XS, /* 14506 */
  IC_VEX_L_W_XS, /* 14507 */
  IC_VEX_L_W_XD, /* 14508 */
  IC_VEX_L_W_XD, /* 14509 */
  IC_VEX_L_W_XD, /* 14510 */
  IC_VEX_L_W_XD, /* 14511 */
  IC_VEX_L_OPSIZE, /* 14512 */
  IC_VEX_L_OPSIZE, /* 14513 */
  IC_VEX_L_OPSIZE, /* 14514 */
  IC_VEX_L_OPSIZE, /* 14515 */
  IC_VEX_L_OPSIZE, /* 14516 */
  IC_VEX_L_OPSIZE, /* 14517 */
  IC_VEX_L_OPSIZE, /* 14518 */
  IC_VEX_L_OPSIZE, /* 14519 */
  IC_VEX_L_W_OPSIZE, /* 14520 */
  IC_VEX_L_W_OPSIZE, /* 14521 */
  IC_VEX_L_W_OPSIZE, /* 14522 */
  IC_VEX_L_W_OPSIZE, /* 14523 */
  IC_VEX_L_W_OPSIZE, /* 14524 */
  IC_VEX_L_W_OPSIZE, /* 14525 */
  IC_VEX_L_W_OPSIZE, /* 14526 */
  IC_VEX_L_W_OPSIZE, /* 14527 */
  IC_VEX_L, /* 14528 */
  IC_VEX_L, /* 14529 */
  IC_VEX_L_XS, /* 14530 */
  IC_VEX_L_XS, /* 14531 */
  IC_VEX_L_XD, /* 14532 */
  IC_VEX_L_XD, /* 14533 */
  IC_VEX_L_XD, /* 14534 */
  IC_VEX_L_XD, /* 14535 */
  IC_VEX_L_W, /* 14536 */
  IC_VEX_L_W, /* 14537 */
  IC_VEX_L_W_XS, /* 14538 */
  IC_VEX_L_W_XS, /* 14539 */
  IC_VEX_L_W_XD, /* 14540 */
  IC_VEX_L_W_XD, /* 14541 */
  IC_VEX_L_W_XD, /* 14542 */
  IC_VEX_L_W_XD, /* 14543 */
  IC_VEX_L_OPSIZE, /* 14544 */
  IC_VEX_L_OPSIZE, /* 14545 */
  IC_VEX_L_OPSIZE, /* 14546 */
  IC_VEX_L_OPSIZE, /* 14547 */
  IC_VEX_L_OPSIZE, /* 14548 */
  IC_VEX_L_OPSIZE, /* 14549 */
  IC_VEX_L_OPSIZE, /* 14550 */
  IC_VEX_L_OPSIZE, /* 14551 */
  IC_VEX_L_W_OPSIZE, /* 14552 */
  IC_VEX_L_W_OPSIZE, /* 14553 */
  IC_VEX_L_W_OPSIZE, /* 14554 */
  IC_VEX_L_W_OPSIZE, /* 14555 */
  IC_VEX_L_W_OPSIZE, /* 14556 */
  IC_VEX_L_W_OPSIZE, /* 14557 */
  IC_VEX_L_W_OPSIZE, /* 14558 */
  IC_VEX_L_W_OPSIZE, /* 14559 */
  IC_VEX_L, /* 14560 */
  IC_VEX_L, /* 14561 */
  IC_VEX_L_XS, /* 14562 */
  IC_VEX_L_XS, /* 14563 */
  IC_VEX_L_XD, /* 14564 */
  IC_VEX_L_XD, /* 14565 */
  IC_VEX_L_XD, /* 14566 */
  IC_VEX_L_XD, /* 14567 */
  IC_VEX_L_W, /* 14568 */
  IC_VEX_L_W, /* 14569 */
  IC_VEX_L_W_XS, /* 14570 */
  IC_VEX_L_W_XS, /* 14571 */
  IC_VEX_L_W_XD, /* 14572 */
  IC_VEX_L_W_XD, /* 14573 */
  IC_VEX_L_W_XD, /* 14574 */
  IC_VEX_L_W_XD, /* 14575 */
  IC_VEX_L_OPSIZE, /* 14576 */
  IC_VEX_L_OPSIZE, /* 14577 */
  IC_VEX_L_OPSIZE, /* 14578 */
  IC_VEX_L_OPSIZE, /* 14579 */
  IC_VEX_L_OPSIZE, /* 14580 */
  IC_VEX_L_OPSIZE, /* 14581 */
  IC_VEX_L_OPSIZE, /* 14582 */
  IC_VEX_L_OPSIZE, /* 14583 */
  IC_VEX_L_W_OPSIZE, /* 14584 */
  IC_VEX_L_W_OPSIZE, /* 14585 */
  IC_VEX_L_W_OPSIZE, /* 14586 */
  IC_VEX_L_W_OPSIZE, /* 14587 */
  IC_VEX_L_W_OPSIZE, /* 14588 */
  IC_VEX_L_W_OPSIZE, /* 14589 */
  IC_VEX_L_W_OPSIZE, /* 14590 */
  IC_VEX_L_W_OPSIZE, /* 14591 */
  IC_EVEX_KZ_B, /* 14592 */
  IC_EVEX_KZ_B, /* 14593 */
  IC_EVEX_XS_KZ_B, /* 14594 */
  IC_EVEX_XS_KZ_B, /* 14595 */
  IC_EVEX_XD_KZ_B, /* 14596 */
  IC_EVEX_XD_KZ_B, /* 14597 */
  IC_EVEX_XD_KZ_B, /* 14598 */
  IC_EVEX_XD_KZ_B, /* 14599 */
  IC_EVEX_W_KZ_B, /* 14600 */
  IC_EVEX_W_KZ_B, /* 14601 */
  IC_EVEX_W_XS_KZ_B, /* 14602 */
  IC_EVEX_W_XS_KZ_B, /* 14603 */
  IC_EVEX_W_XD_KZ_B, /* 14604 */
  IC_EVEX_W_XD_KZ_B, /* 14605 */
  IC_EVEX_W_XD_KZ_B, /* 14606 */
  IC_EVEX_W_XD_KZ_B, /* 14607 */
  IC_EVEX_OPSIZE_KZ_B, /* 14608 */
  IC_EVEX_OPSIZE_KZ_B, /* 14609 */
  IC_EVEX_OPSIZE_KZ_B, /* 14610 */
  IC_EVEX_OPSIZE_KZ_B, /* 14611 */
  IC_EVEX_OPSIZE_KZ_B, /* 14612 */
  IC_EVEX_OPSIZE_KZ_B, /* 14613 */
  IC_EVEX_OPSIZE_KZ_B, /* 14614 */
  IC_EVEX_OPSIZE_KZ_B, /* 14615 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14616 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14617 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14618 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14619 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14620 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14621 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14622 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14623 */
  IC_EVEX_KZ_B, /* 14624 */
  IC_EVEX_KZ_B, /* 14625 */
  IC_EVEX_XS_KZ_B, /* 14626 */
  IC_EVEX_XS_KZ_B, /* 14627 */
  IC_EVEX_XD_KZ_B, /* 14628 */
  IC_EVEX_XD_KZ_B, /* 14629 */
  IC_EVEX_XD_KZ_B, /* 14630 */
  IC_EVEX_XD_KZ_B, /* 14631 */
  IC_EVEX_W_KZ_B, /* 14632 */
  IC_EVEX_W_KZ_B, /* 14633 */
  IC_EVEX_W_XS_KZ_B, /* 14634 */
  IC_EVEX_W_XS_KZ_B, /* 14635 */
  IC_EVEX_W_XD_KZ_B, /* 14636 */
  IC_EVEX_W_XD_KZ_B, /* 14637 */
  IC_EVEX_W_XD_KZ_B, /* 14638 */
  IC_EVEX_W_XD_KZ_B, /* 14639 */
  IC_EVEX_OPSIZE_KZ_B, /* 14640 */
  IC_EVEX_OPSIZE_KZ_B, /* 14641 */
  IC_EVEX_OPSIZE_KZ_B, /* 14642 */
  IC_EVEX_OPSIZE_KZ_B, /* 14643 */
  IC_EVEX_OPSIZE_KZ_B, /* 14644 */
  IC_EVEX_OPSIZE_KZ_B, /* 14645 */
  IC_EVEX_OPSIZE_KZ_B, /* 14646 */
  IC_EVEX_OPSIZE_KZ_B, /* 14647 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14648 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14649 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14650 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14651 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14652 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14653 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14654 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14655 */
  IC_EVEX_KZ_B, /* 14656 */
  IC_EVEX_KZ_B, /* 14657 */
  IC_EVEX_XS_KZ_B, /* 14658 */
  IC_EVEX_XS_KZ_B, /* 14659 */
  IC_EVEX_XD_KZ_B, /* 14660 */
  IC_EVEX_XD_KZ_B, /* 14661 */
  IC_EVEX_XD_KZ_B, /* 14662 */
  IC_EVEX_XD_KZ_B, /* 14663 */
  IC_EVEX_W_KZ_B, /* 14664 */
  IC_EVEX_W_KZ_B, /* 14665 */
  IC_EVEX_W_XS_KZ_B, /* 14666 */
  IC_EVEX_W_XS_KZ_B, /* 14667 */
  IC_EVEX_W_XD_KZ_B, /* 14668 */
  IC_EVEX_W_XD_KZ_B, /* 14669 */
  IC_EVEX_W_XD_KZ_B, /* 14670 */
  IC_EVEX_W_XD_KZ_B, /* 14671 */
  IC_EVEX_OPSIZE_KZ_B, /* 14672 */
  IC_EVEX_OPSIZE_KZ_B, /* 14673 */
  IC_EVEX_OPSIZE_KZ_B, /* 14674 */
  IC_EVEX_OPSIZE_KZ_B, /* 14675 */
  IC_EVEX_OPSIZE_KZ_B, /* 14676 */
  IC_EVEX_OPSIZE_KZ_B, /* 14677 */
  IC_EVEX_OPSIZE_KZ_B, /* 14678 */
  IC_EVEX_OPSIZE_KZ_B, /* 14679 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14680 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14681 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14682 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14683 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14684 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14685 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14686 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14687 */
  IC_EVEX_KZ_B, /* 14688 */
  IC_EVEX_KZ_B, /* 14689 */
  IC_EVEX_XS_KZ_B, /* 14690 */
  IC_EVEX_XS_KZ_B, /* 14691 */
  IC_EVEX_XD_KZ_B, /* 14692 */
  IC_EVEX_XD_KZ_B, /* 14693 */
  IC_EVEX_XD_KZ_B, /* 14694 */
  IC_EVEX_XD_KZ_B, /* 14695 */
  IC_EVEX_W_KZ_B, /* 14696 */
  IC_EVEX_W_KZ_B, /* 14697 */
  IC_EVEX_W_XS_KZ_B, /* 14698 */
  IC_EVEX_W_XS_KZ_B, /* 14699 */
  IC_EVEX_W_XD_KZ_B, /* 14700 */
  IC_EVEX_W_XD_KZ_B, /* 14701 */
  IC_EVEX_W_XD_KZ_B, /* 14702 */
  IC_EVEX_W_XD_KZ_B, /* 14703 */
  IC_EVEX_OPSIZE_KZ_B, /* 14704 */
  IC_EVEX_OPSIZE_KZ_B, /* 14705 */
  IC_EVEX_OPSIZE_KZ_B, /* 14706 */
  IC_EVEX_OPSIZE_KZ_B, /* 14707 */
  IC_EVEX_OPSIZE_KZ_B, /* 14708 */
  IC_EVEX_OPSIZE_KZ_B, /* 14709 */
  IC_EVEX_OPSIZE_KZ_B, /* 14710 */
  IC_EVEX_OPSIZE_KZ_B, /* 14711 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14712 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14713 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14714 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14715 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14716 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14717 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14718 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14719 */
  IC_EVEX_KZ_B, /* 14720 */
  IC_EVEX_KZ_B, /* 14721 */
  IC_EVEX_XS_KZ_B, /* 14722 */
  IC_EVEX_XS_KZ_B, /* 14723 */
  IC_EVEX_XD_KZ_B, /* 14724 */
  IC_EVEX_XD_KZ_B, /* 14725 */
  IC_EVEX_XD_KZ_B, /* 14726 */
  IC_EVEX_XD_KZ_B, /* 14727 */
  IC_EVEX_W_KZ_B, /* 14728 */
  IC_EVEX_W_KZ_B, /* 14729 */
  IC_EVEX_W_XS_KZ_B, /* 14730 */
  IC_EVEX_W_XS_KZ_B, /* 14731 */
  IC_EVEX_W_XD_KZ_B, /* 14732 */
  IC_EVEX_W_XD_KZ_B, /* 14733 */
  IC_EVEX_W_XD_KZ_B, /* 14734 */
  IC_EVEX_W_XD_KZ_B, /* 14735 */
  IC_EVEX_OPSIZE_KZ_B, /* 14736 */
  IC_EVEX_OPSIZE_KZ_B, /* 14737 */
  IC_EVEX_OPSIZE_KZ_B, /* 14738 */
  IC_EVEX_OPSIZE_KZ_B, /* 14739 */
  IC_EVEX_OPSIZE_KZ_B, /* 14740 */
  IC_EVEX_OPSIZE_KZ_B, /* 14741 */
  IC_EVEX_OPSIZE_KZ_B, /* 14742 */
  IC_EVEX_OPSIZE_KZ_B, /* 14743 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14744 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14745 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14746 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14747 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14748 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14749 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14750 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14751 */
  IC_EVEX_KZ_B, /* 14752 */
  IC_EVEX_KZ_B, /* 14753 */
  IC_EVEX_XS_KZ_B, /* 14754 */
  IC_EVEX_XS_KZ_B, /* 14755 */
  IC_EVEX_XD_KZ_B, /* 14756 */
  IC_EVEX_XD_KZ_B, /* 14757 */
  IC_EVEX_XD_KZ_B, /* 14758 */
  IC_EVEX_XD_KZ_B, /* 14759 */
  IC_EVEX_W_KZ_B, /* 14760 */
  IC_EVEX_W_KZ_B, /* 14761 */
  IC_EVEX_W_XS_KZ_B, /* 14762 */
  IC_EVEX_W_XS_KZ_B, /* 14763 */
  IC_EVEX_W_XD_KZ_B, /* 14764 */
  IC_EVEX_W_XD_KZ_B, /* 14765 */
  IC_EVEX_W_XD_KZ_B, /* 14766 */
  IC_EVEX_W_XD_KZ_B, /* 14767 */
  IC_EVEX_OPSIZE_KZ_B, /* 14768 */
  IC_EVEX_OPSIZE_KZ_B, /* 14769 */
  IC_EVEX_OPSIZE_KZ_B, /* 14770 */
  IC_EVEX_OPSIZE_KZ_B, /* 14771 */
  IC_EVEX_OPSIZE_KZ_B, /* 14772 */
  IC_EVEX_OPSIZE_KZ_B, /* 14773 */
  IC_EVEX_OPSIZE_KZ_B, /* 14774 */
  IC_EVEX_OPSIZE_KZ_B, /* 14775 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14776 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14777 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14778 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14779 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14780 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14781 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14782 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14783 */
  IC_EVEX_KZ_B, /* 14784 */
  IC_EVEX_KZ_B, /* 14785 */
  IC_EVEX_XS_KZ_B, /* 14786 */
  IC_EVEX_XS_KZ_B, /* 14787 */
  IC_EVEX_XD_KZ_B, /* 14788 */
  IC_EVEX_XD_KZ_B, /* 14789 */
  IC_EVEX_XD_KZ_B, /* 14790 */
  IC_EVEX_XD_KZ_B, /* 14791 */
  IC_EVEX_W_KZ_B, /* 14792 */
  IC_EVEX_W_KZ_B, /* 14793 */
  IC_EVEX_W_XS_KZ_B, /* 14794 */
  IC_EVEX_W_XS_KZ_B, /* 14795 */
  IC_EVEX_W_XD_KZ_B, /* 14796 */
  IC_EVEX_W_XD_KZ_B, /* 14797 */
  IC_EVEX_W_XD_KZ_B, /* 14798 */
  IC_EVEX_W_XD_KZ_B, /* 14799 */
  IC_EVEX_OPSIZE_KZ_B, /* 14800 */
  IC_EVEX_OPSIZE_KZ_B, /* 14801 */
  IC_EVEX_OPSIZE_KZ_B, /* 14802 */
  IC_EVEX_OPSIZE_KZ_B, /* 14803 */
  IC_EVEX_OPSIZE_KZ_B, /* 14804 */
  IC_EVEX_OPSIZE_KZ_B, /* 14805 */
  IC_EVEX_OPSIZE_KZ_B, /* 14806 */
  IC_EVEX_OPSIZE_KZ_B, /* 14807 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14808 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14809 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14810 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14811 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14812 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14813 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14814 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14815 */
  IC_EVEX_KZ_B, /* 14816 */
  IC_EVEX_KZ_B, /* 14817 */
  IC_EVEX_XS_KZ_B, /* 14818 */
  IC_EVEX_XS_KZ_B, /* 14819 */
  IC_EVEX_XD_KZ_B, /* 14820 */
  IC_EVEX_XD_KZ_B, /* 14821 */
  IC_EVEX_XD_KZ_B, /* 14822 */
  IC_EVEX_XD_KZ_B, /* 14823 */
  IC_EVEX_W_KZ_B, /* 14824 */
  IC_EVEX_W_KZ_B, /* 14825 */
  IC_EVEX_W_XS_KZ_B, /* 14826 */
  IC_EVEX_W_XS_KZ_B, /* 14827 */
  IC_EVEX_W_XD_KZ_B, /* 14828 */
  IC_EVEX_W_XD_KZ_B, /* 14829 */
  IC_EVEX_W_XD_KZ_B, /* 14830 */
  IC_EVEX_W_XD_KZ_B, /* 14831 */
  IC_EVEX_OPSIZE_KZ_B, /* 14832 */
  IC_EVEX_OPSIZE_KZ_B, /* 14833 */
  IC_EVEX_OPSIZE_KZ_B, /* 14834 */
  IC_EVEX_OPSIZE_KZ_B, /* 14835 */
  IC_EVEX_OPSIZE_KZ_B, /* 14836 */
  IC_EVEX_OPSIZE_KZ_B, /* 14837 */
  IC_EVEX_OPSIZE_KZ_B, /* 14838 */
  IC_EVEX_OPSIZE_KZ_B, /* 14839 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14840 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14841 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14842 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14843 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14844 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14845 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14846 */
  IC_EVEX_W_OPSIZE_KZ_B, /* 14847 */
  IC, /* 14848 */
  IC_64BIT, /* 14849 */
  IC_XS, /* 14850 */
  IC_64BIT_XS, /* 14851 */
  IC_XD, /* 14852 */
  IC_64BIT_XD, /* 14853 */
  IC_XS, /* 14854 */
  IC_64BIT_XS, /* 14855 */
  IC, /* 14856 */
  IC_64BIT_REXW, /* 14857 */
  IC_XS, /* 14858 */
  IC_64BIT_REXW_XS, /* 14859 */
  IC_XD, /* 14860 */
  IC_64BIT_REXW_XD, /* 14861 */
  IC_XS, /* 14862 */
  IC_64BIT_REXW_XS, /* 14863 */
  IC_OPSIZE, /* 14864 */
  IC_64BIT_OPSIZE, /* 14865 */
  IC_XS_OPSIZE, /* 14866 */
  IC_64BIT_XS_OPSIZE, /* 14867 */
  IC_XD_OPSIZE, /* 14868 */
  IC_64BIT_XD_OPSIZE, /* 14869 */
  IC_XS_OPSIZE, /* 14870 */
  IC_64BIT_XD_OPSIZE, /* 14871 */
  IC_OPSIZE, /* 14872 */
  IC_64BIT_REXW_OPSIZE, /* 14873 */
  IC_XS_OPSIZE, /* 14874 */
  IC_64BIT_REXW_XS, /* 14875 */
  IC_XD_OPSIZE, /* 14876 */
  IC_64BIT_REXW_XD, /* 14877 */
  IC_XS_OPSIZE, /* 14878 */
  IC_64BIT_REXW_XS, /* 14879 */
  IC_ADSIZE, /* 14880 */
  IC_64BIT_ADSIZE, /* 14881 */
  IC_XS, /* 14882 */
  IC_64BIT_XS, /* 14883 */
  IC_XD, /* 14884 */
  IC_64BIT_XD, /* 14885 */
  IC_XS, /* 14886 */
  IC_64BIT_XS, /* 14887 */
  IC_ADSIZE, /* 14888 */
  IC_64BIT_REXW_ADSIZE, /* 14889 */
  IC_XS, /* 14890 */
  IC_64BIT_REXW_XS, /* 14891 */
  IC_XD, /* 14892 */
  IC_64BIT_REXW_XD, /* 14893 */
  IC_XS, /* 14894 */
  IC_64BIT_REXW_XS, /* 14895 */
  IC_OPSIZE_ADSIZE, /* 14896 */
  IC_64BIT_OPSIZE_ADSIZE, /* 14897 */
  IC_XS_OPSIZE, /* 14898 */
  IC_64BIT_XS_OPSIZE, /* 14899 */
  IC_XD_OPSIZE, /* 14900 */
  IC_64BIT_XD_OPSIZE, /* 14901 */
  IC_XS_OPSIZE, /* 14902 */
  IC_64BIT_XD_OPSIZE, /* 14903 */
  IC_OPSIZE_ADSIZE, /* 14904 */
  IC_64BIT_REXW_OPSIZE, /* 14905 */
  IC_XS_OPSIZE, /* 14906 */
  IC_64BIT_REXW_XS, /* 14907 */
  IC_XD_OPSIZE, /* 14908 */
  IC_64BIT_REXW_XD, /* 14909 */
  IC_XS_OPSIZE, /* 14910 */
  IC_64BIT_REXW_XS, /* 14911 */
  IC_VEX, /* 14912 */
  IC_VEX, /* 14913 */
  IC_VEX_XS, /* 14914 */
  IC_VEX_XS, /* 14915 */
  IC_VEX_XD, /* 14916 */
  IC_VEX_XD, /* 14917 */
  IC_VEX_XD, /* 14918 */
  IC_VEX_XD, /* 14919 */
  IC_VEX_W, /* 14920 */
  IC_VEX_W, /* 14921 */
  IC_VEX_W_XS, /* 14922 */
  IC_VEX_W_XS, /* 14923 */
  IC_VEX_W_XD, /* 14924 */
  IC_VEX_W_XD, /* 14925 */
  IC_VEX_W_XD, /* 14926 */
  IC_VEX_W_XD, /* 14927 */
  IC_VEX_OPSIZE, /* 14928 */
  IC_VEX_OPSIZE, /* 14929 */
  IC_VEX_OPSIZE, /* 14930 */
  IC_VEX_OPSIZE, /* 14931 */
  IC_VEX_OPSIZE, /* 14932 */
  IC_VEX_OPSIZE, /* 14933 */
  IC_VEX_OPSIZE, /* 14934 */
  IC_VEX_OPSIZE, /* 14935 */
  IC_VEX_W_OPSIZE, /* 14936 */
  IC_VEX_W_OPSIZE, /* 14937 */
  IC_VEX_W_OPSIZE, /* 14938 */
  IC_VEX_W_OPSIZE, /* 14939 */
  IC_VEX_W_OPSIZE, /* 14940 */
  IC_VEX_W_OPSIZE, /* 14941 */
  IC_VEX_W_OPSIZE, /* 14942 */
  IC_VEX_W_OPSIZE, /* 14943 */
  IC_VEX, /* 14944 */
  IC_VEX, /* 14945 */
  IC_VEX_XS, /* 14946 */
  IC_VEX_XS, /* 14947 */
  IC_VEX_XD, /* 14948 */
  IC_VEX_XD, /* 14949 */
  IC_VEX_XD, /* 14950 */
  IC_VEX_XD, /* 14951 */
  IC_VEX_W, /* 14952 */
  IC_VEX_W, /* 14953 */
  IC_VEX_W_XS, /* 14954 */
  IC_VEX_W_XS, /* 14955 */
  IC_VEX_W_XD, /* 14956 */
  IC_VEX_W_XD, /* 14957 */
  IC_VEX_W_XD, /* 14958 */
  IC_VEX_W_XD, /* 14959 */
  IC_VEX_OPSIZE, /* 14960 */
  IC_VEX_OPSIZE, /* 14961 */
  IC_VEX_OPSIZE, /* 14962 */
  IC_VEX_OPSIZE, /* 14963 */
  IC_VEX_OPSIZE, /* 14964 */
  IC_VEX_OPSIZE, /* 14965 */
  IC_VEX_OPSIZE, /* 14966 */
  IC_VEX_OPSIZE, /* 14967 */
  IC_VEX_W_OPSIZE, /* 14968 */
  IC_VEX_W_OPSIZE, /* 14969 */
  IC_VEX_W_OPSIZE, /* 14970 */
  IC_VEX_W_OPSIZE, /* 14971 */
  IC_VEX_W_OPSIZE, /* 14972 */
  IC_VEX_W_OPSIZE, /* 14973 */
  IC_VEX_W_OPSIZE, /* 14974 */
  IC_VEX_W_OPSIZE, /* 14975 */
  IC_VEX_L, /* 14976 */
  IC_VEX_L, /* 14977 */
  IC_VEX_L_XS, /* 14978 */
  IC_VEX_L_XS, /* 14979 */
  IC_VEX_L_XD, /* 14980 */
  IC_VEX_L_XD, /* 14981 */
  IC_VEX_L_XD, /* 14982 */
  IC_VEX_L_XD, /* 14983 */
  IC_VEX_L_W, /* 14984 */
  IC_VEX_L_W, /* 14985 */
  IC_VEX_L_W_XS, /* 14986 */
  IC_VEX_L_W_XS, /* 14987 */
  IC_VEX_L_W_XD, /* 14988 */
  IC_VEX_L_W_XD, /* 14989 */
  IC_VEX_L_W_XD, /* 14990 */
  IC_VEX_L_W_XD, /* 14991 */
  IC_VEX_L_OPSIZE, /* 14992 */
  IC_VEX_L_OPSIZE, /* 14993 */
  IC_VEX_L_OPSIZE, /* 14994 */
  IC_VEX_L_OPSIZE, /* 14995 */
  IC_VEX_L_OPSIZE, /* 14996 */
  IC_VEX_L_OPSIZE, /* 14997 */
  IC_VEX_L_OPSIZE, /* 14998 */
  IC_VEX_L_OPSIZE, /* 14999 */
  IC_VEX_L_W_OPSIZE, /* 15000 */
  IC_VEX_L_W_OPSIZE, /* 15001 */
  IC_VEX_L_W_OPSIZE, /* 15002 */
  IC_VEX_L_W_OPSIZE, /* 15003 */
  IC_VEX_L_W_OPSIZE, /* 15004 */
  IC_VEX_L_W_OPSIZE, /* 15005 */
  IC_VEX_L_W_OPSIZE, /* 15006 */
  IC_VEX_L_W_OPSIZE, /* 15007 */
  IC_VEX_L, /* 15008 */
  IC_VEX_L, /* 15009 */
  IC_VEX_L_XS, /* 15010 */
  IC_VEX_L_XS, /* 15011 */
  IC_VEX_L_XD, /* 15012 */
  IC_VEX_L_XD, /* 15013 */
  IC_VEX_L_XD, /* 15014 */
  IC_VEX_L_XD, /* 15015 */
  IC_VEX_L_W, /* 15016 */
  IC_VEX_L_W, /* 15017 */
  IC_VEX_L_W_XS, /* 15018 */
  IC_VEX_L_W_XS, /* 15019 */
  IC_VEX_L_W_XD, /* 15020 */
  IC_VEX_L_W_XD, /* 15021 */
  IC_VEX_L_W_XD, /* 15022 */
  IC_VEX_L_W_XD, /* 15023 */
  IC_VEX_L_OPSIZE, /* 15024 */
  IC_VEX_L_OPSIZE, /* 15025 */
  IC_VEX_L_OPSIZE, /* 15026 */
  IC_VEX_L_OPSIZE, /* 15027 */
  IC_VEX_L_OPSIZE, /* 15028 */
  IC_VEX_L_OPSIZE, /* 15029 */
  IC_VEX_L_OPSIZE, /* 15030 */
  IC_VEX_L_OPSIZE, /* 15031 */
  IC_VEX_L_W_OPSIZE, /* 15032 */
  IC_VEX_L_W_OPSIZE, /* 15033 */
  IC_VEX_L_W_OPSIZE, /* 15034 */
  IC_VEX_L_W_OPSIZE, /* 15035 */
  IC_VEX_L_W_OPSIZE, /* 15036 */
  IC_VEX_L_W_OPSIZE, /* 15037 */
  IC_VEX_L_W_OPSIZE, /* 15038 */
  IC_VEX_L_W_OPSIZE, /* 15039 */
  IC_VEX_L, /* 15040 */
  IC_VEX_L, /* 15041 */
  IC_VEX_L_XS, /* 15042 */
  IC_VEX_L_XS, /* 15043 */
  IC_VEX_L_XD, /* 15044 */
  IC_VEX_L_XD, /* 15045 */
  IC_VEX_L_XD, /* 15046 */
  IC_VEX_L_XD, /* 15047 */
  IC_VEX_L_W, /* 15048 */
  IC_VEX_L_W, /* 15049 */
  IC_VEX_L_W_XS, /* 15050 */
  IC_VEX_L_W_XS, /* 15051 */
  IC_VEX_L_W_XD, /* 15052 */
  IC_VEX_L_W_XD, /* 15053 */
  IC_VEX_L_W_XD, /* 15054 */
  IC_VEX_L_W_XD, /* 15055 */
  IC_VEX_L_OPSIZE, /* 15056 */
  IC_VEX_L_OPSIZE, /* 15057 */
  IC_VEX_L_OPSIZE, /* 15058 */
  IC_VEX_L_OPSIZE, /* 15059 */
  IC_VEX_L_OPSIZE, /* 15060 */
  IC_VEX_L_OPSIZE, /* 15061 */
  IC_VEX_L_OPSIZE, /* 15062 */
  IC_VEX_L_OPSIZE, /* 15063 */
  IC_VEX_L_W_OPSIZE, /* 15064 */
  IC_VEX_L_W_OPSIZE, /* 15065 */
  IC_VEX_L_W_OPSIZE, /* 15066 */
  IC_VEX_L_W_OPSIZE, /* 15067 */
  IC_VEX_L_W_OPSIZE, /* 15068 */
  IC_VEX_L_W_OPSIZE, /* 15069 */
  IC_VEX_L_W_OPSIZE, /* 15070 */
  IC_VEX_L_W_OPSIZE, /* 15071 */
  IC_VEX_L, /* 15072 */
  IC_VEX_L, /* 15073 */
  IC_VEX_L_XS, /* 15074 */
  IC_VEX_L_XS, /* 15075 */
  IC_VEX_L_XD, /* 15076 */
  IC_VEX_L_XD, /* 15077 */
  IC_VEX_L_XD, /* 15078 */
  IC_VEX_L_XD, /* 15079 */
  IC_VEX_L_W, /* 15080 */
  IC_VEX_L_W, /* 15081 */
  IC_VEX_L_W_XS, /* 15082 */
  IC_VEX_L_W_XS, /* 15083 */
  IC_VEX_L_W_XD, /* 15084 */
  IC_VEX_L_W_XD, /* 15085 */
  IC_VEX_L_W_XD, /* 15086 */
  IC_VEX_L_W_XD, /* 15087 */
  IC_VEX_L_OPSIZE, /* 15088 */
  IC_VEX_L_OPSIZE, /* 15089 */
  IC_VEX_L_OPSIZE, /* 15090 */
  IC_VEX_L_OPSIZE, /* 15091 */
  IC_VEX_L_OPSIZE, /* 15092 */
  IC_VEX_L_OPSIZE, /* 15093 */
  IC_VEX_L_OPSIZE, /* 15094 */
  IC_VEX_L_OPSIZE, /* 15095 */
  IC_VEX_L_W_OPSIZE, /* 15096 */
  IC_VEX_L_W_OPSIZE, /* 15097 */
  IC_VEX_L_W_OPSIZE, /* 15098 */
  IC_VEX_L_W_OPSIZE, /* 15099 */
  IC_VEX_L_W_OPSIZE, /* 15100 */
  IC_VEX_L_W_OPSIZE, /* 15101 */
  IC_VEX_L_W_OPSIZE, /* 15102 */
  IC_VEX_L_W_OPSIZE, /* 15103 */
  IC_EVEX_L_KZ_B, /* 15104 */
  IC_EVEX_L_KZ_B, /* 15105 */
  IC_EVEX_L_XS_KZ_B, /* 15106 */
  IC_EVEX_L_XS_KZ_B, /* 15107 */
  IC_EVEX_L_XD_KZ_B, /* 15108 */
  IC_EVEX_L_XD_KZ_B, /* 15109 */
  IC_EVEX_L_XD_KZ_B, /* 15110 */
  IC_EVEX_L_XD_KZ_B, /* 15111 */
  IC_EVEX_L_W_KZ_B, /* 15112 */
  IC_EVEX_L_W_KZ_B, /* 15113 */
  IC_EVEX_L_W_XS_KZ_B, /* 15114 */
  IC_EVEX_L_W_XS_KZ_B, /* 15115 */
  IC_EVEX_L_W_XD_KZ_B, /* 15116 */
  IC_EVEX_L_W_XD_KZ_B, /* 15117 */
  IC_EVEX_L_W_XD_KZ_B, /* 15118 */
  IC_EVEX_L_W_XD_KZ_B, /* 15119 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15120 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15121 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15122 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15123 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15124 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15125 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15126 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15127 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15128 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15129 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15130 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15131 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15132 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15133 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15134 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15135 */
  IC_EVEX_L_KZ_B, /* 15136 */
  IC_EVEX_L_KZ_B, /* 15137 */
  IC_EVEX_L_XS_KZ_B, /* 15138 */
  IC_EVEX_L_XS_KZ_B, /* 15139 */
  IC_EVEX_L_XD_KZ_B, /* 15140 */
  IC_EVEX_L_XD_KZ_B, /* 15141 */
  IC_EVEX_L_XD_KZ_B, /* 15142 */
  IC_EVEX_L_XD_KZ_B, /* 15143 */
  IC_EVEX_L_W_KZ_B, /* 15144 */
  IC_EVEX_L_W_KZ_B, /* 15145 */
  IC_EVEX_L_W_XS_KZ_B, /* 15146 */
  IC_EVEX_L_W_XS_KZ_B, /* 15147 */
  IC_EVEX_L_W_XD_KZ_B, /* 15148 */
  IC_EVEX_L_W_XD_KZ_B, /* 15149 */
  IC_EVEX_L_W_XD_KZ_B, /* 15150 */
  IC_EVEX_L_W_XD_KZ_B, /* 15151 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15152 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15153 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15154 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15155 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15156 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15157 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15158 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15159 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15160 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15161 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15162 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15163 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15164 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15165 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15166 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15167 */
  IC_EVEX_L_KZ_B, /* 15168 */
  IC_EVEX_L_KZ_B, /* 15169 */
  IC_EVEX_L_XS_KZ_B, /* 15170 */
  IC_EVEX_L_XS_KZ_B, /* 15171 */
  IC_EVEX_L_XD_KZ_B, /* 15172 */
  IC_EVEX_L_XD_KZ_B, /* 15173 */
  IC_EVEX_L_XD_KZ_B, /* 15174 */
  IC_EVEX_L_XD_KZ_B, /* 15175 */
  IC_EVEX_L_W_KZ_B, /* 15176 */
  IC_EVEX_L_W_KZ_B, /* 15177 */
  IC_EVEX_L_W_XS_KZ_B, /* 15178 */
  IC_EVEX_L_W_XS_KZ_B, /* 15179 */
  IC_EVEX_L_W_XD_KZ_B, /* 15180 */
  IC_EVEX_L_W_XD_KZ_B, /* 15181 */
  IC_EVEX_L_W_XD_KZ_B, /* 15182 */
  IC_EVEX_L_W_XD_KZ_B, /* 15183 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15184 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15185 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15186 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15187 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15188 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15189 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15190 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15191 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15192 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15193 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15194 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15195 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15196 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15197 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15198 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15199 */
  IC_EVEX_L_KZ_B, /* 15200 */
  IC_EVEX_L_KZ_B, /* 15201 */
  IC_EVEX_L_XS_KZ_B, /* 15202 */
  IC_EVEX_L_XS_KZ_B, /* 15203 */
  IC_EVEX_L_XD_KZ_B, /* 15204 */
  IC_EVEX_L_XD_KZ_B, /* 15205 */
  IC_EVEX_L_XD_KZ_B, /* 15206 */
  IC_EVEX_L_XD_KZ_B, /* 15207 */
  IC_EVEX_L_W_KZ_B, /* 15208 */
  IC_EVEX_L_W_KZ_B, /* 15209 */
  IC_EVEX_L_W_XS_KZ_B, /* 15210 */
  IC_EVEX_L_W_XS_KZ_B, /* 15211 */
  IC_EVEX_L_W_XD_KZ_B, /* 15212 */
  IC_EVEX_L_W_XD_KZ_B, /* 15213 */
  IC_EVEX_L_W_XD_KZ_B, /* 15214 */
  IC_EVEX_L_W_XD_KZ_B, /* 15215 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15216 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15217 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15218 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15219 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15220 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15221 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15222 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15223 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15224 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15225 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15226 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15227 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15228 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15229 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15230 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15231 */
  IC_EVEX_L_KZ_B, /* 15232 */
  IC_EVEX_L_KZ_B, /* 15233 */
  IC_EVEX_L_XS_KZ_B, /* 15234 */
  IC_EVEX_L_XS_KZ_B, /* 15235 */
  IC_EVEX_L_XD_KZ_B, /* 15236 */
  IC_EVEX_L_XD_KZ_B, /* 15237 */
  IC_EVEX_L_XD_KZ_B, /* 15238 */
  IC_EVEX_L_XD_KZ_B, /* 15239 */
  IC_EVEX_L_W_KZ_B, /* 15240 */
  IC_EVEX_L_W_KZ_B, /* 15241 */
  IC_EVEX_L_W_XS_KZ_B, /* 15242 */
  IC_EVEX_L_W_XS_KZ_B, /* 15243 */
  IC_EVEX_L_W_XD_KZ_B, /* 15244 */
  IC_EVEX_L_W_XD_KZ_B, /* 15245 */
  IC_EVEX_L_W_XD_KZ_B, /* 15246 */
  IC_EVEX_L_W_XD_KZ_B, /* 15247 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15248 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15249 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15250 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15251 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15252 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15253 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15254 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15255 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15256 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15257 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15258 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15259 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15260 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15261 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15262 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15263 */
  IC_EVEX_L_KZ_B, /* 15264 */
  IC_EVEX_L_KZ_B, /* 15265 */
  IC_EVEX_L_XS_KZ_B, /* 15266 */
  IC_EVEX_L_XS_KZ_B, /* 15267 */
  IC_EVEX_L_XD_KZ_B, /* 15268 */
  IC_EVEX_L_XD_KZ_B, /* 15269 */
  IC_EVEX_L_XD_KZ_B, /* 15270 */
  IC_EVEX_L_XD_KZ_B, /* 15271 */
  IC_EVEX_L_W_KZ_B, /* 15272 */
  IC_EVEX_L_W_KZ_B, /* 15273 */
  IC_EVEX_L_W_XS_KZ_B, /* 15274 */
  IC_EVEX_L_W_XS_KZ_B, /* 15275 */
  IC_EVEX_L_W_XD_KZ_B, /* 15276 */
  IC_EVEX_L_W_XD_KZ_B, /* 15277 */
  IC_EVEX_L_W_XD_KZ_B, /* 15278 */
  IC_EVEX_L_W_XD_KZ_B, /* 15279 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15280 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15281 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15282 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15283 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15284 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15285 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15286 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15287 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15288 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15289 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15290 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15291 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15292 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15293 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15294 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15295 */
  IC_EVEX_L_KZ_B, /* 15296 */
  IC_EVEX_L_KZ_B, /* 15297 */
  IC_EVEX_L_XS_KZ_B, /* 15298 */
  IC_EVEX_L_XS_KZ_B, /* 15299 */
  IC_EVEX_L_XD_KZ_B, /* 15300 */
  IC_EVEX_L_XD_KZ_B, /* 15301 */
  IC_EVEX_L_XD_KZ_B, /* 15302 */
  IC_EVEX_L_XD_KZ_B, /* 15303 */
  IC_EVEX_L_W_KZ_B, /* 15304 */
  IC_EVEX_L_W_KZ_B, /* 15305 */
  IC_EVEX_L_W_XS_KZ_B, /* 15306 */
  IC_EVEX_L_W_XS_KZ_B, /* 15307 */
  IC_EVEX_L_W_XD_KZ_B, /* 15308 */
  IC_EVEX_L_W_XD_KZ_B, /* 15309 */
  IC_EVEX_L_W_XD_KZ_B, /* 15310 */
  IC_EVEX_L_W_XD_KZ_B, /* 15311 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15312 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15313 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15314 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15315 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15316 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15317 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15318 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15319 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15320 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15321 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15322 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15323 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15324 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15325 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15326 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15327 */
  IC_EVEX_L_KZ_B, /* 15328 */
  IC_EVEX_L_KZ_B, /* 15329 */
  IC_EVEX_L_XS_KZ_B, /* 15330 */
  IC_EVEX_L_XS_KZ_B, /* 15331 */
  IC_EVEX_L_XD_KZ_B, /* 15332 */
  IC_EVEX_L_XD_KZ_B, /* 15333 */
  IC_EVEX_L_XD_KZ_B, /* 15334 */
  IC_EVEX_L_XD_KZ_B, /* 15335 */
  IC_EVEX_L_W_KZ_B, /* 15336 */
  IC_EVEX_L_W_KZ_B, /* 15337 */
  IC_EVEX_L_W_XS_KZ_B, /* 15338 */
  IC_EVEX_L_W_XS_KZ_B, /* 15339 */
  IC_EVEX_L_W_XD_KZ_B, /* 15340 */
  IC_EVEX_L_W_XD_KZ_B, /* 15341 */
  IC_EVEX_L_W_XD_KZ_B, /* 15342 */
  IC_EVEX_L_W_XD_KZ_B, /* 15343 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15344 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15345 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15346 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15347 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15348 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15349 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15350 */
  IC_EVEX_L_OPSIZE_KZ_B, /* 15351 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15352 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15353 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15354 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15355 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15356 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15357 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15358 */
  IC_EVEX_L_W_OPSIZE_KZ_B, /* 15359 */
  IC, /* 15360 */
  IC_64BIT, /* 15361 */
  IC_XS, /* 15362 */
  IC_64BIT_XS, /* 15363 */
  IC_XD, /* 15364 */
  IC_64BIT_XD, /* 15365 */
  IC_XS, /* 15366 */
  IC_64BIT_XS, /* 15367 */
  IC, /* 15368 */
  IC_64BIT_REXW, /* 15369 */
  IC_XS, /* 15370 */
  IC_64BIT_REXW_XS, /* 15371 */
  IC_XD, /* 15372 */
  IC_64BIT_REXW_XD, /* 15373 */
  IC_XS, /* 15374 */
  IC_64BIT_REXW_XS, /* 15375 */
  IC_OPSIZE, /* 15376 */
  IC_64BIT_OPSIZE, /* 15377 */
  IC_XS_OPSIZE, /* 15378 */
  IC_64BIT_XS_OPSIZE, /* 15379 */
  IC_XD_OPSIZE, /* 15380 */
  IC_64BIT_XD_OPSIZE, /* 15381 */
  IC_XS_OPSIZE, /* 15382 */
  IC_64BIT_XD_OPSIZE, /* 15383 */
  IC_OPSIZE, /* 15384 */
  IC_64BIT_REXW_OPSIZE, /* 15385 */
  IC_XS_OPSIZE, /* 15386 */
  IC_64BIT_REXW_XS, /* 15387 */
  IC_XD_OPSIZE, /* 15388 */
  IC_64BIT_REXW_XD, /* 15389 */
  IC_XS_OPSIZE, /* 15390 */
  IC_64BIT_REXW_XS, /* 15391 */
  IC_ADSIZE, /* 15392 */
  IC_64BIT_ADSIZE, /* 15393 */
  IC_XS, /* 15394 */
  IC_64BIT_XS, /* 15395 */
  IC_XD, /* 15396 */
  IC_64BIT_XD, /* 15397 */
  IC_XS, /* 15398 */
  IC_64BIT_XS, /* 15399 */
  IC_ADSIZE, /* 15400 */
  IC_64BIT_REXW_ADSIZE, /* 15401 */
  IC_XS, /* 15402 */
  IC_64BIT_REXW_XS, /* 15403 */
  IC_XD, /* 15404 */
  IC_64BIT_REXW_XD, /* 15405 */
  IC_XS, /* 15406 */
  IC_64BIT_REXW_XS, /* 15407 */
  IC_OPSIZE_ADSIZE, /* 15408 */
  IC_64BIT_OPSIZE_ADSIZE, /* 15409 */
  IC_XS_OPSIZE, /* 15410 */
  IC_64BIT_XS_OPSIZE, /* 15411 */
  IC_XD_OPSIZE, /* 15412 */
  IC_64BIT_XD_OPSIZE, /* 15413 */
  IC_XS_OPSIZE, /* 15414 */
  IC_64BIT_XD_OPSIZE, /* 15415 */
  IC_OPSIZE_ADSIZE, /* 15416 */
  IC_64BIT_REXW_OPSIZE, /* 15417 */
  IC_XS_OPSIZE, /* 15418 */
  IC_64BIT_REXW_XS, /* 15419 */
  IC_XD_OPSIZE, /* 15420 */
  IC_64BIT_REXW_XD, /* 15421 */
  IC_XS_OPSIZE, /* 15422 */
  IC_64BIT_REXW_XS, /* 15423 */
  IC_VEX, /* 15424 */
  IC_VEX, /* 15425 */
  IC_VEX_XS, /* 15426 */
  IC_VEX_XS, /* 15427 */
  IC_VEX_XD, /* 15428 */
  IC_VEX_XD, /* 15429 */
  IC_VEX_XD, /* 15430 */
  IC_VEX_XD, /* 15431 */
  IC_VEX_W, /* 15432 */
  IC_VEX_W, /* 15433 */
  IC_VEX_W_XS, /* 15434 */
  IC_VEX_W_XS, /* 15435 */
  IC_VEX_W_XD, /* 15436 */
  IC_VEX_W_XD, /* 15437 */
  IC_VEX_W_XD, /* 15438 */
  IC_VEX_W_XD, /* 15439 */
  IC_VEX_OPSIZE, /* 15440 */
  IC_VEX_OPSIZE, /* 15441 */
  IC_VEX_OPSIZE, /* 15442 */
  IC_VEX_OPSIZE, /* 15443 */
  IC_VEX_OPSIZE, /* 15444 */
  IC_VEX_OPSIZE, /* 15445 */
  IC_VEX_OPSIZE, /* 15446 */
  IC_VEX_OPSIZE, /* 15447 */
  IC_VEX_W_OPSIZE, /* 15448 */
  IC_VEX_W_OPSIZE, /* 15449 */
  IC_VEX_W_OPSIZE, /* 15450 */
  IC_VEX_W_OPSIZE, /* 15451 */
  IC_VEX_W_OPSIZE, /* 15452 */
  IC_VEX_W_OPSIZE, /* 15453 */
  IC_VEX_W_OPSIZE, /* 15454 */
  IC_VEX_W_OPSIZE, /* 15455 */
  IC_VEX, /* 15456 */
  IC_VEX, /* 15457 */
  IC_VEX_XS, /* 15458 */
  IC_VEX_XS, /* 15459 */
  IC_VEX_XD, /* 15460 */
  IC_VEX_XD, /* 15461 */
  IC_VEX_XD, /* 15462 */
  IC_VEX_XD, /* 15463 */
  IC_VEX_W, /* 15464 */
  IC_VEX_W, /* 15465 */
  IC_VEX_W_XS, /* 15466 */
  IC_VEX_W_XS, /* 15467 */
  IC_VEX_W_XD, /* 15468 */
  IC_VEX_W_XD, /* 15469 */
  IC_VEX_W_XD, /* 15470 */
  IC_VEX_W_XD, /* 15471 */
  IC_VEX_OPSIZE, /* 15472 */
  IC_VEX_OPSIZE, /* 15473 */
  IC_VEX_OPSIZE, /* 15474 */
  IC_VEX_OPSIZE, /* 15475 */
  IC_VEX_OPSIZE, /* 15476 */
  IC_VEX_OPSIZE, /* 15477 */
  IC_VEX_OPSIZE, /* 15478 */
  IC_VEX_OPSIZE, /* 15479 */
  IC_VEX_W_OPSIZE, /* 15480 */
  IC_VEX_W_OPSIZE, /* 15481 */
  IC_VEX_W_OPSIZE, /* 15482 */
  IC_VEX_W_OPSIZE, /* 15483 */
  IC_VEX_W_OPSIZE, /* 15484 */
  IC_VEX_W_OPSIZE, /* 15485 */
  IC_VEX_W_OPSIZE, /* 15486 */
  IC_VEX_W_OPSIZE, /* 15487 */
  IC_VEX_L, /* 15488 */
  IC_VEX_L, /* 15489 */
  IC_VEX_L_XS, /* 15490 */
  IC_VEX_L_XS, /* 15491 */
  IC_VEX_L_XD, /* 15492 */
  IC_VEX_L_XD, /* 15493 */
  IC_VEX_L_XD, /* 15494 */
  IC_VEX_L_XD, /* 15495 */
  IC_VEX_L_W, /* 15496 */
  IC_VEX_L_W, /* 15497 */
  IC_VEX_L_W_XS, /* 15498 */
  IC_VEX_L_W_XS, /* 15499 */
  IC_VEX_L_W_XD, /* 15500 */
  IC_VEX_L_W_XD, /* 15501 */
  IC_VEX_L_W_XD, /* 15502 */
  IC_VEX_L_W_XD, /* 15503 */
  IC_VEX_L_OPSIZE, /* 15504 */
  IC_VEX_L_OPSIZE, /* 15505 */
  IC_VEX_L_OPSIZE, /* 15506 */
  IC_VEX_L_OPSIZE, /* 15507 */
  IC_VEX_L_OPSIZE, /* 15508 */
  IC_VEX_L_OPSIZE, /* 15509 */
  IC_VEX_L_OPSIZE, /* 15510 */
  IC_VEX_L_OPSIZE, /* 15511 */
  IC_VEX_L_W_OPSIZE, /* 15512 */
  IC_VEX_L_W_OPSIZE, /* 15513 */
  IC_VEX_L_W_OPSIZE, /* 15514 */
  IC_VEX_L_W_OPSIZE, /* 15515 */
  IC_VEX_L_W_OPSIZE, /* 15516 */
  IC_VEX_L_W_OPSIZE, /* 15517 */
  IC_VEX_L_W_OPSIZE, /* 15518 */
  IC_VEX_L_W_OPSIZE, /* 15519 */
  IC_VEX_L, /* 15520 */
  IC_VEX_L, /* 15521 */
  IC_VEX_L_XS, /* 15522 */
  IC_VEX_L_XS, /* 15523 */
  IC_VEX_L_XD, /* 15524 */
  IC_VEX_L_XD, /* 15525 */
  IC_VEX_L_XD, /* 15526 */
  IC_VEX_L_XD, /* 15527 */
  IC_VEX_L_W, /* 15528 */
  IC_VEX_L_W, /* 15529 */
  IC_VEX_L_W_XS, /* 15530 */
  IC_VEX_L_W_XS, /* 15531 */
  IC_VEX_L_W_XD, /* 15532 */
  IC_VEX_L_W_XD, /* 15533 */
  IC_VEX_L_W_XD, /* 15534 */
  IC_VEX_L_W_XD, /* 15535 */
  IC_VEX_L_OPSIZE, /* 15536 */
  IC_VEX_L_OPSIZE, /* 15537 */
  IC_VEX_L_OPSIZE, /* 15538 */
  IC_VEX_L_OPSIZE, /* 15539 */
  IC_VEX_L_OPSIZE, /* 15540 */
  IC_VEX_L_OPSIZE, /* 15541 */
  IC_VEX_L_OPSIZE, /* 15542 */
  IC_VEX_L_OPSIZE, /* 15543 */
  IC_VEX_L_W_OPSIZE, /* 15544 */
  IC_VEX_L_W_OPSIZE, /* 15545 */
  IC_VEX_L_W_OPSIZE, /* 15546 */
  IC_VEX_L_W_OPSIZE, /* 15547 */
  IC_VEX_L_W_OPSIZE, /* 15548 */
  IC_VEX_L_W_OPSIZE, /* 15549 */
  IC_VEX_L_W_OPSIZE, /* 15550 */
  IC_VEX_L_W_OPSIZE, /* 15551 */
  IC_VEX_L, /* 15552 */
  IC_VEX_L, /* 15553 */
  IC_VEX_L_XS, /* 15554 */
  IC_VEX_L_XS, /* 15555 */
  IC_VEX_L_XD, /* 15556 */
  IC_VEX_L_XD, /* 15557 */
  IC_VEX_L_XD, /* 15558 */
  IC_VEX_L_XD, /* 15559 */
  IC_VEX_L_W, /* 15560 */
  IC_VEX_L_W, /* 15561 */
  IC_VEX_L_W_XS, /* 15562 */
  IC_VEX_L_W_XS, /* 15563 */
  IC_VEX_L_W_XD, /* 15564 */
  IC_VEX_L_W_XD, /* 15565 */
  IC_VEX_L_W_XD, /* 15566 */
  IC_VEX_L_W_XD, /* 15567 */
  IC_VEX_L_OPSIZE, /* 15568 */
  IC_VEX_L_OPSIZE, /* 15569 */
  IC_VEX_L_OPSIZE, /* 15570 */
  IC_VEX_L_OPSIZE, /* 15571 */
  IC_VEX_L_OPSIZE, /* 15572 */
  IC_VEX_L_OPSIZE, /* 15573 */
  IC_VEX_L_OPSIZE, /* 15574 */
  IC_VEX_L_OPSIZE, /* 15575 */
  IC_VEX_L_W_OPSIZE, /* 15576 */
  IC_VEX_L_W_OPSIZE, /* 15577 */
  IC_VEX_L_W_OPSIZE, /* 15578 */
  IC_VEX_L_W_OPSIZE, /* 15579 */
  IC_VEX_L_W_OPSIZE, /* 15580 */
  IC_VEX_L_W_OPSIZE, /* 15581 */
  IC_VEX_L_W_OPSIZE, /* 15582 */
  IC_VEX_L_W_OPSIZE, /* 15583 */
  IC_VEX_L, /* 15584 */
  IC_VEX_L, /* 15585 */
  IC_VEX_L_XS, /* 15586 */
  IC_VEX_L_XS, /* 15587 */
  IC_VEX_L_XD, /* 15588 */
  IC_VEX_L_XD, /* 15589 */
  IC_VEX_L_XD, /* 15590 */
  IC_VEX_L_XD, /* 15591 */
  IC_VEX_L_W, /* 15592 */
  IC_VEX_L_W, /* 15593 */
  IC_VEX_L_W_XS, /* 15594 */
  IC_VEX_L_W_XS, /* 15595 */
  IC_VEX_L_W_XD, /* 15596 */
  IC_VEX_L_W_XD, /* 15597 */
  IC_VEX_L_W_XD, /* 15598 */
  IC_VEX_L_W_XD, /* 15599 */
  IC_VEX_L_OPSIZE, /* 15600 */
  IC_VEX_L_OPSIZE, /* 15601 */
  IC_VEX_L_OPSIZE, /* 15602 */
  IC_VEX_L_OPSIZE, /* 15603 */
  IC_VEX_L_OPSIZE, /* 15604 */
  IC_VEX_L_OPSIZE, /* 15605 */
  IC_VEX_L_OPSIZE, /* 15606 */
  IC_VEX_L_OPSIZE, /* 15607 */
  IC_VEX_L_W_OPSIZE, /* 15608 */
  IC_VEX_L_W_OPSIZE, /* 15609 */
  IC_VEX_L_W_OPSIZE, /* 15610 */
  IC_VEX_L_W_OPSIZE, /* 15611 */
  IC_VEX_L_W_OPSIZE, /* 15612 */
  IC_VEX_L_W_OPSIZE, /* 15613 */
  IC_VEX_L_W_OPSIZE, /* 15614 */
  IC_VEX_L_W_OPSIZE, /* 15615 */
  IC_EVEX_L2_KZ_B, /* 15616 */
  IC_EVEX_L2_KZ_B, /* 15617 */
  IC_EVEX_L2_XS_KZ_B, /* 15618 */
  IC_EVEX_L2_XS_KZ_B, /* 15619 */
  IC_EVEX_L2_XD_KZ_B, /* 15620 */
  IC_EVEX_L2_XD_KZ_B, /* 15621 */
  IC_EVEX_L2_XD_KZ_B, /* 15622 */
  IC_EVEX_L2_XD_KZ_B, /* 15623 */
  IC_EVEX_L2_W_KZ_B, /* 15624 */
  IC_EVEX_L2_W_KZ_B, /* 15625 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15626 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15627 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15628 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15629 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15630 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15631 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15632 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15633 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15634 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15635 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15636 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15637 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15638 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15639 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15640 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15641 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15642 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15643 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15644 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15645 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15646 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15647 */
  IC_EVEX_L2_KZ_B, /* 15648 */
  IC_EVEX_L2_KZ_B, /* 15649 */
  IC_EVEX_L2_XS_KZ_B, /* 15650 */
  IC_EVEX_L2_XS_KZ_B, /* 15651 */
  IC_EVEX_L2_XD_KZ_B, /* 15652 */
  IC_EVEX_L2_XD_KZ_B, /* 15653 */
  IC_EVEX_L2_XD_KZ_B, /* 15654 */
  IC_EVEX_L2_XD_KZ_B, /* 15655 */
  IC_EVEX_L2_W_KZ_B, /* 15656 */
  IC_EVEX_L2_W_KZ_B, /* 15657 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15658 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15659 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15660 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15661 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15662 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15663 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15664 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15665 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15666 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15667 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15668 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15669 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15670 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15671 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15672 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15673 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15674 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15675 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15676 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15677 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15678 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15679 */
  IC_EVEX_L2_KZ_B, /* 15680 */
  IC_EVEX_L2_KZ_B, /* 15681 */
  IC_EVEX_L2_XS_KZ_B, /* 15682 */
  IC_EVEX_L2_XS_KZ_B, /* 15683 */
  IC_EVEX_L2_XD_KZ_B, /* 15684 */
  IC_EVEX_L2_XD_KZ_B, /* 15685 */
  IC_EVEX_L2_XD_KZ_B, /* 15686 */
  IC_EVEX_L2_XD_KZ_B, /* 15687 */
  IC_EVEX_L2_W_KZ_B, /* 15688 */
  IC_EVEX_L2_W_KZ_B, /* 15689 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15690 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15691 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15692 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15693 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15694 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15695 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15696 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15697 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15698 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15699 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15700 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15701 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15702 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15703 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15704 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15705 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15706 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15707 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15708 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15709 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15710 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15711 */
  IC_EVEX_L2_KZ_B, /* 15712 */
  IC_EVEX_L2_KZ_B, /* 15713 */
  IC_EVEX_L2_XS_KZ_B, /* 15714 */
  IC_EVEX_L2_XS_KZ_B, /* 15715 */
  IC_EVEX_L2_XD_KZ_B, /* 15716 */
  IC_EVEX_L2_XD_KZ_B, /* 15717 */
  IC_EVEX_L2_XD_KZ_B, /* 15718 */
  IC_EVEX_L2_XD_KZ_B, /* 15719 */
  IC_EVEX_L2_W_KZ_B, /* 15720 */
  IC_EVEX_L2_W_KZ_B, /* 15721 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15722 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15723 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15724 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15725 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15726 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15727 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15728 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15729 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15730 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15731 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15732 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15733 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15734 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15735 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15736 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15737 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15738 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15739 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15740 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15741 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15742 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15743 */
  IC_EVEX_L2_KZ_B, /* 15744 */
  IC_EVEX_L2_KZ_B, /* 15745 */
  IC_EVEX_L2_XS_KZ_B, /* 15746 */
  IC_EVEX_L2_XS_KZ_B, /* 15747 */
  IC_EVEX_L2_XD_KZ_B, /* 15748 */
  IC_EVEX_L2_XD_KZ_B, /* 15749 */
  IC_EVEX_L2_XD_KZ_B, /* 15750 */
  IC_EVEX_L2_XD_KZ_B, /* 15751 */
  IC_EVEX_L2_W_KZ_B, /* 15752 */
  IC_EVEX_L2_W_KZ_B, /* 15753 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15754 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15755 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15756 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15757 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15758 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15759 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15760 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15761 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15762 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15763 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15764 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15765 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15766 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15767 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15768 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15769 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15770 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15771 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15772 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15773 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15774 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15775 */
  IC_EVEX_L2_KZ_B, /* 15776 */
  IC_EVEX_L2_KZ_B, /* 15777 */
  IC_EVEX_L2_XS_KZ_B, /* 15778 */
  IC_EVEX_L2_XS_KZ_B, /* 15779 */
  IC_EVEX_L2_XD_KZ_B, /* 15780 */
  IC_EVEX_L2_XD_KZ_B, /* 15781 */
  IC_EVEX_L2_XD_KZ_B, /* 15782 */
  IC_EVEX_L2_XD_KZ_B, /* 15783 */
  IC_EVEX_L2_W_KZ_B, /* 15784 */
  IC_EVEX_L2_W_KZ_B, /* 15785 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15786 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15787 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15788 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15789 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15790 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15791 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15792 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15793 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15794 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15795 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15796 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15797 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15798 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15799 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15800 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15801 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15802 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15803 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15804 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15805 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15806 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15807 */
  IC_EVEX_L2_KZ_B, /* 15808 */
  IC_EVEX_L2_KZ_B, /* 15809 */
  IC_EVEX_L2_XS_KZ_B, /* 15810 */
  IC_EVEX_L2_XS_KZ_B, /* 15811 */
  IC_EVEX_L2_XD_KZ_B, /* 15812 */
  IC_EVEX_L2_XD_KZ_B, /* 15813 */
  IC_EVEX_L2_XD_KZ_B, /* 15814 */
  IC_EVEX_L2_XD_KZ_B, /* 15815 */
  IC_EVEX_L2_W_KZ_B, /* 15816 */
  IC_EVEX_L2_W_KZ_B, /* 15817 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15818 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15819 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15820 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15821 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15822 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15823 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15824 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15825 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15826 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15827 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15828 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15829 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15830 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15831 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15832 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15833 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15834 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15835 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15836 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15837 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15838 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15839 */
  IC_EVEX_L2_KZ_B, /* 15840 */
  IC_EVEX_L2_KZ_B, /* 15841 */
  IC_EVEX_L2_XS_KZ_B, /* 15842 */
  IC_EVEX_L2_XS_KZ_B, /* 15843 */
  IC_EVEX_L2_XD_KZ_B, /* 15844 */
  IC_EVEX_L2_XD_KZ_B, /* 15845 */
  IC_EVEX_L2_XD_KZ_B, /* 15846 */
  IC_EVEX_L2_XD_KZ_B, /* 15847 */
  IC_EVEX_L2_W_KZ_B, /* 15848 */
  IC_EVEX_L2_W_KZ_B, /* 15849 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15850 */
  IC_EVEX_L2_W_XS_KZ_B, /* 15851 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15852 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15853 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15854 */
  IC_EVEX_L2_W_XD_KZ_B, /* 15855 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15856 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15857 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15858 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15859 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15860 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15861 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15862 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 15863 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15864 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15865 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15866 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15867 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15868 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15869 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15870 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 15871 */
  IC, /* 15872 */
  IC_64BIT, /* 15873 */
  IC_XS, /* 15874 */
  IC_64BIT_XS, /* 15875 */
  IC_XD, /* 15876 */
  IC_64BIT_XD, /* 15877 */
  IC_XS, /* 15878 */
  IC_64BIT_XS, /* 15879 */
  IC, /* 15880 */
  IC_64BIT_REXW, /* 15881 */
  IC_XS, /* 15882 */
  IC_64BIT_REXW_XS, /* 15883 */
  IC_XD, /* 15884 */
  IC_64BIT_REXW_XD, /* 15885 */
  IC_XS, /* 15886 */
  IC_64BIT_REXW_XS, /* 15887 */
  IC_OPSIZE, /* 15888 */
  IC_64BIT_OPSIZE, /* 15889 */
  IC_XS_OPSIZE, /* 15890 */
  IC_64BIT_XS_OPSIZE, /* 15891 */
  IC_XD_OPSIZE, /* 15892 */
  IC_64BIT_XD_OPSIZE, /* 15893 */
  IC_XS_OPSIZE, /* 15894 */
  IC_64BIT_XD_OPSIZE, /* 15895 */
  IC_OPSIZE, /* 15896 */
  IC_64BIT_REXW_OPSIZE, /* 15897 */
  IC_XS_OPSIZE, /* 15898 */
  IC_64BIT_REXW_XS, /* 15899 */
  IC_XD_OPSIZE, /* 15900 */
  IC_64BIT_REXW_XD, /* 15901 */
  IC_XS_OPSIZE, /* 15902 */
  IC_64BIT_REXW_XS, /* 15903 */
  IC_ADSIZE, /* 15904 */
  IC_64BIT_ADSIZE, /* 15905 */
  IC_XS, /* 15906 */
  IC_64BIT_XS, /* 15907 */
  IC_XD, /* 15908 */
  IC_64BIT_XD, /* 15909 */
  IC_XS, /* 15910 */
  IC_64BIT_XS, /* 15911 */
  IC_ADSIZE, /* 15912 */
  IC_64BIT_REXW_ADSIZE, /* 15913 */
  IC_XS, /* 15914 */
  IC_64BIT_REXW_XS, /* 15915 */
  IC_XD, /* 15916 */
  IC_64BIT_REXW_XD, /* 15917 */
  IC_XS, /* 15918 */
  IC_64BIT_REXW_XS, /* 15919 */
  IC_OPSIZE_ADSIZE, /* 15920 */
  IC_64BIT_OPSIZE_ADSIZE, /* 15921 */
  IC_XS_OPSIZE, /* 15922 */
  IC_64BIT_XS_OPSIZE, /* 15923 */
  IC_XD_OPSIZE, /* 15924 */
  IC_64BIT_XD_OPSIZE, /* 15925 */
  IC_XS_OPSIZE, /* 15926 */
  IC_64BIT_XD_OPSIZE, /* 15927 */
  IC_OPSIZE_ADSIZE, /* 15928 */
  IC_64BIT_REXW_OPSIZE, /* 15929 */
  IC_XS_OPSIZE, /* 15930 */
  IC_64BIT_REXW_XS, /* 15931 */
  IC_XD_OPSIZE, /* 15932 */
  IC_64BIT_REXW_XD, /* 15933 */
  IC_XS_OPSIZE, /* 15934 */
  IC_64BIT_REXW_XS, /* 15935 */
  IC_VEX, /* 15936 */
  IC_VEX, /* 15937 */
  IC_VEX_XS, /* 15938 */
  IC_VEX_XS, /* 15939 */
  IC_VEX_XD, /* 15940 */
  IC_VEX_XD, /* 15941 */
  IC_VEX_XD, /* 15942 */
  IC_VEX_XD, /* 15943 */
  IC_VEX_W, /* 15944 */
  IC_VEX_W, /* 15945 */
  IC_VEX_W_XS, /* 15946 */
  IC_VEX_W_XS, /* 15947 */
  IC_VEX_W_XD, /* 15948 */
  IC_VEX_W_XD, /* 15949 */
  IC_VEX_W_XD, /* 15950 */
  IC_VEX_W_XD, /* 15951 */
  IC_VEX_OPSIZE, /* 15952 */
  IC_VEX_OPSIZE, /* 15953 */
  IC_VEX_OPSIZE, /* 15954 */
  IC_VEX_OPSIZE, /* 15955 */
  IC_VEX_OPSIZE, /* 15956 */
  IC_VEX_OPSIZE, /* 15957 */
  IC_VEX_OPSIZE, /* 15958 */
  IC_VEX_OPSIZE, /* 15959 */
  IC_VEX_W_OPSIZE, /* 15960 */
  IC_VEX_W_OPSIZE, /* 15961 */
  IC_VEX_W_OPSIZE, /* 15962 */
  IC_VEX_W_OPSIZE, /* 15963 */
  IC_VEX_W_OPSIZE, /* 15964 */
  IC_VEX_W_OPSIZE, /* 15965 */
  IC_VEX_W_OPSIZE, /* 15966 */
  IC_VEX_W_OPSIZE, /* 15967 */
  IC_VEX, /* 15968 */
  IC_VEX, /* 15969 */
  IC_VEX_XS, /* 15970 */
  IC_VEX_XS, /* 15971 */
  IC_VEX_XD, /* 15972 */
  IC_VEX_XD, /* 15973 */
  IC_VEX_XD, /* 15974 */
  IC_VEX_XD, /* 15975 */
  IC_VEX_W, /* 15976 */
  IC_VEX_W, /* 15977 */
  IC_VEX_W_XS, /* 15978 */
  IC_VEX_W_XS, /* 15979 */
  IC_VEX_W_XD, /* 15980 */
  IC_VEX_W_XD, /* 15981 */
  IC_VEX_W_XD, /* 15982 */
  IC_VEX_W_XD, /* 15983 */
  IC_VEX_OPSIZE, /* 15984 */
  IC_VEX_OPSIZE, /* 15985 */
  IC_VEX_OPSIZE, /* 15986 */
  IC_VEX_OPSIZE, /* 15987 */
  IC_VEX_OPSIZE, /* 15988 */
  IC_VEX_OPSIZE, /* 15989 */
  IC_VEX_OPSIZE, /* 15990 */
  IC_VEX_OPSIZE, /* 15991 */
  IC_VEX_W_OPSIZE, /* 15992 */
  IC_VEX_W_OPSIZE, /* 15993 */
  IC_VEX_W_OPSIZE, /* 15994 */
  IC_VEX_W_OPSIZE, /* 15995 */
  IC_VEX_W_OPSIZE, /* 15996 */
  IC_VEX_W_OPSIZE, /* 15997 */
  IC_VEX_W_OPSIZE, /* 15998 */
  IC_VEX_W_OPSIZE, /* 15999 */
  IC_VEX_L, /* 16000 */
  IC_VEX_L, /* 16001 */
  IC_VEX_L_XS, /* 16002 */
  IC_VEX_L_XS, /* 16003 */
  IC_VEX_L_XD, /* 16004 */
  IC_VEX_L_XD, /* 16005 */
  IC_VEX_L_XD, /* 16006 */
  IC_VEX_L_XD, /* 16007 */
  IC_VEX_L_W, /* 16008 */
  IC_VEX_L_W, /* 16009 */
  IC_VEX_L_W_XS, /* 16010 */
  IC_VEX_L_W_XS, /* 16011 */
  IC_VEX_L_W_XD, /* 16012 */
  IC_VEX_L_W_XD, /* 16013 */
  IC_VEX_L_W_XD, /* 16014 */
  IC_VEX_L_W_XD, /* 16015 */
  IC_VEX_L_OPSIZE, /* 16016 */
  IC_VEX_L_OPSIZE, /* 16017 */
  IC_VEX_L_OPSIZE, /* 16018 */
  IC_VEX_L_OPSIZE, /* 16019 */
  IC_VEX_L_OPSIZE, /* 16020 */
  IC_VEX_L_OPSIZE, /* 16021 */
  IC_VEX_L_OPSIZE, /* 16022 */
  IC_VEX_L_OPSIZE, /* 16023 */
  IC_VEX_L_W_OPSIZE, /* 16024 */
  IC_VEX_L_W_OPSIZE, /* 16025 */
  IC_VEX_L_W_OPSIZE, /* 16026 */
  IC_VEX_L_W_OPSIZE, /* 16027 */
  IC_VEX_L_W_OPSIZE, /* 16028 */
  IC_VEX_L_W_OPSIZE, /* 16029 */
  IC_VEX_L_W_OPSIZE, /* 16030 */
  IC_VEX_L_W_OPSIZE, /* 16031 */
  IC_VEX_L, /* 16032 */
  IC_VEX_L, /* 16033 */
  IC_VEX_L_XS, /* 16034 */
  IC_VEX_L_XS, /* 16035 */
  IC_VEX_L_XD, /* 16036 */
  IC_VEX_L_XD, /* 16037 */
  IC_VEX_L_XD, /* 16038 */
  IC_VEX_L_XD, /* 16039 */
  IC_VEX_L_W, /* 16040 */
  IC_VEX_L_W, /* 16041 */
  IC_VEX_L_W_XS, /* 16042 */
  IC_VEX_L_W_XS, /* 16043 */
  IC_VEX_L_W_XD, /* 16044 */
  IC_VEX_L_W_XD, /* 16045 */
  IC_VEX_L_W_XD, /* 16046 */
  IC_VEX_L_W_XD, /* 16047 */
  IC_VEX_L_OPSIZE, /* 16048 */
  IC_VEX_L_OPSIZE, /* 16049 */
  IC_VEX_L_OPSIZE, /* 16050 */
  IC_VEX_L_OPSIZE, /* 16051 */
  IC_VEX_L_OPSIZE, /* 16052 */
  IC_VEX_L_OPSIZE, /* 16053 */
  IC_VEX_L_OPSIZE, /* 16054 */
  IC_VEX_L_OPSIZE, /* 16055 */
  IC_VEX_L_W_OPSIZE, /* 16056 */
  IC_VEX_L_W_OPSIZE, /* 16057 */
  IC_VEX_L_W_OPSIZE, /* 16058 */
  IC_VEX_L_W_OPSIZE, /* 16059 */
  IC_VEX_L_W_OPSIZE, /* 16060 */
  IC_VEX_L_W_OPSIZE, /* 16061 */
  IC_VEX_L_W_OPSIZE, /* 16062 */
  IC_VEX_L_W_OPSIZE, /* 16063 */
  IC_VEX_L, /* 16064 */
  IC_VEX_L, /* 16065 */
  IC_VEX_L_XS, /* 16066 */
  IC_VEX_L_XS, /* 16067 */
  IC_VEX_L_XD, /* 16068 */
  IC_VEX_L_XD, /* 16069 */
  IC_VEX_L_XD, /* 16070 */
  IC_VEX_L_XD, /* 16071 */
  IC_VEX_L_W, /* 16072 */
  IC_VEX_L_W, /* 16073 */
  IC_VEX_L_W_XS, /* 16074 */
  IC_VEX_L_W_XS, /* 16075 */
  IC_VEX_L_W_XD, /* 16076 */
  IC_VEX_L_W_XD, /* 16077 */
  IC_VEX_L_W_XD, /* 16078 */
  IC_VEX_L_W_XD, /* 16079 */
  IC_VEX_L_OPSIZE, /* 16080 */
  IC_VEX_L_OPSIZE, /* 16081 */
  IC_VEX_L_OPSIZE, /* 16082 */
  IC_VEX_L_OPSIZE, /* 16083 */
  IC_VEX_L_OPSIZE, /* 16084 */
  IC_VEX_L_OPSIZE, /* 16085 */
  IC_VEX_L_OPSIZE, /* 16086 */
  IC_VEX_L_OPSIZE, /* 16087 */
  IC_VEX_L_W_OPSIZE, /* 16088 */
  IC_VEX_L_W_OPSIZE, /* 16089 */
  IC_VEX_L_W_OPSIZE, /* 16090 */
  IC_VEX_L_W_OPSIZE, /* 16091 */
  IC_VEX_L_W_OPSIZE, /* 16092 */
  IC_VEX_L_W_OPSIZE, /* 16093 */
  IC_VEX_L_W_OPSIZE, /* 16094 */
  IC_VEX_L_W_OPSIZE, /* 16095 */
  IC_VEX_L, /* 16096 */
  IC_VEX_L, /* 16097 */
  IC_VEX_L_XS, /* 16098 */
  IC_VEX_L_XS, /* 16099 */
  IC_VEX_L_XD, /* 16100 */
  IC_VEX_L_XD, /* 16101 */
  IC_VEX_L_XD, /* 16102 */
  IC_VEX_L_XD, /* 16103 */
  IC_VEX_L_W, /* 16104 */
  IC_VEX_L_W, /* 16105 */
  IC_VEX_L_W_XS, /* 16106 */
  IC_VEX_L_W_XS, /* 16107 */
  IC_VEX_L_W_XD, /* 16108 */
  IC_VEX_L_W_XD, /* 16109 */
  IC_VEX_L_W_XD, /* 16110 */
  IC_VEX_L_W_XD, /* 16111 */
  IC_VEX_L_OPSIZE, /* 16112 */
  IC_VEX_L_OPSIZE, /* 16113 */
  IC_VEX_L_OPSIZE, /* 16114 */
  IC_VEX_L_OPSIZE, /* 16115 */
  IC_VEX_L_OPSIZE, /* 16116 */
  IC_VEX_L_OPSIZE, /* 16117 */
  IC_VEX_L_OPSIZE, /* 16118 */
  IC_VEX_L_OPSIZE, /* 16119 */
  IC_VEX_L_W_OPSIZE, /* 16120 */
  IC_VEX_L_W_OPSIZE, /* 16121 */
  IC_VEX_L_W_OPSIZE, /* 16122 */
  IC_VEX_L_W_OPSIZE, /* 16123 */
  IC_VEX_L_W_OPSIZE, /* 16124 */
  IC_VEX_L_W_OPSIZE, /* 16125 */
  IC_VEX_L_W_OPSIZE, /* 16126 */
  IC_VEX_L_W_OPSIZE, /* 16127 */
  IC_EVEX_L2_KZ_B, /* 16128 */
  IC_EVEX_L2_KZ_B, /* 16129 */
  IC_EVEX_L2_XS_KZ_B, /* 16130 */
  IC_EVEX_L2_XS_KZ_B, /* 16131 */
  IC_EVEX_L2_XD_KZ_B, /* 16132 */
  IC_EVEX_L2_XD_KZ_B, /* 16133 */
  IC_EVEX_L2_XD_KZ_B, /* 16134 */
  IC_EVEX_L2_XD_KZ_B, /* 16135 */
  IC_EVEX_L2_W_KZ_B, /* 16136 */
  IC_EVEX_L2_W_KZ_B, /* 16137 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16138 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16139 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16140 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16141 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16142 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16143 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16144 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16145 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16146 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16147 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16148 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16149 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16150 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16151 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16152 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16153 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16154 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16155 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16156 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16157 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16158 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16159 */
  IC_EVEX_L2_KZ_B, /* 16160 */
  IC_EVEX_L2_KZ_B, /* 16161 */
  IC_EVEX_L2_XS_KZ_B, /* 16162 */
  IC_EVEX_L2_XS_KZ_B, /* 16163 */
  IC_EVEX_L2_XD_KZ_B, /* 16164 */
  IC_EVEX_L2_XD_KZ_B, /* 16165 */
  IC_EVEX_L2_XD_KZ_B, /* 16166 */
  IC_EVEX_L2_XD_KZ_B, /* 16167 */
  IC_EVEX_L2_W_KZ_B, /* 16168 */
  IC_EVEX_L2_W_KZ_B, /* 16169 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16170 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16171 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16172 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16173 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16174 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16175 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16176 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16177 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16178 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16179 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16180 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16181 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16182 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16183 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16184 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16185 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16186 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16187 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16188 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16189 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16190 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16191 */
  IC_EVEX_L2_KZ_B, /* 16192 */
  IC_EVEX_L2_KZ_B, /* 16193 */
  IC_EVEX_L2_XS_KZ_B, /* 16194 */
  IC_EVEX_L2_XS_KZ_B, /* 16195 */
  IC_EVEX_L2_XD_KZ_B, /* 16196 */
  IC_EVEX_L2_XD_KZ_B, /* 16197 */
  IC_EVEX_L2_XD_KZ_B, /* 16198 */
  IC_EVEX_L2_XD_KZ_B, /* 16199 */
  IC_EVEX_L2_W_KZ_B, /* 16200 */
  IC_EVEX_L2_W_KZ_B, /* 16201 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16202 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16203 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16204 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16205 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16206 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16207 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16208 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16209 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16210 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16211 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16212 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16213 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16214 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16215 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16216 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16217 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16218 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16219 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16220 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16221 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16222 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16223 */
  IC_EVEX_L2_KZ_B, /* 16224 */
  IC_EVEX_L2_KZ_B, /* 16225 */
  IC_EVEX_L2_XS_KZ_B, /* 16226 */
  IC_EVEX_L2_XS_KZ_B, /* 16227 */
  IC_EVEX_L2_XD_KZ_B, /* 16228 */
  IC_EVEX_L2_XD_KZ_B, /* 16229 */
  IC_EVEX_L2_XD_KZ_B, /* 16230 */
  IC_EVEX_L2_XD_KZ_B, /* 16231 */
  IC_EVEX_L2_W_KZ_B, /* 16232 */
  IC_EVEX_L2_W_KZ_B, /* 16233 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16234 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16235 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16236 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16237 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16238 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16239 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16240 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16241 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16242 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16243 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16244 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16245 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16246 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16247 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16248 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16249 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16250 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16251 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16252 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16253 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16254 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16255 */
  IC_EVEX_L2_KZ_B, /* 16256 */
  IC_EVEX_L2_KZ_B, /* 16257 */
  IC_EVEX_L2_XS_KZ_B, /* 16258 */
  IC_EVEX_L2_XS_KZ_B, /* 16259 */
  IC_EVEX_L2_XD_KZ_B, /* 16260 */
  IC_EVEX_L2_XD_KZ_B, /* 16261 */
  IC_EVEX_L2_XD_KZ_B, /* 16262 */
  IC_EVEX_L2_XD_KZ_B, /* 16263 */
  IC_EVEX_L2_W_KZ_B, /* 16264 */
  IC_EVEX_L2_W_KZ_B, /* 16265 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16266 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16267 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16268 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16269 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16270 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16271 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16272 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16273 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16274 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16275 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16276 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16277 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16278 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16279 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16280 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16281 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16282 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16283 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16284 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16285 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16286 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16287 */
  IC_EVEX_L2_KZ_B, /* 16288 */
  IC_EVEX_L2_KZ_B, /* 16289 */
  IC_EVEX_L2_XS_KZ_B, /* 16290 */
  IC_EVEX_L2_XS_KZ_B, /* 16291 */
  IC_EVEX_L2_XD_KZ_B, /* 16292 */
  IC_EVEX_L2_XD_KZ_B, /* 16293 */
  IC_EVEX_L2_XD_KZ_B, /* 16294 */
  IC_EVEX_L2_XD_KZ_B, /* 16295 */
  IC_EVEX_L2_W_KZ_B, /* 16296 */
  IC_EVEX_L2_W_KZ_B, /* 16297 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16298 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16299 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16300 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16301 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16302 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16303 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16304 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16305 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16306 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16307 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16308 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16309 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16310 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16311 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16312 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16313 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16314 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16315 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16316 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16317 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16318 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16319 */
  IC_EVEX_L2_KZ_B, /* 16320 */
  IC_EVEX_L2_KZ_B, /* 16321 */
  IC_EVEX_L2_XS_KZ_B, /* 16322 */
  IC_EVEX_L2_XS_KZ_B, /* 16323 */
  IC_EVEX_L2_XD_KZ_B, /* 16324 */
  IC_EVEX_L2_XD_KZ_B, /* 16325 */
  IC_EVEX_L2_XD_KZ_B, /* 16326 */
  IC_EVEX_L2_XD_KZ_B, /* 16327 */
  IC_EVEX_L2_W_KZ_B, /* 16328 */
  IC_EVEX_L2_W_KZ_B, /* 16329 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16330 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16331 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16332 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16333 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16334 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16335 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16336 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16337 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16338 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16339 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16340 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16341 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16342 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16343 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16344 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16345 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16346 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16347 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16348 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16349 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16350 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16351 */
  IC_EVEX_L2_KZ_B, /* 16352 */
  IC_EVEX_L2_KZ_B, /* 16353 */
  IC_EVEX_L2_XS_KZ_B, /* 16354 */
  IC_EVEX_L2_XS_KZ_B, /* 16355 */
  IC_EVEX_L2_XD_KZ_B, /* 16356 */
  IC_EVEX_L2_XD_KZ_B, /* 16357 */
  IC_EVEX_L2_XD_KZ_B, /* 16358 */
  IC_EVEX_L2_XD_KZ_B, /* 16359 */
  IC_EVEX_L2_W_KZ_B, /* 16360 */
  IC_EVEX_L2_W_KZ_B, /* 16361 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16362 */
  IC_EVEX_L2_W_XS_KZ_B, /* 16363 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16364 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16365 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16366 */
  IC_EVEX_L2_W_XD_KZ_B, /* 16367 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16368 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16369 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16370 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16371 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16372 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16373 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16374 */
  IC_EVEX_L2_OPSIZE_KZ_B, /* 16375 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16376 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16377 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16378 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16379 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16380 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16381 */
  IC_EVEX_L2_W_OPSIZE_KZ_B, /* 16382 */
  IC_EVEX_L2_W_OPSIZE_KZ_B  /* 16383 */
};

static const InstrUID modRMTable[] = {
/* EmptyTable */
  0x0,
/* Table1 */
  0x71, /* ADD8mr */
  0x75, /* ADD8rr */
/* Table3 */
  0x59, /* ADD32mr */
  0x5f, /* ADD32rr */
/* Table5 */
  0x74, /* ADD8rm */
  0x76, /* ADD8rr_REV */
/* Table7 */
  0x5e, /* ADD32rm */
  0x61, /* ADD32rr_REV */
/* Table9 */
  0x6e, /* ADD8i8 */
/* Table10 */
  0x56, /* ADD32i32 */
/* Table11 */
  0x906, /* PUSHES32 */
/* Table12 */
  0x88f, /* POPES32 */
/* Table13 */
  0x780, /* OR8mr */
  0x784, /* OR8rr */
/* Table15 */
  0x76d, /* OR32mr */
  0x772, /* OR32rr */
/* Table17 */
  0x783, /* OR8rm */
  0x785, /* OR8rr_REV */
/* Table19 */
  0x771, /* OR32rm */
  0x773, /* OR32rr_REV */
/* Table21 */
  0x77d, /* OR8i8 */
/* Table22 */
  0x76a, /* OR32i32 */
/* Table23 */
  0x902, /* PUSHCS32 */
/* Table24 */
  0x40, /* ADC8mr */
  0x44, /* ADC8rr */
/* Table26 */
  0x2e, /* ADC32mr */
  0x32, /* ADC32rr */
/* Table28 */
  0x43, /* ADC8rm */
  0x45, /* ADC8rr_REV */
/* Table30 */
  0x31, /* ADC32rm */
  0x33, /* ADC32rr_REV */
/* Table32 */
  0x3d, /* ADC8i8 */
/* Table33 */
  0x2b, /* ADC32i32 */
/* Table34 */
  0x911, /* PUSHSS32 */
/* Table35 */
  0x89a, /* POPSS32 */
/* Table36 */
  0xa2a, /* SBB8mr */
  0xa2e, /* SBB8rr */
/* Table38 */
  0xa18, /* SBB32mr */
  0xa1c, /* SBB32rr */
/* Table40 */
  0xa2d, /* SBB8rm */
  0xa2f, /* SBB8rr_REV */
/* Table42 */
  0xa1b, /* SBB32rm */
  0xa1d, /* SBB32rr_REV */
/* Table44 */
  0xa27, /* SBB8i8 */
/* Table45 */
  0xa15, /* SBB32i32 */
/* Table46 */
  0x904, /* PUSHDS32 */
/* Table47 */
  0x88d, /* POPDS32 */
/* Table48 */
  0xce, /* AND8mr */
  0xd2, /* AND8rr */
/* Table50 */
  0xbc, /* AND32mr */
  0xc0, /* AND32rr */
/* Table52 */
  0xd1, /* AND8rm */
  0xd3, /* AND8rr_REV */
/* Table54 */
  0xbf, /* AND32rm */
  0xc1, /* AND32rr_REV */
/* Table56 */
  0xcb, /* AND8i8 */
/* Table57 */
  0xb9, /* AND32i32 */
/* Table58 */
  0x294, /* DAA */
/* Table59 */
  0xb2f, /* SUB8mr */
  0xb33, /* SUB8rr */
/* Table61 */
  0xb1d, /* SUB32mr */
  0xb21, /* SUB32rr */
/* Table63 */
  0xb32, /* SUB8rm */
  0xb34, /* SUB8rr_REV */
/* Table65 */
  0xb20, /* SUB32rm */
  0xb22, /* SUB32rr_REV */
/* Table67 */
  0xb2c, /* SUB8i8 */
/* Table68 */
  0xb1a, /* SUB32i32 */
/* Table69 */
  0x295, /* DAS */
/* Table70 */
  0x2277, /* XOR8mr */
  0x227b, /* XOR8rr */
/* Table72 */
  0x2265, /* XOR32mr */
  0x2269, /* XOR32rr */
/* Table74 */
  0x227a, /* XOR8rm */
  0x227c, /* XOR8rr_REV */
/* Table76 */
  0x2268, /* XOR32rm */
  0x226a, /* XOR32rr_REV */
/* Table78 */
  0x2274, /* XOR8i8 */
/* Table79 */
  0x2262, /* XOR32i32 */
/* Table80 */
  0x16, /* AAA */
/* Table81 */
  0x22a, /* CMP8mr */
  0x22e, /* CMP8rr */
/* Table83 */
  0x218, /* CMP32mr */
  0x21c, /* CMP32rr */
/* Table85 */
  0x22d, /* CMP8rm */
  0x22f, /* CMP8rr_REV */
/* Table87 */
  0x21b, /* CMP32rm */
  0x21d, /* CMP32rr_REV */
/* Table89 */
  0x227, /* CMP8i8 */
/* Table90 */
  0x215, /* CMP32i32 */
/* Table91 */
  0x19, /* AAS */
/* Table92 */
  0x39b, /* INC32r_alt */
/* Table93 */
  0x29c, /* DEC32r_alt */
/* Table94 */
  0x8f6, /* PUSH32r */
/* Table95 */
  0x87e, /* POP32r */
/* Table96 */
  0x900, /* PUSHA32 */
/* Table97 */
  0x885, /* POPA32 */
/* Table98 */
  0x11e, /* BOUNDS32rm */
  0x0, /*  */
/* Table100 */
  0xe0, /* ARPL16mr */
  0xe1, /* ARPL16rr */
/* Table102 */
  0x296, /* DATA16_PREFIX */
/* Table103 */
  0x913, /* PUSHi32 */
/* Table104 */
  0x381, /* IMUL32rmi */
  0x384, /* IMUL32rri */
/* Table106 */
  0x8f5, /* PUSH32i8 */
/* Table107 */
  0x382, /* IMUL32rmi8 */
  0x385, /* IMUL32rri8 */
/* Table109 */
  0x3a0, /* INSB */
/* Table110 */
  0x3a5, /* INSL */
/* Table111 */
  0x790, /* OUTSB */
/* Table112 */
  0x791, /* OUTSL */
/* Table113 */
  0x46d, /* JO_1 */
/* Table114 */
  0x464, /* JNO_1 */
/* Table115 */
  0x444, /* JB_1 */
/* Table116 */
  0x43b, /* JAE_1 */
/* Table117 */
  0x449, /* JE_1 */
/* Table118 */
  0x461, /* JNE_1 */
/* Table119 */
  0x441, /* JBE_1 */
/* Table120 */
  0x43e, /* JA_1 */
/* Table121 */
  0x474, /* JS_1 */
/* Table122 */
  0x46a, /* JNS_1 */
/* Table123 */
  0x470, /* JP_1 */
/* Table124 */
  0x467, /* JNP_1 */
/* Table125 */
  0x455, /* JL_1 */
/* Table126 */
  0x44c, /* JGE_1 */
/* Table127 */
  0x452, /* JLE_1 */
/* Table128 */
  0x44f, /* JG_1 */
/* Table129 */
  0x6f, /* ADD8mi */
  0x77e, /* OR8mi */
  0x3e, /* ADC8mi */
  0xa28, /* SBB8mi */
  0xcc, /* AND8mi */
  0xb2d, /* SUB8mi */
  0x2275, /* XOR8mi */
  0x228, /* CMP8mi */
  0x72, /* ADD8ri */
  0x781, /* OR8ri */
  0x41, /* ADC8ri */
  0xa2b, /* SBB8ri */
  0xcf, /* AND8ri */
  0xb30, /* SUB8ri */
  0x2278, /* XOR8ri */
  0x22b, /* CMP8ri */
/* Table145 */
  0x57, /* ADD32mi */
  0x76b, /* OR32mi */
  0x2c, /* ADC32mi */
  0xa16, /* SBB32mi */
  0xba, /* AND32mi */
  0xb1b, /* SUB32mi */
  0x2263, /* XOR32mi */
  0x216, /* CMP32mi */
  0x5a, /* ADD32ri */
  0x76f, /* OR32ri */
  0x2f, /* ADC32ri */
  0xa19, /* SBB32ri */
  0xbd, /* AND32ri */
  0xb1e, /* SUB32ri */
  0x2266, /* XOR32ri */
  0x219, /* CMP32ri */
/* Table161 */
  0x70, /* ADD8mi8 */
  0x77f, /* OR8mi8 */
  0x3f, /* ADC8mi8 */
  0xa29, /* SBB8mi8 */
  0xcd, /* AND8mi8 */
  0xb2e, /* SUB8mi8 */
  0x2276, /* XOR8mi8 */
  0x229, /* CMP8mi8 */
  0x73, /* ADD8ri8 */
  0x782, /* OR8ri8 */
  0x42, /* ADC8ri8 */
  0xa2c, /* SBB8ri8 */
  0xd0, /* AND8ri8 */
  0xb31, /* SUB8ri8 */
  0x2279, /* XOR8ri8 */
  0x22c, /* CMP8ri8 */
/* Table177 */
  0x58, /* ADD32mi8 */
  0x76c, /* OR32mi8 */
  0x2d, /* ADC32mi8 */
  0xa17, /* SBB32mi8 */
  0xbb, /* AND32mi8 */
  0xb1c, /* SUB32mi8 */
  0x2264, /* XOR32mi8 */
  0x217, /* CMP32mi8 */
  0x5b, /* ADD32ri8 */
  0x770, /* OR32ri8 */
  0x30, /* ADC32ri8 */
  0xa1a, /* SBB32ri8 */
  0xbe, /* AND32ri8 */
  0xb1f, /* SUB32ri8 */
  0x2267, /* XOR32ri8 */
  0x21a, /* CMP32ri8 */
/* Table193 */
  0xb9d, /* TEST8rm */
  0xb9e, /* TEST8rr */
/* Table195 */
  0xb8e, /* TEST32rm */
  0xb8f, /* TEST32rr */
/* Table197 */
  0x224e, /* XCHG8rm */
  0x224f, /* XCHG8rr */
/* Table199 */
  0x2249, /* XCHG32rm */
  0x224a, /* XCHG32rr */
/* Table201 */
  0x681, /* MOV8mr */
  0x68a, /* MOV8rr */
/* Table203 */
  0x655, /* MOV32mr */
  0x661, /* MOV32rr */
/* Table205 */
  0x688, /* MOV8rm */
  0x68c, /* MOV8rr_REV */
/* Table207 */
  0x660, /* MOV32rm */
  0x662, /* MOV32rr_REV */
/* Table209 */
  0x656, /* MOV32ms */
  0x663, /* MOV32rs */
/* Table211 */
  0x4d8, /* LEA32r */
  0x0, /*  */
/* Table213 */
  0x664, /* MOV32sm */
  0x665, /* MOV32sr */
/* Table215 */
  0x87f, /* POP32rmm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x880, /* POP32rmr */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table231 */
  0x739, /* NOOP */
/* Table232 */
  0x2247, /* XCHG32ar */
/* Table233 */
  0x293, /* CWDE */
/* Table234 */
  0x16b, /* CDQ */
/* Table235 */
  0x2f1, /* FARCALL32i */
/* Table236 */
  0x222d, /* WAIT */
/* Table237 */
  0x908, /* PUSHF32 */
/* Table238 */
  0x891, /* POPF32 */
/* Table239 */
  0x9d6, /* SAHF */
/* Table240 */
  0x4b4, /* LAHF */
/* Table241 */
  0x67e, /* MOV8ao32 */
/* Table242 */
  0x650, /* MOV32ao32 */
/* Table243 */
  0x684, /* MOV8o32a */
/* Table244 */
  0x658, /* MOV32o32a */
/* Table245 */
  0x6c5, /* MOVSB */
/* Table246 */
  0x6ce, /* MOVSL */
/* Table247 */
  0x238, /* CMPSB */
/* Table248 */
  0x23d, /* CMPSL */
/* Table249 */
  0xb97, /* TEST8i8 */
/* Table250 */
  0xb89, /* TEST32i32 */
/* Table251 */
  0xaef, /* STOSB */
/* Table252 */
  0xaf0, /* STOSL */
/* Table253 */
  0x530, /* LODSB */
/* Table254 */
  0x531, /* LODSL */
/* Table255 */
  0xa30, /* SCASB */
/* Table256 */
  0xa31, /* SCASL */
/* Table257 */
  0x686, /* MOV8ri */
/* Table258 */
  0x65d, /* MOV32ri */
/* Table259 */
  0x9a3, /* ROL8mi */
  0x9bb, /* ROR8mi */
  0x92a, /* RCL8mi */
  0x94a, /* RCR8mi */
  0xa88, /* SHL8mi */
  0xab0, /* SHR8mi */
  0x9eb, /* SAL8mi */
  0xa04, /* SAR8mi */
  0x9a6, /* ROL8ri */
  0x9be, /* ROR8ri */
  0x92d, /* RCL8ri */
  0x94d, /* RCR8ri */
  0xa8b, /* SHL8ri */
  0xab3, /* SHR8ri */
  0x9ee, /* SAL8ri */
  0xa07, /* SAR8ri */
/* Table275 */
  0x997, /* ROL32mi */
  0x9af, /* ROR32mi */
  0x91e, /* RCL32mi */
  0x93e, /* RCR32mi */
  0xa7c, /* SHL32mi */
  0xaa4, /* SHR32mi */
  0x9df, /* SAL32mi */
  0x9f8, /* SAR32mi */
  0x99a, /* ROL32ri */
  0x9b2, /* ROR32ri */
  0x921, /* RCL32ri */
  0x941, /* RCR32ri */
  0xa7f, /* SHL32ri */
  0xaa7, /* SHR32ri */
  0x9e2, /* SAL32ri */
  0x9fb, /* SAR32ri */
/* Table291 */
  0x988, /* RETIL */
/* Table292 */
  0x98b, /* RETL */
/* Table293 */
  0x4de, /* LES32rm */
  0x0, /*  */
/* Table295 */
  0x4c4, /* LDS32rm */
  0x0, /*  */
/* Table297 */
  0x680, /* MOV8mi */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x687, /* MOV8ri_alt */
  0x687, /* MOV8ri_alt */
  0x687, /* MOV8ri_alt */
  0x687, /* MOV8ri_alt */
  0x687, /* MOV8ri_alt */
  0x687, /* MOV8ri_alt */
  0x687, /* MOV8ri_alt */
  0x687, /* MOV8ri_alt */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2237, /* XABORT */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table369 */
  0x654, /* MOV32mi */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x65f, /* MOV32ri_alt */
  0x65f, /* MOV32ri_alt */
  0x65f, /* MOV32ri_alt */
  0x65f, /* MOV32ri_alt */
  0x65f, /* MOV32ri_alt */
  0x65f, /* MOV32ri_alt */
  0x65f, /* MOV32ri_alt */
  0x65f, /* MOV32ri_alt */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2243, /* XBEGIN_4 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table441 */
  0x2e9, /* ENTER */
/* Table442 */
  0x4db, /* LEAVE */
/* Table443 */
  0x537, /* LRETIL */
/* Table444 */
  0x53a, /* LRETL */
/* Table445 */
  0x3a9, /* INT3 */
/* Table446 */
  0x3a7, /* INT */
/* Table447 */
  0x3aa, /* INTO */
/* Table448 */
  0x3b6, /* IRET32 */
/* Table449 */
  0x9a1, /* ROL8m1 */
  0x9b9, /* ROR8m1 */
  0x928, /* RCL8m1 */
  0x948, /* RCR8m1 */
  0xa86, /* SHL8m1 */
  0xaae, /* SHR8m1 */
  0x9e9, /* SAL8m1 */
  0xa02, /* SAR8m1 */
  0x9a4, /* ROL8r1 */
  0x9bc, /* ROR8r1 */
  0x92b, /* RCL8r1 */
  0x94b, /* RCR8r1 */
  0xa89, /* SHL8r1 */
  0xab1, /* SHR8r1 */
  0x9ec, /* SAL8r1 */
  0xa05, /* SAR8r1 */
/* Table465 */
  0x995, /* ROL32m1 */
  0x9ad, /* ROR32m1 */
  0x91c, /* RCL32m1 */
  0x93c, /* RCR32m1 */
  0xa7a, /* SHL32m1 */
  0xaa2, /* SHR32m1 */
  0x9dd, /* SAL32m1 */
  0x9f6, /* SAR32m1 */
  0x998, /* ROL32r1 */
  0x9b0, /* ROR32r1 */
  0x91f, /* RCL32r1 */
  0x93f, /* RCR32r1 */
  0xa7d, /* SHL32r1 */
  0xaa5, /* SHR32r1 */
  0x9e0, /* SAL32r1 */
  0x9f9, /* SAR32r1 */
/* Table481 */
  0x9a2, /* ROL8mCL */
  0x9ba, /* ROR8mCL */
  0x929, /* RCL8mCL */
  0x949, /* RCR8mCL */
  0xa87, /* SHL8mCL */
  0xaaf, /* SHR8mCL */
  0x9ea, /* SAL8mCL */
  0xa03, /* SAR8mCL */
  0x9a5, /* ROL8rCL */
  0x9bd, /* ROR8rCL */
  0x92c, /* RCL8rCL */
  0x94c, /* RCR8rCL */
  0xa8a, /* SHL8rCL */
  0xab2, /* SHR8rCL */
  0x9ed, /* SAL8rCL */
  0xa06, /* SAR8rCL */
/* Table497 */
  0x996, /* ROL32mCL */
  0x9ae, /* ROR32mCL */
  0x91d, /* RCL32mCL */
  0x93d, /* RCR32mCL */
  0xa7b, /* SHL32mCL */
  0xaa3, /* SHR32mCL */
  0x9de, /* SAL32mCL */
  0x9f7, /* SAR32mCL */
  0x999, /* ROL32rCL */
  0x9b1, /* ROR32rCL */
  0x920, /* RCL32rCL */
  0x940, /* RCR32rCL */
  0xa7e, /* SHL32rCL */
  0xaa6, /* SHR32rCL */
  0x9e1, /* SAL32rCL */
  0x9fa, /* SAR32rCL */
/* Table513 */
  0x18, /* AAM8i8 */
/* Table514 */
  0x17, /* AAD8i8 */
/* Table515 */
  0x9ef, /* SALC */
/* Table516 */
  0x2258, /* XLAT */
/* Table517 */
  0x87, /* ADD_F32m */
  0x71b, /* MUL_F32m */
  0x2fb, /* FCOM32m */
  0x2fd, /* FCOMP32m */
  0xb53, /* SUB_F32m */
  0xb39, /* SUBR_F32m */
  0x2c7, /* DIV_F32m */
  0x2ad, /* DIVR_F32m */
  0x8c, /* ADD_FST0r */
  0x720, /* MUL_FST0r */
  0x255, /* COM_FST0r */
  0x252, /* COMP_FST0r */
  0xb58, /* SUB_FST0r */
  0xb3e, /* SUBR_FST0r */
  0x2cc, /* DIV_FST0r */
  0x2b2, /* DIVR_FST0r */
/* Table533 */
  0x4c7, /* LD_F32m */
  0x0, /*  */
  0xaf7, /* ST_F32m */
  0xafc, /* ST_FP32m */
  0x309, /* FLDENVm */
  0x308, /* FLDCW16m */
  0x329, /* FSTENVm */
  0x312, /* FNSTCW16m */
  0x4d6, /* LD_Frr */
  0x4d6, /* LD_Frr */
  0x4d6, /* LD_Frr */
  0x4d6, /* LD_Frr */
  0x4d6, /* LD_Frr */
  0x4d6, /* LD_Frr */
  0x4d6, /* LD_Frr */
  0x4d6, /* LD_Frr */
  0x2250, /* XCH_F */
  0x2250, /* XCH_F */
  0x2250, /* XCH_F */
  0x2250, /* XCH_F */
  0x2250, /* XCH_F */
  0x2250, /* XCH_F */
  0x2250, /* XCH_F */
  0x2250, /* XCH_F */
  0x311, /* FNOP */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0xaff, /* ST_FPNCEST0r */
  0xaff, /* ST_FPNCEST0r */
  0xaff, /* ST_FPNCEST0r */
  0xaff, /* ST_FPNCEST0r */
  0xaff, /* ST_FPNCEST0r */
  0xaff, /* ST_FPNCEST0r */
  0xaff, /* ST_FPNCEST0r */
  0xaff, /* ST_FPNCEST0r */
  0x16d, /* CHS_F */
  0x1a, /* ABS_F */
  0x0, /*  */
  0x0, /*  */
  0xba6, /* TST_F */
  0x32a, /* FXAM */
  0x0, /*  */
  0x0, /*  */
  0x4c6, /* LD_F1 */
  0x30b, /* FLDL2T */
  0x30a, /* FLDL2E */
  0x30e, /* FLDPI */
  0x30c, /* FLDLG2 */
  0x30d, /* FLDLN2 */
  0x4c5, /* LD_F0 */
  0x0, /*  */
  0x2ee, /* F2XM1 */
  0x330, /* FYL2X */
  0x321, /* FPTAN */
  0x31e, /* FPATAN */
  0x32f, /* FXTRACT */
  0x320, /* FPREM1 */
  0x300, /* FDECSTP */
  0x307, /* FINCSTP */
  0x31f, /* FPREM */
  0x331, /* FYL2XP1 */
  0xae5, /* SQRT_F */
  0x328, /* FSINCOS */
  0x323, /* FRNDINT */
  0x326, /* FSCALE */
  0xacb, /* SIN_F */
  0x256, /* COS_F */
/* Table605 */
  0x8a, /* ADD_FI32m */
  0x71e, /* MUL_FI32m */
  0x304, /* FICOM32m */
  0x306, /* FICOMP32m */
  0xb56, /* SUB_FI32m */
  0xb3c, /* SUBR_FI32m */
  0x2ca, /* DIV_FI32m */
  0x2b0, /* DIVR_FI32m */
  0x197, /* CMOVB_F */
  0x197, /* CMOVB_F */
  0x197, /* CMOVB_F */
  0x197, /* CMOVB_F */
  0x197, /* CMOVB_F */
  0x197, /* CMOVB_F */
  0x197, /* CMOVB_F */
  0x197, /* CMOVB_F */
  0x1a1, /* CMOVE_F */
  0x1a1, /* CMOVE_F */
  0x1a1, /* CMOVE_F */
  0x1a1, /* CMOVE_F */
  0x1a1, /* CMOVE_F */
  0x1a1, /* CMOVE_F */
  0x1a1, /* CMOVE_F */
  0x1a1, /* CMOVE_F */
  0x193, /* CMOVBE_F */
  0x193, /* CMOVBE_F */
  0x193, /* CMOVBE_F */
  0x193, /* CMOVBE_F */
  0x193, /* CMOVBE_F */
  0x193, /* CMOVBE_F */
  0x193, /* CMOVBE_F */
  0x193, /* CMOVBE_F */
  0x1f1, /* CMOVP_F */
  0x1f1, /* CMOVP_F */
  0x1f1, /* CMOVP_F */
  0x1f1, /* CMOVP_F */
  0x1f1, /* CMOVP_F */
  0x1f1, /* CMOVP_F */
  0x1f1, /* CMOVP_F */
  0x1f1, /* CMOVP_F */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0xbba, /* UCOM_FPPr */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table677 */
  0x36b, /* ILD_F32m */
  0x3b9, /* ISTT_FP32m */
  0x3c5, /* IST_F32m */
  0x3c7, /* IST_FP32m */
  0x0, /*  */
  0x4c9, /* LD_F80m */
  0x0, /*  */
  0xafe, /* ST_FP80m */
  0x1c1, /* CMOVNB_F */
  0x1c1, /* CMOVNB_F */
  0x1c1, /* CMOVNB_F */
  0x1c1, /* CMOVNB_F */
  0x1c1, /* CMOVNB_F */
  0x1c1, /* CMOVNB_F */
  0x1c1, /* CMOVNB_F */
  0x1c1, /* CMOVNB_F */
  0x1cb, /* CMOVNE_F */
  0x1cb, /* CMOVNE_F */
  0x1cb, /* CMOVNE_F */
  0x1cb, /* CMOVNE_F */
  0x1cb, /* CMOVNE_F */
  0x1cb, /* CMOVNE_F */
  0x1cb, /* CMOVNE_F */
  0x1cb, /* CMOVNE_F */
  0x1bd, /* CMOVNBE_F */
  0x1bd, /* CMOVNBE_F */
  0x1bd, /* CMOVNBE_F */
  0x1bd, /* CMOVNBE_F */
  0x1bd, /* CMOVNBE_F */
  0x1bd, /* CMOVNBE_F */
  0x1bd, /* CMOVNBE_F */
  0x1bd, /* CMOVNBE_F */
  0x1db, /* CMOVNP_F */
  0x1db, /* CMOVNP_F */
  0x1db, /* CMOVNP_F */
  0x1db, /* CMOVNP_F */
  0x1db, /* CMOVNP_F */
  0x1db, /* CMOVNP_F */
  0x1db, /* CMOVNP_F */
  0x1db, /* CMOVNP_F */
  0x2294, /* feni8087_nop */
  0x2293, /* fdisi8087_nop */
  0x30f, /* FNCLEX */
  0x310, /* FNINIT */
  0x327, /* FSETPM */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0xbb9, /* UCOM_FIr */
  0xbb9, /* UCOM_FIr */
  0xbb9, /* UCOM_FIr */
  0xbb9, /* UCOM_FIr */
  0xbb9, /* UCOM_FIr */
  0xbb9, /* UCOM_FIr */
  0xbb9, /* UCOM_FIr */
  0xbb9, /* UCOM_FIr */
  0x254, /* COM_FIr */
  0x254, /* COM_FIr */
  0x254, /* COM_FIr */
  0x254, /* COM_FIr */
  0x254, /* COM_FIr */
  0x254, /* COM_FIr */
  0x254, /* COM_FIr */
  0x254, /* COM_FIr */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table749 */
  0x88, /* ADD_F64m */
  0x71c, /* MUL_F64m */
  0x2fc, /* FCOM64m */
  0x2fe, /* FCOMP64m */
  0xb54, /* SUB_F64m */
  0xb3a, /* SUBR_F64m */
  0x2c8, /* DIV_F64m */
  0x2ae, /* DIVR_F64m */
  0x9b, /* ADD_FrST0 */
  0x72f, /* MUL_FrST0 */
  0xafb, /* ST_FCOMST0r */
  0xaf9, /* ST_FCOMPST0r */
  0xb4a, /* SUBR_FrST0 */
  0xb67, /* SUB_FrST0 */
  0x2be, /* DIVR_FrST0 */
  0x2db, /* DIV_FrST0 */
/* Table765 */
  0x4c8, /* LD_F64m */
  0x3ba, /* ISTT_FP64m */
  0xaf8, /* ST_F64m */
  0xafd, /* ST_FP64m */
  0x324, /* FRSTORm */
  0x0, /*  */
  0x325, /* FSAVEm */
  0x314, /* FNSTSWm */
  0x302, /* FFREE */
  0xb03, /* ST_FXCHST0r */
  0xb10, /* ST_Frr */
  0xb02, /* ST_FPrr */
  0xbc2, /* UCOM_Fr */
  0xbbb, /* UCOM_FPr */
  0x0, /*  */
  0x0, /*  */
/* Table781 */
  0x89, /* ADD_FI16m */
  0x71d, /* MUL_FI16m */
  0x303, /* FICOM16m */
  0x305, /* FICOMP16m */
  0xb55, /* SUB_FI16m */
  0xb3b, /* SUBR_FI16m */
  0x2c9, /* DIV_FI16m */
  0x2af, /* DIVR_FI16m */
  0x8b, /* ADD_FPrST0 */
  0x8b, /* ADD_FPrST0 */
  0x8b, /* ADD_FPrST0 */
  0x8b, /* ADD_FPrST0 */
  0x8b, /* ADD_FPrST0 */
  0x8b, /* ADD_FPrST0 */
  0x8b, /* ADD_FPrST0 */
  0x8b, /* ADD_FPrST0 */
  0x71f, /* MUL_FPrST0 */
  0x71f, /* MUL_FPrST0 */
  0x71f, /* MUL_FPrST0 */
  0x71f, /* MUL_FPrST0 */
  0x71f, /* MUL_FPrST0 */
  0x71f, /* MUL_FPrST0 */
  0x71f, /* MUL_FPrST0 */
  0x71f, /* MUL_FPrST0 */
  0xafa, /* ST_FCOMPST0r_alt */
  0xafa, /* ST_FCOMPST0r_alt */
  0xafa, /* ST_FCOMPST0r_alt */
  0xafa, /* ST_FCOMPST0r_alt */
  0xafa, /* ST_FCOMPST0r_alt */
  0xafa, /* ST_FCOMPST0r_alt */
  0xafa, /* ST_FCOMPST0r_alt */
  0xafa, /* ST_FCOMPST0r_alt */
  0x0, /*  */
  0x2ff, /* FCOMPP */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0xb3d, /* SUBR_FPrST0 */
  0xb3d, /* SUBR_FPrST0 */
  0xb3d, /* SUBR_FPrST0 */
  0xb3d, /* SUBR_FPrST0 */
  0xb3d, /* SUBR_FPrST0 */
  0xb3d, /* SUBR_FPrST0 */
  0xb3d, /* SUBR_FPrST0 */
  0xb3d, /* SUBR_FPrST0 */
  0xb57, /* SUB_FPrST0 */
  0xb57, /* SUB_FPrST0 */
  0xb57, /* SUB_FPrST0 */
  0xb57, /* SUB_FPrST0 */
  0xb57, /* SUB_FPrST0 */
  0xb57, /* SUB_FPrST0 */
  0xb57, /* SUB_FPrST0 */
  0xb57, /* SUB_FPrST0 */
  0x2b1, /* DIVR_FPrST0 */
  0x2b1, /* DIVR_FPrST0 */
  0x2b1, /* DIVR_FPrST0 */
  0x2b1, /* DIVR_FPrST0 */
  0x2b1, /* DIVR_FPrST0 */
  0x2b1, /* DIVR_FPrST0 */
  0x2b1, /* DIVR_FPrST0 */
  0x2b1, /* DIVR_FPrST0 */
  0x2cb, /* DIV_FPrST0 */
  0x2cb, /* DIV_FPrST0 */
  0x2cb, /* DIV_FPrST0 */
  0x2cb, /* DIV_FPrST0 */
  0x2cb, /* DIV_FPrST0 */
  0x2cb, /* DIV_FPrST0 */
  0x2cb, /* DIV_FPrST0 */
  0x2cb, /* DIV_FPrST0 */
/* Table853 */
  0x36a, /* ILD_F16m */
  0x3b8, /* ISTT_FP16m */
  0x3c4, /* IST_F16m */
  0x3c6, /* IST_FP16m */
  0x2f9, /* FBLDm */
  0x36c, /* ILD_F64m */
  0x2fa, /* FBSTPm */
  0x3c8, /* IST_FP64m */
  0x322, /* FP_FFREEP */
  0x322, /* FP_FFREEP */
  0x322, /* FP_FFREEP */
  0x322, /* FP_FFREEP */
  0x322, /* FP_FFREEP */
  0x322, /* FP_FFREEP */
  0x322, /* FP_FFREEP */
  0x322, /* FP_FFREEP */
  0xb04, /* ST_FXCHST0r_alt */
  0xb04, /* ST_FXCHST0r_alt */
  0xb04, /* ST_FXCHST0r_alt */
  0xb04, /* ST_FXCHST0r_alt */
  0xb04, /* ST_FXCHST0r_alt */
  0xb04, /* ST_FXCHST0r_alt */
  0xb04, /* ST_FXCHST0r_alt */
  0xb04, /* ST_FXCHST0r_alt */
  0xb00, /* ST_FPST0r */
  0xb00, /* ST_FPST0r */
  0xb00, /* ST_FPST0r */
  0xb00, /* ST_FPST0r */
  0xb00, /* ST_FPST0r */
  0xb00, /* ST_FPST0r */
  0xb00, /* ST_FPST0r */
  0xb00, /* ST_FPST0r */
  0xb01, /* ST_FPST0r_alt */
  0xb01, /* ST_FPST0r_alt */
  0xb01, /* ST_FPST0r_alt */
  0xb01, /* ST_FPST0r_alt */
  0xb01, /* ST_FPST0r_alt */
  0xb01, /* ST_FPST0r_alt */
  0xb01, /* ST_FPST0r_alt */
  0xb01, /* ST_FPST0r_alt */
  0x313, /* FNSTSW16r */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0xbb8, /* UCOM_FIPr */
  0xbb8, /* UCOM_FIPr */
  0xbb8, /* UCOM_FIPr */
  0xbb8, /* UCOM_FIPr */
  0xbb8, /* UCOM_FIPr */
  0xbb8, /* UCOM_FIPr */
  0xbb8, /* UCOM_FIPr */
  0xbb8, /* UCOM_FIPr */
  0x253, /* COM_FIPr */
  0x253, /* COM_FIPr */
  0x253, /* COM_FIPr */
  0x253, /* COM_FIPr */
  0x253, /* COM_FIPr */
  0x253, /* COM_FIPr */
  0x253, /* COM_FIPr */
  0x253, /* COM_FIPr */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table925 */
  0x536, /* LOOPNE */
/* Table926 */
  0x535, /* LOOPE */
/* Table927 */
  0x534, /* LOOP */
/* Table928 */
  0x448, /* JECXZ */
/* Table929 */
  0x394, /* IN8ri */
/* Table930 */
  0x392, /* IN32ri */
/* Table931 */
  0x78e, /* OUT8ir */
/* Table932 */
  0x78c, /* OUT32ir */
/* Table933 */
  0x169, /* CALLpcrel32 */
/* Table934 */
  0x460, /* JMP_4 */
/* Table935 */
  0x2f6, /* FARJMP32i */
/* Table936 */
  0x45e, /* JMP_1 */
/* Table937 */
  0x395, /* IN8rr */
/* Table938 */
  0x393, /* IN32rr */
/* Table939 */
  0x78f, /* OUT8rr */
/* Table940 */
  0x78d, /* OUT32rr */
/* Table941 */
  0x519, /* LOCK_PREFIX */
/* Table942 */
  0x3a8, /* INT1 */
/* Table943 */
  0x978, /* REPNE_PREFIX */
/* Table944 */
  0x980, /* REP_PREFIX */
/* Table945 */
  0x35d, /* HLT */
/* Table946 */
  0x17a, /* CMC */
/* Table947 */
  0xb98, /* TEST8mi */
  0xb99, /* TEST8mi_alt */
  0x75f, /* NOT8m */
  0x737, /* NEG8m */
  0x709, /* MUL8m */
  0x38e, /* IMUL8m */
  0x2a7, /* DIV8m */
  0x368, /* IDIV8m */
  0xb9a, /* TEST8ri */
  0xb9c, /* TEST8ri_alt */
  0x760, /* NOT8r */
  0x738, /* NEG8r */
  0x70a, /* MUL8r */
  0x38f, /* IMUL8r */
  0x2a8, /* DIV8r */
  0x369, /* IDIV8r */
/* Table963 */
  0xb8a, /* TEST32mi */
  0xb8b, /* TEST32mi_alt */
  0x75b, /* NOT32m */
  0x733, /* NEG32m */
  0x705, /* MUL32m */
  0x37e, /* IMUL32m */
  0x2a3, /* DIV32m */
  0x364, /* IDIV32m */
  0xb8c, /* TEST32ri */
  0xb8d, /* TEST32ri_alt */
  0x75c, /* NOT32r */
  0x734, /* NEG32r */
  0x706, /* MUL32r */
  0x37f, /* IMUL32r */
  0x2a4, /* DIV32r */
  0x365, /* IDIV32r */
/* Table979 */
  0x172, /* CLC */
/* Table980 */
  0xaea, /* STC */
/* Table981 */
  0x177, /* CLI */
/* Table982 */
  0xaed, /* STI */
/* Table983 */
  0x173, /* CLD */
/* Table984 */
  0xaeb, /* STD */
/* Table985 */
  0x39e, /* INC8m */
  0x29f, /* DEC8m */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x39f, /* INC8r */
  0x2a0, /* DEC8r */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table1001 */
  0x399, /* INC32m */
  0x29a, /* DEC32m */
  0x163, /* CALL32m */
  0x2f2, /* FARCALL32m */
  0x45a, /* JMP32m */
  0x2f7, /* FARJMP32m */
  0x8f7, /* PUSH32rmm */
  0x0, /*  */
  0x39a, /* INC32r */
  0x29b, /* DEC32r */
  0x164, /* CALL32r */
  0x0, /*  */
  0x45b, /* JMP32r */
  0x0, /*  */
  0x8f8, /* PUSH32rmr */
  0x0, /*  */
/* Table1017 */
  0x98e, /* REX64_PREFIX */
/* Table1018 */
  0x8fc, /* PUSH64r */
/* Table1019 */
  0x881, /* POP64r */
/* Table1020 */
  0x6e4, /* MOVSX64rm32_alt */
  0x6e1, /* MOVSX64_NOREXrr32 */
/* Table1022 */
  0x8fa, /* PUSH64i32 */
/* Table1023 */
  0x8fb, /* PUSH64i8 */
/* Table1024 */
  0x4d9, /* LEA64_32r */
  0x0, /*  */
/* Table1026 */
  0x882, /* POP64rmm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x883, /* POP64rmr */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table1042 */
  0x2248, /* XCHG32ar64 */
/* Table1043 */
  0x909, /* PUSHF64 */
/* Table1044 */
  0x892, /* POPF64 */
/* Table1045 */
  0x67f, /* MOV8ao64 */
/* Table1046 */
  0x651, /* MOV32ao64 */
/* Table1047 */
  0x685, /* MOV8o64a */
/* Table1048 */
  0x659, /* MOV32o64a */
/* Table1049 */
  0x989, /* RETIQ */
/* Table1050 */
  0x98c, /* RETQ */
/* Table1051 */
  0x4dc, /* LEAVE64 */
/* Table1052 */
  0x473, /* JRCXZ */
/* Table1053 */
  0x166, /* CALL64pcrel32 */
/* Table1054 */
  0x399, /* INC32m */
  0x29a, /* DEC32m */
  0x165, /* CALL64m */
  0x2f2, /* FARCALL32m */
  0x45c, /* JMP64m */
  0x2f7, /* FARJMP32m */
  0x8fd, /* PUSH64rmm */
  0x0, /*  */
  0x39a, /* INC32r */
  0x29b, /* DEC32r */
  0x167, /* CALL64r */
  0x0, /*  */
  0x45d, /* JMP64r */
  0x0, /*  */
  0x8fe, /* PUSH64rmr */
  0x0, /*  */
/* Table1070 */
  0x4d, /* ADD16mr */
  0x53, /* ADD16rr */
/* Table1072 */
  0x52, /* ADD16rm */
  0x55, /* ADD16rr_REV */
/* Table1074 */
  0x4a, /* ADD16i16 */
/* Table1075 */
  0x905, /* PUSHES16 */
/* Table1076 */
  0x88e, /* POPES16 */
/* Table1077 */
  0x764, /* OR16mr */
  0x768, /* OR16rr */
/* Table1079 */
  0x767, /* OR16rm */
  0x769, /* OR16rr_REV */
/* Table1081 */
  0x761, /* OR16i16 */
/* Table1082 */
  0x901, /* PUSHCS16 */
/* Table1083 */
  0x25, /* ADC16mr */
  0x29, /* ADC16rr */
/* Table1085 */
  0x28, /* ADC16rm */
  0x2a, /* ADC16rr_REV */
/* Table1087 */
  0x22, /* ADC16i16 */
/* Table1088 */
  0x910, /* PUSHSS16 */
/* Table1089 */
  0x899, /* POPSS16 */
/* Table1090 */
  0xa0f, /* SBB16mr */
  0xa13, /* SBB16rr */
/* Table1092 */
  0xa12, /* SBB16rm */
  0xa14, /* SBB16rr_REV */
/* Table1094 */
  0xa0c, /* SBB16i16 */
/* Table1095 */
  0x903, /* PUSHDS16 */
/* Table1096 */
  0x88c, /* POPDS16 */
/* Table1097 */
  0xb3, /* AND16mr */
  0xb7, /* AND16rr */
/* Table1099 */
  0xb6, /* AND16rm */
  0xb8, /* AND16rr_REV */
/* Table1101 */
  0xb0, /* AND16i16 */
/* Table1102 */
  0xb14, /* SUB16mr */
  0xb18, /* SUB16rr */
/* Table1104 */
  0xb17, /* SUB16rm */
  0xb19, /* SUB16rr_REV */
/* Table1106 */
  0xb11, /* SUB16i16 */
/* Table1107 */
  0x225c, /* XOR16mr */
  0x2260, /* XOR16rr */
/* Table1109 */
  0x225f, /* XOR16rm */
  0x2261, /* XOR16rr_REV */
/* Table1111 */
  0x2259, /* XOR16i16 */
/* Table1112 */
  0x20f, /* CMP16mr */
  0x213, /* CMP16rr */
/* Table1114 */
  0x212, /* CMP16rm */
  0x214, /* CMP16rr_REV */
/* Table1116 */
  0x20c, /* CMP16i16 */
/* Table1117 */
  0x398, /* INC16r_alt */
/* Table1118 */
  0x299, /* DEC16r_alt */
/* Table1119 */
  0x8f2, /* PUSH16r */
/* Table1120 */
  0x87b, /* POP16r */
/* Table1121 */
  0x8ff, /* PUSHA16 */
/* Table1122 */
  0x884, /* POPA16 */
/* Table1123 */
  0x11d, /* BOUNDS16rm */
  0x0, /*  */
/* Table1125 */
  0x912, /* PUSHi16 */
/* Table1126 */
  0x379, /* IMUL16rmi */
  0x37c, /* IMUL16rri */
/* Table1128 */
  0x8f1, /* PUSH16i8 */
/* Table1129 */
  0x37a, /* IMUL16rmi8 */
  0x37d, /* IMUL16rri8 */
/* Table1131 */
  0x3a6, /* INSW */
/* Table1132 */
  0x792, /* OUTSW */
/* Table1133 */
  0x4b, /* ADD16mi */
  0x762, /* OR16mi */
  0x23, /* ADC16mi */
  0xa0d, /* SBB16mi */
  0xb1, /* AND16mi */
  0xb12, /* SUB16mi */
  0x225a, /* XOR16mi */
  0x20d, /* CMP16mi */
  0x4e, /* ADD16ri */
  0x765, /* OR16ri */
  0x26, /* ADC16ri */
  0xa10, /* SBB16ri */
  0xb4, /* AND16ri */
  0xb15, /* SUB16ri */
  0x225d, /* XOR16ri */
  0x210, /* CMP16ri */
/* Table1149 */
  0x4c, /* ADD16mi8 */
  0x763, /* OR16mi8 */
  0x24, /* ADC16mi8 */
  0xa0e, /* SBB16mi8 */
  0xb2, /* AND16mi8 */
  0xb13, /* SUB16mi8 */
  0x225b, /* XOR16mi8 */
  0x20e, /* CMP16mi8 */
  0x4f, /* ADD16ri8 */
  0x766, /* OR16ri8 */
  0x27, /* ADC16ri8 */
  0xa11, /* SBB16ri8 */
  0xb5, /* AND16ri8 */
  0xb16, /* SUB16ri8 */
  0x225e, /* XOR16ri8 */
  0x211, /* CMP16ri8 */
/* Table1165 */
  0xb87, /* TEST16rm */
  0xb88, /* TEST16rr */
/* Table1167 */
  0x2245, /* XCHG16rm */
  0x2246, /* XCHG16rr */
/* Table1169 */
  0x642, /* MOV16mr */
  0x64a, /* MOV16rr */
/* Table1171 */
  0x649, /* MOV16rm */
  0x64b, /* MOV16rr_REV */
/* Table1173 */
  0x643, /* MOV16ms */
  0x64c, /* MOV16rs */
/* Table1175 */
  0x4d7, /* LEA16r */
  0x0, /*  */
/* Table1177 */
  0x64d, /* MOV16sm */
  0x64e, /* MOV16sr */
/* Table1179 */
  0x87c, /* POP16rmm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x87d, /* POP16rmr */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table1195 */
  0x2244, /* XCHG16ar */
/* Table1196 */
  0x16a, /* CBW */
/* Table1197 */
  0x292, /* CWD */
/* Table1198 */
  0x2ef, /* FARCALL16i */
/* Table1199 */
  0x907, /* PUSHF16 */
/* Table1200 */
  0x890, /* POPF16 */
/* Table1201 */
  0x63f, /* MOV16ao32 */
/* Table1202 */
  0x645, /* MOV16o32a */
/* Table1203 */
  0x6d8, /* MOVSW */
/* Table1204 */
  0x243, /* CMPSW */
/* Table1205 */
  0xb82, /* TEST16i16 */
/* Table1206 */
  0xaf2, /* STOSW */
/* Table1207 */
  0x533, /* LODSW */
/* Table1208 */
  0xa33, /* SCASW */
/* Table1209 */
  0x647, /* MOV16ri */
/* Table1210 */
  0x991, /* ROL16mi */
  0x9a9, /* ROR16mi */
  0x918, /* RCL16mi */
  0x938, /* RCR16mi */
  0xa76, /* SHL16mi */
  0xa9e, /* SHR16mi */
  0x9d9, /* SAL16mi */
  0x9f2, /* SAR16mi */
  0x994, /* ROL16ri */
  0x9ac, /* ROR16ri */
  0x91b, /* RCL16ri */
  0x93b, /* RCR16ri */
  0xa79, /* SHL16ri */
  0xaa1, /* SHR16ri */
  0x9dc, /* SAL16ri */
  0x9f5, /* SAR16ri */
/* Table1226 */
  0x98a, /* RETIW */
/* Table1227 */
  0x98d, /* RETW */
/* Table1228 */
  0x4dd, /* LES16rm */
  0x0, /*  */
/* Table1230 */
  0x4c3, /* LDS16rm */
  0x0, /*  */
/* Table1232 */
  0x641, /* MOV16mi */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x648, /* MOV16ri_alt */
  0x648, /* MOV16ri_alt */
  0x648, /* MOV16ri_alt */
  0x648, /* MOV16ri_alt */
  0x648, /* MOV16ri_alt */
  0x648, /* MOV16ri_alt */
  0x648, /* MOV16ri_alt */
  0x648, /* MOV16ri_alt */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2242, /* XBEGIN_2 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table1304 */
  0x539, /* LRETIW */
/* Table1305 */
  0x53c, /* LRETW */
/* Table1306 */
  0x3b5, /* IRET16 */
/* Table1307 */
  0x98f, /* ROL16m1 */
  0x9a7, /* ROR16m1 */
  0x916, /* RCL16m1 */
  0x936, /* RCR16m1 */
  0xa74, /* SHL16m1 */
  0xa9c, /* SHR16m1 */
  0x9d7, /* SAL16m1 */
  0x9f0, /* SAR16m1 */
  0x992, /* ROL16r1 */
  0x9aa, /* ROR16r1 */
  0x919, /* RCL16r1 */
  0x939, /* RCR16r1 */
  0xa77, /* SHL16r1 */
  0xa9f, /* SHR16r1 */
  0x9da, /* SAL16r1 */
  0x9f3, /* SAR16r1 */
/* Table1323 */
  0x990, /* ROL16mCL */
  0x9a8, /* ROR16mCL */
  0x917, /* RCL16mCL */
  0x937, /* RCR16mCL */
  0xa75, /* SHL16mCL */
  0xa9d, /* SHR16mCL */
  0x9d8, /* SAL16mCL */
  0x9f1, /* SAR16mCL */
  0x993, /* ROL16rCL */
  0x9ab, /* ROR16rCL */
  0x91a, /* RCL16rCL */
  0x93a, /* RCR16rCL */
  0xa78, /* SHL16rCL */
  0xaa0, /* SHR16rCL */
  0x9db, /* SAL16rCL */
  0x9f4, /* SAR16rCL */
/* Table1339 */
  0x390, /* IN16ri */
/* Table1340 */
  0x78a, /* OUT16ir */
/* Table1341 */
  0x168, /* CALLpcrel16 */
/* Table1342 */
  0x45f, /* JMP_2 */
/* Table1343 */
  0x2f4, /* FARJMP16i */
/* Table1344 */
  0x391, /* IN16rr */
/* Table1345 */
  0x78b, /* OUT16rr */
/* Table1346 */
  0xb83, /* TEST16mi */
  0xb84, /* TEST16mi_alt */
  0x759, /* NOT16m */
  0x731, /* NEG16m */
  0x703, /* MUL16m */
  0x376, /* IMUL16m */
  0x2a1, /* DIV16m */
  0x362, /* IDIV16m */
  0xb85, /* TEST16ri */
  0xb86, /* TEST16ri_alt */
  0x75a, /* NOT16r */
  0x732, /* NEG16r */
  0x704, /* MUL16r */
  0x377, /* IMUL16r */
  0x2a2, /* DIV16r */
  0x363, /* IDIV16r */
/* Table1362 */
  0x396, /* INC16m */
  0x297, /* DEC16m */
  0x161, /* CALL16m */
  0x2f0, /* FARCALL16m */
  0x458, /* JMP16m */
  0x2f5, /* FARJMP16m */
  0x8f3, /* PUSH16rmm */
  0x0, /*  */
  0x397, /* INC16r */
  0x298, /* DEC16r */
  0x162, /* CALL16r */
  0x0, /*  */
  0x459, /* JMP16r */
  0x0, /*  */
  0x8f4, /* PUSH16rmr */
  0x0, /*  */
/* Table1378 */
  0x67d, /* MOV8ao16 */
/* Table1379 */
  0x64f, /* MOV32ao16 */
/* Table1380 */
  0x683, /* MOV8o16a */
/* Table1381 */
  0x657, /* MOV32o16a */
/* Table1382 */
  0x447, /* JCXZ */
/* Table1383 */
  0x63e, /* MOV16ao16 */
/* Table1384 */
  0x644, /* MOV16o16a */
/* Table1385 */
  0x7b7, /* PAUSE */
/* Table1386 */
  0x65, /* ADD64mr */
  0x6b, /* ADD64rr */
/* Table1388 */
  0x6a, /* ADD64rm */
  0x6d, /* ADD64rr_REV */
/* Table1390 */
  0x62, /* ADD64i32 */
/* Table1391 */
  0x777, /* OR64mr */
  0x77b, /* OR64rr */
/* Table1393 */
  0x77a, /* OR64rm */
  0x77c, /* OR64rr_REV */
/* Table1395 */
  0x774, /* OR64i32 */
/* Table1396 */
  0x37, /* ADC64mr */
  0x3b, /* ADC64rr */
/* Table1398 */
  0x3a, /* ADC64rm */
  0x3c, /* ADC64rr_REV */
/* Table1400 */
  0x34, /* ADC64i32 */
/* Table1401 */
  0xa21, /* SBB64mr */
  0xa25, /* SBB64rr */
/* Table1403 */
  0xa24, /* SBB64rm */
  0xa26, /* SBB64rr_REV */
/* Table1405 */
  0xa1e, /* SBB64i32 */
/* Table1406 */
  0xc5, /* AND64mr */
  0xc9, /* AND64rr */
/* Table1408 */
  0xc8, /* AND64rm */
  0xca, /* AND64rr_REV */
/* Table1410 */
  0xc2, /* AND64i32 */
/* Table1411 */
  0xb26, /* SUB64mr */
  0xb2a, /* SUB64rr */
/* Table1413 */
  0xb29, /* SUB64rm */
  0xb2b, /* SUB64rr_REV */
/* Table1415 */
  0xb23, /* SUB64i32 */
/* Table1416 */
  0x226e, /* XOR64mr */
  0x2272, /* XOR64rr */
/* Table1418 */
  0x2271, /* XOR64rm */
  0x2273, /* XOR64rr_REV */
/* Table1420 */
  0x226b, /* XOR64i32 */
/* Table1421 */
  0x221, /* CMP64mr */
  0x225, /* CMP64rr */
/* Table1423 */
  0x224, /* CMP64rm */
  0x226, /* CMP64rr_REV */
/* Table1425 */
  0x21e, /* CMP64i32 */
/* Table1426 */
  0x6e3, /* MOVSX64rm32 */
  0x6e7, /* MOVSX64rr32 */
/* Table1428 */
  0x389, /* IMUL64rmi32 */
  0x38c, /* IMUL64rri32 */
/* Table1430 */
  0x38a, /* IMUL64rmi8 */
  0x38d, /* IMUL64rri8 */
/* Table1432 */
  0x63, /* ADD64mi32 */
  0x775, /* OR64mi32 */
  0x35, /* ADC64mi32 */
  0xa1f, /* SBB64mi32 */
  0xc3, /* AND64mi32 */
  0xb24, /* SUB64mi32 */
  0x226c, /* XOR64mi32 */
  0x21f, /* CMP64mi32 */
  0x66, /* ADD64ri32 */
  0x778, /* OR64ri32 */
  0x38, /* ADC64ri32 */
  0xa22, /* SBB64ri32 */
  0xc6, /* AND64ri32 */
  0xb27, /* SUB64ri32 */
  0x226f, /* XOR64ri32 */
  0x222, /* CMP64ri32 */
/* Table1448 */
  0x64, /* ADD64mi8 */
  0x776, /* OR64mi8 */
  0x36, /* ADC64mi8 */
  0xa20, /* SBB64mi8 */
  0xc4, /* AND64mi8 */
  0xb25, /* SUB64mi8 */
  0x226d, /* XOR64mi8 */
  0x220, /* CMP64mi8 */
  0x68, /* ADD64ri8 */
  0x779, /* OR64ri8 */
  0x39, /* ADC64ri8 */
  0xa23, /* SBB64ri8 */
  0xc7, /* AND64ri8 */
  0xb28, /* SUB64ri8 */
  0x2270, /* XOR64ri8 */
  0x223, /* CMP64ri8 */
/* Table1464 */
  0xb95, /* TEST64rm */
  0xb96, /* TEST64rr */
/* Table1466 */
  0x224c, /* XCHG64rm */
  0x224d, /* XCHG64rr */
/* Table1468 */
  0x66b, /* MOV64mr */
  0x674, /* MOV64rr */
/* Table1470 */
  0x673, /* MOV64rm */
  0x675, /* MOV64rr_REV */
/* Table1472 */
  0x66c, /* MOV64ms */
  0x676, /* MOV64rs */
/* Table1474 */
  0x4da, /* LEA64r */
  0x0, /*  */
/* Table1476 */
  0x677, /* MOV64sm */
  0x678, /* MOV64sr */
/* Table1478 */
  0x224b, /* XCHG64ar */
/* Table1479 */
  0x16c, /* CDQE */
/* Table1480 */
  0x25b, /* CQO */
/* Table1481 */
  0x667, /* MOV64ao64 */
/* Table1482 */
  0x66e, /* MOV64o64a */
/* Table1483 */
  0x6d1, /* MOVSQ */
/* Table1484 */
  0x23e, /* CMPSQ */
/* Table1485 */
  0xb90, /* TEST64i32 */
/* Table1486 */
  0xaf1, /* STOSQ */
/* Table1487 */
  0x532, /* LODSQ */
/* Table1488 */
  0xa32, /* SCASQ */
/* Table1489 */
  0x671, /* MOV64ri */
/* Table1490 */
  0x99d, /* ROL64mi */
  0x9b5, /* ROR64mi */
  0x924, /* RCL64mi */
  0x944, /* RCR64mi */
  0xa82, /* SHL64mi */
  0xaaa, /* SHR64mi */
  0x9e5, /* SAL64mi */
  0x9fe, /* SAR64mi */
  0x9a0, /* ROL64ri */
  0x9b8, /* ROR64ri */
  0x927, /* RCL64ri */
  0x947, /* RCR64ri */
  0xa85, /* SHL64ri */
  0xaad, /* SHR64ri */
  0x9e8, /* SAL64ri */
  0xa01, /* SAR64ri */
/* Table1506 */
  0x66a, /* MOV64mi32 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2243, /* XBEGIN_4 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table1578 */
  0x538, /* LRETIQ */
/* Table1579 */
  0x53b, /* LRETQ */
/* Table1580 */
  0x3b7, /* IRET64 */
/* Table1581 */
  0x99b, /* ROL64m1 */
  0x9b3, /* ROR64m1 */
  0x922, /* RCL64m1 */
  0x942, /* RCR64m1 */
  0xa80, /* SHL64m1 */
  0xaa8, /* SHR64m1 */
  0x9e3, /* SAL64m1 */
  0x9fc, /* SAR64m1 */
  0x99e, /* ROL64r1 */
  0x9b6, /* ROR64r1 */
  0x925, /* RCL64r1 */
  0x945, /* RCR64r1 */
  0xa83, /* SHL64r1 */
  0xaab, /* SHR64r1 */
  0x9e6, /* SAL64r1 */
  0x9ff, /* SAR64r1 */
/* Table1597 */
  0x99c, /* ROL64mCL */
  0x9b4, /* ROR64mCL */
  0x923, /* RCL64mCL */
  0x943, /* RCR64mCL */
  0xa81, /* SHL64mCL */
  0xaa9, /* SHR64mCL */
  0x9e4, /* SAL64mCL */
  0x9fd, /* SAR64mCL */
  0x99f, /* ROL64rCL */
  0x9b7, /* ROR64rCL */
  0x926, /* RCL64rCL */
  0x946, /* RCR64rCL */
  0xa84, /* SHL64rCL */
  0xaac, /* SHR64rCL */
  0x9e7, /* SAL64rCL */
  0xa00, /* SAR64rCL */
/* Table1613 */
  0xb91, /* TEST64mi32 */
  0xb92, /* TEST64mi32_alt */
  0x75d, /* NOT64m */
  0x735, /* NEG64m */
  0x707, /* MUL64m */
  0x386, /* IMUL64m */
  0x2a5, /* DIV64m */
  0x366, /* IDIV64m */
  0xb93, /* TEST64ri32 */
  0xb94, /* TEST64ri32_alt */
  0x75e, /* NOT64r */
  0x736, /* NEG64r */
  0x708, /* MUL64r */
  0x387, /* IMUL64r */
  0x2a6, /* DIV64r */
  0x367, /* IDIV64r */
/* Table1629 */
  0x39c, /* INC64m */
  0x29d, /* DEC64m */
  0x165, /* CALL64m */
  0x2f3, /* FARCALL64 */
  0x45c, /* JMP64m */
  0x2f8, /* FARJMP64 */
  0x8fd, /* PUSH64rmm */
  0x0, /*  */
  0x39d, /* INC64r */
  0x29e, /* DEC64r */
  0x167, /* CALL64r */
  0x0, /*  */
  0x45d, /* JMP64r */
  0x0, /*  */
  0x8fe, /* PUSH64rmr */
  0x0, /*  */
/* Table1645 */
  0x8f9, /* PUSH64i16 */
/* Table1646 */
  0x666, /* MOV64ao32 */
/* Table1647 */
  0x66d, /* MOV64o32a */
/* Table1648 */
  0x66a, /* MOV64mi32 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x672, /* MOV64ri32 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2242, /* XBEGIN_2 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table1720 */
  0x39c, /* INC64m */
  0x29d, /* DEC64m */
  0x165, /* CALL64m */
  0x2f3, /* FARCALL64 */
  0x45c, /* JMP64m */
  0x2f8, /* FARJMP64 */
  0x8f3, /* PUSH16rmm */
  0x0, /*  */
  0x39d, /* INC64r */
  0x29e, /* DEC64r */
  0x167, /* CALL64r */
  0x0, /*  */
  0x45d, /* JMP64r */
  0x0, /*  */
  0x8f4, /* PUSH16rmr */
  0x0, /*  */
/* Table1736 */
  0x640, /* MOV16ao64 */
/* Table1737 */
  0x646, /* MOV16o64a */
/* Table1738 */
  0x396, /* INC16m */
  0x297, /* DEC16m */
  0x165, /* CALL64m */
  0x2f0, /* FARCALL16m */
  0x45c, /* JMP64m */
  0x2f5, /* FARJMP16m */
  0x8f3, /* PUSH16rmm */
  0x0, /*  */
  0x397, /* INC16r */
  0x298, /* DEC16r */
  0x167, /* CALL64r */
  0x0, /*  */
  0x45d, /* JMP64r */
  0x0, /*  */
  0x8f4, /* PUSH16rmr */
  0x0, /*  */
/* Table1754 */
  0xad0, /* SLDT16m */
  0xaf6, /* STRm */
  0x4ec, /* LLDT16m */
  0x546, /* LTRm */
  0xe12, /* VERRm */
  0xe14, /* VERWm */
  0x0, /*  */
  0x0, /*  */
  0xad2, /* SLDT32r */
  0xaf4, /* STR32r */
  0x4ed, /* LLDT16r */
  0x547, /* LTRr */
  0xe13, /* VERRr */
  0xe15, /* VERWr */
  0x0, /*  */
  0x0, /*  */
/* Table1770 */
  0xa64, /* SGDT32m */
  0xac9, /* SIDT32m */
  0x4e4, /* LGDT32m */
  0x4ea, /* LIDT32m */
  0xad5, /* SMSW16m */
  0x0, /*  */
  0x4ee, /* LMSW16m */
  0x3ae, /* INVLPG */
  0x0, /*  */
  0x1397, /* VMCALL */
  0x1402, /* VMLAUNCH */
  0x15fc, /* VMRESUME */
  0x1667, /* VMXOFF */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x63a, /* MONITORrrr */
  0x730, /* MWAITrr */
  0x171, /* CLAC */
  0xae9, /* STAC */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2e7, /* ENCLS */
  0x2257, /* XGETBV */
  0x228e, /* XSETBV */
  0x0, /*  */
  0x0, /*  */
  0x1399, /* VMFUNC */
  0x2256, /* XEND */
  0x2292, /* XTEST */
  0x2e8, /* ENCLU */
  0x15fd, /* VMRUN32 */
  0x1405, /* VMMCALL */
  0x1403, /* VMLOAD32 */
  0x15ff, /* VMSAVE32 */
  0xaec, /* STGI */
  0x176, /* CLGI */
  0xacf, /* SKINIT */
  0x3af, /* INVLPGA32 */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0xb68, /* SWAPGS */
  0x95b, /* RDTSCP */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table1842 */
  0x4b7, /* LAR32rm */
  0x4b8, /* LAR32rr */
/* Table1844 */
  0x53f, /* LSL32rm */
  0x540, /* LSL32rr */
/* Table1846 */
  0xb69, /* SYSCALL */
/* Table1847 */
  0x178, /* CLTS */
/* Table1848 */
  0xb6d, /* SYSRET */
/* Table1849 */
  0x3ab, /* INVD */
/* Table1850 */
  0x222e, /* WBINVD */
/* Table1851 */
  0xba5, /* TRAP */
/* Table1852 */
  0x0, /*  */
  0x8a2, /* PREFETCHW */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table1868 */
  0x6ee, /* MOVUPSrm */
  0x6ef, /* MOVUPSrr */
/* Table1870 */
  0x6ed, /* MOVUPSmr */
  0x6f0, /* MOVUPSrr_REV */
/* Table1872 */
  0x6b2, /* MOVLPSrm */
  0x6a9, /* MOVHLPSrr */
/* Table1874 */
  0x6b1, /* MOVLPSmr */
  0x0, /*  */
/* Table1876 */
  0xbca, /* UNPCKLPSrm */
  0xbcb, /* UNPCKLPSrr */
/* Table1878 */
  0xbc6, /* UNPCKHPSrm */
  0xbc7, /* UNPCKHPSrr */
/* Table1880 */
  0x6ad, /* MOVHPSrm */
  0x6ae, /* MOVLHPSrr */
/* Table1882 */
  0x6ac, /* MOVHPSmr */
  0x0, /*  */
/* Table1884 */
  0x89e, /* PREFETCHNTA */
  0x89f, /* PREFETCHT0 */
  0x8a0, /* PREFETCHT1 */
  0x8a1, /* PREFETCHT2 */
  0x742, /* NOOP18_m4 */
  0x743, /* NOOP18_m5 */
  0x744, /* NOOP18_m6 */
  0x745, /* NOOP18_m7 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x746, /* NOOP18_r4 */
  0x747, /* NOOP18_r5 */
  0x748, /* NOOP18_r6 */
  0x749, /* NOOP18_r7 */
/* Table1900 */
  0x74c, /* NOOPL_19 */
  0x74a, /* NOOP19rr */
/* Table1902 */
  0x74d, /* NOOPL_1a */
  0x0, /*  */
/* Table1904 */
  0x74e, /* NOOPL_1b */
  0x0, /*  */
/* Table1906 */
  0x74f, /* NOOPL_1c */
  0x0, /*  */
/* Table1908 */
  0x750, /* NOOPL_1d */
  0x0, /*  */
/* Table1910 */
  0x751, /* NOOPL_1e */
  0x0, /*  */
/* Table1912 */
  0x74b, /* NOOPL */
  0x0, /*  */
/* Table1914 */
  0x0, /*  */
  0x65b, /* MOV32rc */
/* Table1916 */
  0x0, /*  */
  0x65c, /* MOV32rd */
/* Table1918 */
  0x0, /*  */
  0x652, /* MOV32cr */
/* Table1920 */
  0x0, /*  */
  0x653, /* MOV32dr */
/* Table1922 */
  0x692, /* MOVAPSrm */
  0x693, /* MOVAPSrr */
/* Table1924 */
  0x691, /* MOVAPSmr */
  0x694, /* MOVAPSrr_REV */
/* Table1926 */
  0x581, /* MMX_CVTPI2PSirm */
  0x582, /* MMX_CVTPI2PSirr */
/* Table1928 */
  0x6ba, /* MOVNTPSmr */
  0x0, /*  */
/* Table1930 */
  0x587, /* MMX_CVTTPS2PIirm */
  0x588, /* MMX_CVTTPS2PIirr */
/* Table1932 */
  0x583, /* MMX_CVTPS2PIirm */
  0x584, /* MMX_CVTPS2PIirr */
/* Table1934 */
  0xbb6, /* UCOMISSrm */
  0xbb7, /* UCOMISSrr */
/* Table1936 */
  0x250, /* COMISSrm */
  0x251, /* COMISSrr */
/* Table1938 */
  0x2236, /* WRMSR */
/* Table1939 */
  0x95a, /* RDTSC */
/* Table1940 */
  0x952, /* RDMSR */
/* Table1941 */
  0x953, /* RDPMC */
/* Table1942 */
  0xb6a, /* SYSENTER */
/* Table1943 */
  0xb6b, /* SYSEXIT */
/* Table1944 */
  0x358, /* GETSEC */
/* Table1945 */
  0x1e7, /* CMOVO32rm */
  0x1e8, /* CMOVO32rr */
/* Table1947 */
  0x1d1, /* CMOVNO32rm */
  0x1d2, /* CMOVNO32rr */
/* Table1949 */
  0x189, /* CMOVB32rm */
  0x18a, /* CMOVB32rr */
/* Table1951 */
  0x183, /* CMOVAE32rm */
  0x184, /* CMOVAE32rr */
/* Table1953 */
  0x19d, /* CMOVE32rm */
  0x19e, /* CMOVE32rr */
/* Table1955 */
  0x1c7, /* CMOVNE32rm */
  0x1c8, /* CMOVNE32rr */
/* Table1957 */
  0x18f, /* CMOVBE32rm */
  0x190, /* CMOVBE32rr */
/* Table1959 */
  0x17d, /* CMOVA32rm */
  0x17e, /* CMOVA32rr */
/* Table1961 */
  0x1f7, /* CMOVS32rm */
  0x1f8, /* CMOVS32rr */
/* Table1963 */
  0x1e1, /* CMOVNS32rm */
  0x1e2, /* CMOVNS32rr */
/* Table1965 */
  0x1ed, /* CMOVP32rm */
  0x1ee, /* CMOVP32rr */
/* Table1967 */
  0x1d7, /* CMOVNP32rm */
  0x1d8, /* CMOVNP32rr */
/* Table1969 */
  0x1b3, /* CMOVL32rm */
  0x1b4, /* CMOVL32rr */
/* Table1971 */
  0x1ad, /* CMOVGE32rm */
  0x1ae, /* CMOVGE32rr */
/* Table1973 */
  0x1b9, /* CMOVLE32rm */
  0x1ba, /* CMOVLE32rr */
/* Table1975 */
  0x1a7, /* CMOVG32rm */
  0x1a8, /* CMOVG32rr */
/* Table1977 */
  0x0, /*  */
  0x6b4, /* MOVMSKPSrr */
/* Table1979 */
  0xadb, /* SQRTPSm */
  0xadc, /* SQRTPSr */
/* Table1981 */
  0x9ce, /* RSQRTPSm */
  0x9d0, /* RSQRTPSr */
/* Table1983 */
  0x92e, /* RCPPSm */
  0x930, /* RCPPSr */
/* Table1985 */
  0xde, /* ANDPSrm */
  0xdf, /* ANDPSrr */
/* Table1987 */
  0xda, /* ANDNPSrm */
  0xdb, /* ANDNPSrr */
/* Table1989 */
  0x788, /* ORPSrm */
  0x789, /* ORPSrr */
/* Table1991 */
  0x227f, /* XORPSrm */
  0x2280, /* XORPSrr */
/* Table1993 */
  0x79, /* ADDPSrm */
  0x7a, /* ADDPSrr */
/* Table1995 */
  0x70d, /* MULPSrm */
  0x70e, /* MULPSrr */
/* Table1997 */
  0x270, /* CVTPS2PDrm */
  0x271, /* CVTPS2PDrr */
/* Table1999 */
  0x268, /* CVTDQ2PSrm */
  0x269, /* CVTDQ2PSrr */
/* Table2001 */
  0xb37, /* SUBPSrm */
  0xb38, /* SUBPSrr */
/* Table2003 */
  0x573, /* MINPSrm */
  0x574, /* MINPSrr */
/* Table2005 */
  0x2ab, /* DIVPSrm */
  0x2ac, /* DIVPSrr */
/* Table2007 */
  0x55e, /* MAXPSrm */
  0x55f, /* MAXPSrr */
/* Table2009 */
  0x631, /* MMX_PUNPCKLBWirm */
  0x632, /* MMX_PUNPCKLBWirr */
/* Table2011 */
  0x635, /* MMX_PUNPCKLWDirm */
  0x636, /* MMX_PUNPCKLWDirr */
/* Table2013 */
  0x633, /* MMX_PUNPCKLDQirm */
  0x634, /* MMX_PUNPCKLDQirr */
/* Table2015 */
  0x5a5, /* MMX_PACKSSWBirm */
  0x5a6, /* MMX_PACKSSWBirr */
/* Table2017 */
  0x5c9, /* MMX_PCMPGTBirm */
  0x5ca, /* MMX_PCMPGTBirr */
/* Table2019 */
  0x5cd, /* MMX_PCMPGTWirm */
  0x5ce, /* MMX_PCMPGTWirr */
/* Table2021 */
  0x5cb, /* MMX_PCMPGTDirm */
  0x5cc, /* MMX_PCMPGTDirr */
/* Table2023 */
  0x5a7, /* MMX_PACKUSWBirm */
  0x5a8, /* MMX_PACKUSWBirr */
/* Table2025 */
  0x62b, /* MMX_PUNPCKHBWirm */
  0x62c, /* MMX_PUNPCKHBWirr */
/* Table2027 */
  0x62f, /* MMX_PUNPCKHWDirm */
  0x630, /* MMX_PUNPCKHWDirr */
/* Table2029 */
  0x62d, /* MMX_PUNPCKHDQirm */
  0x62e, /* MMX_PUNPCKHDQirr */
/* Table2031 */
  0x5a3, /* MMX_PACKSSDWirm */
  0x5a4, /* MMX_PACKSSDWirr */
/* Table2033 */
  0x590, /* MMX_MOVD64rm */
  0x591, /* MMX_MOVD64rr */
/* Table2035 */
  0x59a, /* MMX_MOVQ64rm */
  0x59b, /* MMX_MOVQ64rr */
/* Table2037 */
  0x5fb, /* MMX_PSHUFWmi */
  0x5fc, /* MMX_PSHUFWri */
/* Table2039 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x618, /* MMX_PSRLWri */
  0x0, /*  */
  0x60f, /* MMX_PSRAWri */
  0x0, /*  */
  0x609, /* MMX_PSLLWri */
  0x0, /*  */
/* Table2055 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x612, /* MMX_PSRLDri */
  0x0, /*  */
  0x60c, /* MMX_PSRADri */
  0x0, /*  */
  0x603, /* MMX_PSLLDri */
  0x0, /*  */
/* Table2071 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x615, /* MMX_PSRLQri */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x606, /* MMX_PSLLQri */
  0x0, /*  */
/* Table2087 */
  0x5c3, /* MMX_PCMPEQBirm */
  0x5c4, /* MMX_PCMPEQBirr */
/* Table2089 */
  0x5c7, /* MMX_PCMPEQWirm */
  0x5c8, /* MMX_PCMPEQWirr */
/* Table2091 */
  0x5c5, /* MMX_PCMPEQDirm */
  0x5c6, /* MMX_PCMPEQDirr */
/* Table2093 */
  0x589, /* MMX_EMMS */
/* Table2094 */
  0x15f8, /* VMREAD32rm */
  0x15f9, /* VMREAD32rr */
/* Table2096 */
  0x1663, /* VMWRITE32rm */
  0x1664, /* VMWRITE32rr */
/* Table2098 */
  0x58f, /* MMX_MOVD64mr */
  0x58e, /* MMX_MOVD64grr */
/* Table2100 */
  0x599, /* MMX_MOVQ64mr */
  0x59c, /* MMX_MOVQ64rr_REV */
/* Table2102 */
  0x46f, /* JO_4 */
/* Table2103 */
  0x466, /* JNO_4 */
/* Table2104 */
  0x446, /* JB_4 */
/* Table2105 */
  0x43d, /* JAE_4 */
/* Table2106 */
  0x44b, /* JE_4 */
/* Table2107 */
  0x463, /* JNE_4 */
/* Table2108 */
  0x443, /* JBE_4 */
/* Table2109 */
  0x440, /* JA_4 */
/* Table2110 */
  0x476, /* JS_4 */
/* Table2111 */
  0x46c, /* JNS_4 */
/* Table2112 */
  0x472, /* JP_4 */
/* Table2113 */
  0x469, /* JNP_4 */
/* Table2114 */
  0x457, /* JL_4 */
/* Table2115 */
  0x44e, /* JGE_4 */
/* Table2116 */
  0x454, /* JLE_4 */
/* Table2117 */
  0x451, /* JG_4 */
/* Table2118 */
  0xa5c, /* SETOm */
  0xa5d, /* SETOr */
/* Table2120 */
  0xa56, /* SETNOm */
  0xa57, /* SETNOr */
/* Table2122 */
  0xa48, /* SETBm */
  0xa49, /* SETBr */
/* Table2124 */
  0xa3e, /* SETAEm */
  0xa3f, /* SETAEr */
/* Table2126 */
  0xa4a, /* SETEm */
  0xa4b, /* SETEr */
/* Table2128 */
  0xa54, /* SETNEm */
  0xa55, /* SETNEr */
/* Table2130 */
  0xa42, /* SETBEm */
  0xa43, /* SETBEr */
/* Table2132 */
  0xa40, /* SETAm */
  0xa41, /* SETAr */
/* Table2134 */
  0xa60, /* SETSm */
  0xa61, /* SETSr */
/* Table2136 */
  0xa5a, /* SETNSm */
  0xa5b, /* SETNSr */
/* Table2138 */
  0xa5e, /* SETPm */
  0xa5f, /* SETPr */
/* Table2140 */
  0xa58, /* SETNPm */
  0xa59, /* SETNPr */
/* Table2142 */
  0xa52, /* SETLm */
  0xa53, /* SETLr */
/* Table2144 */
  0xa4c, /* SETGEm */
  0xa4d, /* SETGEr */
/* Table2146 */
  0xa50, /* SETLEm */
  0xa51, /* SETLEr */
/* Table2148 */
  0xa4e, /* SETGm */
  0xa4f, /* SETGr */
/* Table2150 */
  0x90b, /* PUSHFS32 */
/* Table2151 */
  0x894, /* POPFS32 */
/* Table2152 */
  0x25a, /* CPUID */
/* Table2153 */
  0x132, /* BT32mr */
  0x134, /* BT32rr */
/* Table2155 */
  0xa91, /* SHLD32mri8 */
  0xa93, /* SHLD32rri8 */
/* Table2157 */
  0xa90, /* SHLD32mrCL */
  0xa92, /* SHLD32rrCL */
/* Table2159 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x63b, /* MONTMUL */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x228f, /* XSHA1 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2290, /* XSHA256 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table2231 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2291, /* XSTORE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2254, /* XCRYPTECB */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2251, /* XCRYPTCBC */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2253, /* XCRYPTCTR */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2252, /* XCRYPTCFB */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2255, /* XCRYPTOFB */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table2303 */
  0x90e, /* PUSHGS32 */
/* Table2304 */
  0x897, /* POPGS32 */
/* Table2305 */
  0x9cd, /* RSM */
/* Table2306 */
  0x156, /* BTS32mr */
  0x158, /* BTS32rr */
/* Table2308 */
  0xab9, /* SHRD32mri8 */
  0xabb, /* SHRD32rri8 */
/* Table2310 */
  0xab8, /* SHRD32mrCL */
  0xaba, /* SHRD32rrCL */
/* Table2312 */
  0x32d, /* FXSAVE */
  0x32b, /* FXRSTOR */
  0x4c2, /* LDMXCSR */
  0xaee, /* STMXCSR */
  0x2286, /* XSAVE */
  0x2282, /* XRSTOR */
  0x228a, /* XSAVEOPT */
  0x174, /* CLFLUSH */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x4df, /* LFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x568, /* MFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0xa62, /* SFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table2384 */
  0x380, /* IMUL32rm */
  0x383, /* IMUL32rr */
/* Table2386 */
  0x24c, /* CMPXCHG8rm */
  0x24d, /* CMPXCHG8rr */
/* Table2388 */
  0x247, /* CMPXCHG32rm */
  0x248, /* CMPXCHG32rr */
/* Table2390 */
  0x544, /* LSS32rm */
  0x0, /*  */
/* Table2392 */
  0x14a, /* BTR32mr */
  0x14c, /* BTR32rr */
/* Table2394 */
  0x4e1, /* LFS32rm */
  0x0, /*  */
/* Table2396 */
  0x4e7, /* LGS32rm */
  0x0, /*  */
/* Table2398 */
  0x6fa, /* MOVZX32rm8 */
  0x6fc, /* MOVZX32rr8 */
/* Table2400 */
  0x6f9, /* MOVZX32rm16 */
  0x6fb, /* MOVZX32rr16 */
/* Table2402 */
  0xbc3, /* UD2B */
/* Table2403 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x131, /* BT32mi8 */
  0x155, /* BTS32mi8 */
  0x149, /* BTR32mi8 */
  0x13d, /* BTC32mi8 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x133, /* BT32ri8 */
  0x157, /* BTS32ri8 */
  0x14b, /* BTR32ri8 */
  0x13f, /* BTC32ri8 */
/* Table2419 */
  0x13e, /* BTC32mr */
  0x140, /* BTC32rr */
/* Table2421 */
  0x121, /* BSF32rm */
  0x122, /* BSF32rr */
/* Table2423 */
  0x127, /* BSR32rm */
  0x128, /* BSR32rr */
/* Table2425 */
  0x6de, /* MOVSX32rm8 */
  0x6e0, /* MOVSX32rr8 */
/* Table2427 */
  0x6dd, /* MOVSX32rm16 */
  0x6df, /* MOVSX32rr16 */
/* Table2429 */
  0x223f, /* XADD8rm */
  0x2240, /* XADD8rr */
/* Table2431 */
  0x223b, /* XADD32rm */
  0x223c, /* XADD32rr */
/* Table2433 */
  0x234, /* CMPPSrmi */
  0x236, /* CMPPSrri */
/* Table2435 */
  0x6b8, /* MOVNTImr */
  0x0, /*  */
/* Table2437 */
  0x5dc, /* MMX_PINSRWirmi */
  0x5dd, /* MMX_PINSRWirri */
/* Table2439 */
  0x0, /*  */
  0x5cf, /* MMX_PEXTRWirri */
/* Table2441 */
  0xac6, /* SHUFPSrmi */
  0xac7, /* SHUFPSrri */
/* Table2443 */
  0x0, /*  */
  0x24b, /* CMPXCHG8B */
  0x0, /*  */
  0x2284, /* XRSTORS */
  0x2288, /* XSAVEC */
  0x228c, /* XSAVES */
  0x15f6, /* VMPTRLDm */
  0x15f7, /* VMPTRSTm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x955, /* RDRAND32r */
  0x958, /* RDSEED32r */
/* Table2459 */
  0x12b, /* BSWAP32r */
/* Table2460 */
  0x619, /* MMX_PSRLWrm */
  0x61a, /* MMX_PSRLWrr */
/* Table2462 */
  0x613, /* MMX_PSRLDrm */
  0x614, /* MMX_PSRLDrr */
/* Table2464 */
  0x616, /* MMX_PSRLQrm */
  0x617, /* MMX_PSRLQrr */
/* Table2466 */
  0x5ad, /* MMX_PADDQirm */
  0x5ae, /* MMX_PADDQirr */
/* Table2468 */
  0x5f1, /* MMX_PMULLWirm */
  0x5f2, /* MMX_PMULLWirr */
/* Table2470 */
  0x0, /*  */
  0x5ea, /* MMX_PMOVMSKBrr */
/* Table2472 */
  0x625, /* MMX_PSUBUSBirm */
  0x626, /* MMX_PSUBUSBirr */
/* Table2474 */
  0x627, /* MMX_PSUBUSWirm */
  0x628, /* MMX_PSUBUSWirr */
/* Table2476 */
  0x5e8, /* MMX_PMINUBirm */
  0x5e9, /* MMX_PMINUBirr */
/* Table2478 */
  0x5bd, /* MMX_PANDirm */
  0x5be, /* MMX_PANDirr */
/* Table2480 */
  0x5b3, /* MMX_PADDUSBirm */
  0x5b4, /* MMX_PADDUSBirr */
/* Table2482 */
  0x5b5, /* MMX_PADDUSWirm */
  0x5b6, /* MMX_PADDUSWirr */
/* Table2484 */
  0x5e4, /* MMX_PMAXUBirm */
  0x5e5, /* MMX_PMAXUBirr */
/* Table2486 */
  0x5bb, /* MMX_PANDNirm */
  0x5bc, /* MMX_PANDNirr */
/* Table2488 */
  0x5bf, /* MMX_PAVGBirm */
  0x5c0, /* MMX_PAVGBirr */
/* Table2490 */
  0x610, /* MMX_PSRAWrm */
  0x611, /* MMX_PSRAWrr */
/* Table2492 */
  0x60d, /* MMX_PSRADrm */
  0x60e, /* MMX_PSRADrr */
/* Table2494 */
  0x5c1, /* MMX_PAVGWirm */
  0x5c2, /* MMX_PAVGWirr */
/* Table2496 */
  0x5ed, /* MMX_PMULHUWirm */
  0x5ee, /* MMX_PMULHUWirr */
/* Table2498 */
  0x5ef, /* MMX_PMULHWirm */
  0x5f0, /* MMX_PMULHWirr */
/* Table2500 */
  0x596, /* MMX_MOVNTQmr */
  0x0, /*  */
/* Table2502 */
  0x621, /* MMX_PSUBSBirm */
  0x622, /* MMX_PSUBSBirr */
/* Table2504 */
  0x623, /* MMX_PSUBSWirm */
  0x624, /* MMX_PSUBSWirr */
/* Table2506 */
  0x5e6, /* MMX_PMINSWirm */
  0x5e7, /* MMX_PMINSWirr */
/* Table2508 */
  0x5f5, /* MMX_PORirm */
  0x5f6, /* MMX_PORirr */
/* Table2510 */
  0x5af, /* MMX_PADDSBirm */
  0x5b0, /* MMX_PADDSBirr */
/* Table2512 */
  0x5b1, /* MMX_PADDSWirm */
  0x5b2, /* MMX_PADDSWirr */
/* Table2514 */
  0x5e2, /* MMX_PMAXSWirm */
  0x5e3, /* MMX_PMAXSWirr */
/* Table2516 */
  0x637, /* MMX_PXORirm */
  0x638, /* MMX_PXORirr */
/* Table2518 */
  0x60a, /* MMX_PSLLWrm */
  0x60b, /* MMX_PSLLWrr */
/* Table2520 */
  0x604, /* MMX_PSLLDrm */
  0x605, /* MMX_PSLLDrr */
/* Table2522 */
  0x607, /* MMX_PSLLQrm */
  0x608, /* MMX_PSLLQrr */
/* Table2524 */
  0x5f3, /* MMX_PMULUDQirm */
  0x5f4, /* MMX_PMULUDQirr */
/* Table2526 */
  0x5e0, /* MMX_PMADDWDirm */
  0x5e1, /* MMX_PMADDWDirr */
/* Table2528 */
  0x5f7, /* MMX_PSADBWirm */
  0x5f8, /* MMX_PSADBWirr */
/* Table2530 */
  0x0, /*  */
  0x58a, /* MMX_MASKMOVQ */
/* Table2532 */
  0x61b, /* MMX_PSUBBirm */
  0x61c, /* MMX_PSUBBirr */
/* Table2534 */
  0x629, /* MMX_PSUBWirm */
  0x62a, /* MMX_PSUBWirr */
/* Table2536 */
  0x61d, /* MMX_PSUBDirm */
  0x61e, /* MMX_PSUBDirr */
/* Table2538 */
  0x61f, /* MMX_PSUBQirm */
  0x620, /* MMX_PSUBQirr */
/* Table2540 */
  0x5a9, /* MMX_PADDBirm */
  0x5aa, /* MMX_PADDBirr */
/* Table2542 */
  0x5b7, /* MMX_PADDWirm */
  0x5b8, /* MMX_PADDWirr */
/* Table2544 */
  0x5ab, /* MMX_PADDDirm */
  0x5ac, /* MMX_PADDDirr */
/* Table2546 */
  0xa65, /* SGDT64m */
  0xaca, /* SIDT64m */
  0x4e5, /* LGDT64m */
  0x4eb, /* LIDT64m */
  0xad5, /* SMSW16m */
  0x0, /*  */
  0x4ee, /* LMSW16m */
  0x3ae, /* INVLPG */
  0x0, /*  */
  0x1397, /* VMCALL */
  0x1402, /* VMLAUNCH */
  0x15fc, /* VMRESUME */
  0x1667, /* VMXOFF */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x63a, /* MONITORrrr */
  0x730, /* MWAITrr */
  0x171, /* CLAC */
  0xae9, /* STAC */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2e7, /* ENCLS */
  0x2257, /* XGETBV */
  0x228e, /* XSETBV */
  0x0, /*  */
  0x0, /*  */
  0x1399, /* VMFUNC */
  0x2256, /* XEND */
  0x2292, /* XTEST */
  0x2e8, /* ENCLU */
  0x15fe, /* VMRUN64 */
  0x1405, /* VMMCALL */
  0x1404, /* VMLOAD64 */
  0x1600, /* VMSAVE64 */
  0xaec, /* STGI */
  0x176, /* CLGI */
  0xacf, /* SKINIT */
  0x3b0, /* INVLPGA64 */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0xad7, /* SMSW32r */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0xb68, /* SWAPGS */
  0x95b, /* RDTSCP */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table2618 */
  0x0, /*  */
  0x66f, /* MOV64rc */
/* Table2620 */
  0x0, /*  */
  0x670, /* MOV64rd */
/* Table2622 */
  0x0, /*  */
  0x668, /* MOV64cr */
/* Table2624 */
  0x0, /*  */
  0x669, /* MOV64dr */
/* Table2626 */
  0x15fa, /* VMREAD64rm */
  0x15fb, /* VMREAD64rr */
/* Table2628 */
  0x1665, /* VMWRITE64rm */
  0x1666, /* VMWRITE64rr */
/* Table2630 */
  0x90c, /* PUSHFS64 */
/* Table2631 */
  0x895, /* POPFS64 */
/* Table2632 */
  0x90f, /* PUSHGS64 */
/* Table2633 */
  0x898, /* POPGS64 */
/* Table2634 */
  0x0, /*  */
  0x58b, /* MMX_MASKMOVQ64 */
/* Table2636 */
  0xad0, /* SLDT16m */
  0xaf6, /* STRm */
  0x4ec, /* LLDT16m */
  0x546, /* LTRm */
  0xe12, /* VERRm */
  0xe14, /* VERWm */
  0x0, /*  */
  0x0, /*  */
  0xad1, /* SLDT16r */
  0xaf3, /* STR16r */
  0x4ed, /* LLDT16r */
  0x547, /* LTRr */
  0xe13, /* VERRr */
  0xe15, /* VERWr */
  0x0, /*  */
  0x0, /*  */
/* Table2652 */
  0xa63, /* SGDT16m */
  0xac8, /* SIDT16m */
  0x4e3, /* LGDT16m */
  0x4e9, /* LIDT16m */
  0xad5, /* SMSW16m */
  0x0, /*  */
  0x4ee, /* LMSW16m */
  0x3ae, /* INVLPG */
  0x0, /*  */
  0x1397, /* VMCALL */
  0x1402, /* VMLAUNCH */
  0x15fc, /* VMRESUME */
  0x1667, /* VMXOFF */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x63a, /* MONITORrrr */
  0x730, /* MWAITrr */
  0x171, /* CLAC */
  0xae9, /* STAC */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2e7, /* ENCLS */
  0x2257, /* XGETBV */
  0x228e, /* XSETBV */
  0x0, /*  */
  0x0, /*  */
  0x1399, /* VMFUNC */
  0x2256, /* XEND */
  0x2292, /* XTEST */
  0x2e8, /* ENCLU */
  0x15fd, /* VMRUN32 */
  0x1405, /* VMMCALL */
  0x1403, /* VMLOAD32 */
  0x15ff, /* VMSAVE32 */
  0xaec, /* STGI */
  0x176, /* CLGI */
  0xacf, /* SKINIT */
  0x3af, /* INVLPGA32 */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0xb68, /* SWAPGS */
  0x95b, /* RDTSCP */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table2724 */
  0x4b5, /* LAR16rm */
  0x4b6, /* LAR16rr */
/* Table2726 */
  0x53d, /* LSL16rm */
  0x53e, /* LSL16rr */
/* Table2728 */
  0x6ea, /* MOVUPDrm */
  0x6eb, /* MOVUPDrr */
/* Table2730 */
  0x6e9, /* MOVUPDmr */
  0x6ec, /* MOVUPDrr_REV */
/* Table2732 */
  0x6b0, /* MOVLPDrm */
  0x6a9, /* MOVHLPSrr */
/* Table2734 */
  0x6af, /* MOVLPDmr */
  0x0, /*  */
/* Table2736 */
  0xbc8, /* UNPCKLPDrm */
  0xbc9, /* UNPCKLPDrr */
/* Table2738 */
  0xbc4, /* UNPCKHPDrm */
  0xbc5, /* UNPCKHPDrr */
/* Table2740 */
  0x6ab, /* MOVHPDrm */
  0x6ae, /* MOVLHPSrr */
/* Table2742 */
  0x6aa, /* MOVHPDmr */
  0x0, /*  */
/* Table2744 */
  0x89e, /* PREFETCHNTA */
  0x89f, /* PREFETCHT0 */
  0x8a0, /* PREFETCHT1 */
  0x8a1, /* PREFETCHT2 */
  0x73a, /* NOOP18_16m4 */
  0x73b, /* NOOP18_16m5 */
  0x73c, /* NOOP18_16m6 */
  0x73d, /* NOOP18_16m7 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x73e, /* NOOP18_16r4 */
  0x73f, /* NOOP18_16r5 */
  0x740, /* NOOP18_16r6 */
  0x741, /* NOOP18_16r7 */
/* Table2760 */
  0x753, /* NOOPW_19 */
  0x74a, /* NOOP19rr */
/* Table2762 */
  0x754, /* NOOPW_1a */
  0x0, /*  */
/* Table2764 */
  0x755, /* NOOPW_1b */
  0x0, /*  */
/* Table2766 */
  0x756, /* NOOPW_1c */
  0x0, /*  */
/* Table2768 */
  0x757, /* NOOPW_1d */
  0x0, /*  */
/* Table2770 */
  0x758, /* NOOPW_1e */
  0x0, /*  */
/* Table2772 */
  0x752, /* NOOPW */
  0x0, /*  */
/* Table2774 */
  0x68e, /* MOVAPDrm */
  0x68f, /* MOVAPDrr */
/* Table2776 */
  0x68d, /* MOVAPDmr */
  0x690, /* MOVAPDrr_REV */
/* Table2778 */
  0x57f, /* MMX_CVTPI2PDirm */
  0x580, /* MMX_CVTPI2PDirr */
/* Table2780 */
  0x6b9, /* MOVNTPDmr */
  0x0, /*  */
/* Table2782 */
  0x585, /* MMX_CVTTPD2PIirm */
  0x586, /* MMX_CVTTPD2PIirr */
/* Table2784 */
  0x57d, /* MMX_CVTPD2PIirm */
  0x57e, /* MMX_CVTPD2PIirr */
/* Table2786 */
  0xbb4, /* UCOMISDrm */
  0xbb5, /* UCOMISDrr */
/* Table2788 */
  0x24e, /* COMISDrm */
  0x24f, /* COMISDrr */
/* Table2790 */
  0x1e5, /* CMOVO16rm */
  0x1e6, /* CMOVO16rr */
/* Table2792 */
  0x1cf, /* CMOVNO16rm */
  0x1d0, /* CMOVNO16rr */
/* Table2794 */
  0x187, /* CMOVB16rm */
  0x188, /* CMOVB16rr */
/* Table2796 */
  0x181, /* CMOVAE16rm */
  0x182, /* CMOVAE16rr */
/* Table2798 */
  0x19b, /* CMOVE16rm */
  0x19c, /* CMOVE16rr */
/* Table2800 */
  0x1c5, /* CMOVNE16rm */
  0x1c6, /* CMOVNE16rr */
/* Table2802 */
  0x18d, /* CMOVBE16rm */
  0x18e, /* CMOVBE16rr */
/* Table2804 */
  0x17b, /* CMOVA16rm */
  0x17c, /* CMOVA16rr */
/* Table2806 */
  0x1f5, /* CMOVS16rm */
  0x1f6, /* CMOVS16rr */
/* Table2808 */
  0x1df, /* CMOVNS16rm */
  0x1e0, /* CMOVNS16rr */
/* Table2810 */
  0x1eb, /* CMOVP16rm */
  0x1ec, /* CMOVP16rr */
/* Table2812 */
  0x1d5, /* CMOVNP16rm */
  0x1d6, /* CMOVNP16rr */
/* Table2814 */
  0x1b1, /* CMOVL16rm */
  0x1b2, /* CMOVL16rr */
/* Table2816 */
  0x1ab, /* CMOVGE16rm */
  0x1ac, /* CMOVGE16rr */
/* Table2818 */
  0x1b7, /* CMOVLE16rm */
  0x1b8, /* CMOVLE16rr */
/* Table2820 */
  0x1a5, /* CMOVG16rm */
  0x1a6, /* CMOVG16rr */
/* Table2822 */
  0x0, /*  */
  0x6b3, /* MOVMSKPDrr */
/* Table2824 */
  0xad9, /* SQRTPDm */
  0xada, /* SQRTPDr */
/* Table2826 */
  0xdc, /* ANDPDrm */
  0xdd, /* ANDPDrr */
/* Table2828 */
  0xd8, /* ANDNPDrm */
  0xd9, /* ANDNPDrr */
/* Table2830 */
  0x786, /* ORPDrm */
  0x787, /* ORPDrr */
/* Table2832 */
  0x227d, /* XORPDrm */
  0x227e, /* XORPDrr */
/* Table2834 */
  0x77, /* ADDPDrm */
  0x78, /* ADDPDrr */
/* Table2836 */
  0x70b, /* MULPDrm */
  0x70c, /* MULPDrr */
/* Table2838 */
  0x26c, /* CVTPD2PSrm */
  0x26d, /* CVTPD2PSrr */
/* Table2840 */
  0x26e, /* CVTPS2DQrm */
  0x26f, /* CVTPS2DQrr */
/* Table2842 */
  0xb35, /* SUBPDrm */
  0xb36, /* SUBPDrr */
/* Table2844 */
  0x571, /* MINPDrm */
  0x572, /* MINPDrr */
/* Table2846 */
  0x2a9, /* DIVPDrm */
  0x2aa, /* DIVPDrr */
/* Table2848 */
  0x55c, /* MAXPDrm */
  0x55d, /* MAXPDrr */
/* Table2850 */
  0x8e9, /* PUNPCKLBWrm */
  0x8ea, /* PUNPCKLBWrr */
/* Table2852 */
  0x8ef, /* PUNPCKLWDrm */
  0x8f0, /* PUNPCKLWDrr */
/* Table2854 */
  0x8eb, /* PUNPCKLDQrm */
  0x8ec, /* PUNPCKLDQrr */
/* Table2856 */
  0x79b, /* PACKSSWBrm */
  0x79c, /* PACKSSWBrr */
/* Table2858 */
  0x7d4, /* PCMPGTBrm */
  0x7d5, /* PCMPGTBrr */
/* Table2860 */
  0x7da, /* PCMPGTWrm */
  0x7db, /* PCMPGTWrr */
/* Table2862 */
  0x7d6, /* PCMPGTDrm */
  0x7d7, /* PCMPGTDrr */
/* Table2864 */
  0x79f, /* PACKUSWBrm */
  0x7a0, /* PACKUSWBrr */
/* Table2866 */
  0x8e1, /* PUNPCKHBWrm */
  0x8e2, /* PUNPCKHBWrr */
/* Table2868 */
  0x8e7, /* PUNPCKHWDrm */
  0x8e8, /* PUNPCKHWDrr */
/* Table2870 */
  0x8e3, /* PUNPCKHDQrm */
  0x8e4, /* PUNPCKHDQrr */
/* Table2872 */
  0x799, /* PACKSSDWrm */
  0x79a, /* PACKSSDWrr */
/* Table2874 */
  0x8ed, /* PUNPCKLQDQrm */
  0x8ee, /* PUNPCKLQDQrr */
/* Table2876 */
  0x8e5, /* PUNPCKHQDQrm */
  0x8e6, /* PUNPCKHQDQrr */
/* Table2878 */
  0x69d, /* MOVDI2PDIrm */
  0x69e, /* MOVDI2PDIrr */
/* Table2880 */
  0x6a2, /* MOVDQArm */
  0x6a3, /* MOVDQArr */
/* Table2882 */
  0x8a7, /* PSHUFDmi */
  0x8a8, /* PSHUFDri */
/* Table2884 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x8ca, /* PSRLWri */
  0x0, /*  */
  0x8c0, /* PSRAWri */
  0x0, /*  */
  0x8ba, /* PSLLWri */
  0x0, /*  */
/* Table2900 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x8c4, /* PSRLDri */
  0x0, /*  */
  0x8bd, /* PSRADri */
  0x0, /*  */
  0x8b4, /* PSLLDri */
  0x0, /*  */
/* Table2916 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x8c7, /* PSRLQri */
  0x8c3, /* PSRLDQri */
  0x0, /*  */
  0x0, /*  */
  0x8b7, /* PSLLQri */
  0x8b3, /* PSLLDQri */
/* Table2932 */
  0x7c4, /* PCMPEQBrm */
  0x7c5, /* PCMPEQBrr */
/* Table2934 */
  0x7ca, /* PCMPEQWrm */
  0x7cb, /* PCMPEQWrr */
/* Table2936 */
  0x7c6, /* PCMPEQDrm */
  0x7c7, /* PCMPEQDrr */
/* Table2938 */
  0x15f8, /* VMREAD32rm */
  0x2ed, /* EXTRQI */
/* Table2940 */
  0x1663, /* VMWRITE32rm */
  0x2ec, /* EXTRQ */
/* Table2942 */
  0x359, /* HADDPDrm */
  0x35a, /* HADDPDrr */
/* Table2944 */
  0x35e, /* HSUBPDrm */
  0x35f, /* HSUBPDrr */
/* Table2946 */
  0x6be, /* MOVPDI2DImr */
  0x6bf, /* MOVPDI2DIrr */
/* Table2948 */
  0x6a1, /* MOVDQAmr */
  0x6a4, /* MOVDQArr_REV */
/* Table2950 */
  0x46e, /* JO_2 */
/* Table2951 */
  0x465, /* JNO_2 */
/* Table2952 */
  0x445, /* JB_2 */
/* Table2953 */
  0x43c, /* JAE_2 */
/* Table2954 */
  0x44a, /* JE_2 */
/* Table2955 */
  0x462, /* JNE_2 */
/* Table2956 */
  0x442, /* JBE_2 */
/* Table2957 */
  0x43f, /* JA_2 */
/* Table2958 */
  0x475, /* JS_2 */
/* Table2959 */
  0x46b, /* JNS_2 */
/* Table2960 */
  0x471, /* JP_2 */
/* Table2961 */
  0x468, /* JNP_2 */
/* Table2962 */
  0x456, /* JL_2 */
/* Table2963 */
  0x44d, /* JGE_2 */
/* Table2964 */
  0x453, /* JLE_2 */
/* Table2965 */
  0x450, /* JG_2 */
/* Table2966 */
  0x90a, /* PUSHFS16 */
/* Table2967 */
  0x893, /* POPFS16 */
/* Table2968 */
  0x12e, /* BT16mr */
  0x130, /* BT16rr */
/* Table2970 */
  0xa8d, /* SHLD16mri8 */
  0xa8f, /* SHLD16rri8 */
/* Table2972 */
  0xa8c, /* SHLD16mrCL */
  0xa8e, /* SHLD16rrCL */
/* Table2974 */
  0x90d, /* PUSHGS16 */
/* Table2975 */
  0x896, /* POPGS16 */
/* Table2976 */
  0x152, /* BTS16mr */
  0x154, /* BTS16rr */
/* Table2978 */
  0xab5, /* SHRD16mri8 */
  0xab7, /* SHRD16rri8 */
/* Table2980 */
  0xab4, /* SHRD16mrCL */
  0xab6, /* SHRD16rrCL */
/* Table2982 */
  0x32d, /* FXSAVE */
  0x32b, /* FXRSTOR */
  0x4c2, /* LDMXCSR */
  0xaee, /* STMXCSR */
  0x2286, /* XSAVE */
  0x2282, /* XRSTOR */
  0x179, /* CLWB */
  0x175, /* CLFLUSHOPT */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x4df, /* LFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x568, /* MFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x7e4, /* PCOMMIT */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table3054 */
  0x378, /* IMUL16rm */
  0x37b, /* IMUL16rr */
/* Table3056 */
  0x245, /* CMPXCHG16rm */
  0x246, /* CMPXCHG16rr */
/* Table3058 */
  0x543, /* LSS16rm */
  0x0, /*  */
/* Table3060 */
  0x146, /* BTR16mr */
  0x148, /* BTR16rr */
/* Table3062 */
  0x4e0, /* LFS16rm */
  0x0, /*  */
/* Table3064 */
  0x4e6, /* LGS16rm */
  0x0, /*  */
/* Table3066 */
  0x6f5, /* MOVZX16rm8 */
  0x6f6, /* MOVZX16rr8 */
/* Table3068 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x12d, /* BT16mi8 */
  0x151, /* BTS16mi8 */
  0x145, /* BTR16mi8 */
  0x139, /* BTC16mi8 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x12f, /* BT16ri8 */
  0x153, /* BTS16ri8 */
  0x147, /* BTR16ri8 */
  0x13b, /* BTC16ri8 */
/* Table3084 */
  0x13a, /* BTC16mr */
  0x13c, /* BTC16rr */
/* Table3086 */
  0x11f, /* BSF16rm */
  0x120, /* BSF16rr */
/* Table3088 */
  0x125, /* BSR16rm */
  0x126, /* BSR16rr */
/* Table3090 */
  0x6d9, /* MOVSX16rm8 */
  0x6da, /* MOVSX16rr8 */
/* Table3092 */
  0x2239, /* XADD16rm */
  0x223a, /* XADD16rr */
/* Table3094 */
  0x230, /* CMPPDrmi */
  0x232, /* CMPPDrri */
/* Table3096 */
  0x834, /* PINSRWrmi */
  0x835, /* PINSRWrri */
/* Table3098 */
  0x0, /*  */
  0x7f4, /* PEXTRWri */
/* Table3100 */
  0xac4, /* SHUFPDrmi */
  0xac5, /* SHUFPDrri */
/* Table3102 */
  0x0, /*  */
  0x24b, /* CMPXCHG8B */
  0x0, /*  */
  0x2284, /* XRSTORS */
  0x2288, /* XSAVEC */
  0x228c, /* XSAVES */
  0x1398, /* VMCLEARm */
  0x15f7, /* VMPTRSTm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x954, /* RDRAND16r */
  0x957, /* RDSEED16r */
/* Table3118 */
  0x83, /* ADDSUBPDrm */
  0x84, /* ADDSUBPDrr */
/* Table3120 */
  0x8cb, /* PSRLWrm */
  0x8cc, /* PSRLWrr */
/* Table3122 */
  0x8c5, /* PSRLDrm */
  0x8c6, /* PSRLDrr */
/* Table3124 */
  0x8c8, /* PSRLQrm */
  0x8c9, /* PSRLQrr */
/* Table3126 */
  0x7a5, /* PADDQrm */
  0x7a6, /* PADDQrr */
/* Table3128 */
  0x877, /* PMULLWrm */
  0x878, /* PMULLWrr */
/* Table3130 */
  0x6c0, /* MOVPQI2QImr */
  0x6c1, /* MOVPQI2QIrr */
/* Table3132 */
  0x0, /*  */
  0x852, /* PMOVMSKBrr */
/* Table3134 */
  0x8d7, /* PSUBUSBrm */
  0x8d8, /* PSUBUSBrr */
/* Table3136 */
  0x8d9, /* PSUBUSWrm */
  0x8da, /* PSUBUSWrr */
/* Table3138 */
  0x84c, /* PMINUBrm */
  0x84d, /* PMINUBrr */
/* Table3140 */
  0x7b5, /* PANDrm */
  0x7b6, /* PANDrr */
/* Table3142 */
  0x7ab, /* PADDUSBrm */
  0x7ac, /* PADDUSBrr */
/* Table3144 */
  0x7ad, /* PADDUSWrm */
  0x7ae, /* PADDUSWrr */
/* Table3146 */
  0x840, /* PMAXUBrm */
  0x841, /* PMAXUBrr */
/* Table3148 */
  0x7b3, /* PANDNrm */
  0x7b4, /* PANDNrr */
/* Table3150 */
  0x7b8, /* PAVGBrm */
  0x7b9, /* PAVGBrr */
/* Table3152 */
  0x8c1, /* PSRAWrm */
  0x8c2, /* PSRAWrr */
/* Table3154 */
  0x8be, /* PSRADrm */
  0x8bf, /* PSRADrr */
/* Table3156 */
  0x7bc, /* PAVGWrm */
  0x7bd, /* PAVGWrr */
/* Table3158 */
  0x871, /* PMULHUWrm */
  0x872, /* PMULHUWrr */
/* Table3160 */
  0x873, /* PMULHWrm */
  0x874, /* PMULHWrr */
/* Table3162 */
  0x286, /* CVTTPD2DQrm */
  0x287, /* CVTTPD2DQrr */
/* Table3164 */
  0x6b6, /* MOVNTDQmr */
  0x0, /*  */
/* Table3166 */
  0x8d3, /* PSUBSBrm */
  0x8d4, /* PSUBSBrr */
/* Table3168 */
  0x8d5, /* PSUBSWrm */
  0x8d6, /* PSUBSWrr */
/* Table3170 */
  0x84a, /* PMINSWrm */
  0x84b, /* PMINSWrr */
/* Table3172 */
  0x89b, /* PORrm */
  0x89c, /* PORrr */
/* Table3174 */
  0x7a7, /* PADDSBrm */
  0x7a8, /* PADDSBrr */
/* Table3176 */
  0x7a9, /* PADDSWrm */
  0x7aa, /* PADDSWrr */
/* Table3178 */
  0x83e, /* PMAXSWrm */
  0x83f, /* PMAXSWrr */
/* Table3180 */
  0x914, /* PXORrm */
  0x915, /* PXORrr */
/* Table3182 */
  0x8bb, /* PSLLWrm */
  0x8bc, /* PSLLWrr */
/* Table3184 */
  0x8b5, /* PSLLDrm */
  0x8b6, /* PSLLDrr */
/* Table3186 */
  0x8b8, /* PSLLQrm */
  0x8b9, /* PSLLQrr */
/* Table3188 */
  0x879, /* PMULUDQrm */
  0x87a, /* PMULUDQrr */
/* Table3190 */
  0x838, /* PMADDWDrm */
  0x839, /* PMADDWDrr */
/* Table3192 */
  0x8a3, /* PSADBWrm */
  0x8a4, /* PSADBWrr */
/* Table3194 */
  0x0, /*  */
  0x552, /* MASKMOVDQU */
/* Table3196 */
  0x8cd, /* PSUBBrm */
  0x8ce, /* PSUBBrr */
/* Table3198 */
  0x8db, /* PSUBWrm */
  0x8dc, /* PSUBWrr */
/* Table3200 */
  0x8cf, /* PSUBDrm */
  0x8d0, /* PSUBDrr */
/* Table3202 */
  0x8d1, /* PSUBQrm */
  0x8d2, /* PSUBQrr */
/* Table3204 */
  0x7a1, /* PADDBrm */
  0x7a2, /* PADDBrr */
/* Table3206 */
  0x7af, /* PADDWrm */
  0x7b0, /* PADDWrr */
/* Table3208 */
  0x7a3, /* PADDDrm */
  0x7a4, /* PADDDrr */
/* Table3210 */
  0x6c7, /* MOVSDrm */
  0x6c8, /* MOVSDrr */
/* Table3212 */
  0x6c6, /* MOVSDmr */
  0x6c9, /* MOVSDrr_REV */
/* Table3214 */
  0x69b, /* MOVDDUPrm */
  0x69c, /* MOVDDUPrr */
/* Table3216 */
  0x27a, /* CVTSI2SDrm */
  0x27b, /* CVTSI2SDrr */
/* Table3218 */
  0x6bb, /* MOVNTSD */
  0x0, /*  */
/* Table3220 */
  0x28c, /* CVTTSD2SIrm */
  0x28d, /* CVTTSD2SIrr */
/* Table3222 */
  0x274, /* CVTSD2SIrm */
  0x275, /* CVTSD2SIrr */
/* Table3224 */
  0xadd, /* SQRTSDm */
  0xadf, /* SQRTSDr */
/* Table3226 */
  0x7b, /* ADDSDrm */
  0x7d, /* ADDSDrr */
/* Table3228 */
  0x70f, /* MULSDrm */
  0x711, /* MULSDrr */
/* Table3230 */
  0x276, /* CVTSD2SSrm */
  0x277, /* CVTSD2SSrr */
/* Table3232 */
  0xb4b, /* SUBSDrm */
  0xb4d, /* SUBSDrr */
/* Table3234 */
  0x575, /* MINSDrm */
  0x577, /* MINSDrr */
/* Table3236 */
  0x2bf, /* DIVSDrm */
  0x2c1, /* DIVSDrr */
/* Table3238 */
  0x560, /* MAXSDrm */
  0x562, /* MAXSDrr */
/* Table3240 */
  0x8ab, /* PSHUFLWmi */
  0x8ac, /* PSHUFLWri */
/* Table3242 */
  0x15f8, /* VMREAD32rm */
  0x3a4, /* INSERTQI */
/* Table3244 */
  0x1663, /* VMWRITE32rm */
  0x3a3, /* INSERTQ */
/* Table3246 */
  0x35b, /* HADDPSrm */
  0x35c, /* HADDPSrr */
/* Table3248 */
  0x360, /* HSUBPSrm */
  0x361, /* HSUBPSrr */
/* Table3250 */
  0x239, /* CMPSDrm */
  0x23b, /* CMPSDrr */
/* Table3252 */
  0x85, /* ADDSUBPSrm */
  0x86, /* ADDSUBPSrr */
/* Table3254 */
  0x0, /*  */
  0x594, /* MMX_MOVDQ2Qrr */
/* Table3256 */
  0x26a, /* CVTPD2DQrm */
  0x26b, /* CVTPD2DQrr */
/* Table3258 */
  0x4c1, /* LDDQUrm */
  0x0, /*  */
/* Table3260 */
  0x6d5, /* MOVSSrm */
  0x6d6, /* MOVSSrr */
/* Table3262 */
  0x6d4, /* MOVSSmr */
  0x6d7, /* MOVSSrr_REV */
/* Table3264 */
  0x6cf, /* MOVSLDUPrm */
  0x6d0, /* MOVSLDUPrr */
/* Table3266 */
  0x6cc, /* MOVSHDUPrm */
  0x6cd, /* MOVSHDUPrr */
/* Table3268 */
  0x27e, /* CVTSI2SSrm */
  0x27f, /* CVTSI2SSrr */
/* Table3270 */
  0x6bc, /* MOVNTSS */
  0x0, /*  */
/* Table3272 */
  0x290, /* CVTTSS2SIrm */
  0x291, /* CVTTSS2SIrr */
/* Table3274 */
  0x284, /* CVTSS2SIrm */
  0x285, /* CVTSS2SIrr */
/* Table3276 */
  0xae1, /* SQRTSSm */
  0xae3, /* SQRTSSr */
/* Table3278 */
  0x9d2, /* RSQRTSSm */
  0x9d4, /* RSQRTSSr */
/* Table3280 */
  0x932, /* RCPSSm */
  0x934, /* RCPSSr */
/* Table3282 */
  0x7f, /* ADDSSrm */
  0x81, /* ADDSSrr */
/* Table3284 */
  0x713, /* MULSSrm */
  0x715, /* MULSSrr */
/* Table3286 */
  0x280, /* CVTSS2SDrm */
  0x281, /* CVTSS2SDrr */
/* Table3288 */
  0x288, /* CVTTPS2DQrm */
  0x289, /* CVTTPS2DQrr */
/* Table3290 */
  0xb4f, /* SUBSSrm */
  0xb51, /* SUBSSrr */
/* Table3292 */
  0x579, /* MINSSrm */
  0x57b, /* MINSSrr */
/* Table3294 */
  0x2c3, /* DIVSSrm */
  0x2c5, /* DIVSSrr */
/* Table3296 */
  0x564, /* MAXSSrm */
  0x566, /* MAXSSrr */
/* Table3298 */
  0x6a6, /* MOVDQUrm */
  0x6a7, /* MOVDQUrr */
/* Table3300 */
  0x8a9, /* PSHUFHWmi */
  0x8aa, /* PSHUFHWri */
/* Table3302 */
  0x6c4, /* MOVQI2PQIrm */
  0x6f2, /* MOVZPQILo2PQIrr */
/* Table3304 */
  0x6a5, /* MOVDQUmr */
  0x6a8, /* MOVDQUrr_REV */
/* Table3306 */
  0x888, /* POPCNT32rm */
  0x889, /* POPCNT32rr */
/* Table3308 */
  0xbac, /* TZCNT32rm */
  0xbad, /* TZCNT32rr */
/* Table3310 */
  0x54e, /* LZCNT32rm */
  0x54f, /* LZCNT32rr */
/* Table3312 */
  0x23f, /* CMPSSrm */
  0x241, /* CMPSSrr */
/* Table3314 */
  0x0, /*  */
  0x24b, /* CMPXCHG8B */
  0x0, /*  */
  0x2284, /* XRSTORS */
  0x2288, /* XSAVEC */
  0x228c, /* XSAVES */
  0x1668, /* VMXON */
  0x15f7, /* VMPTRSTm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x955, /* RDRAND32r */
  0x958, /* RDSEED32r */
/* Table3330 */
  0x0, /*  */
  0x597, /* MMX_MOVQ2DQrr */
/* Table3332 */
  0x266, /* CVTDQ2PDrm */
  0x267, /* CVTDQ2PDrr */
/* Table3334 */
  0x886, /* POPCNT16rm */
  0x887, /* POPCNT16rr */
/* Table3336 */
  0xbaa, /* TZCNT16rm */
  0xbab, /* TZCNT16rr */
/* Table3338 */
  0x54c, /* LZCNT16rm */
  0x54d, /* LZCNT16rr */
/* Table3340 */
  0xad3, /* SLDT64m */
  0xaf6, /* STRm */
  0x4ec, /* LLDT16m */
  0x546, /* LTRm */
  0xe12, /* VERRm */
  0xe14, /* VERWm */
  0x0, /*  */
  0x0, /*  */
  0xad4, /* SLDT64r */
  0xaf5, /* STR64r */
  0x4ed, /* LLDT16r */
  0x547, /* LTRr */
  0xe13, /* VERRr */
  0xe15, /* VERWr */
  0x0, /*  */
  0x0, /*  */
/* Table3356 */
  0xa65, /* SGDT64m */
  0xaca, /* SIDT64m */
  0x4e5, /* LGDT64m */
  0x4eb, /* LIDT64m */
  0xad5, /* SMSW16m */
  0x0, /*  */
  0x4ee, /* LMSW16m */
  0x3ae, /* INVLPG */
  0x0, /*  */
  0x1397, /* VMCALL */
  0x1402, /* VMLAUNCH */
  0x15fc, /* VMRESUME */
  0x1667, /* VMXOFF */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x63a, /* MONITORrrr */
  0x730, /* MWAITrr */
  0x171, /* CLAC */
  0xae9, /* STAC */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2e7, /* ENCLS */
  0x2257, /* XGETBV */
  0x228e, /* XSETBV */
  0x0, /*  */
  0x0, /*  */
  0x1399, /* VMFUNC */
  0x2256, /* XEND */
  0x2292, /* XTEST */
  0x2e8, /* ENCLU */
  0x15fe, /* VMRUN64 */
  0x1405, /* VMMCALL */
  0x1404, /* VMLOAD64 */
  0x1600, /* VMSAVE64 */
  0xaec, /* STGI */
  0x176, /* CLGI */
  0xacf, /* SKINIT */
  0x3b0, /* INVLPGA64 */
  0xad8, /* SMSW64r */
  0xad8, /* SMSW64r */
  0xad8, /* SMSW64r */
  0xad8, /* SMSW64r */
  0xad8, /* SMSW64r */
  0xad8, /* SMSW64r */
  0xad8, /* SMSW64r */
  0xad8, /* SMSW64r */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0xb68, /* SWAPGS */
  0x95b, /* RDTSCP */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table3428 */
  0x4b9, /* LAR64rm */
  0x4ba, /* LAR64rr */
/* Table3430 */
  0x541, /* LSL64rm */
  0x542, /* LSL64rr */
/* Table3432 */
  0xb6e, /* SYSRET64 */
/* Table3433 */
  0xb6c, /* SYSEXIT64 */
/* Table3434 */
  0x1e9, /* CMOVO64rm */
  0x1ea, /* CMOVO64rr */
/* Table3436 */
  0x1d3, /* CMOVNO64rm */
  0x1d4, /* CMOVNO64rr */
/* Table3438 */
  0x18b, /* CMOVB64rm */
  0x18c, /* CMOVB64rr */
/* Table3440 */
  0x185, /* CMOVAE64rm */
  0x186, /* CMOVAE64rr */
/* Table3442 */
  0x19f, /* CMOVE64rm */
  0x1a0, /* CMOVE64rr */
/* Table3444 */
  0x1c9, /* CMOVNE64rm */
  0x1ca, /* CMOVNE64rr */
/* Table3446 */
  0x191, /* CMOVBE64rm */
  0x192, /* CMOVBE64rr */
/* Table3448 */
  0x17f, /* CMOVA64rm */
  0x180, /* CMOVA64rr */
/* Table3450 */
  0x1f9, /* CMOVS64rm */
  0x1fa, /* CMOVS64rr */
/* Table3452 */
  0x1e3, /* CMOVNS64rm */
  0x1e4, /* CMOVNS64rr */
/* Table3454 */
  0x1ef, /* CMOVP64rm */
  0x1f0, /* CMOVP64rr */
/* Table3456 */
  0x1d9, /* CMOVNP64rm */
  0x1da, /* CMOVNP64rr */
/* Table3458 */
  0x1b5, /* CMOVL64rm */
  0x1b6, /* CMOVL64rr */
/* Table3460 */
  0x1af, /* CMOVGE64rm */
  0x1b0, /* CMOVGE64rr */
/* Table3462 */
  0x1bb, /* CMOVLE64rm */
  0x1bc, /* CMOVLE64rr */
/* Table3464 */
  0x1a9, /* CMOVG64rm */
  0x1aa, /* CMOVG64rr */
/* Table3466 */
  0x592, /* MMX_MOVD64to64rm */
  0x593, /* MMX_MOVD64to64rr */
/* Table3468 */
  0x58c, /* MMX_MOVD64from64rm */
  0x58d, /* MMX_MOVD64from64rr */
/* Table3470 */
  0x136, /* BT64mr */
  0x138, /* BT64rr */
/* Table3472 */
  0xa95, /* SHLD64mri8 */
  0xa97, /* SHLD64rri8 */
/* Table3474 */
  0xa94, /* SHLD64mrCL */
  0xa96, /* SHLD64rrCL */
/* Table3476 */
  0x15a, /* BTS64mr */
  0x15c, /* BTS64rr */
/* Table3478 */
  0xabd, /* SHRD64mri8 */
  0xabf, /* SHRD64rri8 */
/* Table3480 */
  0xabc, /* SHRD64mrCL */
  0xabe, /* SHRD64rrCL */
/* Table3482 */
  0x32e, /* FXSAVE64 */
  0x32c, /* FXRSTOR64 */
  0x4c2, /* LDMXCSR */
  0xaee, /* STMXCSR */
  0x2287, /* XSAVE64 */
  0x2283, /* XRSTOR64 */
  0x228b, /* XSAVEOPT64 */
  0x174, /* CLFLUSH */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x4df, /* LFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x568, /* MFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0xa62, /* SFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table3554 */
  0x388, /* IMUL64rm */
  0x38b, /* IMUL64rr */
/* Table3556 */
  0x249, /* CMPXCHG64rm */
  0x24a, /* CMPXCHG64rr */
/* Table3558 */
  0x545, /* LSS64rm */
  0x0, /*  */
/* Table3560 */
  0x14e, /* BTR64mr */
  0x150, /* BTR64rr */
/* Table3562 */
  0x4e2, /* LFS64rm */
  0x0, /*  */
/* Table3564 */
  0x4e8, /* LGS64rm */
  0x0, /*  */
/* Table3566 */
  0x6fe, /* MOVZX64rm8_Q */
  0x700, /* MOVZX64rr8_Q */
/* Table3568 */
  0x6fd, /* MOVZX64rm16_Q */
  0x6ff, /* MOVZX64rr16_Q */
/* Table3570 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x135, /* BT64mi8 */
  0x159, /* BTS64mi8 */
  0x14d, /* BTR64mi8 */
  0x141, /* BTC64mi8 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x137, /* BT64ri8 */
  0x15b, /* BTS64ri8 */
  0x14f, /* BTR64ri8 */
  0x143, /* BTC64ri8 */
/* Table3586 */
  0x142, /* BTC64mr */
  0x144, /* BTC64rr */
/* Table3588 */
  0x123, /* BSF64rm */
  0x124, /* BSF64rr */
/* Table3590 */
  0x129, /* BSR64rm */
  0x12a, /* BSR64rr */
/* Table3592 */
  0x6e5, /* MOVSX64rm8 */
  0x6e8, /* MOVSX64rr8 */
/* Table3594 */
  0x6e2, /* MOVSX64rm16 */
  0x6e6, /* MOVSX64rr16 */
/* Table3596 */
  0x223d, /* XADD64rm */
  0x223e, /* XADD64rr */
/* Table3598 */
  0x6b7, /* MOVNTI_64mr */
  0x0, /*  */
/* Table3600 */
  0x0, /*  */
  0x244, /* CMPXCHG16B */
  0x0, /*  */
  0x2285, /* XRSTORS64 */
  0x2289, /* XSAVEC64 */
  0x228d, /* XSAVES64 */
  0x15f6, /* VMPTRLDm */
  0x15f7, /* VMPTRSTm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x956, /* RDRAND64r */
  0x959, /* RDSEED64r */
/* Table3616 */
  0x12c, /* BSWAP64r */
/* Table3617 */
  0x15fa, /* VMREAD64rm */
  0x2ed, /* EXTRQI */
/* Table3619 */
  0x1665, /* VMWRITE64rm */
  0x2ec, /* EXTRQ */
/* Table3621 */
  0x32e, /* FXSAVE64 */
  0x32c, /* FXRSTOR64 */
  0x4c2, /* LDMXCSR */
  0xaee, /* STMXCSR */
  0x2287, /* XSAVE64 */
  0x2283, /* XRSTOR64 */
  0x228b, /* XSAVEOPT64 */
  0x175, /* CLFLUSHOPT */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x4df, /* LFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x568, /* MFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x7e4, /* PCOMMIT */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table3693 */
  0x0, /*  */
  0x244, /* CMPXCHG16B */
  0x0, /*  */
  0x2285, /* XRSTORS64 */
  0x2289, /* XSAVEC64 */
  0x228d, /* XSAVES64 */
  0x1398, /* VMCLEARm */
  0x15f7, /* VMPTRSTm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x956, /* RDRAND64r */
  0x959, /* RDSEED64r */
/* Table3709 */
  0x0, /*  */
  0x553, /* MASKMOVDQU64 */
/* Table3711 */
  0xa65, /* SGDT64m */
  0xaca, /* SIDT64m */
  0x4e5, /* LGDT64m */
  0x4eb, /* LIDT64m */
  0xad5, /* SMSW16m */
  0x0, /*  */
  0x4ee, /* LMSW16m */
  0x3ae, /* INVLPG */
  0x0, /*  */
  0x1397, /* VMCALL */
  0x1402, /* VMLAUNCH */
  0x15fc, /* VMRESUME */
  0x1667, /* VMXOFF */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x63a, /* MONITORrrr */
  0x730, /* MWAITrr */
  0x171, /* CLAC */
  0xae9, /* STAC */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x2e7, /* ENCLS */
  0x2257, /* XGETBV */
  0x228e, /* XSETBV */
  0x0, /*  */
  0x0, /*  */
  0x1399, /* VMFUNC */
  0x2256, /* XEND */
  0x2292, /* XTEST */
  0x2e8, /* ENCLU */
  0x15fe, /* VMRUN64 */
  0x1405, /* VMMCALL */
  0x1404, /* VMLOAD64 */
  0x1600, /* VMSAVE64 */
  0xaec, /* STGI */
  0x176, /* CLGI */
  0xacf, /* SKINIT */
  0x3b0, /* INVLPGA64 */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0xad6, /* SMSW16r */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0x4ef, /* LMSW16r */
  0xb68, /* SWAPGS */
  0x95b, /* RDTSCP */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table3783 */
  0x15fa, /* VMREAD64rm */
  0x3a4, /* INSERTQI */
/* Table3785 */
  0x1665, /* VMWRITE64rm */
  0x3a3, /* INSERTQ */
/* Table3787 */
  0x32d, /* FXSAVE */
  0x32b, /* FXRSTOR */
  0x4c2, /* LDMXCSR */
  0xaee, /* STMXCSR */
  0x2286, /* XSAVE */
  0x2282, /* XRSTOR */
  0x228a, /* XSAVEOPT */
  0x174, /* CLFLUSH */
  0x94e, /* RDFSBASE */
  0x94e, /* RDFSBASE */
  0x94e, /* RDFSBASE */
  0x94e, /* RDFSBASE */
  0x94e, /* RDFSBASE */
  0x94e, /* RDFSBASE */
  0x94e, /* RDFSBASE */
  0x94e, /* RDFSBASE */
  0x950, /* RDGSBASE */
  0x950, /* RDGSBASE */
  0x950, /* RDGSBASE */
  0x950, /* RDGSBASE */
  0x950, /* RDGSBASE */
  0x950, /* RDGSBASE */
  0x950, /* RDGSBASE */
  0x950, /* RDGSBASE */
  0x2232, /* WRFSBASE */
  0x2232, /* WRFSBASE */
  0x2232, /* WRFSBASE */
  0x2232, /* WRFSBASE */
  0x2232, /* WRFSBASE */
  0x2232, /* WRFSBASE */
  0x2232, /* WRFSBASE */
  0x2232, /* WRFSBASE */
  0x2234, /* WRGSBASE */
  0x2234, /* WRGSBASE */
  0x2234, /* WRGSBASE */
  0x2234, /* WRGSBASE */
  0x2234, /* WRGSBASE */
  0x2234, /* WRGSBASE */
  0x2234, /* WRGSBASE */
  0x2234, /* WRGSBASE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x4df, /* LFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x568, /* MFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0xa62, /* SFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table3859 */
  0x27c, /* CVTSI2SS64rm */
  0x27d, /* CVTSI2SS64rr */
/* Table3861 */
  0x28e, /* CVTTSS2SI64rm */
  0x28f, /* CVTTSS2SI64rr */
/* Table3863 */
  0x282, /* CVTSS2SI64rm */
  0x283, /* CVTSS2SI64rr */
/* Table3865 */
  0x32e, /* FXSAVE64 */
  0x32c, /* FXRSTOR64 */
  0x4c2, /* LDMXCSR */
  0xaee, /* STMXCSR */
  0x2287, /* XSAVE64 */
  0x2283, /* XRSTOR64 */
  0x228b, /* XSAVEOPT64 */
  0x174, /* CLFLUSH */
  0x94f, /* RDFSBASE64 */
  0x94f, /* RDFSBASE64 */
  0x94f, /* RDFSBASE64 */
  0x94f, /* RDFSBASE64 */
  0x94f, /* RDFSBASE64 */
  0x94f, /* RDFSBASE64 */
  0x94f, /* RDFSBASE64 */
  0x94f, /* RDFSBASE64 */
  0x951, /* RDGSBASE64 */
  0x951, /* RDGSBASE64 */
  0x951, /* RDGSBASE64 */
  0x951, /* RDGSBASE64 */
  0x951, /* RDGSBASE64 */
  0x951, /* RDGSBASE64 */
  0x951, /* RDGSBASE64 */
  0x951, /* RDGSBASE64 */
  0x2233, /* WRFSBASE64 */
  0x2233, /* WRFSBASE64 */
  0x2233, /* WRFSBASE64 */
  0x2233, /* WRFSBASE64 */
  0x2233, /* WRFSBASE64 */
  0x2233, /* WRFSBASE64 */
  0x2233, /* WRFSBASE64 */
  0x2233, /* WRFSBASE64 */
  0x2235, /* WRGSBASE64 */
  0x2235, /* WRGSBASE64 */
  0x2235, /* WRGSBASE64 */
  0x2235, /* WRGSBASE64 */
  0x2235, /* WRGSBASE64 */
  0x2235, /* WRGSBASE64 */
  0x2235, /* WRGSBASE64 */
  0x2235, /* WRGSBASE64 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x4df, /* LFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x568, /* MFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0xa62, /* SFENCE */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table3937 */
  0x88a, /* POPCNT64rm */
  0x88b, /* POPCNT64rr */
/* Table3939 */
  0xbae, /* TZCNT64rm */
  0xbaf, /* TZCNT64rr */
/* Table3941 */
  0x550, /* LZCNT64rm */
  0x551, /* LZCNT64rr */
/* Table3943 */
  0x0, /*  */
  0x244, /* CMPXCHG16B */
  0x0, /*  */
  0x2285, /* XRSTORS64 */
  0x2289, /* XSAVEC64 */
  0x228d, /* XSAVES64 */
  0x1668, /* VMXON */
  0x15f7, /* VMPTRSTm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x956, /* RDRAND64r */
  0x959, /* RDSEED64r */
/* Table3959 */
  0x278, /* CVTSI2SD64rm */
  0x279, /* CVTSI2SD64rr */
/* Table3961 */
  0x28a, /* CVTTSD2SI64rm */
  0x28b, /* CVTTSD2SI64rr */
/* Table3963 */
  0x272, /* CVTSD2SI64rm */
  0x273, /* CVTSD2SI64rr */
/* Table3965 */
  0x679, /* MOV64toPQIrm */
  0x67a, /* MOV64toPQIrr */
/* Table3967 */
  0x6c2, /* MOVPQIto64rm */
  0x6c3, /* MOVPQIto64rr */
/* Table3969 */
  0x15e9, /* VMOVUPSrm */
  0x15ea, /* VMOVUPSrr */
/* Table3971 */
  0x15e8, /* VMOVUPSmr */
  0x15eb, /* VMOVUPSrr_REV */
/* Table3973 */
  0x154d, /* VMOVLPSrm */
  0x1543, /* VMOVHLPSrr */
/* Table3975 */
  0x154c, /* VMOVLPSmr */
  0x0, /*  */
/* Table3977 */
  0x221f, /* VUNPCKLPSrm */
  0x2220, /* VUNPCKLPSrr */
/* Table3979 */
  0x2213, /* VUNPCKHPSrm */
  0x2214, /* VUNPCKHPSrr */
/* Table3981 */
  0x1547, /* VMOVHPSrm */
  0x1549, /* VMOVLHPSrr */
/* Table3983 */
  0x1546, /* VMOVHPSmr */
  0x0, /*  */
/* Table3985 */
  0x145b, /* VMOVAPSrm */
  0x145c, /* VMOVAPSrr */
/* Table3987 */
  0x145a, /* VMOVAPSmr */
  0x145d, /* VMOVAPSrr_REV */
/* Table3989 */
  0x1565, /* VMOVNTPSmr */
  0x0, /*  */
/* Table3991 */
  0x2207, /* VUCOMISSrm */
  0x2208, /* VUCOMISSrr */
/* Table3993 */
  0xcf7, /* VCOMISSrm */
  0xcf8, /* VCOMISSrr */
/* Table3995 */
  0x0, /*  */
  0x496, /* KNOTWrr */
/* Table3997 */
  0x0, /*  */
  0x1551, /* VMOVMSKPSrr */
/* Table3999 */
  0x2186, /* VSQRTPSm */
  0x2187, /* VSQRTPSr */
/* Table4001 */
  0x212b, /* VRSQRTPSm */
  0x212d, /* VRSQRTPSr */
/* Table4003 */
  0x2098, /* VRCPPSm */
  0x209a, /* VRCPPSr */
/* Table4005 */
  0xc59, /* VANDPSrm */
  0xc5a, /* VANDPSrr */
/* Table4007 */
  0xc51, /* VANDNPSrm */
  0xc52, /* VANDNPSrr */
/* Table4009 */
  0x166f, /* VORPSrm */
  0x1670, /* VORPSrr */
/* Table4011 */
  0x2227, /* VXORPSrm */
  0x2228, /* VXORPSrr */
/* Table4013 */
  0xc0f, /* VADDPSrm */
  0xc10, /* VADDPSrr */
/* Table4015 */
  0x1643, /* VMULPSrm */
  0x1644, /* VMULPSrr */
/* Table4017 */
  0xd3a, /* VCVTPS2PDrm */
  0xd3b, /* VCVTPS2PDrr */
/* Table4019 */
  0xd16, /* VCVTDQ2PSrm */
  0xd17, /* VCVTDQ2PSrr */
/* Table4021 */
  0x21d9, /* VSUBPSrm */
  0x21da, /* VSUBPSrr */
/* Table4023 */
  0x13e2, /* VMINPSrm */
  0x13e3, /* VMINPSrr */
/* Table4025 */
  0xdec, /* VDIVPSrm */
  0xded, /* VDIVPSrr */
/* Table4027 */
  0x1377, /* VMAXPSrm */
  0x1378, /* VMAXPSrr */
/* Table4029 */
  0x222a, /* VZEROUPPER */
/* Table4030 */
  0x48f, /* KMOVWkm */
  0x48e, /* KMOVWkk */
/* Table4032 */
  0x491, /* KMOVWmk */
  0x0, /*  */
/* Table4034 */
  0x0, /*  */
  0x490, /* KMOVWkr */
/* Table4036 */
  0x0, /*  */
  0x492, /* KMOVWrk */
/* Table4038 */
  0x0, /*  */
  0x49d, /* KORTESTWrr */
/* Table4040 */
  0x0, /*  */
  0x0, /*  */
  0x1324, /* VLDMXCSR */
  0x2196, /* VSTMXCSR */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table4056 */
  0xcdd, /* VCMPPSrmi */
  0xcdf, /* VCMPPSrri */
/* Table4058 */
  0x2148, /* VSHUFPSrmi */
  0x2149, /* VSHUFPSrri */
/* Table4060 */
  0x1597, /* VMOVSSrm */
  0x1598, /* VMOVSSrr */
/* Table4062 */
  0x1596, /* VMOVSSmr */
  0x1599, /* VMOVSSrr_REV */
/* Table4064 */
  0x158a, /* VMOVSLDUPrm */
  0x158b, /* VMOVSLDUPrr */
/* Table4066 */
  0x1584, /* VMOVSHDUPrm */
  0x1585, /* VMOVSHDUPrr */
/* Table4068 */
  0xd5f, /* VCVTSI2SSrm */
  0xd60, /* VCVTSI2SSrr */
/* Table4070 */
  0xd97, /* VCVTTSS2SIrm */
  0xd98, /* VCVTTSS2SIrr */
/* Table4072 */
  0xd6f, /* VCVTSS2SIrm */
  0xd70, /* VCVTSS2SIrr */
/* Table4074 */
  0x2193, /* VSQRTSSm */
  0x2195, /* VSQRTSSr */
/* Table4076 */
  0x212f, /* VRSQRTSSm */
  0x2131, /* VRSQRTSSr */
/* Table4078 */
  0x209c, /* VRCPSSm */
  0x209e, /* VRCPSSr */
/* Table4080 */
  0xc2b, /* VADDSSrm */
  0xc2d, /* VADDSSrr */
/* Table4082 */
  0x165f, /* VMULSSrm */
  0x1661, /* VMULSSrr */
/* Table4084 */
  0xd67, /* VCVTSS2SDrm */
  0xd68, /* VCVTSS2SDrr */
/* Table4086 */
  0xd81, /* VCVTTPS2DQrm */
  0xd82, /* VCVTTPS2DQrr */
/* Table4088 */
  0x21f5, /* VSUBSSrm */
  0x21f7, /* VSUBSSrr */
/* Table4090 */
  0x13fe, /* VMINSSrm */
  0x1400, /* VMINSSrr */
/* Table4092 */
  0xe08, /* VDIVSSrm */
  0xe0a, /* VDIVSSrr */
/* Table4094 */
  0x1393, /* VMAXSSrm */
  0x1395, /* VMAXSSrr */
/* Table4096 */
  0x153f, /* VMOVDQUrm */
  0x1540, /* VMOVDQUrr */
/* Table4098 */
  0x1e82, /* VPSHUFHWmi */
  0x1e83, /* VPSHUFHWri */
/* Table4100 */
  0x1571, /* VMOVQI2PQIrm */
  0x15ef, /* VMOVZPQILo2PQIrr */
/* Table4102 */
  0x153e, /* VMOVDQUmr */
  0x1541, /* VMOVDQUrr_REV */
/* Table4104 */
  0xced, /* VCMPSSrm */
  0xcef, /* VCMPSSrr */
/* Table4106 */
  0xd0f, /* VCVTDQ2PDrm */
  0xd10, /* VCVTDQ2PDrr */
/* Table4108 */
  0x1579, /* VMOVSDrm */
  0x157a, /* VMOVSDrr */
/* Table4110 */
  0x1578, /* VMOVSDmr */
  0x157b, /* VMOVSDrr_REV */
/* Table4112 */
  0x1462, /* VMOVDDUPrm */
  0x1463, /* VMOVDDUPrr */
/* Table4114 */
  0xd59, /* VCVTSI2SDrm */
  0xd5a, /* VCVTSI2SDrr */
/* Table4116 */
  0xd8b, /* VCVTTSD2SIrm */
  0xd8c, /* VCVTTSD2SIrr */
/* Table4118 */
  0xd4b, /* VCVTSD2SIrm */
  0xd4c, /* VCVTSD2SIrr */
/* Table4120 */
  0x218c, /* VSQRTSDm */
  0x218e, /* VSQRTSDr */
/* Table4122 */
  0xc1c, /* VADDSDrm */
  0xc1e, /* VADDSDrr */
/* Table4124 */
  0x1650, /* VMULSDrm */
  0x1652, /* VMULSDrr */
/* Table4126 */
  0xd4f, /* VCVTSD2SSrm */
  0xd50, /* VCVTSD2SSrr */
/* Table4128 */
  0x21e6, /* VSUBSDrm */
  0x21e8, /* VSUBSDrr */
/* Table4130 */
  0x13ef, /* VMINSDrm */
  0x13f1, /* VMINSDrr */
/* Table4132 */
  0xdf9, /* VDIVSDrm */
  0xdfb, /* VDIVSDrr */
/* Table4134 */
  0x1384, /* VMAXSDrm */
  0x1386, /* VMAXSDrr */
/* Table4136 */
  0x1e86, /* VPSHUFLWmi */
  0x1e87, /* VPSHUFLWri */
/* Table4138 */
  0x1300, /* VHADDPSrm */
  0x1301, /* VHADDPSrr */
/* Table4140 */
  0x1308, /* VHSUBPSrm */
  0x1309, /* VHSUBPSrr */
/* Table4142 */
  0x0, /*  */
  0x486, /* KMOVDkr */
/* Table4144 */
  0x0, /*  */
  0x488, /* KMOVDrk */
/* Table4146 */
  0xce5, /* VCMPSDrm */
  0xce7, /* VCMPSDrr */
/* Table4148 */
  0xc35, /* VADDSUBPSrm */
  0xc36, /* VADDSUBPSrr */
/* Table4150 */
  0xd18, /* VCVTPD2DQXrm */
  0xd1e, /* VCVTPD2DQrr */
/* Table4152 */
  0x1323, /* VLDDQUrm */
  0x0, /*  */
/* Table4154 */
  0x15c0, /* VMOVUPDrm */
  0x15c1, /* VMOVUPDrr */
/* Table4156 */
  0x15bf, /* VMOVUPDmr */
  0x15c2, /* VMOVUPDrr_REV */
/* Table4158 */
  0x154b, /* VMOVLPDrm */
  0x0, /*  */
/* Table4160 */
  0x154a, /* VMOVLPDmr */
  0x0, /*  */
/* Table4162 */
  0x2219, /* VUNPCKLPDrm */
  0x221a, /* VUNPCKLPDrr */
/* Table4164 */
  0x220d, /* VUNPCKHPDrm */
  0x220e, /* VUNPCKHPDrr */
/* Table4166 */
  0x1545, /* VMOVHPDrm */
  0x0, /*  */
/* Table4168 */
  0x1544, /* VMOVHPDmr */
  0x0, /*  */
/* Table4170 */
  0x1432, /* VMOVAPDrm */
  0x1433, /* VMOVAPDrr */
/* Table4172 */
  0x1431, /* VMOVAPDmr */
  0x1434, /* VMOVAPDrr_REV */
/* Table4174 */
  0x1560, /* VMOVNTPDmr */
  0x0, /*  */
/* Table4176 */
  0x2203, /* VUCOMISDrm */
  0x2204, /* VUCOMISDrr */
/* Table4178 */
  0xcf3, /* VCOMISDrm */
  0xcf4, /* VCOMISDrr */
/* Table4180 */
  0x0, /*  */
  0x493, /* KNOTBrr */
/* Table4182 */
  0x0, /*  */
  0x154f, /* VMOVMSKPDrr */
/* Table4184 */
  0x2167, /* VSQRTPDm */
  0x2168, /* VSQRTPDr */
/* Table4186 */
  0xc55, /* VANDPDrm */
  0xc56, /* VANDPDrr */
/* Table4188 */
  0xc4d, /* VANDNPDrm */
  0xc4e, /* VANDNPDrr */
/* Table4190 */
  0x166b, /* VORPDrm */
  0x166c, /* VORPDrr */
/* Table4192 */
  0x2223, /* VXORPDrm */
  0x2224, /* VXORPDrr */
/* Table4194 */
  0xbed, /* VADDPDrm */
  0xbee, /* VADDPDrr */
/* Table4196 */
  0x1621, /* VMULPDrm */
  0x1622, /* VMULPDrr */
/* Table4198 */
  0xd1f, /* VCVTPD2PSXrm */
  0xd25, /* VCVTPD2PSrr */
/* Table4200 */
  0xd34, /* VCVTPS2DQrm */
  0xd35, /* VCVTPS2DQrr */
/* Table4202 */
  0x21b7, /* VSUBPDrm */
  0x21b8, /* VSUBPDrr */
/* Table4204 */
  0x13c3, /* VMINPDrm */
  0x13c4, /* VMINPDrr */
/* Table4206 */
  0xdca, /* VDIVPDrm */
  0xdcb, /* VDIVPDrr */
/* Table4208 */
  0x1358, /* VMAXPDrm */
  0x1359, /* VMAXPDrr */
/* Table4210 */
  0x1fe4, /* VPUNPCKLBWrm */
  0x1fe5, /* VPUNPCKLBWrr */
/* Table4212 */
  0x1ff4, /* VPUNPCKLWDrm */
  0x1ff5, /* VPUNPCKLWDrr */
/* Table4214 */
  0x1fea, /* VPUNPCKLDQrm */
  0x1feb, /* VPUNPCKLDQrr */
/* Table4216 */
  0x1695, /* VPACKSSWBrm */
  0x1696, /* VPACKSSWBrr */
/* Table4218 */
  0x18e1, /* VPCMPGTBrm */
  0x18e2, /* VPCMPGTBrr */
/* Table4220 */
  0x191d, /* VPCMPGTWrm */
  0x191e, /* VPCMPGTWrr */
/* Table4222 */
  0x18f7, /* VPCMPGTDrm */
  0x18f8, /* VPCMPGTDrr */
/* Table4224 */
  0x169d, /* VPACKUSWBrm */
  0x169e, /* VPACKUSWBrr */
/* Table4226 */
  0x1fd0, /* VPUNPCKHBWrm */
  0x1fd1, /* VPUNPCKHBWrr */
/* Table4228 */
  0x1fe0, /* VPUNPCKHWDrm */
  0x1fe1, /* VPUNPCKHWDrr */
/* Table4230 */
  0x1fd6, /* VPUNPCKHDQrm */
  0x1fd7, /* VPUNPCKHDQrr */
/* Table4232 */
  0x1691, /* VPACKSSDWrm */
  0x1692, /* VPACKSSDWrr */
/* Table4234 */
  0x1ff0, /* VPUNPCKLQDQrm */
  0x1ff1, /* VPUNPCKLQDQrr */
/* Table4236 */
  0x1fdc, /* VPUNPCKHQDQrm */
  0x1fdd, /* VPUNPCKHQDQrr */
/* Table4238 */
  0x1466, /* VMOVDI2PDIrm */
  0x1467, /* VMOVDI2PDIrr */
/* Table4240 */
  0x14b3, /* VMOVDQArm */
  0x14b4, /* VMOVDQArr */
/* Table4242 */
  0x1e7e, /* VPSHUFDmi */
  0x1e7f, /* VPSHUFDri */
/* Table4244 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1f45, /* VPSRLWri */
  0x0, /*  */
  0x1f05, /* VPSRAWri */
  0x0, /*  */
  0x1ed1, /* VPSLLWri */
  0x0, /*  */
/* Table4260 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1f19, /* VPSRLDri */
  0x0, /*  */
  0x1ee3, /* VPSRADri */
  0x0, /*  */
  0x1ea5, /* VPSLLDri */
  0x0, /*  */
/* Table4276 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1f2b, /* VPSRLQri */
  0x1f09, /* VPSRLDQri */
  0x0, /*  */
  0x0, /*  */
  0x1eb7, /* VPSLLQri */
  0x1e95, /* VPSLLDQri */
/* Table4292 */
  0x188d, /* VPCMPEQBrm */
  0x188e, /* VPCMPEQBrr */
/* Table4294 */
  0x18c9, /* VPCMPEQWrm */
  0x18ca, /* VPCMPEQWrr */
/* Table4296 */
  0x18a3, /* VPCMPEQDrm */
  0x18a4, /* VPCMPEQDrr */
/* Table4298 */
  0x12fc, /* VHADDPDrm */
  0x12fd, /* VHADDPDrr */
/* Table4300 */
  0x1304, /* VHSUBPDrm */
  0x1305, /* VHSUBPDrr */
/* Table4302 */
  0x1568, /* VMOVPDI2DImr */
  0x1569, /* VMOVPDI2DIrr */
/* Table4304 */
  0x14b2, /* VMOVDQAmr */
  0x14b5, /* VMOVDQArr_REV */
/* Table4306 */
  0x480, /* KMOVBkm */
  0x47f, /* KMOVBkk */
/* Table4308 */
  0x482, /* KMOVBmk */
  0x0, /*  */
/* Table4310 */
  0x0, /*  */
  0x481, /* KMOVBkr */
/* Table4312 */
  0x0, /*  */
  0x483, /* KMOVBrk */
/* Table4314 */
  0x0, /*  */
  0x49a, /* KORTESTBrr */
/* Table4316 */
  0xccf, /* VCMPPDrmi */
  0xcd1, /* VCMPPDrri */
/* Table4318 */
  0x1af6, /* VPINSRWrmi */
  0x1af7, /* VPINSRWrri */
/* Table4320 */
  0x0, /*  */
  0x1aaa, /* VPEXTRWri */
/* Table4322 */
  0x2142, /* VSHUFPDrmi */
  0x2143, /* VSHUFPDrri */
/* Table4324 */
  0xc31, /* VADDSUBPDrm */
  0xc32, /* VADDSUBPDrr */
/* Table4326 */
  0x1f46, /* VPSRLWrm */
  0x1f47, /* VPSRLWrr */
/* Table4328 */
  0x1f1a, /* VPSRLDrm */
  0x1f1b, /* VPSRLDrr */
/* Table4330 */
  0x1f2c, /* VPSRLQrm */
  0x1f2d, /* VPSRLQrr */
/* Table4332 */
  0x16f1, /* VPADDQrm */
  0x16f2, /* VPADDQrr */
/* Table4334 */
  0x1df6, /* VPMULLWrm */
  0x1df7, /* VPMULLWrr */
/* Table4336 */
  0x156a, /* VMOVPQI2QImr */
  0x156b, /* VMOVPQI2QIrr */
/* Table4338 */
  0x0, /*  */
  0x1ce1, /* VPMOVMSKBrr */
/* Table4340 */
  0x1fa6, /* VPSUBUSBrm */
  0x1fa7, /* VPSUBUSBrr */
/* Table4342 */
  0x1faa, /* VPSUBUSWrm */
  0x1fab, /* VPSUBUSWrr */
/* Table4344 */
  0x1c78, /* VPMINUBrm */
  0x1c79, /* VPMINUBrr */
/* Table4346 */
  0x178f, /* VPANDrm */
  0x1790, /* VPANDrr */
/* Table4348 */
  0x16fd, /* VPADDUSBrm */
  0x16fe, /* VPADDUSBrr */
/* Table4350 */
  0x1701, /* VPADDUSWrm */
  0x1702, /* VPADDUSWrr */
/* Table4352 */
  0x1bac, /* VPMAXUBrm */
  0x1bad, /* VPMAXUBrr */
/* Table4354 */
  0x1770, /* VPANDNrm */
  0x1771, /* VPANDNrr */
/* Table4356 */
  0x1793, /* VPAVGBrm */
  0x1794, /* VPAVGBrr */
/* Table4358 */
  0x1f06, /* VPSRAWrm */
  0x1f07, /* VPSRAWrr */
/* Table4360 */
  0x1ee4, /* VPSRADrm */
  0x1ee5, /* VPSRADrr */
/* Table4362 */
  0x1797, /* VPAVGWrm */
  0x1798, /* VPAVGWrr */
/* Table4364 */
  0x1da2, /* VPMULHUWrm */
  0x1da3, /* VPMULHUWrr */
/* Table4366 */
  0x1da6, /* VPMULHWrm */
  0x1da7, /* VPMULHWrr */
/* Table4368 */
  0xd75, /* VCVTTPD2DQXrm */
  0xd7a, /* VCVTTPD2DQrr */
/* Table4370 */
  0x155b, /* VMOVNTDQmr */
  0x0, /*  */
/* Table4372 */
  0x1f9e, /* VPSUBSBrm */
  0x1f9f, /* VPSUBSBrr */
/* Table4374 */
  0x1fa2, /* VPSUBSWrm */
  0x1fa3, /* VPSUBSWrr */
/* Table4376 */
  0x1c62, /* VPMINSWrm */
  0x1c63, /* VPMINSWrr */
/* Table4378 */
  0x1e3d, /* VPORrm */
  0x1e3e, /* VPORrr */
/* Table4380 */
  0x16f5, /* VPADDSBrm */
  0x16f6, /* VPADDSBrr */
/* Table4382 */
  0x16f9, /* VPADDSWrm */
  0x16fa, /* VPADDSWrr */
/* Table4384 */
  0x1b96, /* VPMAXSWrm */
  0x1b97, /* VPMAXSWrr */
/* Table4386 */
  0x202e, /* VPXORrm */
  0x202f, /* VPXORrr */
/* Table4388 */
  0x1ed2, /* VPSLLWrm */
  0x1ed3, /* VPSLLWrr */
/* Table4390 */
  0x1ea6, /* VPSLLDrm */
  0x1ea7, /* VPSLLDrr */
/* Table4392 */
  0x1eb8, /* VPSLLQrm */
  0x1eb9, /* VPSLLQrr */
/* Table4394 */
  0x1e03, /* VPMULUDQrm */
  0x1e04, /* VPMULUDQrr */
/* Table4396 */
  0x1b28, /* VPMADDWDrm */
  0x1b29, /* VPMADDWDrr */
/* Table4398 */
  0x1e58, /* VPSADBWrm */
  0x1e59, /* VPSADBWrr */
/* Table4400 */
  0x0, /*  */
  0x1325, /* VMASKMOVDQU */
/* Table4402 */
  0x1f5c, /* VPSUBBrm */
  0x1f5d, /* VPSUBBrr */
/* Table4404 */
  0x1fc0, /* VPSUBWrm */
  0x1fc1, /* VPSUBWrr */
/* Table4406 */
  0x1f7b, /* VPSUBDrm */
  0x1f7c, /* VPSUBDrr */
/* Table4408 */
  0x1f9a, /* VPSUBQrm */
  0x1f9b, /* VPSUBQrr */
/* Table4410 */
  0x16b3, /* VPADDBrm */
  0x16b4, /* VPADDBrr */
/* Table4412 */
  0x1717, /* VPADDWrm */
  0x1718, /* VPADDWrr */
/* Table4414 */
  0x16d2, /* VPADDDrm */
  0x16d3, /* VPADDDrr */
/* Table4416 */
  0x0, /*  */
  0x495, /* KNOTQrr */
/* Table4418 */
  0x48a, /* KMOVQkm */
  0x489, /* KMOVQkk */
/* Table4420 */
  0x48c, /* KMOVQmk */
  0x0, /*  */
/* Table4422 */
  0x0, /*  */
  0x49c, /* KORTESTQrr */
/* Table4424 */
  0xd5b, /* VCVTSI2SS64rm */
  0xd5c, /* VCVTSI2SS64rr */
/* Table4426 */
  0xd93, /* VCVTTSS2SI64rm */
  0xd94, /* VCVTTSS2SI64rr */
/* Table4428 */
  0xd6b, /* VCVTSS2SI64rm */
  0xd6c, /* VCVTSS2SI64rr */
/* Table4430 */
  0xd55, /* VCVTSI2SD64rm */
  0xd56, /* VCVTSI2SD64rr */
/* Table4432 */
  0xd87, /* VCVTTSD2SI64rm */
  0xd88, /* VCVTTSD2SI64rr */
/* Table4434 */
  0xd47, /* VCVTSD2SI64rm */
  0xd48, /* VCVTSD2SI64rr */
/* Table4436 */
  0x0, /*  */
  0x48b, /* KMOVQkr */
/* Table4438 */
  0x0, /*  */
  0x48d, /* KMOVQrk */
/* Table4440 */
  0x0, /*  */
  0x494, /* KNOTDrr */
/* Table4442 */
  0x1407, /* VMOV64toPQIrm */
  0x1408, /* VMOV64toPQIrr */
/* Table4444 */
  0x156e, /* VMOVPQIto64rm */
  0x156f, /* VMOVPQIto64rr */
/* Table4446 */
  0x485, /* KMOVDkm */
  0x484, /* KMOVDkk */
/* Table4448 */
  0x487, /* KMOVDmk */
  0x0, /*  */
/* Table4450 */
  0x0, /*  */
  0x49b, /* KORTESTDrr */
/* Table4452 */
  0x15c4, /* VMOVUPSYrm */
  0x15c5, /* VMOVUPSYrr */
/* Table4454 */
  0x15c3, /* VMOVUPSYmr */
  0x15c6, /* VMOVUPSYrr_REV */
/* Table4456 */
  0x221b, /* VUNPCKLPSYrm */
  0x221c, /* VUNPCKLPSYrr */
/* Table4458 */
  0x220f, /* VUNPCKHPSYrm */
  0x2210, /* VUNPCKHPSYrr */
/* Table4460 */
  0x1436, /* VMOVAPSYrm */
  0x1437, /* VMOVAPSYrr */
/* Table4462 */
  0x1435, /* VMOVAPSYmr */
  0x1438, /* VMOVAPSYrr_REV */
/* Table4464 */
  0x1561, /* VMOVNTPSYmr */
  0x0, /*  */
/* Table4466 */
  0x0, /*  */
  0x47e, /* KANDWrr */
/* Table4468 */
  0x0, /*  */
  0x47c, /* KANDNWrr */
/* Table4470 */
  0x0, /*  */
  0x49e, /* KORWrr */
/* Table4472 */
  0x0, /*  */
  0x4af, /* KXNORWrr */
/* Table4474 */
  0x0, /*  */
  0x4b3, /* KXORWrr */
/* Table4476 */
  0x0, /*  */
  0x1550, /* VMOVMSKPSYrr */
/* Table4478 */
  0x2169, /* VSQRTPSYm */
  0x216a, /* VSQRTPSYr */
/* Table4480 */
  0x2127, /* VRSQRTPSYm */
  0x2129, /* VRSQRTPSYr */
/* Table4482 */
  0x2094, /* VRCPPSYm */
  0x2096, /* VRCPPSYr */
/* Table4484 */
  0xc57, /* VANDPSYrm */
  0xc58, /* VANDPSYrr */
/* Table4486 */
  0xc4f, /* VANDNPSYrm */
  0xc50, /* VANDNPSYrr */
/* Table4488 */
  0x166d, /* VORPSYrm */
  0x166e, /* VORPSYrr */
/* Table4490 */
  0x2225, /* VXORPSYrm */
  0x2226, /* VXORPSYrr */
/* Table4492 */
  0xbef, /* VADDPSYrm */
  0xbf0, /* VADDPSYrr */
/* Table4494 */
  0x1623, /* VMULPSYrm */
  0x1624, /* VMULPSYrr */
/* Table4496 */
  0xd36, /* VCVTPS2PDYrm */
  0xd37, /* VCVTPS2PDYrr */
/* Table4498 */
  0xd11, /* VCVTDQ2PSYrm */
  0xd12, /* VCVTDQ2PSYrr */
/* Table4500 */
  0x21b9, /* VSUBPSYrm */
  0x21ba, /* VSUBPSYrr */
/* Table4502 */
  0x13c5, /* VMINPSYrm */
  0x13c6, /* VMINPSYrr */
/* Table4504 */
  0xdcc, /* VDIVPSYrm */
  0xdcd, /* VDIVPSYrr */
/* Table4506 */
  0x135a, /* VMAXPSYrm */
  0x135b, /* VMAXPSYrr */
/* Table4508 */
  0x2229, /* VZEROALL */
/* Table4509 */
  0xcd3, /* VCMPPSYrmi */
  0xcd5, /* VCMPPSYrri */
/* Table4511 */
  0x2144, /* VSHUFPSYrmi */
  0x2145, /* VSHUFPSYrri */
/* Table4513 */
  0x1586, /* VMOVSLDUPYrm */
  0x1587, /* VMOVSLDUPYrr */
/* Table4515 */
  0x1580, /* VMOVSHDUPYrm */
  0x1581, /* VMOVSHDUPYrr */
/* Table4517 */
  0xd7d, /* VCVTTPS2DQYrm */
  0xd7e, /* VCVTTPS2DQYrr */
/* Table4519 */
  0x153b, /* VMOVDQUYrm */
  0x153c, /* VMOVDQUYrr */
/* Table4521 */
  0x1e80, /* VPSHUFHWYmi */
  0x1e81, /* VPSHUFHWYri */
/* Table4523 */
  0x153a, /* VMOVDQUYmr */
  0x153d, /* VMOVDQUYrr_REV */
/* Table4525 */
  0xd0b, /* VCVTDQ2PDYrm */
  0xd0c, /* VCVTDQ2PDYrr */
/* Table4527 */
  0x145e, /* VMOVDDUPYrm */
  0x145f, /* VMOVDDUPYrr */
/* Table4529 */
  0x1e84, /* VPSHUFLWYmi */
  0x1e85, /* VPSHUFLWYri */
/* Table4531 */
  0x12fe, /* VHADDPSYrm */
  0x12ff, /* VHADDPSYrr */
/* Table4533 */
  0x1306, /* VHSUBPSYrm */
  0x1307, /* VHSUBPSYrr */
/* Table4535 */
  0xc33, /* VADDSUBPSYrm */
  0xc34, /* VADDSUBPSYrr */
/* Table4537 */
  0xd19, /* VCVTPD2DQYrm */
  0xd1a, /* VCVTPD2DQYrr */
/* Table4539 */
  0x1322, /* VLDDQUYrm */
  0x0, /*  */
/* Table4541 */
  0x159b, /* VMOVUPDYrm */
  0x159c, /* VMOVUPDYrr */
/* Table4543 */
  0x159a, /* VMOVUPDYmr */
  0x159d, /* VMOVUPDYrr_REV */
/* Table4545 */
  0x2215, /* VUNPCKLPDYrm */
  0x2216, /* VUNPCKLPDYrr */
/* Table4547 */
  0x2209, /* VUNPCKHPDYrm */
  0x220a, /* VUNPCKHPDYrr */
/* Table4549 */
  0x140d, /* VMOVAPDYrm */
  0x140e, /* VMOVAPDYrr */
/* Table4551 */
  0x140c, /* VMOVAPDYmr */
  0x140f, /* VMOVAPDYrr_REV */
/* Table4553 */
  0x155c, /* VMOVNTPDYmr */
  0x0, /*  */
/* Table4555 */
  0x0, /*  */
  0x477, /* KANDBrr */
/* Table4557 */
  0x0, /*  */
  0x479, /* KANDNBrr */
/* Table4559 */
  0x0, /*  */
  0x497, /* KORBrr */
/* Table4561 */
  0x0, /*  */
  0x4ac, /* KXNORBrr */
/* Table4563 */
  0x0, /*  */
  0x4b0, /* KXORBrr */
/* Table4565 */
  0x0, /*  */
  0x4ab, /* KUNPCKBWrr */
/* Table4567 */
  0x0, /*  */
  0x154e, /* VMOVMSKPDYrr */
/* Table4569 */
  0x214a, /* VSQRTPDYm */
  0x214b, /* VSQRTPDYr */
/* Table4571 */
  0xc53, /* VANDPDYrm */
  0xc54, /* VANDPDYrr */
/* Table4573 */
  0xc4b, /* VANDNPDYrm */
  0xc4c, /* VANDNPDYrr */
/* Table4575 */
  0x1669, /* VORPDYrm */
  0x166a, /* VORPDYrr */
/* Table4577 */
  0x2221, /* VXORPDYrm */
  0x2222, /* VXORPDYrr */
/* Table4579 */
  0xbcd, /* VADDPDYrm */
  0xbce, /* VADDPDYrr */
/* Table4581 */
  0x1601, /* VMULPDYrm */
  0x1602, /* VMULPDYrr */
/* Table4583 */
  0xd20, /* VCVTPD2PSYrm */
  0xd21, /* VCVTPD2PSYrr */
/* Table4585 */
  0xd2f, /* VCVTPS2DQYrm */
  0xd30, /* VCVTPS2DQYrr */
/* Table4587 */
  0x2197, /* VSUBPDYrm */
  0x2198, /* VSUBPDYrr */
/* Table4589 */
  0x13a6, /* VMINPDYrm */
  0x13a7, /* VMINPDYrr */
/* Table4591 */
  0xdaa, /* VDIVPDYrm */
  0xdab, /* VDIVPDYrr */
/* Table4593 */
  0x133b, /* VMAXPDYrm */
  0x133c, /* VMAXPDYrr */
/* Table4595 */
  0x1fe2, /* VPUNPCKLBWYrm */
  0x1fe3, /* VPUNPCKLBWYrr */
/* Table4597 */
  0x1ff2, /* VPUNPCKLWDYrm */
  0x1ff3, /* VPUNPCKLWDYrr */
/* Table4599 */
  0x1fe6, /* VPUNPCKLDQYrm */
  0x1fe7, /* VPUNPCKLDQYrr */
/* Table4601 */
  0x1693, /* VPACKSSWBYrm */
  0x1694, /* VPACKSSWBYrr */
/* Table4603 */
  0x18d3, /* VPCMPGTBYrm */
  0x18d4, /* VPCMPGTBYrr */
/* Table4605 */
  0x190f, /* VPCMPGTWYrm */
  0x1910, /* VPCMPGTWYrr */
/* Table4607 */
  0x18e3, /* VPCMPGTDYrm */
  0x18e4, /* VPCMPGTDYrr */
/* Table4609 */
  0x169b, /* VPACKUSWBYrm */
  0x169c, /* VPACKUSWBYrr */
/* Table4611 */
  0x1fce, /* VPUNPCKHBWYrm */
  0x1fcf, /* VPUNPCKHBWYrr */
/* Table4613 */
  0x1fde, /* VPUNPCKHWDYrm */
  0x1fdf, /* VPUNPCKHWDYrr */
/* Table4615 */
  0x1fd2, /* VPUNPCKHDQYrm */
  0x1fd3, /* VPUNPCKHDQYrr */
/* Table4617 */
  0x168f, /* VPACKSSDWYrm */
  0x1690, /* VPACKSSDWYrr */
/* Table4619 */
  0x1fec, /* VPUNPCKLQDQYrm */
  0x1fed, /* VPUNPCKLQDQYrr */
/* Table4621 */
  0x1fd8, /* VPUNPCKHQDQYrm */
  0x1fd9, /* VPUNPCKHQDQYrr */
/* Table4623 */
  0x14af, /* VMOVDQAYrm */
  0x14b0, /* VMOVDQAYrr */
/* Table4625 */
  0x1e7a, /* VPSHUFDYmi */
  0x1e7b, /* VPSHUFDYri */
/* Table4627 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1f42, /* VPSRLWYri */
  0x0, /*  */
  0x1f02, /* VPSRAWYri */
  0x0, /*  */
  0x1ece, /* VPSLLWYri */
  0x0, /*  */
/* Table4643 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1f0a, /* VPSRLDYri */
  0x0, /*  */
  0x1ed4, /* VPSRADYri */
  0x0, /*  */
  0x1e96, /* VPSLLDYri */
  0x0, /*  */
/* Table4659 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1f1c, /* VPSRLQYri */
  0x1f08, /* VPSRLDQYri */
  0x0, /*  */
  0x0, /*  */
  0x1ea8, /* VPSLLQYri */
  0x1e94, /* VPSLLDQYri */
/* Table4675 */
  0x187f, /* VPCMPEQBYrm */
  0x1880, /* VPCMPEQBYrr */
/* Table4677 */
  0x18bb, /* VPCMPEQWYrm */
  0x18bc, /* VPCMPEQWYrr */
/* Table4679 */
  0x188f, /* VPCMPEQDYrm */
  0x1890, /* VPCMPEQDYrr */
/* Table4681 */
  0x12fa, /* VHADDPDYrm */
  0x12fb, /* VHADDPDYrr */
/* Table4683 */
  0x1302, /* VHSUBPDYrm */
  0x1303, /* VHSUBPDYrr */
/* Table4685 */
  0x14ae, /* VMOVDQAYmr */
  0x14b1, /* VMOVDQAYrr_REV */
/* Table4687 */
  0xcc5, /* VCMPPDYrmi */
  0xcc7, /* VCMPPDYrri */
/* Table4689 */
  0x213e, /* VSHUFPDYrmi */
  0x213f, /* VSHUFPDYrri */
/* Table4691 */
  0xc2f, /* VADDSUBPDYrm */
  0xc30, /* VADDSUBPDYrr */
/* Table4693 */
  0x1f43, /* VPSRLWYrm */
  0x1f44, /* VPSRLWYrr */
/* Table4695 */
  0x1f0b, /* VPSRLDYrm */
  0x1f0c, /* VPSRLDYrr */
/* Table4697 */
  0x1f1d, /* VPSRLQYrm */
  0x1f1e, /* VPSRLQYrr */
/* Table4699 */
  0x16d4, /* VPADDQYrm */
  0x16d5, /* VPADDQYrr */
/* Table4701 */
  0x1de2, /* VPMULLWYrm */
  0x1de3, /* VPMULLWYrr */
/* Table4703 */
  0x0, /*  */
  0x1ce0, /* VPMOVMSKBYrr */
/* Table4705 */
  0x1fa4, /* VPSUBUSBYrm */
  0x1fa5, /* VPSUBUSBYrr */
/* Table4707 */
  0x1fa8, /* VPSUBUSWYrm */
  0x1fa9, /* VPSUBUSWYrr */
/* Table4709 */
  0x1c64, /* VPMINUBYrm */
  0x1c65, /* VPMINUBYrr */
/* Table4711 */
  0x178d, /* VPANDYrm */
  0x178e, /* VPANDYrr */
/* Table4713 */
  0x16fb, /* VPADDUSBYrm */
  0x16fc, /* VPADDUSBYrr */
/* Table4715 */
  0x16ff, /* VPADDUSWYrm */
  0x1700, /* VPADDUSWYrr */
/* Table4717 */
  0x1b98, /* VPMAXUBYrm */
  0x1b99, /* VPMAXUBYrr */
/* Table4719 */
  0x176e, /* VPANDNYrm */
  0x176f, /* VPANDNYrr */
/* Table4721 */
  0x1791, /* VPAVGBYrm */
  0x1792, /* VPAVGBYrr */
/* Table4723 */
  0x1f03, /* VPSRAWYrm */
  0x1f04, /* VPSRAWYrr */
/* Table4725 */
  0x1ed5, /* VPSRADYrm */
  0x1ed6, /* VPSRADYrr */
/* Table4727 */
  0x1795, /* VPAVGWYrm */
  0x1796, /* VPAVGWYrr */
/* Table4729 */
  0x1da0, /* VPMULHUWYrm */
  0x1da1, /* VPMULHUWYrr */
/* Table4731 */
  0x1da4, /* VPMULHWYrm */
  0x1da5, /* VPMULHWYrr */
/* Table4733 */
  0xd76, /* VCVTTPD2DQYrm */
  0xd77, /* VCVTTPD2DQYrr */
/* Table4735 */
  0x1557, /* VMOVNTDQYmr */
  0x0, /*  */
/* Table4737 */
  0x1f9c, /* VPSUBSBYrm */
  0x1f9d, /* VPSUBSBYrr */
/* Table4739 */
  0x1fa0, /* VPSUBSWYrm */
  0x1fa1, /* VPSUBSWYrr */
/* Table4741 */
  0x1c4e, /* VPMINSWYrm */
  0x1c4f, /* VPMINSWYrr */
/* Table4743 */
  0x1e3b, /* VPORYrm */
  0x1e3c, /* VPORYrr */
/* Table4745 */
  0x16f3, /* VPADDSBYrm */
  0x16f4, /* VPADDSBYrr */
/* Table4747 */
  0x16f7, /* VPADDSWYrm */
  0x16f8, /* VPADDSWYrr */
/* Table4749 */
  0x1b82, /* VPMAXSWYrm */
  0x1b83, /* VPMAXSWYrr */
/* Table4751 */
  0x202c, /* VPXORYrm */
  0x202d, /* VPXORYrr */
/* Table4753 */
  0x1ecf, /* VPSLLWYrm */
  0x1ed0, /* VPSLLWYrr */
/* Table4755 */
  0x1e97, /* VPSLLDYrm */
  0x1e98, /* VPSLLDYrr */
/* Table4757 */
  0x1ea9, /* VPSLLQYrm */
  0x1eaa, /* VPSLLQYrr */
/* Table4759 */
  0x1df8, /* VPMULUDQYrm */
  0x1df9, /* VPMULUDQYrr */
/* Table4761 */
  0x1b26, /* VPMADDWDYrm */
  0x1b27, /* VPMADDWDYrr */
/* Table4763 */
  0x1e56, /* VPSADBWYrm */
  0x1e57, /* VPSADBWYrr */
/* Table4765 */
  0x1f48, /* VPSUBBYrm */
  0x1f49, /* VPSUBBYrr */
/* Table4767 */
  0x1fac, /* VPSUBWYrm */
  0x1fad, /* VPSUBWYrr */
/* Table4769 */
  0x1f5e, /* VPSUBDYrm */
  0x1f5f, /* VPSUBDYrr */
/* Table4771 */
  0x1f7d, /* VPSUBQYrm */
  0x1f7e, /* VPSUBQYrr */
/* Table4773 */
  0x169f, /* VPADDBYrm */
  0x16a0, /* VPADDBYrr */
/* Table4775 */
  0x1703, /* VPADDWYrm */
  0x1704, /* VPADDWYrr */
/* Table4777 */
  0x16b5, /* VPADDDYrm */
  0x16b6, /* VPADDDYrr */
/* Table4779 */
  0x0, /*  */
  0x47d, /* KANDQrr */
/* Table4781 */
  0x0, /*  */
  0x47b, /* KANDNQrr */
/* Table4783 */
  0x0, /*  */
  0x499, /* KORQrr */
/* Table4785 */
  0x0, /*  */
  0x4ae, /* KXNORQrr */
/* Table4787 */
  0x0, /*  */
  0x4b2, /* KXORQrr */
/* Table4789 */
  0x0, /*  */
  0x478, /* KANDDrr */
/* Table4791 */
  0x0, /*  */
  0x47a, /* KANDNDrr */
/* Table4793 */
  0x0, /*  */
  0x498, /* KORDrr */
/* Table4795 */
  0x0, /*  */
  0x4ad, /* KXNORDrr */
/* Table4797 */
  0x0, /*  */
  0x4b1, /* KXORDrr */
/* Table4799 */
  0x15c9, /* VMOVUPSZ128rm */
  0x15cc, /* VMOVUPSZ128rr */
/* Table4801 */
  0x15c7, /* VMOVUPSZ128mr */
  0x15cd, /* VMOVUPSZ128rr_alt */
/* Table4803 */
  0x0, /*  */
  0x1542, /* VMOVHLPSZrr */
/* Table4805 */
  0x0, /*  */
  0x1548, /* VMOVLHPSZrr */
/* Table4807 */
  0x143b, /* VMOVAPSZ128rm */
  0x143e, /* VMOVAPSZ128rr */
/* Table4809 */
  0x1439, /* VMOVAPSZ128mr */
  0x143f, /* VMOVAPSZ128rr_alt */
/* Table4811 */
  0x1562, /* VMOVNTPSZ128mr */
  0x0, /*  */
/* Table4813 */
  0x2205, /* VUCOMISSZrm */
  0x2206, /* VUCOMISSZrr */
/* Table4815 */
  0xcf5, /* VCOMISSZrm */
  0xcf6, /* VCOMISSZrr */
/* Table4817 */
  0x216b, /* VSQRTPSZ128m */
  0x2171, /* VSQRTPSZ128r */
/* Table4819 */
  0xbf1, /* VADDPSZ128rm */
  0xbf7, /* VADDPSZ128rr */
/* Table4821 */
  0x1625, /* VMULPSZ128rm */
  0x162b, /* VMULPSZ128rr */
/* Table4823 */
  0x21bb, /* VSUBPSZ128rm */
  0x21c1, /* VSUBPSZ128rr */
/* Table4825 */
  0x13c7, /* VMINPSZ128rm */
  0x13cd, /* VMINPSZ128rr */
/* Table4827 */
  0xdce, /* VDIVPSZ128rm */
  0xdd4, /* VDIVPSZ128rr */
/* Table4829 */
  0x135c, /* VMAXPSZ128rm */
  0x1362, /* VMAXPSZ128rr */
/* Table4831 */
  0x1592, /* VMOVSSZrm */
  0x1593, /* VMOVSSZrr */
/* Table4833 */
  0x1590, /* VMOVSSZmr */
  0x1594, /* VMOVSSZrr_REV */
/* Table4835 */
  0xd5d, /* VCVTSI2SSZrm */
  0xd5e, /* VCVTSI2SSZrr */
/* Table4837 */
  0xd95, /* VCVTTSS2SIZrm */
  0xd96, /* VCVTTSS2SIZrr */
/* Table4839 */
  0xd6d, /* VCVTSS2SIZrm */
  0xd6e, /* VCVTSS2SIZrr */
/* Table4841 */
  0x218f, /* VSQRTSSZm */
  0x2191, /* VSQRTSSZr */
/* Table4843 */
  0xc21, /* VADDSSZrm_Int */
  0xc25, /* VADDSSZrr_Int */
/* Table4845 */
  0x1655, /* VMULSSZrm_Int */
  0x1659, /* VMULSSZrr_Int */
/* Table4847 */
  0xd65, /* VCVTSS2SDZrm */
  0xd66, /* VCVTSS2SDZrr */
/* Table4849 */
  0x21eb, /* VSUBSSZrm_Int */
  0x21ef, /* VSUBSSZrr_Int */
/* Table4851 */
  0x13f4, /* VMINSSZrm_Int */
  0x13f8, /* VMINSSZrr_Int */
/* Table4853 */
  0xdfe, /* VDIVSSZrm_Int */
  0xe02, /* VDIVSSZrr_Int */
/* Table4855 */
  0x1389, /* VMAXSSZrm_Int */
  0x138d, /* VMAXSSZrr_Int */
/* Table4857 */
  0x14d9, /* VMOVDQU32Z128rm */
  0x14dc, /* VMOVDQU32Z128rr */
/* Table4859 */
  0xd9b, /* VCVTTSS2USIZrm */
  0xd9c, /* VCVTTSS2USIZrr */
/* Table4861 */
  0xd73, /* VCVTSS2USIZrm */
  0xd74, /* VCVTSS2USIZrr */
/* Table4863 */
  0xda4, /* VCVTUSI2SSZrm */
  0xda5, /* VCVTUSI2SSZrr */
/* Table4865 */
  0x14d7, /* VMOVDQU32Z128mr */
  0x14dd, /* VMOVDQU32Z128rr_alt */
/* Table4867 */
  0xce9, /* VCMPSSZrm */
  0xceb, /* VCMPSSZrr */
/* Table4869 */
  0xd57, /* VCVTSI2SDZrm */
  0xd58, /* VCVTSI2SDZrr */
/* Table4871 */
  0xd89, /* VCVTTSD2SIZrm */
  0xd8a, /* VCVTTSD2SIZrr */
/* Table4873 */
  0xd49, /* VCVTSD2SIZrm */
  0xd4a, /* VCVTSD2SIZrr */
/* Table4875 */
  0x151b, /* VMOVDQU8Z128rm */
  0x151e, /* VMOVDQU8Z128rr */
/* Table4877 */
  0xd8f, /* VCVTTSD2USIZrm */
  0xd90, /* VCVTTSD2USIZrr */
/* Table4879 */
  0xd53, /* VCVTSD2USIZrm */
  0xd54, /* VCVTSD2USIZrr */
/* Table4881 */
  0xda2, /* VCVTUSI2SDZrm */
  0xda3, /* VCVTUSI2SDZrr */
/* Table4883 */
  0x1519, /* VMOVDQU8Z128mr */
  0x151f, /* VMOVDQU8Z128rr_alt */
/* Table4885 */
  0x18d5, /* VPCMPGTBZ128rm */
  0x18d7, /* VPCMPGTBZ128rr */
/* Table4887 */
  0x1911, /* VPCMPGTWZ128rm */
  0x1913, /* VPCMPGTWZ128rr */
/* Table4889 */
  0x18e5, /* VPCMPGTDZ128rm */
  0x18e9, /* VPCMPGTDZ128rr */
/* Table4891 */
  0x1464, /* VMOVDI2PDIZrm */
  0x1465, /* VMOVDI2PDIZrr */
/* Table4893 */
  0x146e, /* VMOVDQA32Z128rm */
  0x1471, /* VMOVDQA32Z128rr */
/* Table4895 */
  0x1881, /* VPCMPEQBZ128rm */
  0x1883, /* VPCMPEQBZ128rr */
/* Table4897 */
  0x18bd, /* VPCMPEQWZ128rm */
  0x18bf, /* VPCMPEQWZ128rr */
/* Table4899 */
  0x1891, /* VPCMPEQDZ128rm */
  0x1895, /* VPCMPEQDZ128rr */
/* Table4901 */
  0x1566, /* VMOVPDI2DIZmr */
  0x1567, /* VMOVPDI2DIZrr */
/* Table4903 */
  0x146c, /* VMOVDQA32Z128mr */
  0x1472, /* VMOVDQA32Z128rr_alt */
/* Table4905 */
  0x1de4, /* VPMULLWZ128rm */
  0x1de7, /* VPMULLWZ128rr */
/* Table4907 */
  0x1c66, /* VPMINUBZ128rm */
  0x1c69, /* VPMINUBZ128rr */
/* Table4909 */
  0x171d, /* VPANDDZ128rm */
  0x1723, /* VPANDDZ128rr */
/* Table4911 */
  0x1b9a, /* VPMAXUBZ128rm */
  0x1b9d, /* VPMAXUBZ128rr */
/* Table4913 */
  0x1738, /* VPANDNDZ128rm */
  0x173e, /* VPANDNDZ128rr */
/* Table4915 */
  0x1558, /* VMOVNTDQZ128mr */
  0x0, /*  */
/* Table4917 */
  0x1c50, /* VPMINSWZ128rm */
  0x1c53, /* VPMINSWZ128rr */
/* Table4919 */
  0x1e05, /* VPORDZ128rm */
  0x1e0b, /* VPORDZ128rr */
/* Table4921 */
  0x1b84, /* VPMAXSWZ128rm */
  0x1b87, /* VPMAXSWZ128rr */
/* Table4923 */
  0x1ff6, /* VPXORDZ128rm */
  0x1ffc, /* VPXORDZ128rr */
/* Table4925 */
  0x1f4a, /* VPSUBBZ128rm */
  0x1f4d, /* VPSUBBZ128rr */
/* Table4927 */
  0x1fae, /* VPSUBWZ128rm */
  0x1fb1, /* VPSUBWZ128rr */
/* Table4929 */
  0x1f60, /* VPSUBDZ128rm */
  0x1f66, /* VPSUBDZ128rr */
/* Table4931 */
  0x16a1, /* VPADDBZ128rm */
  0x16a4, /* VPADDBZ128rr */
/* Table4933 */
  0x1705, /* VPADDWZ128rm */
  0x1708, /* VPADDWZ128rr */
/* Table4935 */
  0x16b7, /* VPADDDZ128rm */
  0x16bd, /* VPADDDZ128rr */
/* Table4937 */
  0xd63, /* VCVTSI642SSZrm */
  0xd64, /* VCVTSI642SSZrr */
/* Table4939 */
  0xd91, /* VCVTTSS2SI64Zrm */
  0xd92, /* VCVTTSS2SI64Zrr */
/* Table4941 */
  0xd69, /* VCVTSS2SI64Zrm */
  0xd6a, /* VCVTSS2SI64Zrr */
/* Table4943 */
  0x14fa, /* VMOVDQU64Z128rm */
  0x14fd, /* VMOVDQU64Z128rr */
/* Table4945 */
  0xd99, /* VCVTTSS2USI64Zrm */
  0xd9a, /* VCVTTSS2USI64Zrr */
/* Table4947 */
  0xd71, /* VCVTSS2USI64Zrm */
  0xd72, /* VCVTSS2USI64Zrr */
/* Table4949 */
  0xda8, /* VCVTUSI642SSZrm */
  0xda9, /* VCVTUSI642SSZrr */
/* Table4951 */
  0x15ec, /* VMOVZPQILo2PQIZrm */
  0x15ed, /* VMOVZPQILo2PQIZrr */
/* Table4953 */
  0x14f8, /* VMOVDQU64Z128mr */
  0x14fe, /* VMOVDQU64Z128rr_alt */
/* Table4955 */
  0x1574, /* VMOVSDZrm */
  0x1575, /* VMOVSDZrr */
/* Table4957 */
  0x1572, /* VMOVSDZmr */
  0x1576, /* VMOVSDZrr_REV */
/* Table4959 */
  0xd61, /* VCVTSI642SDZrm */
  0xd62, /* VCVTSI642SDZrr */
/* Table4961 */
  0xd85, /* VCVTTSD2SI64Zrm */
  0xd86, /* VCVTTSD2SI64Zrr */
/* Table4963 */
  0xd45, /* VCVTSD2SI64Zrm */
  0xd46, /* VCVTSD2SI64Zrr */
/* Table4965 */
  0x2188, /* VSQRTSDZm */
  0x218a, /* VSQRTSDZr */
/* Table4967 */
  0xc12, /* VADDSDZrm_Int */
  0xc16, /* VADDSDZrr_Int */
/* Table4969 */
  0x1646, /* VMULSDZrm_Int */
  0x164a, /* VMULSDZrr_Int */
/* Table4971 */
  0xd4d, /* VCVTSD2SSZrm */
  0xd4e, /* VCVTSD2SSZrr */
/* Table4973 */
  0x21dc, /* VSUBSDZrm_Int */
  0x21e0, /* VSUBSDZrr_Int */
/* Table4975 */
  0x13e5, /* VMINSDZrm_Int */
  0x13e9, /* VMINSDZrr_Int */
/* Table4977 */
  0xdef, /* VDIVSDZrm_Int */
  0xdf3, /* VDIVSDZrr_Int */
/* Table4979 */
  0x137a, /* VMAXSDZrm_Int */
  0x137e, /* VMAXSDZrr_Int */
/* Table4981 */
  0x14b8, /* VMOVDQU16Z128rm */
  0x14bb, /* VMOVDQU16Z128rr */
/* Table4983 */
  0xd8d, /* VCVTTSD2USI64Zrm */
  0xd8e, /* VCVTTSD2USI64Zrr */
/* Table4985 */
  0xd51, /* VCVTSD2USI64Zrm */
  0xd52, /* VCVTSD2USI64Zrr */
/* Table4987 */
  0xda6, /* VCVTUSI642SDZrm */
  0xda7, /* VCVTUSI642SDZrr */
/* Table4989 */
  0x14b6, /* VMOVDQU16Z128mr */
  0x14bc, /* VMOVDQU16Z128rr_alt */
/* Table4991 */
  0xce1, /* VCMPSDZrm */
  0xce3, /* VCMPSDZrr */
/* Table4993 */
  0x15a0, /* VMOVUPDZ128rm */
  0x15a3, /* VMOVUPDZ128rr */
/* Table4995 */
  0x159e, /* VMOVUPDZ128mr */
  0x15a4, /* VMOVUPDZ128rr_alt */
/* Table4997 */
  0x1412, /* VMOVAPDZ128rm */
  0x1415, /* VMOVAPDZ128rr */
/* Table4999 */
  0x1410, /* VMOVAPDZ128mr */
  0x1416, /* VMOVAPDZ128rr_alt */
/* Table5001 */
  0x155d, /* VMOVNTPDZ128mr */
  0x0, /*  */
/* Table5003 */
  0x2201, /* VUCOMISDZrm */
  0x2202, /* VUCOMISDZrr */
/* Table5005 */
  0xcf1, /* VCOMISDZrm */
  0xcf2, /* VCOMISDZrr */
/* Table5007 */
  0x214c, /* VSQRTPDZ128m */
  0x2152, /* VSQRTPDZ128r */
/* Table5009 */
  0xbcf, /* VADDPDZ128rm */
  0xbd5, /* VADDPDZ128rr */
/* Table5011 */
  0x1603, /* VMULPDZ128rm */
  0x1609, /* VMULPDZ128rr */
/* Table5013 */
  0x2199, /* VSUBPDZ128rm */
  0x219f, /* VSUBPDZ128rr */
/* Table5015 */
  0x13a8, /* VMINPDZ128rm */
  0x13ae, /* VMINPDZ128rr */
/* Table5017 */
  0xdac, /* VDIVPDZ128rm */
  0xdb2, /* VDIVPDZ128rr */
/* Table5019 */
  0x133d, /* VMAXPDZ128rm */
  0x1343, /* VMAXPDZ128rr */
/* Table5021 */
  0x1570, /* VMOVQI2PQIZrm */
  0x1406, /* VMOV64toPQIZrr */
/* Table5023 */
  0x148f, /* VMOVDQA64Z128rm */
  0x1492, /* VMOVDQA64Z128rr */
/* Table5025 */
  0x157c, /* VMOVSDto64Zmr */
  0x156d, /* VMOVPQIto64Zrr */
/* Table5027 */
  0x148d, /* VMOVDQA64Z128mr */
  0x1493, /* VMOVDQA64Z128rr_alt */
/* Table5029 */
  0x16d6, /* VPADDQZ128rm */
  0x16dc, /* VPADDQZ128rr */
/* Table5031 */
  0x156c, /* VMOVPQIto64Zmr */
  0x0, /*  */
/* Table5033 */
  0x1772, /* VPANDQZ128rm */
  0x1778, /* VPANDQZ128rr */
/* Table5035 */
  0x1753, /* VPANDNQZ128rm */
  0x1759, /* VPANDNQZ128rr */
/* Table5037 */
  0x1e20, /* VPORQZ128rm */
  0x1e26, /* VPORQZ128rr */
/* Table5039 */
  0x2011, /* VPXORQZ128rm */
  0x2017, /* VPXORQZ128rr */
/* Table5041 */
  0x1f7f, /* VPSUBQZ128rm */
  0x1f85, /* VPSUBQZ128rr */
/* Table5043 */
  0x15d4, /* VMOVUPSZ256rm */
  0x15d7, /* VMOVUPSZ256rr */
/* Table5045 */
  0x15d2, /* VMOVUPSZ256mr */
  0x15d8, /* VMOVUPSZ256rr_alt */
/* Table5047 */
  0x1446, /* VMOVAPSZ256rm */
  0x1449, /* VMOVAPSZ256rr */
/* Table5049 */
  0x1444, /* VMOVAPSZ256mr */
  0x144a, /* VMOVAPSZ256rr_alt */
/* Table5051 */
  0x1563, /* VMOVNTPSZ256mr */
  0x0, /*  */
/* Table5053 */
  0x2174, /* VSQRTPSZ256m */
  0x217a, /* VSQRTPSZ256r */
/* Table5055 */
  0xbfa, /* VADDPSZ256rm */
  0xc00, /* VADDPSZ256rr */
/* Table5057 */
  0x162e, /* VMULPSZ256rm */
  0x1634, /* VMULPSZ256rr */
/* Table5059 */
  0x21c4, /* VSUBPSZ256rm */
  0x21ca, /* VSUBPSZ256rr */
/* Table5061 */
  0x13d0, /* VMINPSZ256rm */
  0x13d6, /* VMINPSZ256rr */
/* Table5063 */
  0xdd7, /* VDIVPSZ256rm */
  0xddd, /* VDIVPSZ256rr */
/* Table5065 */
  0x1365, /* VMAXPSZ256rm */
  0x136b, /* VMAXPSZ256rr */
/* Table5067 */
  0x14e4, /* VMOVDQU32Z256rm */
  0x14e7, /* VMOVDQU32Z256rr */
/* Table5069 */
  0x14e2, /* VMOVDQU32Z256mr */
  0x14e8, /* VMOVDQU32Z256rr_alt */
/* Table5071 */
  0x1526, /* VMOVDQU8Z256rm */
  0x1529, /* VMOVDQU8Z256rr */
/* Table5073 */
  0x1524, /* VMOVDQU8Z256mr */
  0x152a, /* VMOVDQU8Z256rr_alt */
/* Table5075 */
  0x18d9, /* VPCMPGTBZ256rm */
  0x18db, /* VPCMPGTBZ256rr */
/* Table5077 */
  0x1915, /* VPCMPGTWZ256rm */
  0x1917, /* VPCMPGTWZ256rr */
/* Table5079 */
  0x18eb, /* VPCMPGTDZ256rm */
  0x18ef, /* VPCMPGTDZ256rr */
/* Table5081 */
  0x1479, /* VMOVDQA32Z256rm */
  0x147c, /* VMOVDQA32Z256rr */
/* Table5083 */
  0x1885, /* VPCMPEQBZ256rm */
  0x1887, /* VPCMPEQBZ256rr */
/* Table5085 */
  0x18c1, /* VPCMPEQWZ256rm */
  0x18c3, /* VPCMPEQWZ256rr */
/* Table5087 */
  0x1897, /* VPCMPEQDZ256rm */
  0x189b, /* VPCMPEQDZ256rr */
/* Table5089 */
  0x1477, /* VMOVDQA32Z256mr */
  0x147d, /* VMOVDQA32Z256rr_alt */
/* Table5091 */
  0x1dea, /* VPMULLWZ256rm */
  0x1ded, /* VPMULLWZ256rr */
/* Table5093 */
  0x1c6c, /* VPMINUBZ256rm */
  0x1c6f, /* VPMINUBZ256rr */
/* Table5095 */
  0x1726, /* VPANDDZ256rm */
  0x172c, /* VPANDDZ256rr */
/* Table5097 */
  0x1ba0, /* VPMAXUBZ256rm */
  0x1ba3, /* VPMAXUBZ256rr */
/* Table5099 */
  0x1741, /* VPANDNDZ256rm */
  0x1747, /* VPANDNDZ256rr */
/* Table5101 */
  0x1559, /* VMOVNTDQZ256mr */
  0x0, /*  */
/* Table5103 */
  0x1c56, /* VPMINSWZ256rm */
  0x1c59, /* VPMINSWZ256rr */
/* Table5105 */
  0x1e0e, /* VPORDZ256rm */
  0x1e14, /* VPORDZ256rr */
/* Table5107 */
  0x1b8a, /* VPMAXSWZ256rm */
  0x1b8d, /* VPMAXSWZ256rr */
/* Table5109 */
  0x1fff, /* VPXORDZ256rm */
  0x2005, /* VPXORDZ256rr */
/* Table5111 */
  0x1f50, /* VPSUBBZ256rm */
  0x1f53, /* VPSUBBZ256rr */
/* Table5113 */
  0x1fb4, /* VPSUBWZ256rm */
  0x1fb7, /* VPSUBWZ256rr */
/* Table5115 */
  0x1f69, /* VPSUBDZ256rm */
  0x1f6f, /* VPSUBDZ256rr */
/* Table5117 */
  0x16a7, /* VPADDBZ256rm */
  0x16aa, /* VPADDBZ256rr */
/* Table5119 */
  0x170b, /* VPADDWZ256rm */
  0x170e, /* VPADDWZ256rr */
/* Table5121 */
  0x16c0, /* VPADDDZ256rm */
  0x16c6, /* VPADDDZ256rr */
/* Table5123 */
  0x1505, /* VMOVDQU64Z256rm */
  0x1508, /* VMOVDQU64Z256rr */
/* Table5125 */
  0x1503, /* VMOVDQU64Z256mr */
  0x1509, /* VMOVDQU64Z256rr_alt */
/* Table5127 */
  0x14c3, /* VMOVDQU16Z256rm */
  0x14c6, /* VMOVDQU16Z256rr */
/* Table5129 */
  0x14c1, /* VMOVDQU16Z256mr */
  0x14c7, /* VMOVDQU16Z256rr_alt */
/* Table5131 */
  0x15ab, /* VMOVUPDZ256rm */
  0x15ae, /* VMOVUPDZ256rr */
/* Table5133 */
  0x15a9, /* VMOVUPDZ256mr */
  0x15af, /* VMOVUPDZ256rr_alt */
/* Table5135 */
  0x141d, /* VMOVAPDZ256rm */
  0x1420, /* VMOVAPDZ256rr */
/* Table5137 */
  0x141b, /* VMOVAPDZ256mr */
  0x1421, /* VMOVAPDZ256rr_alt */
/* Table5139 */
  0x155e, /* VMOVNTPDZ256mr */
  0x0, /*  */
/* Table5141 */
  0x2155, /* VSQRTPDZ256m */
  0x215b, /* VSQRTPDZ256r */
/* Table5143 */
  0xbd8, /* VADDPDZ256rm */
  0xbde, /* VADDPDZ256rr */
/* Table5145 */
  0x160c, /* VMULPDZ256rm */
  0x1612, /* VMULPDZ256rr */
/* Table5147 */
  0x21a2, /* VSUBPDZ256rm */
  0x21a8, /* VSUBPDZ256rr */
/* Table5149 */
  0x13b1, /* VMINPDZ256rm */
  0x13b7, /* VMINPDZ256rr */
/* Table5151 */
  0xdb5, /* VDIVPDZ256rm */
  0xdbb, /* VDIVPDZ256rr */
/* Table5153 */
  0x1346, /* VMAXPDZ256rm */
  0x134c, /* VMAXPDZ256rr */
/* Table5155 */
  0x149a, /* VMOVDQA64Z256rm */
  0x149d, /* VMOVDQA64Z256rr */
/* Table5157 */
  0x1498, /* VMOVDQA64Z256mr */
  0x149e, /* VMOVDQA64Z256rr_alt */
/* Table5159 */
  0x16df, /* VPADDQZ256rm */
  0x16e5, /* VPADDQZ256rr */
/* Table5161 */
  0x177b, /* VPANDQZ256rm */
  0x1781, /* VPANDQZ256rr */
/* Table5163 */
  0x175c, /* VPANDNQZ256rm */
  0x1762, /* VPANDNQZ256rr */
/* Table5165 */
  0x1e29, /* VPORQZ256rm */
  0x1e2f, /* VPORQZ256rr */
/* Table5167 */
  0x201a, /* VPXORQZ256rm */
  0x2020, /* VPXORQZ256rr */
/* Table5169 */
  0x1f88, /* VPSUBQZ256rm */
  0x1f8e, /* VPSUBQZ256rr */
/* Table5171 */
  0x15df, /* VMOVUPSZrm */
  0x15e2, /* VMOVUPSZrr */
/* Table5173 */
  0x15dd, /* VMOVUPSZmr */
  0x15e3, /* VMOVUPSZrr_alt */
/* Table5175 */
  0x221d, /* VUNPCKLPSZrm */
  0x221e, /* VUNPCKLPSZrr */
/* Table5177 */
  0x2211, /* VUNPCKHPSZrm */
  0x2212, /* VUNPCKHPSZrr */
/* Table5179 */
  0x1451, /* VMOVAPSZrm */
  0x1454, /* VMOVAPSZrr */
/* Table5181 */
  0x144f, /* VMOVAPSZmr */
  0x1455, /* VMOVAPSZrr_alt */
/* Table5183 */
  0x1564, /* VMOVNTPSZmr */
  0x0, /*  */
/* Table5185 */
  0x217d, /* VSQRTPSZm */
  0x2183, /* VSQRTPSZr */
/* Table5187 */
  0xc06, /* VADDPSZrm */
  0xc0c, /* VADDPSZrr */
/* Table5189 */
  0x163a, /* VMULPSZrm */
  0x1640, /* VMULPSZrr */
/* Table5191 */
  0xd38, /* VCVTPS2PDZrm */
  0xd39, /* VCVTPS2PDZrr */
/* Table5193 */
  0xd13, /* VCVTDQ2PSZrm */
  0xd14, /* VCVTDQ2PSZrr */
/* Table5195 */
  0x21d0, /* VSUBPSZrm */
  0x21d6, /* VSUBPSZrr */
/* Table5197 */
  0x13d9, /* VMINPSZrm */
  0x13df, /* VMINPSZrr */
/* Table5199 */
  0xde3, /* VDIVPSZrm */
  0xde9, /* VDIVPSZrr */
/* Table5201 */
  0x136e, /* VMAXPSZrm */
  0x1374, /* VMAXPSZrr */
/* Table5203 */
  0xd83, /* VCVTTPS2UDQZrm */
  0xd84, /* VCVTTPS2UDQZrr */
/* Table5205 */
  0xd42, /* VCVTPS2UDQZrm */
  0xd43, /* VCVTPS2UDQZrr */
/* Table5207 */
  0xcd7, /* VCMPPSZrmi */
  0xcd9, /* VCMPPSZrri */
/* Table5209 */
  0x2146, /* VSHUFPSZrmi */
  0x2147, /* VSHUFPSZrri */
/* Table5211 */
  0x1588, /* VMOVSLDUPZrm */
  0x1589, /* VMOVSLDUPZrr */
/* Table5213 */
  0x1582, /* VMOVSHDUPZrm */
  0x1583, /* VMOVSHDUPZrr */
/* Table5215 */
  0xd7f, /* VCVTTPS2DQZrm */
  0xd80, /* VCVTTPS2DQZrr */
/* Table5217 */
  0x14ef, /* VMOVDQU32Zrm */
  0x14f2, /* VMOVDQU32Zrr */
/* Table5219 */
  0xd9d, /* VCVTUDQ2PDZrm */
  0xd9e, /* VCVTUDQ2PDZrr */
/* Table5221 */
  0x14ed, /* VMOVDQU32Zmr */
  0x14f3, /* VMOVDQU32Zrr_alt */
/* Table5223 */
  0xd0d, /* VCVTDQ2PDZrm */
  0xd0e, /* VCVTDQ2PDZrr */
/* Table5225 */
  0x1531, /* VMOVDQU8Zrm */
  0x1534, /* VMOVDQU8Zrr */
/* Table5227 */
  0xd9f, /* VCVTUDQ2PSZrm */
  0xda0, /* VCVTUDQ2PSZrr */
/* Table5229 */
  0x152f, /* VMOVDQU8Zmr */
  0x1535, /* VMOVDQU8Zrr_alt */
/* Table5231 */
  0xd31, /* VCVTPS2DQZrm */
  0xd32, /* VCVTPS2DQZrr */
/* Table5233 */
  0x1fe8, /* VPUNPCKLDQZrm */
  0x1fe9, /* VPUNPCKLDQZrr */
/* Table5235 */
  0x18dd, /* VPCMPGTBZrm */
  0x18df, /* VPCMPGTBZrr */
/* Table5237 */
  0x1919, /* VPCMPGTWZrm */
  0x191b, /* VPCMPGTWZrr */
/* Table5239 */
  0x18f1, /* VPCMPGTDZrm */
  0x18f5, /* VPCMPGTDZrr */
/* Table5241 */
  0x1fd4, /* VPUNPCKHDQZrm */
  0x1fd5, /* VPUNPCKHDQZrr */
/* Table5243 */
  0x1484, /* VMOVDQA32Zrm */
  0x1487, /* VMOVDQA32Zrr */
/* Table5245 */
  0x1e7c, /* VPSHUFDZmi */
  0x1e7d, /* VPSHUFDZri */
/* Table5247 */
  0x0, /*  */
  0x0, /*  */
  0x1f0d, /* VPSRLDZmi */
  0x0, /*  */
  0x1ed7, /* VPSRADZmi */
  0x0, /*  */
  0x1e99, /* VPSLLDZmi */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1f10, /* VPSRLDZri */
  0x0, /*  */
  0x1eda, /* VPSRADZri */
  0x0, /*  */
  0x1e9c, /* VPSLLDZri */
  0x0, /*  */
/* Table5263 */
  0x1889, /* VPCMPEQBZrm */
  0x188b, /* VPCMPEQBZrr */
/* Table5265 */
  0x18c5, /* VPCMPEQWZrm */
  0x18c7, /* VPCMPEQWZrr */
/* Table5267 */
  0x189d, /* VPCMPEQDZrm */
  0x18a1, /* VPCMPEQDZrr */
/* Table5269 */
  0x1482, /* VMOVDQA32Zmr */
  0x1488, /* VMOVDQA32Zrr_alt */
/* Table5271 */
  0x1f13, /* VPSRLDZrm */
  0x1f16, /* VPSRLDZrr */
/* Table5273 */
  0x1df0, /* VPMULLWZrm */
  0x1df3, /* VPMULLWZrr */
/* Table5275 */
  0x1c72, /* VPMINUBZrm */
  0x1c75, /* VPMINUBZrr */
/* Table5277 */
  0x172f, /* VPANDDZrm */
  0x1735, /* VPANDDZrr */
/* Table5279 */
  0x1ba6, /* VPMAXUBZrm */
  0x1ba9, /* VPMAXUBZrr */
/* Table5281 */
  0x174a, /* VPANDNDZrm */
  0x1750, /* VPANDNDZrr */
/* Table5283 */
  0x1edd, /* VPSRADZrm */
  0x1ee0, /* VPSRADZrr */
/* Table5285 */
  0x155a, /* VMOVNTDQZmr */
  0x0, /*  */
/* Table5287 */
  0x1c5c, /* VPMINSWZrm */
  0x1c5f, /* VPMINSWZrr */
/* Table5289 */
  0x1e17, /* VPORDZrm */
  0x1e1d, /* VPORDZrr */
/* Table5291 */
  0x1b90, /* VPMAXSWZrm */
  0x1b93, /* VPMAXSWZrr */
/* Table5293 */
  0x2008, /* VPXORDZrm */
  0x200e, /* VPXORDZrr */
/* Table5295 */
  0x1e9f, /* VPSLLDZrm */
  0x1ea2, /* VPSLLDZrr */
/* Table5297 */
  0x1f56, /* VPSUBBZrm */
  0x1f59, /* VPSUBBZrr */
/* Table5299 */
  0x1fba, /* VPSUBWZrm */
  0x1fbd, /* VPSUBWZrr */
/* Table5301 */
  0x1f72, /* VPSUBDZrm */
  0x1f78, /* VPSUBDZrr */
/* Table5303 */
  0x16ad, /* VPADDBZrm */
  0x16b0, /* VPADDBZrr */
/* Table5305 */
  0x1711, /* VPADDWZrm */
  0x1714, /* VPADDWZrr */
/* Table5307 */
  0x16c9, /* VPADDDZrm */
  0x16cf, /* VPADDDZrr */
/* Table5309 */
  0xd7b, /* VCVTTPD2UDQZrm */
  0xd7c, /* VCVTTPD2UDQZrr */
/* Table5311 */
  0xd26, /* VCVTPD2UDQZrm */
  0xd27, /* VCVTPD2UDQZrr */
/* Table5313 */
  0x1510, /* VMOVDQU64Zrm */
  0x1513, /* VMOVDQU64Zrr */
/* Table5315 */
  0x150e, /* VMOVDQU64Zmr */
  0x1514, /* VMOVDQU64Zrr_alt */
/* Table5317 */
  0x14ce, /* VMOVDQU16Zrm */
  0x14d1, /* VMOVDQU16Zrr */
/* Table5319 */
  0x14cc, /* VMOVDQU16Zmr */
  0x14d2, /* VMOVDQU16Zrr_alt */
/* Table5321 */
  0xd1b, /* VCVTPD2DQZrm */
  0xd1c, /* VCVTPD2DQZrr */
/* Table5323 */
  0x15b6, /* VMOVUPDZrm */
  0x15b9, /* VMOVUPDZrr */
/* Table5325 */
  0x15b4, /* VMOVUPDZmr */
  0x15ba, /* VMOVUPDZrr_alt */
/* Table5327 */
  0x1460, /* VMOVDDUPZrm */
  0x1461, /* VMOVDDUPZrr */
/* Table5329 */
  0x2217, /* VUNPCKLPDZrm */
  0x2218, /* VUNPCKLPDZrr */
/* Table5331 */
  0x220b, /* VUNPCKHPDZrm */
  0x220c, /* VUNPCKHPDZrr */
/* Table5333 */
  0x1428, /* VMOVAPDZrm */
  0x142b, /* VMOVAPDZrr */
/* Table5335 */
  0x1426, /* VMOVAPDZmr */
  0x142c, /* VMOVAPDZrr_alt */
/* Table5337 */
  0x155f, /* VMOVNTPDZmr */
  0x0, /*  */
/* Table5339 */
  0x215e, /* VSQRTPDZm */
  0x2164, /* VSQRTPDZr */
/* Table5341 */
  0xbe4, /* VADDPDZrm */
  0xbea, /* VADDPDZrr */
/* Table5343 */
  0x1618, /* VMULPDZrm */
  0x161e, /* VMULPDZrr */
/* Table5345 */
  0xd22, /* VCVTPD2PSZrm */
  0xd23, /* VCVTPD2PSZrr */
/* Table5347 */
  0x21ae, /* VSUBPDZrm */
  0x21b4, /* VSUBPDZrr */
/* Table5349 */
  0x13ba, /* VMINPDZrm */
  0x13c0, /* VMINPDZrr */
/* Table5351 */
  0xdc1, /* VDIVPDZrm */
  0xdc7, /* VDIVPDZrr */
/* Table5353 */
  0x134f, /* VMAXPDZrm */
  0x1355, /* VMAXPDZrr */
/* Table5355 */
  0x1fee, /* VPUNPCKLQDQZrm */
  0x1fef, /* VPUNPCKLQDQZrr */
/* Table5357 */
  0x1fda, /* VPUNPCKHQDQZrm */
  0x1fdb, /* VPUNPCKHQDQZrr */
/* Table5359 */
  0x14a5, /* VMOVDQA64Zrm */
  0x14a8, /* VMOVDQA64Zrr */
/* Table5361 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1ee6, /* VPSRAQZmi */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1ee9, /* VPSRAQZri */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table5377 */
  0x0, /*  */
  0x0, /*  */
  0x1f1f, /* VPSRLQZmi */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1eab, /* VPSLLQZmi */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1f22, /* VPSRLQZri */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1eae, /* VPSLLQZri */
  0x0, /*  */
/* Table5393 */
  0x14a3, /* VMOVDQA64Zmr */
  0x14a9, /* VMOVDQA64Zrr_alt */
/* Table5395 */
  0xcc9, /* VCMPPDZrmi */
  0xccb, /* VCMPPDZrri */
/* Table5397 */
  0x2140, /* VSHUFPDZrmi */
  0x2141, /* VSHUFPDZrri */
/* Table5399 */
  0x1f25, /* VPSRLQZrm */
  0x1f28, /* VPSRLQZrr */
/* Table5401 */
  0x16e8, /* VPADDQZrm */
  0x16ee, /* VPADDQZrr */
/* Table5403 */
  0x1784, /* VPANDQZrm */
  0x178a, /* VPANDQZrr */
/* Table5405 */
  0x1765, /* VPANDNQZrm */
  0x176b, /* VPANDNQZrr */
/* Table5407 */
  0x1eec, /* VPSRAQZrm */
  0x1eef, /* VPSRAQZrr */
/* Table5409 */
  0xd78, /* VCVTTPD2DQZrm */
  0xd79, /* VCVTTPD2DQZrr */
/* Table5411 */
  0x1e32, /* VPORQZrm */
  0x1e38, /* VPORQZrr */
/* Table5413 */
  0x2023, /* VPXORQZrm */
  0x2029, /* VPXORQZrr */
/* Table5415 */
  0x1eb1, /* VPSLLQZrm */
  0x1eb4, /* VPSLLQZrr */
/* Table5417 */
  0x1dfa, /* VPMULUDQZrm */
  0x1e00, /* VPMULUDQZrr */
/* Table5419 */
  0x1f91, /* VPSUBQZrm */
  0x1f97, /* VPSUBQZrr */
/* Table5421 */
  0x15ca, /* VMOVUPSZ128rmk */
  0x15ce, /* VMOVUPSZ128rrk */
/* Table5423 */
  0x15c8, /* VMOVUPSZ128mrk */
  0x15cf, /* VMOVUPSZ128rrk_alt */
/* Table5425 */
  0x143c, /* VMOVAPSZ128rmk */
  0x1440, /* VMOVAPSZ128rrk */
/* Table5427 */
  0x143a, /* VMOVAPSZ128mrk */
  0x1441, /* VMOVAPSZ128rrk_alt */
/* Table5429 */
  0x216f, /* VSQRTPSZ128mk */
  0x2172, /* VSQRTPSZ128rk */
/* Table5431 */
  0xbf5, /* VADDPSZ128rmk */
  0xbf8, /* VADDPSZ128rrk */
/* Table5433 */
  0x1629, /* VMULPSZ128rmk */
  0x162c, /* VMULPSZ128rrk */
/* Table5435 */
  0x21bf, /* VSUBPSZ128rmk */
  0x21c2, /* VSUBPSZ128rrk */
/* Table5437 */
  0x13cb, /* VMINPSZ128rmk */
  0x13ce, /* VMINPSZ128rrk */
/* Table5439 */
  0xdd2, /* VDIVPSZ128rmk */
  0xdd5, /* VDIVPSZ128rrk */
/* Table5441 */
  0x1360, /* VMAXPSZ128rmk */
  0x1363, /* VMAXPSZ128rrk */
/* Table5443 */
  0x0, /*  */
  0x1595, /* VMOVSSZrrk */
/* Table5445 */
  0x1591, /* VMOVSSZmrk */
  0x0, /*  */
/* Table5447 */
  0xc22, /* VADDSSZrm_Intk */
  0xc26, /* VADDSSZrr_Intk */
/* Table5449 */
  0x1656, /* VMULSSZrm_Intk */
  0x165a, /* VMULSSZrr_Intk */
/* Table5451 */
  0x21ec, /* VSUBSSZrm_Intk */
  0x21f0, /* VSUBSSZrr_Intk */
/* Table5453 */
  0x13f5, /* VMINSSZrm_Intk */
  0x13f9, /* VMINSSZrr_Intk */
/* Table5455 */
  0xdff, /* VDIVSSZrm_Intk */
  0xe03, /* VDIVSSZrr_Intk */
/* Table5457 */
  0x138a, /* VMAXSSZrm_Intk */
  0x138e, /* VMAXSSZrr_Intk */
/* Table5459 */
  0x14da, /* VMOVDQU32Z128rmk */
  0x14de, /* VMOVDQU32Z128rrk */
/* Table5461 */
  0x14d8, /* VMOVDQU32Z128mrk */
  0x14df, /* VMOVDQU32Z128rrk_alt */
/* Table5463 */
  0x151c, /* VMOVDQU8Z128rmk */
  0x1520, /* VMOVDQU8Z128rrk */
/* Table5465 */
  0x151a, /* VMOVDQU8Z128mrk */
  0x1521, /* VMOVDQU8Z128rrk_alt */
/* Table5467 */
  0x18d6, /* VPCMPGTBZ128rmk */
  0x18d8, /* VPCMPGTBZ128rrk */
/* Table5469 */
  0x1912, /* VPCMPGTWZ128rmk */
  0x1914, /* VPCMPGTWZ128rrk */
/* Table5471 */
  0x18e8, /* VPCMPGTDZ128rmk */
  0x18ea, /* VPCMPGTDZ128rrk */
/* Table5473 */
  0x146f, /* VMOVDQA32Z128rmk */
  0x1473, /* VMOVDQA32Z128rrk */
/* Table5475 */
  0x1882, /* VPCMPEQBZ128rmk */
  0x1884, /* VPCMPEQBZ128rrk */
/* Table5477 */
  0x18be, /* VPCMPEQWZ128rmk */
  0x18c0, /* VPCMPEQWZ128rrk */
/* Table5479 */
  0x1894, /* VPCMPEQDZ128rmk */
  0x1896, /* VPCMPEQDZ128rrk */
/* Table5481 */
  0x146d, /* VMOVDQA32Z128mrk */
  0x1474, /* VMOVDQA32Z128rrk_alt */
/* Table5483 */
  0x1de5, /* VPMULLWZ128rmk */
  0x1de8, /* VPMULLWZ128rrk */
/* Table5485 */
  0x1c67, /* VPMINUBZ128rmk */
  0x1c6a, /* VPMINUBZ128rrk */
/* Table5487 */
  0x1721, /* VPANDDZ128rmk */
  0x1724, /* VPANDDZ128rrk */
/* Table5489 */
  0x1b9b, /* VPMAXUBZ128rmk */
  0x1b9e, /* VPMAXUBZ128rrk */
/* Table5491 */
  0x173c, /* VPANDNDZ128rmk */
  0x173f, /* VPANDNDZ128rrk */
/* Table5493 */
  0x1c51, /* VPMINSWZ128rmk */
  0x1c54, /* VPMINSWZ128rrk */
/* Table5495 */
  0x1e09, /* VPORDZ128rmk */
  0x1e0c, /* VPORDZ128rrk */
/* Table5497 */
  0x1b85, /* VPMAXSWZ128rmk */
  0x1b88, /* VPMAXSWZ128rrk */
/* Table5499 */
  0x1ffa, /* VPXORDZ128rmk */
  0x1ffd, /* VPXORDZ128rrk */
/* Table5501 */
  0x1f4b, /* VPSUBBZ128rmk */
  0x1f4e, /* VPSUBBZ128rrk */
/* Table5503 */
  0x1faf, /* VPSUBWZ128rmk */
  0x1fb2, /* VPSUBWZ128rrk */
/* Table5505 */
  0x1f64, /* VPSUBDZ128rmk */
  0x1f67, /* VPSUBDZ128rrk */
/* Table5507 */
  0x16a2, /* VPADDBZ128rmk */
  0x16a5, /* VPADDBZ128rrk */
/* Table5509 */
  0x1706, /* VPADDWZ128rmk */
  0x1709, /* VPADDWZ128rrk */
/* Table5511 */
  0x16bb, /* VPADDDZ128rmk */
  0x16be, /* VPADDDZ128rrk */
/* Table5513 */
  0xc22, /* VADDSSZrm_Intk */
  0xc2a, /* VADDSSZrrbkz */
/* Table5515 */
  0x1656, /* VMULSSZrm_Intk */
  0x165e, /* VMULSSZrrbkz */
/* Table5517 */
  0x21ec, /* VSUBSSZrm_Intk */
  0x21f4, /* VSUBSSZrrbkz */
/* Table5519 */
  0x13f5, /* VMINSSZrm_Intk */
  0x13fd, /* VMINSSZrrbkz */
/* Table5521 */
  0xdff, /* VDIVSSZrm_Intk */
  0xe07, /* VDIVSSZrrbkz */
/* Table5523 */
  0x138a, /* VMAXSSZrm_Intk */
  0x1392, /* VMAXSSZrrbkz */
/* Table5525 */
  0x14fb, /* VMOVDQU64Z128rmk */
  0x14ff, /* VMOVDQU64Z128rrk */
/* Table5527 */
  0x14f9, /* VMOVDQU64Z128mrk */
  0x1500, /* VMOVDQU64Z128rrk_alt */
/* Table5529 */
  0x0, /*  */
  0x1577, /* VMOVSDZrrk */
/* Table5531 */
  0x1573, /* VMOVSDZmrk */
  0x0, /*  */
/* Table5533 */
  0xc13, /* VADDSDZrm_Intk */
  0xc17, /* VADDSDZrr_Intk */
/* Table5535 */
  0x1647, /* VMULSDZrm_Intk */
  0x164b, /* VMULSDZrr_Intk */
/* Table5537 */
  0x21dd, /* VSUBSDZrm_Intk */
  0x21e1, /* VSUBSDZrr_Intk */
/* Table5539 */
  0x13e6, /* VMINSDZrm_Intk */
  0x13ea, /* VMINSDZrr_Intk */
/* Table5541 */
  0xdf0, /* VDIVSDZrm_Intk */
  0xdf4, /* VDIVSDZrr_Intk */
/* Table5543 */
  0x137b, /* VMAXSDZrm_Intk */
  0x137f, /* VMAXSDZrr_Intk */
/* Table5545 */
  0x14b9, /* VMOVDQU16Z128rmk */
  0x14bd, /* VMOVDQU16Z128rrk */
/* Table5547 */
  0x14b7, /* VMOVDQU16Z128mrk */
  0x14be, /* VMOVDQU16Z128rrk_alt */
/* Table5549 */
  0x15a1, /* VMOVUPDZ128rmk */
  0x15a5, /* VMOVUPDZ128rrk */
/* Table5551 */
  0x159f, /* VMOVUPDZ128mrk */
  0x15a6, /* VMOVUPDZ128rrk_alt */
/* Table5553 */
  0x1413, /* VMOVAPDZ128rmk */
  0x1417, /* VMOVAPDZ128rrk */
/* Table5555 */
  0x1411, /* VMOVAPDZ128mrk */
  0x1418, /* VMOVAPDZ128rrk_alt */
/* Table5557 */
  0x2150, /* VSQRTPDZ128mk */
  0x2153, /* VSQRTPDZ128rk */
/* Table5559 */
  0xbd3, /* VADDPDZ128rmk */
  0xbd6, /* VADDPDZ128rrk */
/* Table5561 */
  0x1607, /* VMULPDZ128rmk */
  0x160a, /* VMULPDZ128rrk */
/* Table5563 */
  0x219d, /* VSUBPDZ128rmk */
  0x21a0, /* VSUBPDZ128rrk */
/* Table5565 */
  0x13ac, /* VMINPDZ128rmk */
  0x13af, /* VMINPDZ128rrk */
/* Table5567 */
  0xdb0, /* VDIVPDZ128rmk */
  0xdb3, /* VDIVPDZ128rrk */
/* Table5569 */
  0x1341, /* VMAXPDZ128rmk */
  0x1344, /* VMAXPDZ128rrk */
/* Table5571 */
  0x1490, /* VMOVDQA64Z128rmk */
  0x1494, /* VMOVDQA64Z128rrk */
/* Table5573 */
  0x148e, /* VMOVDQA64Z128mrk */
  0x1495, /* VMOVDQA64Z128rrk_alt */
/* Table5575 */
  0x16da, /* VPADDQZ128rmk */
  0x16dd, /* VPADDQZ128rrk */
/* Table5577 */
  0x1776, /* VPANDQZ128rmk */
  0x1779, /* VPANDQZ128rrk */
/* Table5579 */
  0x1757, /* VPANDNQZ128rmk */
  0x175a, /* VPANDNQZ128rrk */
/* Table5581 */
  0x1e24, /* VPORQZ128rmk */
  0x1e27, /* VPORQZ128rrk */
/* Table5583 */
  0x2015, /* VPXORQZ128rmk */
  0x2018, /* VPXORQZ128rrk */
/* Table5585 */
  0x1f83, /* VPSUBQZ128rmk */
  0x1f86, /* VPSUBQZ128rrk */
/* Table5587 */
  0x15d5, /* VMOVUPSZ256rmk */
  0x15d9, /* VMOVUPSZ256rrk */
/* Table5589 */
  0x15d3, /* VMOVUPSZ256mrk */
  0x15da, /* VMOVUPSZ256rrk_alt */
/* Table5591 */
  0x1447, /* VMOVAPSZ256rmk */
  0x144b, /* VMOVAPSZ256rrk */
/* Table5593 */
  0x1445, /* VMOVAPSZ256mrk */
  0x144c, /* VMOVAPSZ256rrk_alt */
/* Table5595 */
  0x2178, /* VSQRTPSZ256mk */
  0x217b, /* VSQRTPSZ256rk */
/* Table5597 */
  0xbfe, /* VADDPSZ256rmk */
  0xc01, /* VADDPSZ256rrk */
/* Table5599 */
  0x1632, /* VMULPSZ256rmk */
  0x1635, /* VMULPSZ256rrk */
/* Table5601 */
  0x21c8, /* VSUBPSZ256rmk */
  0x21cb, /* VSUBPSZ256rrk */
/* Table5603 */
  0x13d4, /* VMINPSZ256rmk */
  0x13d7, /* VMINPSZ256rrk */
/* Table5605 */
  0xddb, /* VDIVPSZ256rmk */
  0xdde, /* VDIVPSZ256rrk */
/* Table5607 */
  0x1369, /* VMAXPSZ256rmk */
  0x136c, /* VMAXPSZ256rrk */
/* Table5609 */
  0x14e5, /* VMOVDQU32Z256rmk */
  0x14e9, /* VMOVDQU32Z256rrk */
/* Table5611 */
  0x14e3, /* VMOVDQU32Z256mrk */
  0x14ea, /* VMOVDQU32Z256rrk_alt */
/* Table5613 */
  0x1527, /* VMOVDQU8Z256rmk */
  0x152b, /* VMOVDQU8Z256rrk */
/* Table5615 */
  0x1525, /* VMOVDQU8Z256mrk */
  0x152c, /* VMOVDQU8Z256rrk_alt */
/* Table5617 */
  0x18da, /* VPCMPGTBZ256rmk */
  0x18dc, /* VPCMPGTBZ256rrk */
/* Table5619 */
  0x1916, /* VPCMPGTWZ256rmk */
  0x1918, /* VPCMPGTWZ256rrk */
/* Table5621 */
  0x18ee, /* VPCMPGTDZ256rmk */
  0x18f0, /* VPCMPGTDZ256rrk */
/* Table5623 */
  0x147a, /* VMOVDQA32Z256rmk */
  0x147e, /* VMOVDQA32Z256rrk */
/* Table5625 */
  0x1886, /* VPCMPEQBZ256rmk */
  0x1888, /* VPCMPEQBZ256rrk */
/* Table5627 */
  0x18c2, /* VPCMPEQWZ256rmk */
  0x18c4, /* VPCMPEQWZ256rrk */
/* Table5629 */
  0x189a, /* VPCMPEQDZ256rmk */
  0x189c, /* VPCMPEQDZ256rrk */
/* Table5631 */
  0x1478, /* VMOVDQA32Z256mrk */
  0x147f, /* VMOVDQA32Z256rrk_alt */
/* Table5633 */
  0x1deb, /* VPMULLWZ256rmk */
  0x1dee, /* VPMULLWZ256rrk */
/* Table5635 */
  0x1c6d, /* VPMINUBZ256rmk */
  0x1c70, /* VPMINUBZ256rrk */
/* Table5637 */
  0x172a, /* VPANDDZ256rmk */
  0x172d, /* VPANDDZ256rrk */
/* Table5639 */
  0x1ba1, /* VPMAXUBZ256rmk */
  0x1ba4, /* VPMAXUBZ256rrk */
/* Table5641 */
  0x1745, /* VPANDNDZ256rmk */
  0x1748, /* VPANDNDZ256rrk */
/* Table5643 */
  0x1c57, /* VPMINSWZ256rmk */
  0x1c5a, /* VPMINSWZ256rrk */
/* Table5645 */
  0x1e12, /* VPORDZ256rmk */
  0x1e15, /* VPORDZ256rrk */
/* Table5647 */
  0x1b8b, /* VPMAXSWZ256rmk */
  0x1b8e, /* VPMAXSWZ256rrk */
/* Table5649 */
  0x2003, /* VPXORDZ256rmk */
  0x2006, /* VPXORDZ256rrk */
/* Table5651 */
  0x1f51, /* VPSUBBZ256rmk */
  0x1f54, /* VPSUBBZ256rrk */
/* Table5653 */
  0x1fb5, /* VPSUBWZ256rmk */
  0x1fb8, /* VPSUBWZ256rrk */
/* Table5655 */
  0x1f6d, /* VPSUBDZ256rmk */
  0x1f70, /* VPSUBDZ256rrk */
/* Table5657 */
  0x16a8, /* VPADDBZ256rmk */
  0x16ab, /* VPADDBZ256rrk */
/* Table5659 */
  0x170c, /* VPADDWZ256rmk */
  0x170f, /* VPADDWZ256rrk */
/* Table5661 */
  0x16c4, /* VPADDDZ256rmk */
  0x16c7, /* VPADDDZ256rrk */
/* Table5663 */
  0x1506, /* VMOVDQU64Z256rmk */
  0x150a, /* VMOVDQU64Z256rrk */
/* Table5665 */
  0x1504, /* VMOVDQU64Z256mrk */
  0x150b, /* VMOVDQU64Z256rrk_alt */
/* Table5667 */
  0x14c4, /* VMOVDQU16Z256rmk */
  0x14c8, /* VMOVDQU16Z256rrk */
/* Table5669 */
  0x14c2, /* VMOVDQU16Z256mrk */
  0x14c9, /* VMOVDQU16Z256rrk_alt */
/* Table5671 */
  0x15ac, /* VMOVUPDZ256rmk */
  0x15b0, /* VMOVUPDZ256rrk */
/* Table5673 */
  0x15aa, /* VMOVUPDZ256mrk */
  0x15b1, /* VMOVUPDZ256rrk_alt */
/* Table5675 */
  0x141e, /* VMOVAPDZ256rmk */
  0x1422, /* VMOVAPDZ256rrk */
/* Table5677 */
  0x141c, /* VMOVAPDZ256mrk */
  0x1423, /* VMOVAPDZ256rrk_alt */
/* Table5679 */
  0x2159, /* VSQRTPDZ256mk */
  0x215c, /* VSQRTPDZ256rk */
/* Table5681 */
  0xbdc, /* VADDPDZ256rmk */
  0xbdf, /* VADDPDZ256rrk */
/* Table5683 */
  0x1610, /* VMULPDZ256rmk */
  0x1613, /* VMULPDZ256rrk */
/* Table5685 */
  0x21a6, /* VSUBPDZ256rmk */
  0x21a9, /* VSUBPDZ256rrk */
/* Table5687 */
  0x13b5, /* VMINPDZ256rmk */
  0x13b8, /* VMINPDZ256rrk */
/* Table5689 */
  0xdb9, /* VDIVPDZ256rmk */
  0xdbc, /* VDIVPDZ256rrk */
/* Table5691 */
  0x134a, /* VMAXPDZ256rmk */
  0x134d, /* VMAXPDZ256rrk */
/* Table5693 */
  0x149b, /* VMOVDQA64Z256rmk */
  0x149f, /* VMOVDQA64Z256rrk */
/* Table5695 */
  0x1499, /* VMOVDQA64Z256mrk */
  0x14a0, /* VMOVDQA64Z256rrk_alt */
/* Table5697 */
  0x16e3, /* VPADDQZ256rmk */
  0x16e6, /* VPADDQZ256rrk */
/* Table5699 */
  0x177f, /* VPANDQZ256rmk */
  0x1782, /* VPANDQZ256rrk */
/* Table5701 */
  0x1760, /* VPANDNQZ256rmk */
  0x1763, /* VPANDNQZ256rrk */
/* Table5703 */
  0x1e2d, /* VPORQZ256rmk */
  0x1e30, /* VPORQZ256rrk */
/* Table5705 */
  0x201e, /* VPXORQZ256rmk */
  0x2021, /* VPXORQZ256rrk */
/* Table5707 */
  0x1f8c, /* VPSUBQZ256rmk */
  0x1f8f, /* VPSUBQZ256rrk */
/* Table5709 */
  0x15e0, /* VMOVUPSZrmk */
  0x15e4, /* VMOVUPSZrrk */
/* Table5711 */
  0x15de, /* VMOVUPSZmrk */
  0x15e5, /* VMOVUPSZrrk_alt */
/* Table5713 */
  0x1452, /* VMOVAPSZrmk */
  0x1456, /* VMOVAPSZrrk */
/* Table5715 */
  0x1450, /* VMOVAPSZmrk */
  0x1457, /* VMOVAPSZrrk_alt */
/* Table5717 */
  0x2181, /* VSQRTPSZmk */
  0x2184, /* VSQRTPSZrk */
/* Table5719 */
  0xc0a, /* VADDPSZrmk */
  0xc0d, /* VADDPSZrrk */
/* Table5721 */
  0x163e, /* VMULPSZrmk */
  0x1641, /* VMULPSZrrk */
/* Table5723 */
  0x21d4, /* VSUBPSZrmk */
  0x21d7, /* VSUBPSZrrk */
/* Table5725 */
  0x13dd, /* VMINPSZrmk */
  0x13e0, /* VMINPSZrrk */
/* Table5727 */
  0xde7, /* VDIVPSZrmk */
  0xdea, /* VDIVPSZrrk */
/* Table5729 */
  0x1372, /* VMAXPSZrmk */
  0x1375, /* VMAXPSZrrk */
/* Table5731 */
  0x14f0, /* VMOVDQU32Zrmk */
  0x14f4, /* VMOVDQU32Zrrk */
/* Table5733 */
  0x14ee, /* VMOVDQU32Zmrk */
  0x14f5, /* VMOVDQU32Zrrk_alt */
/* Table5735 */
  0x1532, /* VMOVDQU8Zrmk */
  0x1536, /* VMOVDQU8Zrrk */
/* Table5737 */
  0x1530, /* VMOVDQU8Zmrk */
  0x1537, /* VMOVDQU8Zrrk_alt */
/* Table5739 */
  0x18de, /* VPCMPGTBZrmk */
  0x18e0, /* VPCMPGTBZrrk */
/* Table5741 */
  0x191a, /* VPCMPGTWZrmk */
  0x191c, /* VPCMPGTWZrrk */
/* Table5743 */
  0x18f4, /* VPCMPGTDZrmk */
  0x18f6, /* VPCMPGTDZrrk */
/* Table5745 */
  0x1485, /* VMOVDQA32Zrmk */
  0x1489, /* VMOVDQA32Zrrk */
/* Table5747 */
  0x0, /*  */
  0x0, /*  */
  0x1f0e, /* VPSRLDZmik */
  0x0, /*  */
  0x1ed8, /* VPSRADZmik */
  0x0, /*  */
  0x1e9a, /* VPSLLDZmik */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1f11, /* VPSRLDZrik */
  0x0, /*  */
  0x1edb, /* VPSRADZrik */
  0x0, /*  */
  0x1e9d, /* VPSLLDZrik */
  0x0, /*  */
/* Table5763 */
  0x188a, /* VPCMPEQBZrmk */
  0x188c, /* VPCMPEQBZrrk */
/* Table5765 */
  0x18c6, /* VPCMPEQWZrmk */
  0x18c8, /* VPCMPEQWZrrk */
/* Table5767 */
  0x18a0, /* VPCMPEQDZrmk */
  0x18a2, /* VPCMPEQDZrrk */
/* Table5769 */
  0x1483, /* VMOVDQA32Zmrk */
  0x148a, /* VMOVDQA32Zrrk_alt */
/* Table5771 */
  0x1f14, /* VPSRLDZrmk */
  0x1f17, /* VPSRLDZrrk */
/* Table5773 */
  0x1df1, /* VPMULLWZrmk */
  0x1df4, /* VPMULLWZrrk */
/* Table5775 */
  0x1c73, /* VPMINUBZrmk */
  0x1c76, /* VPMINUBZrrk */
/* Table5777 */
  0x1733, /* VPANDDZrmk */
  0x1736, /* VPANDDZrrk */
/* Table5779 */
  0x1ba7, /* VPMAXUBZrmk */
  0x1baa, /* VPMAXUBZrrk */
/* Table5781 */
  0x174e, /* VPANDNDZrmk */
  0x1751, /* VPANDNDZrrk */
/* Table5783 */
  0x1ede, /* VPSRADZrmk */
  0x1ee1, /* VPSRADZrrk */
/* Table5785 */
  0x1c5d, /* VPMINSWZrmk */
  0x1c60, /* VPMINSWZrrk */
/* Table5787 */
  0x1e1b, /* VPORDZrmk */
  0x1e1e, /* VPORDZrrk */
/* Table5789 */
  0x1b91, /* VPMAXSWZrmk */
  0x1b94, /* VPMAXSWZrrk */
/* Table5791 */
  0x200c, /* VPXORDZrmk */
  0x200f, /* VPXORDZrrk */
/* Table5793 */
  0x1ea0, /* VPSLLDZrmk */
  0x1ea3, /* VPSLLDZrrk */
/* Table5795 */
  0x1f57, /* VPSUBBZrmk */
  0x1f5a, /* VPSUBBZrrk */
/* Table5797 */
  0x1fbb, /* VPSUBWZrmk */
  0x1fbe, /* VPSUBWZrrk */
/* Table5799 */
  0x1f76, /* VPSUBDZrmk */
  0x1f79, /* VPSUBDZrrk */
/* Table5801 */
  0x16ae, /* VPADDBZrmk */
  0x16b1, /* VPADDBZrrk */
/* Table5803 */
  0x1712, /* VPADDWZrmk */
  0x1715, /* VPADDWZrrk */
/* Table5805 */
  0x16cd, /* VPADDDZrmk */
  0x16d0, /* VPADDDZrrk */
/* Table5807 */
  0x1511, /* VMOVDQU64Zrmk */
  0x1515, /* VMOVDQU64Zrrk */
/* Table5809 */
  0x150f, /* VMOVDQU64Zmrk */
  0x1516, /* VMOVDQU64Zrrk_alt */
/* Table5811 */
  0x14cf, /* VMOVDQU16Zrmk */
  0x14d3, /* VMOVDQU16Zrrk */
/* Table5813 */
  0x14cd, /* VMOVDQU16Zmrk */
  0x14d4, /* VMOVDQU16Zrrk_alt */
/* Table5815 */
  0x15b7, /* VMOVUPDZrmk */
  0x15bb, /* VMOVUPDZrrk */
/* Table5817 */
  0x15b5, /* VMOVUPDZmrk */
  0x15bc, /* VMOVUPDZrrk_alt */
/* Table5819 */
  0x1429, /* VMOVAPDZrmk */
  0x142d, /* VMOVAPDZrrk */
/* Table5821 */
  0x1427, /* VMOVAPDZmrk */
  0x142e, /* VMOVAPDZrrk_alt */
/* Table5823 */
  0x2162, /* VSQRTPDZmk */
  0x2165, /* VSQRTPDZrk */
/* Table5825 */
  0xbe8, /* VADDPDZrmk */
  0xbeb, /* VADDPDZrrk */
/* Table5827 */
  0x161c, /* VMULPDZrmk */
  0x161f, /* VMULPDZrrk */
/* Table5829 */
  0x21b2, /* VSUBPDZrmk */
  0x21b5, /* VSUBPDZrrk */
/* Table5831 */
  0x13be, /* VMINPDZrmk */
  0x13c1, /* VMINPDZrrk */
/* Table5833 */
  0xdc5, /* VDIVPDZrmk */
  0xdc8, /* VDIVPDZrrk */
/* Table5835 */
  0x1353, /* VMAXPDZrmk */
  0x1356, /* VMAXPDZrrk */
/* Table5837 */
  0x14a6, /* VMOVDQA64Zrmk */
  0x14aa, /* VMOVDQA64Zrrk */
/* Table5839 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1ee7, /* VPSRAQZmik */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1eea, /* VPSRAQZrik */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table5855 */
  0x0, /*  */
  0x0, /*  */
  0x1f20, /* VPSRLQZmik */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1eac, /* VPSLLQZmik */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1f23, /* VPSRLQZrik */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1eaf, /* VPSLLQZrik */
  0x0, /*  */
/* Table5871 */
  0x14a4, /* VMOVDQA64Zmrk */
  0x14ab, /* VMOVDQA64Zrrk_alt */
/* Table5873 */
  0x1f26, /* VPSRLQZrmk */
  0x1f29, /* VPSRLQZrrk */
/* Table5875 */
  0x16ec, /* VPADDQZrmk */
  0x16ef, /* VPADDQZrrk */
/* Table5877 */
  0x1788, /* VPANDQZrmk */
  0x178b, /* VPANDQZrrk */
/* Table5879 */
  0x1769, /* VPANDNQZrmk */
  0x176c, /* VPANDNQZrrk */
/* Table5881 */
  0x1eed, /* VPSRAQZrmk */
  0x1ef0, /* VPSRAQZrrk */
/* Table5883 */
  0x1e36, /* VPORQZrmk */
  0x1e39, /* VPORQZrrk */
/* Table5885 */
  0x2027, /* VPXORQZrmk */
  0x202a, /* VPXORQZrrk */
/* Table5887 */
  0x1eb2, /* VPSLLQZrmk */
  0x1eb5, /* VPSLLQZrrk */
/* Table5889 */
  0x1dfe, /* VPMULUDQZrmk */
  0x1e01, /* VPMULUDQZrrk */
/* Table5891 */
  0x1f95, /* VPSUBQZrmk */
  0x1f98, /* VPSUBQZrrk */
/* Table5893 */
  0x216c, /* VSQRTPSZ128mb */
  0x0, /*  */
/* Table5895 */
  0xbf2, /* VADDPSZ128rmb */
  0x0, /*  */
/* Table5897 */
  0x1626, /* VMULPSZ128rmb */
  0x0, /*  */
/* Table5899 */
  0x21bc, /* VSUBPSZ128rmb */
  0x0, /*  */
/* Table5901 */
  0x13c8, /* VMINPSZ128rmb */
  0x0, /*  */
/* Table5903 */
  0xdcf, /* VDIVPSZ128rmb */
  0x0, /*  */
/* Table5905 */
  0x135d, /* VMAXPSZ128rmb */
  0x0, /*  */
/* Table5907 */
  0x0, /*  */
  0xc28, /* VADDSSZrrb */
/* Table5909 */
  0x0, /*  */
  0x165c, /* VMULSSZrrb */
/* Table5911 */
  0x0, /*  */
  0x21f2, /* VSUBSSZrrb */
/* Table5913 */
  0x0, /*  */
  0x13fb, /* VMINSSZrrb */
/* Table5915 */
  0x0, /*  */
  0xe05, /* VDIVSSZrrb */
/* Table5917 */
  0x0, /*  */
  0x1390, /* VMAXSSZrrb */
/* Table5919 */
  0x18e6, /* VPCMPGTDZ128rmb */
  0x0, /*  */
/* Table5921 */
  0x1892, /* VPCMPEQDZ128rmb */
  0x0, /*  */
/* Table5923 */
  0x171e, /* VPANDDZ128rmb */
  0x0, /*  */
/* Table5925 */
  0x1739, /* VPANDNDZ128rmb */
  0x0, /*  */
/* Table5927 */
  0x1e06, /* VPORDZ128rmb */
  0x0, /*  */
/* Table5929 */
  0x1ff7, /* VPXORDZ128rmb */
  0x0, /*  */
/* Table5931 */
  0x1f61, /* VPSUBDZ128rmb */
  0x0, /*  */
/* Table5933 */
  0x16b8, /* VPADDDZ128rmb */
  0x0, /*  */
/* Table5935 */
  0x0, /*  */
  0xc19, /* VADDSDZrrb */
/* Table5937 */
  0x0, /*  */
  0x164d, /* VMULSDZrrb */
/* Table5939 */
  0x0, /*  */
  0x21e3, /* VSUBSDZrrb */
/* Table5941 */
  0x0, /*  */
  0x13ec, /* VMINSDZrrb */
/* Table5943 */
  0x0, /*  */
  0xdf6, /* VDIVSDZrrb */
/* Table5945 */
  0x0, /*  */
  0x1381, /* VMAXSDZrrb */
/* Table5947 */
  0x214d, /* VSQRTPDZ128mb */
  0x0, /*  */
/* Table5949 */
  0xbd0, /* VADDPDZ128rmb */
  0x0, /*  */
/* Table5951 */
  0x1604, /* VMULPDZ128rmb */
  0x0, /*  */
/* Table5953 */
  0x219a, /* VSUBPDZ128rmb */
  0x0, /*  */
/* Table5955 */
  0x13a9, /* VMINPDZ128rmb */
  0x0, /*  */
/* Table5957 */
  0xdad, /* VDIVPDZ128rmb */
  0x0, /*  */
/* Table5959 */
  0x133e, /* VMAXPDZ128rmb */
  0x0, /*  */
/* Table5961 */
  0x16d7, /* VPADDQZ128rmb */
  0x0, /*  */
/* Table5963 */
  0x1773, /* VPANDQZ128rmb */
  0x0, /*  */
/* Table5965 */
  0x1754, /* VPANDNQZ128rmb */
  0x0, /*  */
/* Table5967 */
  0x1e21, /* VPORQZ128rmb */
  0x0, /*  */
/* Table5969 */
  0x2012, /* VPXORQZ128rmb */
  0x0, /*  */
/* Table5971 */
  0x1f80, /* VPSUBQZ128rmb */
  0x0, /*  */
/* Table5973 */
  0x2175, /* VSQRTPSZ256mb */
  0x0, /*  */
/* Table5975 */
  0xbfb, /* VADDPSZ256rmb */
  0x0, /*  */
/* Table5977 */
  0x162f, /* VMULPSZ256rmb */
  0x0, /*  */
/* Table5979 */
  0x21c5, /* VSUBPSZ256rmb */
  0x0, /*  */
/* Table5981 */
  0x13d1, /* VMINPSZ256rmb */
  0x0, /*  */
/* Table5983 */
  0xdd8, /* VDIVPSZ256rmb */
  0x0, /*  */
/* Table5985 */
  0x1366, /* VMAXPSZ256rmb */
  0x0, /*  */
/* Table5987 */
  0x18ec, /* VPCMPGTDZ256rmb */
  0x0, /*  */
/* Table5989 */
  0x1898, /* VPCMPEQDZ256rmb */
  0x0, /*  */
/* Table5991 */
  0x1727, /* VPANDDZ256rmb */
  0x0, /*  */
/* Table5993 */
  0x1742, /* VPANDNDZ256rmb */
  0x0, /*  */
/* Table5995 */
  0x1e0f, /* VPORDZ256rmb */
  0x0, /*  */
/* Table5997 */
  0x2000, /* VPXORDZ256rmb */
  0x0, /*  */
/* Table5999 */
  0x1f6a, /* VPSUBDZ256rmb */
  0x0, /*  */
/* Table6001 */
  0x16c1, /* VPADDDZ256rmb */
  0x0, /*  */
/* Table6003 */
  0x2156, /* VSQRTPDZ256mb */
  0x0, /*  */
/* Table6005 */
  0xbd9, /* VADDPDZ256rmb */
  0x0, /*  */
/* Table6007 */
  0x160d, /* VMULPDZ256rmb */
  0x0, /*  */
/* Table6009 */
  0x21a3, /* VSUBPDZ256rmb */
  0x0, /*  */
/* Table6011 */
  0x13b2, /* VMINPDZ256rmb */
  0x0, /*  */
/* Table6013 */
  0xdb6, /* VDIVPDZ256rmb */
  0x0, /*  */
/* Table6015 */
  0x1347, /* VMAXPDZ256rmb */
  0x0, /*  */
/* Table6017 */
  0x16e0, /* VPADDQZ256rmb */
  0x0, /*  */
/* Table6019 */
  0x177c, /* VPANDQZ256rmb */
  0x0, /*  */
/* Table6021 */
  0x175d, /* VPANDNQZ256rmb */
  0x0, /*  */
/* Table6023 */
  0x1e2a, /* VPORQZ256rmb */
  0x0, /*  */
/* Table6025 */
  0x201b, /* VPXORQZ256rmb */
  0x0, /*  */
/* Table6027 */
  0x1f89, /* VPSUBQZ256rmb */
  0x0, /*  */
/* Table6029 */
  0x217e, /* VSQRTPSZmb */
  0x0, /*  */
/* Table6031 */
  0xc07, /* VADDPSZrmb */
  0xc03, /* VADDPSZrb */
/* Table6033 */
  0x163b, /* VMULPSZrmb */
  0x1637, /* VMULPSZrb */
/* Table6035 */
  0x0, /*  */
  0xd15, /* VCVTDQ2PSZrrb */
/* Table6037 */
  0x21d1, /* VSUBPSZrmb */
  0x21cd, /* VSUBPSZrb */
/* Table6039 */
  0x13da, /* VMINPSZrmb */
  0x0, /*  */
/* Table6041 */
  0xde4, /* VDIVPSZrmb */
  0xde0, /* VDIVPSZrb */
/* Table6043 */
  0x136f, /* VMAXPSZrmb */
  0x0, /*  */
/* Table6045 */
  0x0, /*  */
  0xd44, /* VCVTPS2UDQZrrb */
/* Table6047 */
  0x0, /*  */
  0xcdb, /* VCMPPSZrrib */
/* Table6049 */
  0x0, /*  */
  0xda1, /* VCVTUDQ2PSZrrb */
/* Table6051 */
  0x0, /*  */
  0xd33, /* VCVTPS2DQZrrb */
/* Table6053 */
  0x18f2, /* VPCMPGTDZrmb */
  0x0, /*  */
/* Table6055 */
  0x189e, /* VPCMPEQDZrmb */
  0x0, /*  */
/* Table6057 */
  0x1730, /* VPANDDZrmb */
  0x0, /*  */
/* Table6059 */
  0x174b, /* VPANDNDZrmb */
  0x0, /*  */
/* Table6061 */
  0x1e18, /* VPORDZrmb */
  0x0, /*  */
/* Table6063 */
  0x2009, /* VPXORDZrmb */
  0x0, /*  */
/* Table6065 */
  0x1f73, /* VPSUBDZrmb */
  0x0, /*  */
/* Table6067 */
  0x16ca, /* VPADDDZrmb */
  0x0, /*  */
/* Table6069 */
  0x0, /*  */
  0xd28, /* VCVTPD2UDQZrrb */
/* Table6071 */
  0x0, /*  */
  0xd1d, /* VCVTPD2DQZrrb */
/* Table6073 */
  0x215f, /* VSQRTPDZmb */
  0x0, /*  */
/* Table6075 */
  0xbe5, /* VADDPDZrmb */
  0xbe1, /* VADDPDZrb */
/* Table6077 */
  0x1619, /* VMULPDZrmb */
  0x1615, /* VMULPDZrb */
/* Table6079 */
  0x0, /*  */
  0xd24, /* VCVTPD2PSZrrb */
/* Table6081 */
  0x21af, /* VSUBPDZrmb */
  0x21ab, /* VSUBPDZrb */
/* Table6083 */
  0x13bb, /* VMINPDZrmb */
  0x0, /*  */
/* Table6085 */
  0xdc2, /* VDIVPDZrmb */
  0xdbe, /* VDIVPDZrb */
/* Table6087 */
  0x1350, /* VMAXPDZrmb */
  0x0, /*  */
/* Table6089 */
  0x0, /*  */
  0xccd, /* VCMPPDZrrib */
/* Table6091 */
  0x16e9, /* VPADDQZrmb */
  0x0, /*  */
/* Table6093 */
  0x1785, /* VPANDQZrmb */
  0x0, /*  */
/* Table6095 */
  0x1766, /* VPANDNQZrmb */
  0x0, /*  */
/* Table6097 */
  0x1e33, /* VPORQZrmb */
  0x0, /*  */
/* Table6099 */
  0x2024, /* VPXORQZrmb */
  0x0, /*  */
/* Table6101 */
  0x1dfb, /* VPMULUDQZrmb */
  0x0, /*  */
/* Table6103 */
  0x1f92, /* VPSUBQZrmb */
  0x0, /*  */
/* Table6105 */
  0x216d, /* VSQRTPSZ128mbk */
  0x0, /*  */
/* Table6107 */
  0xbf3, /* VADDPSZ128rmbk */
  0x0, /*  */
/* Table6109 */
  0x1627, /* VMULPSZ128rmbk */
  0x0, /*  */
/* Table6111 */
  0x21bd, /* VSUBPSZ128rmbk */
  0x0, /*  */
/* Table6113 */
  0x13c9, /* VMINPSZ128rmbk */
  0x0, /*  */
/* Table6115 */
  0xdd0, /* VDIVPSZ128rmbk */
  0x0, /*  */
/* Table6117 */
  0x135e, /* VMAXPSZ128rmbk */
  0x0, /*  */
/* Table6119 */
  0x0, /*  */
  0xc29, /* VADDSSZrrbk */
/* Table6121 */
  0x0, /*  */
  0x165d, /* VMULSSZrrbk */
/* Table6123 */
  0x0, /*  */
  0x21f3, /* VSUBSSZrrbk */
/* Table6125 */
  0x0, /*  */
  0x13fc, /* VMINSSZrrbk */
/* Table6127 */
  0x0, /*  */
  0xe06, /* VDIVSSZrrbk */
/* Table6129 */
  0x0, /*  */
  0x1391, /* VMAXSSZrrbk */
/* Table6131 */
  0x18e7, /* VPCMPGTDZ128rmbk */
  0x0, /*  */
/* Table6133 */
  0x1893, /* VPCMPEQDZ128rmbk */
  0x0, /*  */
/* Table6135 */
  0x171f, /* VPANDDZ128rmbk */
  0x0, /*  */
/* Table6137 */
  0x173a, /* VPANDNDZ128rmbk */
  0x0, /*  */
/* Table6139 */
  0x1e07, /* VPORDZ128rmbk */
  0x0, /*  */
/* Table6141 */
  0x1ff8, /* VPXORDZ128rmbk */
  0x0, /*  */
/* Table6143 */
  0x1f62, /* VPSUBDZ128rmbk */
  0x0, /*  */
/* Table6145 */
  0x16b9, /* VPADDDZ128rmbk */
  0x0, /*  */
/* Table6147 */
  0x0, /*  */
  0xc1a, /* VADDSDZrrbk */
/* Table6149 */
  0x0, /*  */
  0x164e, /* VMULSDZrrbk */
/* Table6151 */
  0x0, /*  */
  0x21e4, /* VSUBSDZrrbk */
/* Table6153 */
  0x0, /*  */
  0x13ed, /* VMINSDZrrbk */
/* Table6155 */
  0x0, /*  */
  0xdf7, /* VDIVSDZrrbk */
/* Table6157 */
  0x0, /*  */
  0x1382, /* VMAXSDZrrbk */
/* Table6159 */
  0x214e, /* VSQRTPDZ128mbk */
  0x0, /*  */
/* Table6161 */
  0xbd1, /* VADDPDZ128rmbk */
  0x0, /*  */
/* Table6163 */
  0x1605, /* VMULPDZ128rmbk */
  0x0, /*  */
/* Table6165 */
  0x219b, /* VSUBPDZ128rmbk */
  0x0, /*  */
/* Table6167 */
  0x13aa, /* VMINPDZ128rmbk */
  0x0, /*  */
/* Table6169 */
  0xdae, /* VDIVPDZ128rmbk */
  0x0, /*  */
/* Table6171 */
  0x133f, /* VMAXPDZ128rmbk */
  0x0, /*  */
/* Table6173 */
  0x16d8, /* VPADDQZ128rmbk */
  0x0, /*  */
/* Table6175 */
  0x1774, /* VPANDQZ128rmbk */
  0x0, /*  */
/* Table6177 */
  0x1755, /* VPANDNQZ128rmbk */
  0x0, /*  */
/* Table6179 */
  0x1e22, /* VPORQZ128rmbk */
  0x0, /*  */
/* Table6181 */
  0x2013, /* VPXORQZ128rmbk */
  0x0, /*  */
/* Table6183 */
  0x1f81, /* VPSUBQZ128rmbk */
  0x0, /*  */
/* Table6185 */
  0x2176, /* VSQRTPSZ256mbk */
  0x0, /*  */
/* Table6187 */
  0xbfc, /* VADDPSZ256rmbk */
  0x0, /*  */
/* Table6189 */
  0x1630, /* VMULPSZ256rmbk */
  0x0, /*  */
/* Table6191 */
  0x21c6, /* VSUBPSZ256rmbk */
  0x0, /*  */
/* Table6193 */
  0x13d2, /* VMINPSZ256rmbk */
  0x0, /*  */
/* Table6195 */
  0xdd9, /* VDIVPSZ256rmbk */
  0x0, /*  */
/* Table6197 */
  0x1367, /* VMAXPSZ256rmbk */
  0x0, /*  */
/* Table6199 */
  0x18ed, /* VPCMPGTDZ256rmbk */
  0x0, /*  */
/* Table6201 */
  0x1899, /* VPCMPEQDZ256rmbk */
  0x0, /*  */
/* Table6203 */
  0x1728, /* VPANDDZ256rmbk */
  0x0, /*  */
/* Table6205 */
  0x1743, /* VPANDNDZ256rmbk */
  0x0, /*  */
/* Table6207 */
  0x1e10, /* VPORDZ256rmbk */
  0x0, /*  */
/* Table6209 */
  0x2001, /* VPXORDZ256rmbk */
  0x0, /*  */
/* Table6211 */
  0x1f6b, /* VPSUBDZ256rmbk */
  0x0, /*  */
/* Table6213 */
  0x16c2, /* VPADDDZ256rmbk */
  0x0, /*  */
/* Table6215 */
  0x2157, /* VSQRTPDZ256mbk */
  0x0, /*  */
/* Table6217 */
  0xbda, /* VADDPDZ256rmbk */
  0x0, /*  */
/* Table6219 */
  0x160e, /* VMULPDZ256rmbk */
  0x0, /*  */
/* Table6221 */
  0x21a4, /* VSUBPDZ256rmbk */
  0x0, /*  */
/* Table6223 */
  0x13b3, /* VMINPDZ256rmbk */
  0x0, /*  */
/* Table6225 */
  0xdb7, /* VDIVPDZ256rmbk */
  0x0, /*  */
/* Table6227 */
  0x1348, /* VMAXPDZ256rmbk */
  0x0, /*  */
/* Table6229 */
  0x16e1, /* VPADDQZ256rmbk */
  0x0, /*  */
/* Table6231 */
  0x177d, /* VPANDQZ256rmbk */
  0x0, /*  */
/* Table6233 */
  0x175e, /* VPANDNQZ256rmbk */
  0x0, /*  */
/* Table6235 */
  0x1e2b, /* VPORQZ256rmbk */
  0x0, /*  */
/* Table6237 */
  0x201c, /* VPXORQZ256rmbk */
  0x0, /*  */
/* Table6239 */
  0x1f8a, /* VPSUBQZ256rmbk */
  0x0, /*  */
/* Table6241 */
  0x217f, /* VSQRTPSZmbk */
  0x0, /*  */
/* Table6243 */
  0xc08, /* VADDPSZrmbk */
  0xc04, /* VADDPSZrbk */
/* Table6245 */
  0x163c, /* VMULPSZrmbk */
  0x1638, /* VMULPSZrbk */
/* Table6247 */
  0x21d2, /* VSUBPSZrmbk */
  0x21ce, /* VSUBPSZrbk */
/* Table6249 */
  0x13db, /* VMINPSZrmbk */
  0x0, /*  */
/* Table6251 */
  0xde5, /* VDIVPSZrmbk */
  0xde1, /* VDIVPSZrbk */
/* Table6253 */
  0x1370, /* VMAXPSZrmbk */
  0x0, /*  */
/* Table6255 */
  0x18f3, /* VPCMPGTDZrmbk */
  0x0, /*  */
/* Table6257 */
  0x189f, /* VPCMPEQDZrmbk */
  0x0, /*  */
/* Table6259 */
  0x1731, /* VPANDDZrmbk */
  0x0, /*  */
/* Table6261 */
  0x174c, /* VPANDNDZrmbk */
  0x0, /*  */
/* Table6263 */
  0x1e19, /* VPORDZrmbk */
  0x0, /*  */
/* Table6265 */
  0x200a, /* VPXORDZrmbk */
  0x0, /*  */
/* Table6267 */
  0x1f74, /* VPSUBDZrmbk */
  0x0, /*  */
/* Table6269 */
  0x16cb, /* VPADDDZrmbk */
  0x0, /*  */
/* Table6271 */
  0x2160, /* VSQRTPDZmbk */
  0x0, /*  */
/* Table6273 */
  0xbe6, /* VADDPDZrmbk */
  0xbe2, /* VADDPDZrbk */
/* Table6275 */
  0x161a, /* VMULPDZrmbk */
  0x1616, /* VMULPDZrbk */
/* Table6277 */
  0x21b0, /* VSUBPDZrmbk */
  0x21ac, /* VSUBPDZrbk */
/* Table6279 */
  0x13bc, /* VMINPDZrmbk */
  0x0, /*  */
/* Table6281 */
  0xdc3, /* VDIVPDZrmbk */
  0xdbf, /* VDIVPDZrbk */
/* Table6283 */
  0x1351, /* VMAXPDZrmbk */
  0x0, /*  */
/* Table6285 */
  0x16ea, /* VPADDQZrmbk */
  0x0, /*  */
/* Table6287 */
  0x1786, /* VPANDQZrmbk */
  0x0, /*  */
/* Table6289 */
  0x1767, /* VPANDNQZrmbk */
  0x0, /*  */
/* Table6291 */
  0x1e34, /* VPORQZrmbk */
  0x0, /*  */
/* Table6293 */
  0x2025, /* VPXORQZrmbk */
  0x0, /*  */
/* Table6295 */
  0x1dfc, /* VPMULUDQZrmbk */
  0x0, /*  */
/* Table6297 */
  0x1f93, /* VPSUBQZrmbk */
  0x0, /*  */
/* Table6299 */
  0x216e, /* VSQRTPSZ128mbkz */
  0x0, /*  */
/* Table6301 */
  0xbf4, /* VADDPSZ128rmbkz */
  0x0, /*  */
/* Table6303 */
  0x1628, /* VMULPSZ128rmbkz */
  0x0, /*  */
/* Table6305 */
  0x21be, /* VSUBPSZ128rmbkz */
  0x0, /*  */
/* Table6307 */
  0x13ca, /* VMINPSZ128rmbkz */
  0x0, /*  */
/* Table6309 */
  0xdd1, /* VDIVPSZ128rmbkz */
  0x0, /*  */
/* Table6311 */
  0x135f, /* VMAXPSZ128rmbkz */
  0x0, /*  */
/* Table6313 */
  0x0, /*  */
  0xc2a, /* VADDSSZrrbkz */
/* Table6315 */
  0x0, /*  */
  0x165e, /* VMULSSZrrbkz */
/* Table6317 */
  0x0, /*  */
  0x21f4, /* VSUBSSZrrbkz */
/* Table6319 */
  0x0, /*  */
  0x13fd, /* VMINSSZrrbkz */
/* Table6321 */
  0x0, /*  */
  0xe07, /* VDIVSSZrrbkz */
/* Table6323 */
  0x0, /*  */
  0x1392, /* VMAXSSZrrbkz */
/* Table6325 */
  0x1720, /* VPANDDZ128rmbkz */
  0x0, /*  */
/* Table6327 */
  0x173b, /* VPANDNDZ128rmbkz */
  0x0, /*  */
/* Table6329 */
  0x1e08, /* VPORDZ128rmbkz */
  0x0, /*  */
/* Table6331 */
  0x1ff9, /* VPXORDZ128rmbkz */
  0x0, /*  */
/* Table6333 */
  0x1f63, /* VPSUBDZ128rmbkz */
  0x0, /*  */
/* Table6335 */
  0x16ba, /* VPADDDZ128rmbkz */
  0x0, /*  */
/* Table6337 */
  0x0, /*  */
  0xc1b, /* VADDSDZrrbkz */
/* Table6339 */
  0x0, /*  */
  0x164f, /* VMULSDZrrbkz */
/* Table6341 */
  0x0, /*  */
  0x21e5, /* VSUBSDZrrbkz */
/* Table6343 */
  0x0, /*  */
  0x13ee, /* VMINSDZrrbkz */
/* Table6345 */
  0x0, /*  */
  0xdf8, /* VDIVSDZrrbkz */
/* Table6347 */
  0x0, /*  */
  0x1383, /* VMAXSDZrrbkz */
/* Table6349 */
  0x214f, /* VSQRTPDZ128mbkz */
  0x0, /*  */
/* Table6351 */
  0xbd2, /* VADDPDZ128rmbkz */
  0x0, /*  */
/* Table6353 */
  0x1606, /* VMULPDZ128rmbkz */
  0x0, /*  */
/* Table6355 */
  0x219c, /* VSUBPDZ128rmbkz */
  0x0, /*  */
/* Table6357 */
  0x13ab, /* VMINPDZ128rmbkz */
  0x0, /*  */
/* Table6359 */
  0xdaf, /* VDIVPDZ128rmbkz */
  0x0, /*  */
/* Table6361 */
  0x1340, /* VMAXPDZ128rmbkz */
  0x0, /*  */
/* Table6363 */
  0x16d9, /* VPADDQZ128rmbkz */
  0x0, /*  */
/* Table6365 */
  0x1775, /* VPANDQZ128rmbkz */
  0x0, /*  */
/* Table6367 */
  0x1756, /* VPANDNQZ128rmbkz */
  0x0, /*  */
/* Table6369 */
  0x1e23, /* VPORQZ128rmbkz */
  0x0, /*  */
/* Table6371 */
  0x2014, /* VPXORQZ128rmbkz */
  0x0, /*  */
/* Table6373 */
  0x1f82, /* VPSUBQZ128rmbkz */
  0x0, /*  */
/* Table6375 */
  0x2177, /* VSQRTPSZ256mbkz */
  0x0, /*  */
/* Table6377 */
  0xbfd, /* VADDPSZ256rmbkz */
  0x0, /*  */
/* Table6379 */
  0x1631, /* VMULPSZ256rmbkz */
  0x0, /*  */
/* Table6381 */
  0x21c7, /* VSUBPSZ256rmbkz */
  0x0, /*  */
/* Table6383 */
  0x13d3, /* VMINPSZ256rmbkz */
  0x0, /*  */
/* Table6385 */
  0xdda, /* VDIVPSZ256rmbkz */
  0x0, /*  */
/* Table6387 */
  0x1368, /* VMAXPSZ256rmbkz */
  0x0, /*  */
/* Table6389 */
  0x1729, /* VPANDDZ256rmbkz */
  0x0, /*  */
/* Table6391 */
  0x1744, /* VPANDNDZ256rmbkz */
  0x0, /*  */
/* Table6393 */
  0x1e11, /* VPORDZ256rmbkz */
  0x0, /*  */
/* Table6395 */
  0x2002, /* VPXORDZ256rmbkz */
  0x0, /*  */
/* Table6397 */
  0x1f6c, /* VPSUBDZ256rmbkz */
  0x0, /*  */
/* Table6399 */
  0x16c3, /* VPADDDZ256rmbkz */
  0x0, /*  */
/* Table6401 */
  0x2158, /* VSQRTPDZ256mbkz */
  0x0, /*  */
/* Table6403 */
  0xbdb, /* VADDPDZ256rmbkz */
  0x0, /*  */
/* Table6405 */
  0x160f, /* VMULPDZ256rmbkz */
  0x0, /*  */
/* Table6407 */
  0x21a5, /* VSUBPDZ256rmbkz */
  0x0, /*  */
/* Table6409 */
  0x13b4, /* VMINPDZ256rmbkz */
  0x0, /*  */
/* Table6411 */
  0xdb8, /* VDIVPDZ256rmbkz */
  0x0, /*  */
/* Table6413 */
  0x1349, /* VMAXPDZ256rmbkz */
  0x0, /*  */
/* Table6415 */
  0x16e2, /* VPADDQZ256rmbkz */
  0x0, /*  */
/* Table6417 */
  0x177e, /* VPANDQZ256rmbkz */
  0x0, /*  */
/* Table6419 */
  0x175f, /* VPANDNQZ256rmbkz */
  0x0, /*  */
/* Table6421 */
  0x1e2c, /* VPORQZ256rmbkz */
  0x0, /*  */
/* Table6423 */
  0x201d, /* VPXORQZ256rmbkz */
  0x0, /*  */
/* Table6425 */
  0x1f8b, /* VPSUBQZ256rmbkz */
  0x0, /*  */
/* Table6427 */
  0x2180, /* VSQRTPSZmbkz */
  0x0, /*  */
/* Table6429 */
  0xc09, /* VADDPSZrmbkz */
  0xc05, /* VADDPSZrbkz */
/* Table6431 */
  0x163d, /* VMULPSZrmbkz */
  0x1639, /* VMULPSZrbkz */
/* Table6433 */
  0x21d3, /* VSUBPSZrmbkz */
  0x21cf, /* VSUBPSZrbkz */
/* Table6435 */
  0x13dc, /* VMINPSZrmbkz */
  0x0, /*  */
/* Table6437 */
  0xde6, /* VDIVPSZrmbkz */
  0xde2, /* VDIVPSZrbkz */
/* Table6439 */
  0x1371, /* VMAXPSZrmbkz */
  0x0, /*  */
/* Table6441 */
  0x1732, /* VPANDDZrmbkz */
  0x0, /*  */
/* Table6443 */
  0x174d, /* VPANDNDZrmbkz */
  0x0, /*  */
/* Table6445 */
  0x1e1a, /* VPORDZrmbkz */
  0x0, /*  */
/* Table6447 */
  0x200b, /* VPXORDZrmbkz */
  0x0, /*  */
/* Table6449 */
  0x1f75, /* VPSUBDZrmbkz */
  0x0, /*  */
/* Table6451 */
  0x16cc, /* VPADDDZrmbkz */
  0x0, /*  */
/* Table6453 */
  0x2161, /* VSQRTPDZmbkz */
  0x0, /*  */
/* Table6455 */
  0xbe7, /* VADDPDZrmbkz */
  0xbe3, /* VADDPDZrbkz */
/* Table6457 */
  0x161b, /* VMULPDZrmbkz */
  0x1617, /* VMULPDZrbkz */
/* Table6459 */
  0x21b1, /* VSUBPDZrmbkz */
  0x21ad, /* VSUBPDZrbkz */
/* Table6461 */
  0x13bd, /* VMINPDZrmbkz */
  0x0, /*  */
/* Table6463 */
  0xdc4, /* VDIVPDZrmbkz */
  0xdc0, /* VDIVPDZrbkz */
/* Table6465 */
  0x1352, /* VMAXPDZrmbkz */
  0x0, /*  */
/* Table6467 */
  0x16eb, /* VPADDQZrmbkz */
  0x0, /*  */
/* Table6469 */
  0x1787, /* VPANDQZrmbkz */
  0x0, /*  */
/* Table6471 */
  0x1768, /* VPANDNQZrmbkz */
  0x0, /*  */
/* Table6473 */
  0x1e35, /* VPORQZrmbkz */
  0x0, /*  */
/* Table6475 */
  0x2026, /* VPXORQZrmbkz */
  0x0, /*  */
/* Table6477 */
  0x1dfd, /* VPMULUDQZrmbkz */
  0x0, /*  */
/* Table6479 */
  0x1f94, /* VPSUBQZrmbkz */
  0x0, /*  */
/* Table6481 */
  0x15cb, /* VMOVUPSZ128rmkz */
  0x15d0, /* VMOVUPSZ128rrkz */
/* Table6483 */
  0x0, /*  */
  0x15d1, /* VMOVUPSZ128rrkz_alt */
/* Table6485 */
  0x143d, /* VMOVAPSZ128rmkz */
  0x1442, /* VMOVAPSZ128rrkz */
/* Table6487 */
  0x0, /*  */
  0x1443, /* VMOVAPSZ128rrkz_alt */
/* Table6489 */
  0x2170, /* VSQRTPSZ128mkz */
  0x2173, /* VSQRTPSZ128rkz */
/* Table6491 */
  0xbf6, /* VADDPSZ128rmkz */
  0xbf9, /* VADDPSZ128rrkz */
/* Table6493 */
  0x162a, /* VMULPSZ128rmkz */
  0x162d, /* VMULPSZ128rrkz */
/* Table6495 */
  0x21c0, /* VSUBPSZ128rmkz */
  0x21c3, /* VSUBPSZ128rrkz */
/* Table6497 */
  0x13cc, /* VMINPSZ128rmkz */
  0x13cf, /* VMINPSZ128rrkz */
/* Table6499 */
  0xdd3, /* VDIVPSZ128rmkz */
  0xdd6, /* VDIVPSZ128rrkz */
/* Table6501 */
  0x1361, /* VMAXPSZ128rmkz */
  0x1364, /* VMAXPSZ128rrkz */
/* Table6503 */
  0xc23, /* VADDSSZrm_Intkz */
  0xc27, /* VADDSSZrr_Intkz */
/* Table6505 */
  0x1657, /* VMULSSZrm_Intkz */
  0x165b, /* VMULSSZrr_Intkz */
/* Table6507 */
  0x21ed, /* VSUBSSZrm_Intkz */
  0x21f1, /* VSUBSSZrr_Intkz */
/* Table6509 */
  0x13f6, /* VMINSSZrm_Intkz */
  0x13fa, /* VMINSSZrr_Intkz */
/* Table6511 */
  0xe00, /* VDIVSSZrm_Intkz */
  0xe04, /* VDIVSSZrr_Intkz */
/* Table6513 */
  0x138b, /* VMAXSSZrm_Intkz */
  0x138f, /* VMAXSSZrr_Intkz */
/* Table6515 */
  0x14db, /* VMOVDQU32Z128rmkz */
  0x14e0, /* VMOVDQU32Z128rrkz */
/* Table6517 */
  0x0, /*  */
  0x14e1, /* VMOVDQU32Z128rrkz_alt */
/* Table6519 */
  0x151d, /* VMOVDQU8Z128rmkz */
  0x1522, /* VMOVDQU8Z128rrkz */
/* Table6521 */
  0x0, /*  */
  0x1523, /* VMOVDQU8Z128rrkz_alt */
/* Table6523 */
  0x1470, /* VMOVDQA32Z128rmkz */
  0x1475, /* VMOVDQA32Z128rrkz */
/* Table6525 */
  0x0, /*  */
  0x1476, /* VMOVDQA32Z128rrkz_alt */
/* Table6527 */
  0x1de6, /* VPMULLWZ128rmkz */
  0x1de9, /* VPMULLWZ128rrkz */
/* Table6529 */
  0x1c68, /* VPMINUBZ128rmkz */
  0x1c6b, /* VPMINUBZ128rrkz */
/* Table6531 */
  0x1722, /* VPANDDZ128rmkz */
  0x1725, /* VPANDDZ128rrkz */
/* Table6533 */
  0x1b9c, /* VPMAXUBZ128rmkz */
  0x1b9f, /* VPMAXUBZ128rrkz */
/* Table6535 */
  0x173d, /* VPANDNDZ128rmkz */
  0x1740, /* VPANDNDZ128rrkz */
/* Table6537 */
  0x1c52, /* VPMINSWZ128rmkz */
  0x1c55, /* VPMINSWZ128rrkz */
/* Table6539 */
  0x1e0a, /* VPORDZ128rmkz */
  0x1e0d, /* VPORDZ128rrkz */
/* Table6541 */
  0x1b86, /* VPMAXSWZ128rmkz */
  0x1b89, /* VPMAXSWZ128rrkz */
/* Table6543 */
  0x1ffb, /* VPXORDZ128rmkz */
  0x1ffe, /* VPXORDZ128rrkz */
/* Table6545 */
  0x1f4c, /* VPSUBBZ128rmkz */
  0x1f4f, /* VPSUBBZ128rrkz */
/* Table6547 */
  0x1fb0, /* VPSUBWZ128rmkz */
  0x1fb3, /* VPSUBWZ128rrkz */
/* Table6549 */
  0x1f65, /* VPSUBDZ128rmkz */
  0x1f68, /* VPSUBDZ128rrkz */
/* Table6551 */
  0x16a3, /* VPADDBZ128rmkz */
  0x16a6, /* VPADDBZ128rrkz */
/* Table6553 */
  0x1707, /* VPADDWZ128rmkz */
  0x170a, /* VPADDWZ128rrkz */
/* Table6555 */
  0x16bc, /* VPADDDZ128rmkz */
  0x16bf, /* VPADDDZ128rrkz */
/* Table6557 */
  0x14fc, /* VMOVDQU64Z128rmkz */
  0x1501, /* VMOVDQU64Z128rrkz */
/* Table6559 */
  0x0, /*  */
  0x1502, /* VMOVDQU64Z128rrkz_alt */
/* Table6561 */
  0xc14, /* VADDSDZrm_Intkz */
  0xc18, /* VADDSDZrr_Intkz */
/* Table6563 */
  0x1648, /* VMULSDZrm_Intkz */
  0x164c, /* VMULSDZrr_Intkz */
/* Table6565 */
  0x21de, /* VSUBSDZrm_Intkz */
  0x21e2, /* VSUBSDZrr_Intkz */
/* Table6567 */
  0x13e7, /* VMINSDZrm_Intkz */
  0x13eb, /* VMINSDZrr_Intkz */
/* Table6569 */
  0xdf1, /* VDIVSDZrm_Intkz */
  0xdf5, /* VDIVSDZrr_Intkz */
/* Table6571 */
  0x137c, /* VMAXSDZrm_Intkz */
  0x1380, /* VMAXSDZrr_Intkz */
/* Table6573 */
  0x14ba, /* VMOVDQU16Z128rmkz */
  0x14bf, /* VMOVDQU16Z128rrkz */
/* Table6575 */
  0x0, /*  */
  0x14c0, /* VMOVDQU16Z128rrkz_alt */
/* Table6577 */
  0x15a2, /* VMOVUPDZ128rmkz */
  0x15a7, /* VMOVUPDZ128rrkz */
/* Table6579 */
  0x0, /*  */
  0x15a8, /* VMOVUPDZ128rrkz_alt */
/* Table6581 */
  0x1414, /* VMOVAPDZ128rmkz */
  0x1419, /* VMOVAPDZ128rrkz */
/* Table6583 */
  0x0, /*  */
  0x141a, /* VMOVAPDZ128rrkz_alt */
/* Table6585 */
  0x2151, /* VSQRTPDZ128mkz */
  0x2154, /* VSQRTPDZ128rkz */
/* Table6587 */
  0xbd4, /* VADDPDZ128rmkz */
  0xbd7, /* VADDPDZ128rrkz */
/* Table6589 */
  0x1608, /* VMULPDZ128rmkz */
  0x160b, /* VMULPDZ128rrkz */
/* Table6591 */
  0x219e, /* VSUBPDZ128rmkz */
  0x21a1, /* VSUBPDZ128rrkz */
/* Table6593 */
  0x13ad, /* VMINPDZ128rmkz */
  0x13b0, /* VMINPDZ128rrkz */
/* Table6595 */
  0xdb1, /* VDIVPDZ128rmkz */
  0xdb4, /* VDIVPDZ128rrkz */
/* Table6597 */
  0x1342, /* VMAXPDZ128rmkz */
  0x1345, /* VMAXPDZ128rrkz */
/* Table6599 */
  0x1491, /* VMOVDQA64Z128rmkz */
  0x1496, /* VMOVDQA64Z128rrkz */
/* Table6601 */
  0x0, /*  */
  0x1497, /* VMOVDQA64Z128rrkz_alt */
/* Table6603 */
  0x16db, /* VPADDQZ128rmkz */
  0x16de, /* VPADDQZ128rrkz */
/* Table6605 */
  0x1777, /* VPANDQZ128rmkz */
  0x177a, /* VPANDQZ128rrkz */
/* Table6607 */
  0x1758, /* VPANDNQZ128rmkz */
  0x175b, /* VPANDNQZ128rrkz */
/* Table6609 */
  0x1e25, /* VPORQZ128rmkz */
  0x1e28, /* VPORQZ128rrkz */
/* Table6611 */
  0x2016, /* VPXORQZ128rmkz */
  0x2019, /* VPXORQZ128rrkz */
/* Table6613 */
  0x1f84, /* VPSUBQZ128rmkz */
  0x1f87, /* VPSUBQZ128rrkz */
/* Table6615 */
  0x15d6, /* VMOVUPSZ256rmkz */
  0x15db, /* VMOVUPSZ256rrkz */
/* Table6617 */
  0x0, /*  */
  0x15dc, /* VMOVUPSZ256rrkz_alt */
/* Table6619 */
  0x1448, /* VMOVAPSZ256rmkz */
  0x144d, /* VMOVAPSZ256rrkz */
/* Table6621 */
  0x0, /*  */
  0x144e, /* VMOVAPSZ256rrkz_alt */
/* Table6623 */
  0x2179, /* VSQRTPSZ256mkz */
  0x217c, /* VSQRTPSZ256rkz */
/* Table6625 */
  0xbff, /* VADDPSZ256rmkz */
  0xc02, /* VADDPSZ256rrkz */
/* Table6627 */
  0x1633, /* VMULPSZ256rmkz */
  0x1636, /* VMULPSZ256rrkz */
/* Table6629 */
  0x21c9, /* VSUBPSZ256rmkz */
  0x21cc, /* VSUBPSZ256rrkz */
/* Table6631 */
  0x13d5, /* VMINPSZ256rmkz */
  0x13d8, /* VMINPSZ256rrkz */
/* Table6633 */
  0xddc, /* VDIVPSZ256rmkz */
  0xddf, /* VDIVPSZ256rrkz */
/* Table6635 */
  0x136a, /* VMAXPSZ256rmkz */
  0x136d, /* VMAXPSZ256rrkz */
/* Table6637 */
  0x14e6, /* VMOVDQU32Z256rmkz */
  0x14eb, /* VMOVDQU32Z256rrkz */
/* Table6639 */
  0x0, /*  */
  0x14ec, /* VMOVDQU32Z256rrkz_alt */
/* Table6641 */
  0x1528, /* VMOVDQU8Z256rmkz */
  0x152d, /* VMOVDQU8Z256rrkz */
/* Table6643 */
  0x0, /*  */
  0x152e, /* VMOVDQU8Z256rrkz_alt */
/* Table6645 */
  0x147b, /* VMOVDQA32Z256rmkz */
  0x1480, /* VMOVDQA32Z256rrkz */
/* Table6647 */
  0x0, /*  */
  0x1481, /* VMOVDQA32Z256rrkz_alt */
/* Table6649 */
  0x1dec, /* VPMULLWZ256rmkz */
  0x1def, /* VPMULLWZ256rrkz */
/* Table6651 */
  0x1c6e, /* VPMINUBZ256rmkz */
  0x1c71, /* VPMINUBZ256rrkz */
/* Table6653 */
  0x172b, /* VPANDDZ256rmkz */
  0x172e, /* VPANDDZ256rrkz */
/* Table6655 */
  0x1ba2, /* VPMAXUBZ256rmkz */
  0x1ba5, /* VPMAXUBZ256rrkz */
/* Table6657 */
  0x1746, /* VPANDNDZ256rmkz */
  0x1749, /* VPANDNDZ256rrkz */
/* Table6659 */
  0x1c58, /* VPMINSWZ256rmkz */
  0x1c5b, /* VPMINSWZ256rrkz */
/* Table6661 */
  0x1e13, /* VPORDZ256rmkz */
  0x1e16, /* VPORDZ256rrkz */
/* Table6663 */
  0x1b8c, /* VPMAXSWZ256rmkz */
  0x1b8f, /* VPMAXSWZ256rrkz */
/* Table6665 */
  0x2004, /* VPXORDZ256rmkz */
  0x2007, /* VPXORDZ256rrkz */
/* Table6667 */
  0x1f52, /* VPSUBBZ256rmkz */
  0x1f55, /* VPSUBBZ256rrkz */
/* Table6669 */
  0x1fb6, /* VPSUBWZ256rmkz */
  0x1fb9, /* VPSUBWZ256rrkz */
/* Table6671 */
  0x1f6e, /* VPSUBDZ256rmkz */
  0x1f71, /* VPSUBDZ256rrkz */
/* Table6673 */
  0x16a9, /* VPADDBZ256rmkz */
  0x16ac, /* VPADDBZ256rrkz */
/* Table6675 */
  0x170d, /* VPADDWZ256rmkz */
  0x1710, /* VPADDWZ256rrkz */
/* Table6677 */
  0x16c5, /* VPADDDZ256rmkz */
  0x16c8, /* VPADDDZ256rrkz */
/* Table6679 */
  0x1507, /* VMOVDQU64Z256rmkz */
  0x150c, /* VMOVDQU64Z256rrkz */
/* Table6681 */
  0x0, /*  */
  0x150d, /* VMOVDQU64Z256rrkz_alt */
/* Table6683 */
  0x14c5, /* VMOVDQU16Z256rmkz */
  0x14ca, /* VMOVDQU16Z256rrkz */
/* Table6685 */
  0x0, /*  */
  0x14cb, /* VMOVDQU16Z256rrkz_alt */
/* Table6687 */
  0x15ad, /* VMOVUPDZ256rmkz */
  0x15b2, /* VMOVUPDZ256rrkz */
/* Table6689 */
  0x0, /*  */
  0x15b3, /* VMOVUPDZ256rrkz_alt */
/* Table6691 */
  0x141f, /* VMOVAPDZ256rmkz */
  0x1424, /* VMOVAPDZ256rrkz */
/* Table6693 */
  0x0, /*  */
  0x1425, /* VMOVAPDZ256rrkz_alt */
/* Table6695 */
  0x215a, /* VSQRTPDZ256mkz */
  0x215d, /* VSQRTPDZ256rkz */
/* Table6697 */
  0xbdd, /* VADDPDZ256rmkz */
  0xbe0, /* VADDPDZ256rrkz */
/* Table6699 */
  0x1611, /* VMULPDZ256rmkz */
  0x1614, /* VMULPDZ256rrkz */
/* Table6701 */
  0x21a7, /* VSUBPDZ256rmkz */
  0x21aa, /* VSUBPDZ256rrkz */
/* Table6703 */
  0x13b6, /* VMINPDZ256rmkz */
  0x13b9, /* VMINPDZ256rrkz */
/* Table6705 */
  0xdba, /* VDIVPDZ256rmkz */
  0xdbd, /* VDIVPDZ256rrkz */
/* Table6707 */
  0x134b, /* VMAXPDZ256rmkz */
  0x134e, /* VMAXPDZ256rrkz */
/* Table6709 */
  0x149c, /* VMOVDQA64Z256rmkz */
  0x14a1, /* VMOVDQA64Z256rrkz */
/* Table6711 */
  0x0, /*  */
  0x14a2, /* VMOVDQA64Z256rrkz_alt */
/* Table6713 */
  0x16e4, /* VPADDQZ256rmkz */
  0x16e7, /* VPADDQZ256rrkz */
/* Table6715 */
  0x1780, /* VPANDQZ256rmkz */
  0x1783, /* VPANDQZ256rrkz */
/* Table6717 */
  0x1761, /* VPANDNQZ256rmkz */
  0x1764, /* VPANDNQZ256rrkz */
/* Table6719 */
  0x1e2e, /* VPORQZ256rmkz */
  0x1e31, /* VPORQZ256rrkz */
/* Table6721 */
  0x201f, /* VPXORQZ256rmkz */
  0x2022, /* VPXORQZ256rrkz */
/* Table6723 */
  0x1f8d, /* VPSUBQZ256rmkz */
  0x1f90, /* VPSUBQZ256rrkz */
/* Table6725 */
  0x15e1, /* VMOVUPSZrmkz */
  0x15e6, /* VMOVUPSZrrkz */
/* Table6727 */
  0x0, /*  */
  0x15e7, /* VMOVUPSZrrkz_alt */
/* Table6729 */
  0x1453, /* VMOVAPSZrmkz */
  0x1458, /* VMOVAPSZrrkz */
/* Table6731 */
  0x0, /*  */
  0x1459, /* VMOVAPSZrrkz_alt */
/* Table6733 */
  0x2182, /* VSQRTPSZmkz */
  0x2185, /* VSQRTPSZrkz */
/* Table6735 */
  0xc0b, /* VADDPSZrmkz */
  0xc0e, /* VADDPSZrrkz */
/* Table6737 */
  0x163f, /* VMULPSZrmkz */
  0x1642, /* VMULPSZrrkz */
/* Table6739 */
  0x21d5, /* VSUBPSZrmkz */
  0x21d8, /* VSUBPSZrrkz */
/* Table6741 */
  0x13de, /* VMINPSZrmkz */
  0x13e1, /* VMINPSZrrkz */
/* Table6743 */
  0xde8, /* VDIVPSZrmkz */
  0xdeb, /* VDIVPSZrrkz */
/* Table6745 */
  0x1373, /* VMAXPSZrmkz */
  0x1376, /* VMAXPSZrrkz */
/* Table6747 */
  0x14f1, /* VMOVDQU32Zrmkz */
  0x14f6, /* VMOVDQU32Zrrkz */
/* Table6749 */
  0x0, /*  */
  0x14f7, /* VMOVDQU32Zrrkz_alt */
/* Table6751 */
  0x1533, /* VMOVDQU8Zrmkz */
  0x1538, /* VMOVDQU8Zrrkz */
/* Table6753 */
  0x0, /*  */
  0x1539, /* VMOVDQU8Zrrkz_alt */
/* Table6755 */
  0x1486, /* VMOVDQA32Zrmkz */
  0x148b, /* VMOVDQA32Zrrkz */
/* Table6757 */
  0x0, /*  */
  0x0, /*  */
  0x1f0f, /* VPSRLDZmikz */
  0x0, /*  */
  0x1ed9, /* VPSRADZmikz */
  0x0, /*  */
  0x1e9b, /* VPSLLDZmikz */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1f12, /* VPSRLDZrikz */
  0x0, /*  */
  0x1edc, /* VPSRADZrikz */
  0x0, /*  */
  0x1e9e, /* VPSLLDZrikz */
  0x0, /*  */
/* Table6773 */
  0x0, /*  */
  0x148c, /* VMOVDQA32Zrrkz_alt */
/* Table6775 */
  0x1f15, /* VPSRLDZrmkz */
  0x1f18, /* VPSRLDZrrkz */
/* Table6777 */
  0x1df2, /* VPMULLWZrmkz */
  0x1df5, /* VPMULLWZrrkz */
/* Table6779 */
  0x1c74, /* VPMINUBZrmkz */
  0x1c77, /* VPMINUBZrrkz */
/* Table6781 */
  0x1734, /* VPANDDZrmkz */
  0x1737, /* VPANDDZrrkz */
/* Table6783 */
  0x1ba8, /* VPMAXUBZrmkz */
  0x1bab, /* VPMAXUBZrrkz */
/* Table6785 */
  0x174f, /* VPANDNDZrmkz */
  0x1752, /* VPANDNDZrrkz */
/* Table6787 */
  0x1edf, /* VPSRADZrmkz */
  0x1ee2, /* VPSRADZrrkz */
/* Table6789 */
  0x1c5e, /* VPMINSWZrmkz */
  0x1c61, /* VPMINSWZrrkz */
/* Table6791 */
  0x1e1c, /* VPORDZrmkz */
  0x1e1f, /* VPORDZrrkz */
/* Table6793 */
  0x1b92, /* VPMAXSWZrmkz */
  0x1b95, /* VPMAXSWZrrkz */
/* Table6795 */
  0x200d, /* VPXORDZrmkz */
  0x2010, /* VPXORDZrrkz */
/* Table6797 */
  0x1ea1, /* VPSLLDZrmkz */
  0x1ea4, /* VPSLLDZrrkz */
/* Table6799 */
  0x1f58, /* VPSUBBZrmkz */
  0x1f5b, /* VPSUBBZrrkz */
/* Table6801 */
  0x1fbc, /* VPSUBWZrmkz */
  0x1fbf, /* VPSUBWZrrkz */
/* Table6803 */
  0x1f77, /* VPSUBDZrmkz */
  0x1f7a, /* VPSUBDZrrkz */
/* Table6805 */
  0x16af, /* VPADDBZrmkz */
  0x16b2, /* VPADDBZrrkz */
/* Table6807 */
  0x1713, /* VPADDWZrmkz */
  0x1716, /* VPADDWZrrkz */
/* Table6809 */
  0x16ce, /* VPADDDZrmkz */
  0x16d1, /* VPADDDZrrkz */
/* Table6811 */
  0x1512, /* VMOVDQU64Zrmkz */
  0x1517, /* VMOVDQU64Zrrkz */
/* Table6813 */
  0x0, /*  */
  0x1518, /* VMOVDQU64Zrrkz_alt */
/* Table6815 */
  0x14d0, /* VMOVDQU16Zrmkz */
  0x14d5, /* VMOVDQU16Zrrkz */
/* Table6817 */
  0x0, /*  */
  0x14d6, /* VMOVDQU16Zrrkz_alt */
/* Table6819 */
  0x15b8, /* VMOVUPDZrmkz */
  0x15bd, /* VMOVUPDZrrkz */
/* Table6821 */
  0x0, /*  */
  0x15be, /* VMOVUPDZrrkz_alt */
/* Table6823 */
  0x142a, /* VMOVAPDZrmkz */
  0x142f, /* VMOVAPDZrrkz */
/* Table6825 */
  0x0, /*  */
  0x1430, /* VMOVAPDZrrkz_alt */
/* Table6827 */
  0x2163, /* VSQRTPDZmkz */
  0x2166, /* VSQRTPDZrkz */
/* Table6829 */
  0xbe9, /* VADDPDZrmkz */
  0xbec, /* VADDPDZrrkz */
/* Table6831 */
  0x161d, /* VMULPDZrmkz */
  0x1620, /* VMULPDZrrkz */
/* Table6833 */
  0x21b3, /* VSUBPDZrmkz */
  0x21b6, /* VSUBPDZrrkz */
/* Table6835 */
  0x13bf, /* VMINPDZrmkz */
  0x13c2, /* VMINPDZrrkz */
/* Table6837 */
  0xdc6, /* VDIVPDZrmkz */
  0xdc9, /* VDIVPDZrrkz */
/* Table6839 */
  0x1354, /* VMAXPDZrmkz */
  0x1357, /* VMAXPDZrrkz */
/* Table6841 */
  0x14a7, /* VMOVDQA64Zrmkz */
  0x14ac, /* VMOVDQA64Zrrkz */
/* Table6843 */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1ee8, /* VPSRAQZmikz */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1eeb, /* VPSRAQZrikz */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table6859 */
  0x0, /*  */
  0x0, /*  */
  0x1f21, /* VPSRLQZmikz */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1ead, /* VPSLLQZmikz */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1f24, /* VPSRLQZrikz */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x1eb0, /* VPSLLQZrikz */
  0x0, /*  */
/* Table6875 */
  0x0, /*  */
  0x14ad, /* VMOVDQA64Zrrkz_alt */
/* Table6877 */
  0x1f27, /* VPSRLQZrmkz */
  0x1f2a, /* VPSRLQZrrkz */
/* Table6879 */
  0x16ed, /* VPADDQZrmkz */
  0x16f0, /* VPADDQZrrkz */
/* Table6881 */
  0x1789, /* VPANDQZrmkz */
  0x178c, /* VPANDQZrrkz */
/* Table6883 */
  0x176a, /* VPANDNQZrmkz */
  0x176d, /* VPANDNQZrrkz */
/* Table6885 */
  0x1eee, /* VPSRAQZrmkz */
  0x1ef1, /* VPSRAQZrrkz */
/* Table6887 */
  0x1e37, /* VPORQZrmkz */
  0x1e3a, /* VPORQZrrkz */
/* Table6889 */
  0x2028, /* VPXORQZrmkz */
  0x202b, /* VPXORQZrrkz */
/* Table6891 */
  0x1eb3, /* VPSLLQZrmkz */
  0x1eb6, /* VPSLLQZrrkz */
/* Table6893 */
  0x1dff, /* VPMULUDQZrmkz */
  0x1e02, /* VPMULUDQZrrkz */
/* Table6895 */
  0x1f96, /* VPSUBQZrmkz */
  0x1f99, /* VPSUBQZrrkz */
/* Table6897 */
  0x5f9, /* MMX_PSHUFBrm64 */
  0x5fa, /* MMX_PSHUFBrr64 */
/* Table6899 */
  0x5d2, /* MMX_PHADDWrm64 */
  0x5d3, /* MMX_PHADDWrr64 */
/* Table6901 */
  0x5d4, /* MMX_PHADDrm64 */
  0x5d5, /* MMX_PHADDrr64 */
/* Table6903 */
  0x5d0, /* MMX_PHADDSWrm64 */
  0x5d1, /* MMX_PHADDSWrr64 */
/* Table6905 */
  0x5de, /* MMX_PMADDUBSWrm64 */
  0x5df, /* MMX_PMADDUBSWrr64 */
/* Table6907 */
  0x5da, /* MMX_PHSUBWrm64 */
  0x5db, /* MMX_PHSUBWrr64 */
/* Table6909 */
  0x5d6, /* MMX_PHSUBDrm64 */
  0x5d7, /* MMX_PHSUBDrr64 */
/* Table6911 */
  0x5d8, /* MMX_PHSUBSWrm64 */
  0x5d9, /* MMX_PHSUBSWrr64 */
/* Table6913 */
  0x5fd, /* MMX_PSIGNBrm64 */
  0x5fe, /* MMX_PSIGNBrr64 */
/* Table6915 */
  0x601, /* MMX_PSIGNWrm64 */
  0x602, /* MMX_PSIGNWrr64 */
/* Table6917 */
  0x5ff, /* MMX_PSIGNDrm64 */
  0x600, /* MMX_PSIGNDrr64 */
/* Table6919 */
  0x5eb, /* MMX_PMULHRSWrm64 */
  0x5ec, /* MMX_PMULHRSWrr64 */
/* Table6921 */
  0x59d, /* MMX_PABSBrm64 */
  0x59e, /* MMX_PABSBrr64 */
/* Table6923 */
  0x5a1, /* MMX_PABSWrm64 */
  0x5a2, /* MMX_PABSWrr64 */
/* Table6925 */
  0x59f, /* MMX_PABSDrm64 */
  0x5a0, /* MMX_PABSDrr64 */
/* Table6927 */
  0xa6a, /* SHA1NEXTErm */
  0xa6b, /* SHA1NEXTErr */
/* Table6929 */
  0xa66, /* SHA1MSG1rm */
  0xa67, /* SHA1MSG1rr */
/* Table6931 */
  0xa68, /* SHA1MSG2rm */
  0xa69, /* SHA1MSG2rr */
/* Table6933 */
  0xa72, /* SHA256RNDS2rm */
  0xa73, /* SHA256RNDS2rr */
/* Table6935 */
  0xa6e, /* SHA256MSG1rm */
  0xa6f, /* SHA256MSG1rr */
/* Table6937 */
  0xa70, /* SHA256MSG2rm */
  0xa71, /* SHA256MSG2rr */
/* Table6939 */
  0x698, /* MOVBE32rm */
  0x0, /*  */
/* Table6941 */
  0x697, /* MOVBE32mr */
  0x0, /*  */
/* Table6943 */
  0x8a5, /* PSHUFBrm */
  0x8a6, /* PSHUFBrr */
/* Table6945 */
  0x820, /* PHADDWrm */
  0x821, /* PHADDWrr */
/* Table6947 */
  0x81c, /* PHADDDrm */
  0x81d, /* PHADDDrr */
/* Table6949 */
  0x81e, /* PHADDSWrm128 */
  0x81f, /* PHADDSWrr128 */
/* Table6951 */
  0x836, /* PMADDUBSWrm128 */
  0x837, /* PMADDUBSWrr128 */
/* Table6953 */
  0x828, /* PHSUBWrm */
  0x829, /* PHSUBWrr */
/* Table6955 */
  0x824, /* PHSUBDrm */
  0x825, /* PHSUBDrr */
/* Table6957 */
  0x826, /* PHSUBSWrm128 */
  0x827, /* PHSUBSWrr128 */
/* Table6959 */
  0x8ad, /* PSIGNBrm */
  0x8ae, /* PSIGNBrr */
/* Table6961 */
  0x8b1, /* PSIGNWrm */
  0x8b2, /* PSIGNWrr */
/* Table6963 */
  0x8af, /* PSIGNDrm */
  0x8b0, /* PSIGNDrr */
/* Table6965 */
  0x86d, /* PMULHRSWrm128 */
  0x86e, /* PMULHRSWrr128 */
/* Table6967 */
  0x7be, /* PBLENDVBrm0 */
  0x7bf, /* PBLENDVBrr0 */
/* Table6969 */
  0x107, /* BLENDVPSrm0 */
  0x108, /* BLENDVPSrr0 */
/* Table6971 */
  0x105, /* BLENDVPDrm0 */
  0x106, /* BLENDVPDrr0 */
/* Table6973 */
  0x8df, /* PTESTrm */
  0x8e0, /* PTESTrr */
/* Table6975 */
  0x793, /* PABSBrm128 */
  0x794, /* PABSBrr128 */
/* Table6977 */
  0x797, /* PABSWrm128 */
  0x798, /* PABSWrr128 */
/* Table6979 */
  0x795, /* PABSDrm128 */
  0x796, /* PABSDrr128 */
/* Table6981 */
  0x857, /* PMOVSXBWrm */
  0x858, /* PMOVSXBWrr */
/* Table6983 */
  0x853, /* PMOVSXBDrm */
  0x854, /* PMOVSXBDrr */
/* Table6985 */
  0x855, /* PMOVSXBQrm */
  0x856, /* PMOVSXBQrr */
/* Table6987 */
  0x85b, /* PMOVSXWDrm */
  0x85c, /* PMOVSXWDrr */
/* Table6989 */
  0x85d, /* PMOVSXWQrm */
  0x85e, /* PMOVSXWQrr */
/* Table6991 */
  0x859, /* PMOVSXDQrm */
  0x85a, /* PMOVSXDQrr */
/* Table6993 */
  0x86b, /* PMULDQrm */
  0x86c, /* PMULDQrr */
/* Table6995 */
  0x7c8, /* PCMPEQQrm */
  0x7c9, /* PCMPEQQrr */
/* Table6997 */
  0x6b5, /* MOVNTDQArm */
  0x0, /*  */
/* Table6999 */
  0x79d, /* PACKUSDWrm */
  0x79e, /* PACKUSDWrr */
/* Table7001 */
  0x863, /* PMOVZXBWrm */
  0x864, /* PMOVZXBWrr */
/* Table7003 */
  0x85f, /* PMOVZXBDrm */
  0x860, /* PMOVZXBDrr */
/* Table7005 */
  0x861, /* PMOVZXBQrm */
  0x862, /* PMOVZXBQrr */
/* Table7007 */
  0x867, /* PMOVZXWDrm */
  0x868, /* PMOVZXWDrr */
/* Table7009 */
  0x869, /* PMOVZXWQrm */
  0x86a, /* PMOVZXWQrr */
/* Table7011 */
  0x865, /* PMOVZXDQrm */
  0x866, /* PMOVZXDQrr */
/* Table7013 */
  0x7d8, /* PCMPGTQrm */
  0x7d9, /* PCMPGTQrr */
/* Table7015 */
  0x846, /* PMINSBrm */
  0x847, /* PMINSBrr */
/* Table7017 */
  0x848, /* PMINSDrm */
  0x849, /* PMINSDrr */
/* Table7019 */
  0x850, /* PMINUWrm */
  0x851, /* PMINUWrr */
/* Table7021 */
  0x84e, /* PMINUDrm */
  0x84f, /* PMINUDrr */
/* Table7023 */
  0x83a, /* PMAXSBrm */
  0x83b, /* PMAXSBrr */
/* Table7025 */
  0x83c, /* PMAXSDrm */
  0x83d, /* PMAXSDrr */
/* Table7027 */
  0x844, /* PMAXUWrm */
  0x845, /* PMAXUWrr */
/* Table7029 */
  0x842, /* PMAXUDrm */
  0x843, /* PMAXUDrr */
/* Table7031 */
  0x875, /* PMULLDrm */
  0x876, /* PMULLDrr */
/* Table7033 */
  0x822, /* PHMINPOSUWrm128 */
  0x823, /* PHMINPOSUWrr128 */
/* Table7035 */
  0x3ac, /* INVEPT32 */
  0x0, /*  */
/* Table7037 */
  0x3b3, /* INVVPID32 */
  0x0, /*  */
/* Table7039 */
  0x3b1, /* INVPCID32 */
  0x0, /*  */
/* Table7041 */
  0xac, /* AESIMCrm */
  0xad, /* AESIMCrr */
/* Table7043 */
  0xaa, /* AESENCrm */
  0xab, /* AESENCrr */
/* Table7045 */
  0xa8, /* AESENCLASTrm */
  0xa9, /* AESENCLASTrr */
/* Table7047 */
  0xa6, /* AESDECrm */
  0xa7, /* AESDECrr */
/* Table7049 */
  0xa4, /* AESDECLASTrm */
  0xa5, /* AESDECLASTrr */
/* Table7051 */
  0x696, /* MOVBE16rm */
  0x0, /*  */
/* Table7053 */
  0x695, /* MOVBE16mr */
  0x0, /*  */
/* Table7055 */
  0x46, /* ADCX32rm */
  0x47, /* ADCX32rr */
/* Table7057 */
  0x25e, /* CRC32r32m8 */
  0x261, /* CRC32r32r8 */
/* Table7059 */
  0x25d, /* CRC32r32m32 */
  0x260, /* CRC32r32r32 */
/* Table7061 */
  0xa0, /* ADOX32rm */
  0xa1, /* ADOX32rr */
/* Table7063 */
  0x25c, /* CRC32r32m16 */
  0x25f, /* CRC32r32r16 */
/* Table7065 */
  0x69a, /* MOVBE64rm */
  0x0, /*  */
/* Table7067 */
  0x699, /* MOVBE64mr */
  0x0, /*  */
/* Table7069 */
  0x3ad, /* INVEPT64 */
  0x0, /*  */
/* Table7071 */
  0x3b4, /* INVVPID64 */
  0x0, /*  */
/* Table7073 */
  0x3b2, /* INVPCID64 */
  0x0, /*  */
/* Table7075 */
  0xa2, /* ADOX64rm */
  0xa3, /* ADOX64rr */
/* Table7077 */
  0x263, /* CRC32r64m8 */
  0x265, /* CRC32r64r8 */
/* Table7079 */
  0x262, /* CRC32r64m64 */
  0x264, /* CRC32r64r64 */
/* Table7081 */
  0x48, /* ADCX64rm */
  0x49, /* ADCX64rr */
/* Table7083 */
  0xd4, /* ANDN32rm */
  0xd5, /* ANDN32rr */
/* Table7085 */
  0x0, /*  */
  0x119, /* BLSR32rm */
  0x115, /* BLSMSK32rm */
  0x10d, /* BLSI32rm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x11a, /* BLSR32rr */
  0x116, /* BLSMSK32rr */
  0x10e, /* BLSI32rr */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table7101 */
  0x15d, /* BZHI32rm */
  0x15e, /* BZHI32rr */
/* Table7103 */
  0xe5, /* BEXTR32rm */
  0xe6, /* BEXTR32rr */
/* Table7105 */
  0x7e9, /* PEXT32rm */
  0x7ea, /* PEXT32rr */
/* Table7107 */
  0xa08, /* SARX32rm */
  0xa09, /* SARX32rr */
/* Table7109 */
  0x7e5, /* PDEP32rm */
  0x7e6, /* PDEP32rr */
/* Table7111 */
  0x717, /* MULX32rm */
  0x718, /* MULX32rr */
/* Table7113 */
  0xac0, /* SHRX32rm */
  0xac1, /* SHRX32rr */
/* Table7115 */
  0x1e78, /* VPSHUFBrm */
  0x1e79, /* VPSHUFBrr */
/* Table7117 */
  0x1ada, /* VPHADDWrm */
  0x1adb, /* VPHADDWrr */
/* Table7119 */
  0x1ac2, /* VPHADDDrm */
  0x1ac3, /* VPHADDDrr */
/* Table7121 */
  0x1ac4, /* VPHADDSWrm128 */
  0x1ac6, /* VPHADDSWrr128 */
/* Table7123 */
  0x1b22, /* VPMADDUBSWrm128 */
  0x1b24, /* VPMADDUBSWrr128 */
/* Table7125 */
  0x1aee, /* VPHSUBWrm */
  0x1aef, /* VPHSUBWrr */
/* Table7127 */
  0x1ae4, /* VPHSUBDrm */
  0x1ae5, /* VPHSUBDrr */
/* Table7129 */
  0x1ae6, /* VPHSUBSWrm128 */
  0x1ae8, /* VPHSUBSWrr128 */
/* Table7131 */
  0x1e8a, /* VPSIGNBrm */
  0x1e8b, /* VPSIGNBrr */
/* Table7133 */
  0x1e92, /* VPSIGNWrm */
  0x1e93, /* VPSIGNWrr */
/* Table7135 */
  0x1e8e, /* VPSIGNDrm */
  0x1e8f, /* VPSIGNDrr */
/* Table7137 */
  0x1d9c, /* VPMULHRSWrm128 */
  0x1d9e, /* VPMULHRSWrr128 */
/* Table7139 */
  0x1a61, /* VPERMILPSrm */
  0x1a62, /* VPERMILPSrr */
/* Table7141 */
  0x1a55, /* VPERMILPDrm */
  0x1a56, /* VPERMILPDrr */
/* Table7143 */
  0x21ff, /* VTESTPSrm */
  0x2200, /* VTESTPSrr */
/* Table7145 */
  0x21fb, /* VTESTPDrm */
  0x21fc, /* VTESTPDrr */
/* Table7147 */
  0xd2d, /* VCVTPH2PSrm */
  0xd2e, /* VCVTPH2PSrr */
/* Table7149 */
  0x1fcc, /* VPTESTrm */
  0x1fcd, /* VPTESTrr */
/* Table7151 */
  0xcc3, /* VBROADCASTSSrm */
  0xcc4, /* VBROADCASTSSrr */
/* Table7153 */
  0x1671, /* VPABSBrm128 */
  0x1673, /* VPABSBrr128 */
/* Table7155 */
  0x168b, /* VPABSWrm128 */
  0x168d, /* VPABSWrr128 */
/* Table7157 */
  0x167e, /* VPABSDrm128 */
  0x1680, /* VPABSDrr128 */
/* Table7159 */
  0x1d20, /* VPMOVSXBWrm */
  0x1d21, /* VPMOVSXBWrr */
/* Table7161 */
  0x1d12, /* VPMOVSXBDrm */
  0x1d13, /* VPMOVSXBDrr */
/* Table7163 */
  0x1d1c, /* VPMOVSXBQrm */
  0x1d1d, /* VPMOVSXBQrr */
/* Table7165 */
  0x1d34, /* VPMOVSXWDrm */
  0x1d35, /* VPMOVSXWDrr */
/* Table7167 */
  0x1d3e, /* VPMOVSXWQrm */
  0x1d3f, /* VPMOVSXWQrr */
/* Table7169 */
  0x1d2a, /* VPMOVSXDQrm */
  0x1d2b, /* VPMOVSXDQrr */
/* Table7171 */
  0x1d9a, /* VPMULDQrm */
  0x1d9b, /* VPMULDQrr */
/* Table7173 */
  0x18b9, /* VPCMPEQQrm */
  0x18ba, /* VPCMPEQQrr */
/* Table7175 */
  0x1556, /* VMOVNTDQArm */
  0x0, /*  */
/* Table7177 */
  0x1699, /* VPACKUSDWrm */
  0x169a, /* VPACKUSDWrr */
/* Table7179 */
  0x132e, /* VMASKMOVPSrm */
  0x0, /*  */
/* Table7181 */
  0x132a, /* VMASKMOVPDrm */
  0x0, /*  */
/* Table7183 */
  0x132d, /* VMASKMOVPSmr */
  0x0, /*  */
/* Table7185 */
  0x1329, /* VMASKMOVPDmr */
  0x0, /*  */
/* Table7187 */
  0x1d6f, /* VPMOVZXBWrm */
  0x1d70, /* VPMOVZXBWrr */
/* Table7189 */
  0x1d61, /* VPMOVZXBDrm */
  0x1d62, /* VPMOVZXBDrr */
/* Table7191 */
  0x1d6b, /* VPMOVZXBQrm */
  0x1d6c, /* VPMOVZXBQrr */
/* Table7193 */
  0x1d83, /* VPMOVZXWDrm */
  0x1d84, /* VPMOVZXWDrr */
/* Table7195 */
  0x1d8d, /* VPMOVZXWQrm */
  0x1d8e, /* VPMOVZXWQrr */
/* Table7197 */
  0x1d79, /* VPMOVZXDQrm */
  0x1d7a, /* VPMOVZXDQrr */
/* Table7199 */
  0x190d, /* VPCMPGTQrm */
  0x190e, /* VPCMPGTQrr */
/* Table7201 */
  0x1c12, /* VPMINSBrm */
  0x1c13, /* VPMINSBrr */
/* Table7203 */
  0x1c31, /* VPMINSDrm */
  0x1c32, /* VPMINSDrr */
/* Table7205 */
  0x1cc8, /* VPMINUWrm */
  0x1cc9, /* VPMINUWrr */
/* Table7207 */
  0x1c97, /* VPMINUDrm */
  0x1c98, /* VPMINUDrr */
/* Table7209 */
  0x1b46, /* VPMAXSBrm */
  0x1b47, /* VPMAXSBrr */
/* Table7211 */
  0x1b65, /* VPMAXSDrm */
  0x1b66, /* VPMAXSDrr */
/* Table7213 */
  0x1bfc, /* VPMAXUWrm */
  0x1bfd, /* VPMAXUWrr */
/* Table7215 */
  0x1bcb, /* VPMAXUDrm */
  0x1bcc, /* VPMAXUDrr */
/* Table7217 */
  0x1dc5, /* VPMULLDrm */
  0x1dc6, /* VPMULLDrr */
/* Table7219 */
  0x1adc, /* VPHMINPOSUWrm128 */
  0x1add, /* VPHMINPOSUWrr128 */
/* Table7221 */
  0x1f36, /* VPSRLVDrm */
  0x1f37, /* VPSRLVDrr */
/* Table7223 */
  0x1efa, /* VPSRAVDrm */
  0x1efb, /* VPSRAVDrr */
/* Table7225 */
  0x1ec2, /* VPSLLVDrm */
  0x1ec3, /* VPSLLVDrr */
/* Table7227 */
  0x1815, /* VPBROADCASTDrm */
  0x1816, /* VPBROADCASTDrr */
/* Table7229 */
  0x182c, /* VPBROADCASTQrm */
  0x182d, /* VPBROADCASTQrr */
/* Table7231 */
  0x1804, /* VPBROADCASTBrm */
  0x1805, /* VPBROADCASTBrr */
/* Table7233 */
  0x1839, /* VPBROADCASTWrm */
  0x183a, /* VPBROADCASTWrr */
/* Table7235 */
  0x1b2d, /* VPMASKMOVDrm */
  0x0, /*  */
/* Table7237 */
  0x1b2c, /* VPMASKMOVDmr */
  0x0, /*  */
/* Table7239 */
  0x1aae, /* VPGATHERDDrm */
  0x0, /*  */
/* Table7241 */
  0x1ab4, /* VPGATHERQDrm */
  0x0, /*  */
/* Table7243 */
  0x12eb, /* VGATHERDPSrm */
  0x0, /*  */
/* Table7245 */
  0x12f9, /* VGATHERQPSrm */
  0x0, /*  */
/* Table7247 */
  0xfbc, /* VFMADDSUBPSr132m */
  0xfbe, /* VFMADDSUBPSr132r */
/* Table7249 */
  0x106e, /* VFMSUBADDPSr132m */
  0x1070, /* VFMSUBADDPSr132r */
/* Table7251 */
  0xef8, /* VFMADDPSr132m */
  0xefa, /* VFMADDPSr132r */
/* Table7253 */
  0xf1c, /* VFMADDSSr132m */
  0xf1d, /* VFMADDSSr132r */
/* Table7255 */
  0x1108, /* VFMSUBPSr132m */
  0x110a, /* VFMSUBPSr132r */
/* Table7257 */
  0x112c, /* VFMSUBSSr132m */
  0x112d, /* VFMSUBSSr132r */
/* Table7259 */
  0x11cc, /* VFNMADDPSr132m */
  0x11ce, /* VFNMADDPSr132r */
/* Table7261 */
  0x11f0, /* VFNMADDSSr132m */
  0x11f1, /* VFNMADDSSr132r */
/* Table7263 */
  0x1290, /* VFNMSUBPSr132m */
  0x1292, /* VFNMSUBPSr132r */
/* Table7265 */
  0x12b4, /* VFNMSUBSSr132m */
  0x12b5, /* VFNMSUBSSr132r */
/* Table7267 */
  0xfc0, /* VFMADDSUBPSr213m */
  0xfc2, /* VFMADDSUBPSr213r */
/* Table7269 */
  0x1072, /* VFMSUBADDPSr213m */
  0x1074, /* VFMSUBADDPSr213r */
/* Table7271 */
  0xefc, /* VFMADDPSr213m */
  0xefe, /* VFMADDPSr213r */
/* Table7273 */
  0xf1e, /* VFMADDSSr213m */
  0xf1f, /* VFMADDSSr213r */
/* Table7275 */
  0x110c, /* VFMSUBPSr213m */
  0x110e, /* VFMSUBPSr213r */
/* Table7277 */
  0x112e, /* VFMSUBSSr213m */
  0x112f, /* VFMSUBSSr213r */
/* Table7279 */
  0x11d0, /* VFNMADDPSr213m */
  0x11d2, /* VFNMADDPSr213r */
/* Table7281 */
  0x11f2, /* VFNMADDSSr213m */
  0x11f3, /* VFNMADDSSr213r */
/* Table7283 */
  0x1294, /* VFNMSUBPSr213m */
  0x1296, /* VFNMSUBPSr213r */
/* Table7285 */
  0x12b6, /* VFNMSUBSSr213m */
  0x12b7, /* VFNMSUBSSr213r */
/* Table7287 */
  0xfc4, /* VFMADDSUBPSr231m */
  0xfc6, /* VFMADDSUBPSr231r */
/* Table7289 */
  0x1076, /* VFMSUBADDPSr231m */
  0x1078, /* VFMSUBADDPSr231r */
/* Table7291 */
  0xf00, /* VFMADDPSr231m */
  0xf02, /* VFMADDPSr231r */
/* Table7293 */
  0xf20, /* VFMADDSSr231m */
  0xf21, /* VFMADDSSr231r */
/* Table7295 */
  0x1110, /* VFMSUBPSr231m */
  0x1112, /* VFMSUBPSr231r */
/* Table7297 */
  0x1130, /* VFMSUBSSr231m */
  0x1131, /* VFMSUBSSr231r */
/* Table7299 */
  0x11d4, /* VFNMADDPSr231m */
  0x11d6, /* VFNMADDPSr231r */
/* Table7301 */
  0x11f4, /* VFNMADDSSr231m */
  0x11f5, /* VFNMADDSSr231r */
/* Table7303 */
  0x1298, /* VFNMSUBPSr231m */
  0x129a, /* VFNMSUBPSr231r */
/* Table7305 */
  0x12b8, /* VFNMSUBSSr231m */
  0x12b9, /* VFNMSUBSSr231r */
/* Table7307 */
  0xc3f, /* VAESIMCrm */
  0xc40, /* VAESIMCrr */
/* Table7309 */
  0xc3d, /* VAESENCrm */
  0xc3e, /* VAESENCrr */
/* Table7311 */
  0xc3b, /* VAESENCLASTrm */
  0xc3c, /* VAESENCLASTrr */
/* Table7313 */
  0xc39, /* VAESDECrm */
  0xc3a, /* VAESDECrr */
/* Table7315 */
  0xc37, /* VAESDECLASTrm */
  0xc38, /* VAESDECLASTrr */
/* Table7317 */
  0xa98, /* SHLX32rm */
  0xa99, /* SHLX32rr */
/* Table7319 */
  0xd6, /* ANDN64rm */
  0xd7, /* ANDN64rr */
/* Table7321 */
  0x0, /*  */
  0x11b, /* BLSR64rm */
  0x117, /* BLSMSK64rm */
  0x10f, /* BLSI64rm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x11c, /* BLSR64rr */
  0x118, /* BLSMSK64rr */
  0x110, /* BLSI64rr */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table7337 */
  0x15f, /* BZHI64rm */
  0x160, /* BZHI64rr */
/* Table7339 */
  0xe7, /* BEXTR64rm */
  0xe8, /* BEXTR64rr */
/* Table7341 */
  0x7eb, /* PEXT64rm */
  0x7ec, /* PEXT64rr */
/* Table7343 */
  0xa0a, /* SARX64rm */
  0xa0b, /* SARX64rr */
/* Table7345 */
  0x7e7, /* PDEP64rm */
  0x7e8, /* PDEP64rr */
/* Table7347 */
  0x719, /* MULX64rm */
  0x71a, /* MULX64rr */
/* Table7349 */
  0xac2, /* SHRX64rm */
  0xac3, /* SHRX64rr */
/* Table7351 */
  0x1f40, /* VPSRLVQrm */
  0x1f41, /* VPSRLVQrr */
/* Table7353 */
  0x1ecc, /* VPSLLVQrm */
  0x1ecd, /* VPSLLVQrr */
/* Table7355 */
  0x1b31, /* VPMASKMOVQrm */
  0x0, /*  */
/* Table7357 */
  0x1b30, /* VPMASKMOVQmr */
  0x0, /*  */
/* Table7359 */
  0x1ab1, /* VPGATHERDQrm */
  0x0, /*  */
/* Table7361 */
  0x1ab7, /* VPGATHERQQrm */
  0x0, /*  */
/* Table7363 */
  0x12e8, /* VGATHERDPDrm */
  0x0, /*  */
/* Table7365 */
  0x12f6, /* VGATHERQPDrm */
  0x0, /*  */
/* Table7367 */
  0xf6f, /* VFMADDSUBPDr132m */
  0xf71, /* VFMADDSUBPDr132r */
/* Table7369 */
  0x1021, /* VFMSUBADDPDr132m */
  0x1023, /* VFMSUBADDPDr132r */
/* Table7371 */
  0xeab, /* VFMADDPDr132m */
  0xead, /* VFMADDPDr132r */
/* Table7373 */
  0xf0d, /* VFMADDSDr132m */
  0xf0e, /* VFMADDSDr132r */
/* Table7375 */
  0x10bb, /* VFMSUBPDr132m */
  0x10bd, /* VFMSUBPDr132r */
/* Table7377 */
  0x111d, /* VFMSUBSDr132m */
  0x111e, /* VFMSUBSDr132r */
/* Table7379 */
  0x117f, /* VFNMADDPDr132m */
  0x1181, /* VFNMADDPDr132r */
/* Table7381 */
  0x11e1, /* VFNMADDSDr132m */
  0x11e2, /* VFNMADDSDr132r */
/* Table7383 */
  0x1243, /* VFNMSUBPDr132m */
  0x1245, /* VFNMSUBPDr132r */
/* Table7385 */
  0x12a5, /* VFNMSUBSDr132m */
  0x12a6, /* VFNMSUBSDr132r */
/* Table7387 */
  0xf73, /* VFMADDSUBPDr213m */
  0xf75, /* VFMADDSUBPDr213r */
/* Table7389 */
  0x1025, /* VFMSUBADDPDr213m */
  0x1027, /* VFMSUBADDPDr213r */
/* Table7391 */
  0xeaf, /* VFMADDPDr213m */
  0xeb1, /* VFMADDPDr213r */
/* Table7393 */
  0xf0f, /* VFMADDSDr213m */
  0xf10, /* VFMADDSDr213r */
/* Table7395 */
  0x10bf, /* VFMSUBPDr213m */
  0x10c1, /* VFMSUBPDr213r */
/* Table7397 */
  0x111f, /* VFMSUBSDr213m */
  0x1120, /* VFMSUBSDr213r */
/* Table7399 */
  0x1183, /* VFNMADDPDr213m */
  0x1185, /* VFNMADDPDr213r */
/* Table7401 */
  0x11e3, /* VFNMADDSDr213m */
  0x11e4, /* VFNMADDSDr213r */
/* Table7403 */
  0x1247, /* VFNMSUBPDr213m */
  0x1249, /* VFNMSUBPDr213r */
/* Table7405 */
  0x12a7, /* VFNMSUBSDr213m */
  0x12a8, /* VFNMSUBSDr213r */
/* Table7407 */
  0xf77, /* VFMADDSUBPDr231m */
  0xf79, /* VFMADDSUBPDr231r */
/* Table7409 */
  0x1029, /* VFMSUBADDPDr231m */
  0x102b, /* VFMSUBADDPDr231r */
/* Table7411 */
  0xeb3, /* VFMADDPDr231m */
  0xeb5, /* VFMADDPDr231r */
/* Table7413 */
  0xf11, /* VFMADDSDr231m */
  0xf12, /* VFMADDSDr231r */
/* Table7415 */
  0x10c3, /* VFMSUBPDr231m */
  0x10c5, /* VFMSUBPDr231r */
/* Table7417 */
  0x1121, /* VFMSUBSDr231m */
  0x1122, /* VFMSUBSDr231r */
/* Table7419 */
  0x1187, /* VFNMADDPDr231m */
  0x1189, /* VFNMADDPDr231r */
/* Table7421 */
  0x11e5, /* VFNMADDSDr231m */
  0x11e6, /* VFNMADDSDr231r */
/* Table7423 */
  0x124b, /* VFNMSUBPDr231m */
  0x124d, /* VFNMSUBPDr231r */
/* Table7425 */
  0x12a9, /* VFNMSUBSDr231m */
  0x12aa, /* VFNMSUBSDr231r */
/* Table7427 */
  0xa9a, /* SHLX64rm */
  0xa9b, /* SHLX64rr */
/* Table7429 */
  0x1e76, /* VPSHUFBYrm */
  0x1e77, /* VPSHUFBYrr */
/* Table7431 */
  0x1ad8, /* VPHADDWYrm */
  0x1ad9, /* VPHADDWYrr */
/* Table7433 */
  0x1ac0, /* VPHADDDYrm */
  0x1ac1, /* VPHADDDYrr */
/* Table7435 */
  0x1ac5, /* VPHADDSWrm256 */
  0x1ac7, /* VPHADDSWrr256 */
/* Table7437 */
  0x1b23, /* VPMADDUBSWrm256 */
  0x1b25, /* VPMADDUBSWrr256 */
/* Table7439 */
  0x1aec, /* VPHSUBWYrm */
  0x1aed, /* VPHSUBWYrr */
/* Table7441 */
  0x1ae2, /* VPHSUBDYrm */
  0x1ae3, /* VPHSUBDYrr */
/* Table7443 */
  0x1ae7, /* VPHSUBSWrm256 */
  0x1ae9, /* VPHSUBSWrr256 */
/* Table7445 */
  0x1e88, /* VPSIGNBYrm */
  0x1e89, /* VPSIGNBYrr */
/* Table7447 */
  0x1e90, /* VPSIGNWYrm */
  0x1e91, /* VPSIGNWYrr */
/* Table7449 */
  0x1e8c, /* VPSIGNDYrm */
  0x1e8d, /* VPSIGNDYrr */
/* Table7451 */
  0x1d9d, /* VPMULHRSWrm256 */
  0x1d9f, /* VPMULHRSWrr256 */
/* Table7453 */
  0x1a59, /* VPERMILPSYrm */
  0x1a5a, /* VPERMILPSYrr */
/* Table7455 */
  0x1a4d, /* VPERMILPDYrm */
  0x1a4e, /* VPERMILPDYrr */
/* Table7457 */
  0x21fd, /* VTESTPSYrm */
  0x21fe, /* VTESTPSYrr */
/* Table7459 */
  0x21f9, /* VTESTPDYrm */
  0x21fa, /* VTESTPDYrr */
/* Table7461 */
  0xd29, /* VCVTPH2PSYrm */
  0xd2a, /* VCVTPH2PSYrr */
/* Table7463 */
  0x1a69, /* VPERMPSYrm */
  0x1a6a, /* VPERMPSYrr */
/* Table7465 */
  0x1fca, /* VPTESTYrm */
  0x1fcb, /* VPTESTYrr */
/* Table7467 */
  0xcaf, /* VBROADCASTSSYrm */
  0xcb0, /* VBROADCASTSSYrr */
/* Table7469 */
  0xca1, /* VBROADCASTSDYrm */
  0xca2, /* VBROADCASTSDYrr */
/* Table7471 */
  0xc9c, /* VBROADCASTF128 */
  0x0, /*  */
/* Table7473 */
  0x1672, /* VPABSBrm256 */
  0x1674, /* VPABSBrr256 */
/* Table7475 */
  0x168c, /* VPABSWrm256 */
  0x168e, /* VPABSWrr256 */
/* Table7477 */
  0x167f, /* VPABSDrm256 */
  0x1681, /* VPABSDrr256 */
/* Table7479 */
  0x1d1e, /* VPMOVSXBWYrm */
  0x1d1f, /* VPMOVSXBWYrr */
/* Table7481 */
  0x1d0a, /* VPMOVSXBDYrm */
  0x1d0b, /* VPMOVSXBDYrr */
/* Table7483 */
  0x1d14, /* VPMOVSXBQYrm */
  0x1d15, /* VPMOVSXBQYrr */
/* Table7485 */
  0x1d2c, /* VPMOVSXWDYrm */
  0x1d2d, /* VPMOVSXWDYrr */
/* Table7487 */
  0x1d36, /* VPMOVSXWQYrm */
  0x1d37, /* VPMOVSXWQYrr */
/* Table7489 */
  0x1d22, /* VPMOVSXDQYrm */
  0x1d23, /* VPMOVSXDQYrr */
/* Table7491 */
  0x1d8f, /* VPMULDQYrm */
  0x1d90, /* VPMULDQYrr */
/* Table7493 */
  0x18a5, /* VPCMPEQQYrm */
  0x18a6, /* VPCMPEQQYrr */
/* Table7495 */
  0x1552, /* VMOVNTDQAYrm */
  0x0, /*  */
/* Table7497 */
  0x1697, /* VPACKUSDWYrm */
  0x1698, /* VPACKUSDWYrr */
/* Table7499 */
  0x132c, /* VMASKMOVPSYrm */
  0x0, /*  */
/* Table7501 */
  0x1328, /* VMASKMOVPDYrm */
  0x0, /*  */
/* Table7503 */
  0x132b, /* VMASKMOVPSYmr */
  0x0, /*  */
/* Table7505 */
  0x1327, /* VMASKMOVPDYmr */
  0x0, /*  */
/* Table7507 */
  0x1d6d, /* VPMOVZXBWYrm */
  0x1d6e, /* VPMOVZXBWYrr */
/* Table7509 */
  0x1d59, /* VPMOVZXBDYrm */
  0x1d5a, /* VPMOVZXBDYrr */
/* Table7511 */
  0x1d63, /* VPMOVZXBQYrm */
  0x1d64, /* VPMOVZXBQYrr */
/* Table7513 */
  0x1d7b, /* VPMOVZXWDYrm */
  0x1d7c, /* VPMOVZXWDYrr */
/* Table7515 */
  0x1d85, /* VPMOVZXWQYrm */
  0x1d86, /* VPMOVZXWQYrr */
/* Table7517 */
  0x1d71, /* VPMOVZXDQYrm */
  0x1d72, /* VPMOVZXDQYrr */
/* Table7519 */
  0x1a23, /* VPERMDYrm */
  0x1a24, /* VPERMDYrr */
/* Table7521 */
  0x18f9, /* VPCMPGTQYrm */
  0x18fa, /* VPCMPGTQYrr */
/* Table7523 */
  0x1bfe, /* VPMINSBYrm */
  0x1bff, /* VPMINSBYrr */
/* Table7525 */
  0x1c14, /* VPMINSDYrm */
  0x1c15, /* VPMINSDYrr */
/* Table7527 */
  0x1cb4, /* VPMINUWYrm */
  0x1cb5, /* VPMINUWYrr */
/* Table7529 */
  0x1c7a, /* VPMINUDYrm */
  0x1c7b, /* VPMINUDYrr */
/* Table7531 */
  0x1b32, /* VPMAXSBYrm */
  0x1b33, /* VPMAXSBYrr */
/* Table7533 */
  0x1b48, /* VPMAXSDYrm */
  0x1b49, /* VPMAXSDYrr */
/* Table7535 */
  0x1be8, /* VPMAXUWYrm */
  0x1be9, /* VPMAXUWYrr */
/* Table7537 */
  0x1bae, /* VPMAXUDYrm */
  0x1baf, /* VPMAXUDYrr */
/* Table7539 */
  0x1da8, /* VPMULLDYrm */
  0x1da9, /* VPMULLDYrr */
/* Table7541 */
  0x1f2e, /* VPSRLVDYrm */
  0x1f2f, /* VPSRLVDYrr */
/* Table7543 */
  0x1ef2, /* VPSRAVDYrm */
  0x1ef3, /* VPSRAVDYrr */
/* Table7545 */
  0x1eba, /* VPSLLVDYrm */
  0x1ebb, /* VPSLLVDYrr */
/* Table7547 */
  0x1806, /* VPBROADCASTDYrm */
  0x1807, /* VPBROADCASTDYrr */
/* Table7549 */
  0x181d, /* VPBROADCASTQYrm */
  0x181e, /* VPBROADCASTQYrr */
/* Table7551 */
  0x17f9, /* VPBROADCASTBYrm */
  0x17fa, /* VPBROADCASTBYrr */
/* Table7553 */
  0x182e, /* VPBROADCASTWYrm */
  0x182f, /* VPBROADCASTWYrr */
/* Table7555 */
  0x1b2b, /* VPMASKMOVDYrm */
  0x0, /*  */
/* Table7557 */
  0x1b2a, /* VPMASKMOVDYmr */
  0x0, /*  */
/* Table7559 */
  0x1aac, /* VPGATHERDDYrm */
  0x0, /*  */
/* Table7561 */
  0x1ab2, /* VPGATHERQDYrm */
  0x0, /*  */
/* Table7563 */
  0x12e9, /* VGATHERDPSYrm */
  0x0, /*  */
/* Table7565 */
  0x12f7, /* VGATHERQPSYrm */
  0x0, /*  */
/* Table7567 */
  0xfbd, /* VFMADDSUBPSr132mY */
  0xfbf, /* VFMADDSUBPSr132rY */
/* Table7569 */
  0x106f, /* VFMSUBADDPSr132mY */
  0x1071, /* VFMSUBADDPSr132rY */
/* Table7571 */
  0xef9, /* VFMADDPSr132mY */
  0xefb, /* VFMADDPSr132rY */
/* Table7573 */
  0x1109, /* VFMSUBPSr132mY */
  0x110b, /* VFMSUBPSr132rY */
/* Table7575 */
  0x11cd, /* VFNMADDPSr132mY */
  0x11cf, /* VFNMADDPSr132rY */
/* Table7577 */
  0x1291, /* VFNMSUBPSr132mY */
  0x1293, /* VFNMSUBPSr132rY */
/* Table7579 */
  0xfc1, /* VFMADDSUBPSr213mY */
  0xfc3, /* VFMADDSUBPSr213rY */
/* Table7581 */
  0x1073, /* VFMSUBADDPSr213mY */
  0x1075, /* VFMSUBADDPSr213rY */
/* Table7583 */
  0xefd, /* VFMADDPSr213mY */
  0xeff, /* VFMADDPSr213rY */
/* Table7585 */
  0x110d, /* VFMSUBPSr213mY */
  0x110f, /* VFMSUBPSr213rY */
/* Table7587 */
  0x11d1, /* VFNMADDPSr213mY */
  0x11d3, /* VFNMADDPSr213rY */
/* Table7589 */
  0x1295, /* VFNMSUBPSr213mY */
  0x1297, /* VFNMSUBPSr213rY */
/* Table7591 */
  0xfc5, /* VFMADDSUBPSr231mY */
  0xfc7, /* VFMADDSUBPSr231rY */
/* Table7593 */
  0x1077, /* VFMSUBADDPSr231mY */
  0x1079, /* VFMSUBADDPSr231rY */
/* Table7595 */
  0xf01, /* VFMADDPSr231mY */
  0xf03, /* VFMADDPSr231rY */
/* Table7597 */
  0x1111, /* VFMSUBPSr231mY */
  0x1113, /* VFMSUBPSr231rY */
/* Table7599 */
  0x11d5, /* VFNMADDPSr231mY */
  0x11d7, /* VFNMADDPSr231rY */
/* Table7601 */
  0x1299, /* VFNMSUBPSr231mY */
  0x129b, /* VFNMSUBPSr231rY */
/* Table7603 */
  0x1f38, /* VPSRLVQYrm */
  0x1f39, /* VPSRLVQYrr */
/* Table7605 */
  0x1ec4, /* VPSLLVQYrm */
  0x1ec5, /* VPSLLVQYrr */
/* Table7607 */
  0x1b2f, /* VPMASKMOVQYrm */
  0x0, /*  */
/* Table7609 */
  0x1b2e, /* VPMASKMOVQYmr */
  0x0, /*  */
/* Table7611 */
  0x1aaf, /* VPGATHERDQYrm */
  0x0, /*  */
/* Table7613 */
  0x1ab5, /* VPGATHERQQYrm */
  0x0, /*  */
/* Table7615 */
  0x12e6, /* VGATHERDPDYrm */
  0x0, /*  */
/* Table7617 */
  0x12f4, /* VGATHERQPDYrm */
  0x0, /*  */
/* Table7619 */
  0xf70, /* VFMADDSUBPDr132mY */
  0xf72, /* VFMADDSUBPDr132rY */
/* Table7621 */
  0x1022, /* VFMSUBADDPDr132mY */
  0x1024, /* VFMSUBADDPDr132rY */
/* Table7623 */
  0xeac, /* VFMADDPDr132mY */
  0xeae, /* VFMADDPDr132rY */
/* Table7625 */
  0x10bc, /* VFMSUBPDr132mY */
  0x10be, /* VFMSUBPDr132rY */
/* Table7627 */
  0x1180, /* VFNMADDPDr132mY */
  0x1182, /* VFNMADDPDr132rY */
/* Table7629 */
  0x1244, /* VFNMSUBPDr132mY */
  0x1246, /* VFNMSUBPDr132rY */
/* Table7631 */
  0xf74, /* VFMADDSUBPDr213mY */
  0xf76, /* VFMADDSUBPDr213rY */
/* Table7633 */
  0x1026, /* VFMSUBADDPDr213mY */
  0x1028, /* VFMSUBADDPDr213rY */
/* Table7635 */
  0xeb0, /* VFMADDPDr213mY */
  0xeb2, /* VFMADDPDr213rY */
/* Table7637 */
  0x10c0, /* VFMSUBPDr213mY */
  0x10c2, /* VFMSUBPDr213rY */
/* Table7639 */
  0x1184, /* VFNMADDPDr213mY */
  0x1186, /* VFNMADDPDr213rY */
/* Table7641 */
  0x1248, /* VFNMSUBPDr213mY */
  0x124a, /* VFNMSUBPDr213rY */
/* Table7643 */
  0xf78, /* VFMADDSUBPDr231mY */
  0xf7a, /* VFMADDSUBPDr231rY */
/* Table7645 */
  0x102a, /* VFMSUBADDPDr231mY */
  0x102c, /* VFMSUBADDPDr231rY */
/* Table7647 */
  0xeb4, /* VFMADDPDr231mY */
  0xeb6, /* VFMADDPDr231rY */
/* Table7649 */
  0x10c4, /* VFMSUBPDr231mY */
  0x10c6, /* VFMSUBPDr231rY */
/* Table7651 */
  0x1188, /* VFNMADDPDr231mY */
  0x118a, /* VFNMADDPDr231rY */
/* Table7653 */
  0x124c, /* VFNMSUBPDr231mY */
  0x124e, /* VFNMSUBPDr231rY */
/* Table7655 */
  0x0, /*  */
  0x1cd4, /* VPMOVM2BZ128rr */
/* Table7657 */
  0x0, /*  */
  0x1cd7, /* VPMOVM2DZ128rr */
/* Table7659 */
  0x0, /*  */
  0x181a, /* VPBROADCASTMW2DZ128rr */
/* Table7661 */
  0xcb1, /* VBROADCASTSSZ128m */
  0xcb4, /* VBROADCASTSSZ128r */
/* Table7663 */
  0x1553, /* VMOVNTDQAZ128rm */
  0x0, /*  */
/* Table7665 */
  0x1c00, /* VPMINSBZ128rm */
  0x1c03, /* VPMINSBZ128rr */
/* Table7667 */
  0x1c16, /* VPMINSDZ128rm */
  0x1c1c, /* VPMINSDZ128rr */
/* Table7669 */
  0x1cb6, /* VPMINUWZ128rm */
  0x1cb9, /* VPMINUWZ128rr */
/* Table7671 */
  0x1c7c, /* VPMINUDZ128rm */
  0x1c82, /* VPMINUDZ128rr */
/* Table7673 */
  0x1b34, /* VPMAXSBZ128rm */
  0x1b37, /* VPMAXSBZ128rr */
/* Table7675 */
  0x1b4a, /* VPMAXSDZ128rm */
  0x1b50, /* VPMAXSDZ128rr */
/* Table7677 */
  0x1bea, /* VPMAXUWZ128rm */
  0x1bed, /* VPMAXUWZ128rr */
/* Table7679 */
  0x1bb0, /* VPMAXUDZ128rm */
  0x1bb6, /* VPMAXUDZ128rr */
/* Table7681 */
  0x1daa, /* VPMULLDZ128rm */
  0x1db0, /* VPMULLDZ128rr */
/* Table7683 */
  0x204b, /* VRCP14PSZ128m */
  0x2051, /* VRCP14PSZ128r */
/* Table7685 */
  0x2068, /* VRCP14SSrm */
  0x2069, /* VRCP14SSrr */
/* Table7687 */
  0x20de, /* VRSQRT14PSZ128m */
  0x20e4, /* VRSQRT14PSZ128r */
/* Table7689 */
  0x20fb, /* VRSQRT14SSrm */
  0x20fc, /* VRSQRT14SSrr */
/* Table7691 */
  0x17af, /* VPBLENDMDZ128rm */
  0x17b4, /* VPBLENDMDZ128rr */
/* Table7693 */
  0xc74, /* VBLENDMPSZ128rm */
  0xc79, /* VBLENDMPSZ128rr */
/* Table7695 */
  0x179d, /* VPBLENDMBZ128rm */
  0x17a0, /* VPBLENDMBZ128rr */
/* Table7697 */
  0x0, /*  */
  0x17fb, /* VPBROADCASTBrZ128r */
/* Table7699 */
  0x0, /*  */
  0x1830, /* VPBROADCASTWrZ128r */
/* Table7701 */
  0x0, /*  */
  0x180c, /* VPBROADCASTDrZ128r */
/* Table7703 */
  0xf28, /* VFMADDSUB132PSZ128m */
  0x0, /*  */
/* Table7705 */
  0xfda, /* VFMSUBADD132PSZ128m */
  0x0, /*  */
/* Table7707 */
  0xe64, /* VFMADD132PSZ128m */
  0x0, /*  */
/* Table7709 */
  0xfce, /* VFMSUB132PSZ128m */
  0x0, /*  */
/* Table7711 */
  0x1138, /* VFNMADD132PSZ128m */
  0x0, /*  */
/* Table7713 */
  0x11fc, /* VFNMSUB132PSZ128m */
  0x0, /*  */
/* Table7715 */
  0xf83, /* VFMADDSUBPSZ128v213rm */
  0xf89, /* VFMADDSUBPSZ128v213rr */
/* Table7717 */
  0x1035, /* VFMSUBADDPSZ128v213rm */
  0x103b, /* VFMSUBADDPSZ128v213rr */
/* Table7719 */
  0xebf, /* VFMADDPSZ128v213rm */
  0xec5, /* VFMADDPSZ128v213rr */
/* Table7721 */
  0xf1a, /* VFMADDSSZm */
  0xf1b, /* VFMADDSSZr */
/* Table7723 */
  0x10cf, /* VFMSUBPSZ128v213rm */
  0x10d5, /* VFMSUBPSZ128v213rr */
/* Table7725 */
  0x112a, /* VFMSUBSSZm */
  0x112b, /* VFMSUBSSZr */
/* Table7727 */
  0x1193, /* VFNMADDPSZ128v213rm */
  0x1199, /* VFNMADDPSZ128v213rr */
/* Table7729 */
  0x11ee, /* VFNMADDSSZm */
  0x11ef, /* VFNMADDSSZr */
/* Table7731 */
  0x1257, /* VFNMSUBPSZ128v213rm */
  0x125d, /* VFNMSUBPSZ128v213rr */
/* Table7733 */
  0x12b2, /* VFNMSUBSSZm */
  0x12b3, /* VFNMSUBSSZr */
/* Table7735 */
  0xf8c, /* VFMADDSUBPSZ128v231rm */
  0xf92, /* VFMADDSUBPSZ128v231rr */
/* Table7737 */
  0x103e, /* VFMSUBADDPSZ128v231rm */
  0x1044, /* VFMSUBADDPSZ128v231rr */
/* Table7739 */
  0xec8, /* VFMADDPSZ128v231rm */
  0xece, /* VFMADDPSZ128v231rr */
/* Table7741 */
  0x10d8, /* VFMSUBPSZ128v231rm */
  0x10de, /* VFMSUBPSZ128v231rr */
/* Table7743 */
  0x119c, /* VFNMADDPSZ128v231rm */
  0x11a2, /* VFNMADDPSZ128v231rr */
/* Table7745 */
  0x1260, /* VFNMSUBPSZ128v231rm */
  0x1266, /* VFNMSUBPSZ128v231rr */
/* Table7747 */
  0x208b, /* VRCP28SSm */
  0x208e, /* VRCP28SSr */
/* Table7749 */
  0x211e, /* VRSQRT28SSm */
  0x2121, /* VRSQRT28SSr */
/* Table7751 */
  0x0, /*  */
  0x1cdd, /* VPMOVM2WZ128rr */
/* Table7753 */
  0x0, /*  */
  0x1817, /* VPBROADCASTMB2QZ128rr */
/* Table7755 */
  0x0, /*  */
  0x1cda, /* VPMOVM2QZ128rr */
/* Table7757 */
  0x18a7, /* VPCMPEQQZ128rm */
  0x18ab, /* VPCMPEQQZ128rr */
/* Table7759 */
  0x18fb, /* VPCMPGTQZ128rm */
  0x18ff, /* VPCMPGTQZ128rr */
/* Table7761 */
  0x1c33, /* VPMINSQZ128rm */
  0x1c39, /* VPMINSQZ128rr */
/* Table7763 */
  0x1c99, /* VPMINUQZ128rm */
  0x1c9f, /* VPMINUQZ128rr */
/* Table7765 */
  0x1b67, /* VPMAXSQZ128rm */
  0x1b6d, /* VPMAXSQZ128rr */
/* Table7767 */
  0x1bcd, /* VPMAXUQZ128rm */
  0x1bd3, /* VPMAXUQZ128rr */
/* Table7769 */
  0x1dc7, /* VPMULLQZ128rm */
  0x1dcd, /* VPMULLQZ128rr */
/* Table7771 */
  0x2030, /* VRCP14PDZ128m */
  0x2036, /* VRCP14PDZ128r */
/* Table7773 */
  0x2066, /* VRCP14SDrm */
  0x2067, /* VRCP14SDrr */
/* Table7775 */
  0x20c3, /* VRSQRT14PDZ128m */
  0x20c9, /* VRSQRT14PDZ128r */
/* Table7777 */
  0x20f9, /* VRSQRT14SDrm */
  0x20fa, /* VRSQRT14SDrr */
/* Table7779 */
  0x17c7, /* VPBLENDMQZ128rm */
  0x17cc, /* VPBLENDMQZ128rr */
/* Table7781 */
  0xc5c, /* VBLENDMPDZ128rm */
  0xc61, /* VBLENDMPDZ128rr */
/* Table7783 */
  0x17df, /* VPBLENDMWZ128rm */
  0x17e2, /* VPBLENDMWZ128rr */
/* Table7785 */
  0x0, /*  */
  0x1823, /* VPBROADCASTQrZ128r */
/* Table7787 */
  0xf22, /* VFMADDSUB132PDZ128m */
  0x0, /*  */
/* Table7789 */
  0xfd4, /* VFMSUBADD132PDZ128m */
  0x0, /*  */
/* Table7791 */
  0xe5e, /* VFMADD132PDZ128m */
  0x0, /*  */
/* Table7793 */
  0xfc8, /* VFMSUB132PDZ128m */
  0x0, /*  */
/* Table7795 */
  0x1132, /* VFNMADD132PDZ128m */
  0x0, /*  */
/* Table7797 */
  0x11f6, /* VFNMSUB132PDZ128m */
  0x0, /*  */
/* Table7799 */
  0xf36, /* VFMADDSUBPDZ128v213rm */
  0xf3c, /* VFMADDSUBPDZ128v213rr */
/* Table7801 */
  0xfe8, /* VFMSUBADDPDZ128v213rm */
  0xfee, /* VFMSUBADDPDZ128v213rr */
/* Table7803 */
  0xe72, /* VFMADDPDZ128v213rm */
  0xe78, /* VFMADDPDZ128v213rr */
/* Table7805 */
  0xf0b, /* VFMADDSDZm */
  0xf0c, /* VFMADDSDZr */
/* Table7807 */
  0x1082, /* VFMSUBPDZ128v213rm */
  0x1088, /* VFMSUBPDZ128v213rr */
/* Table7809 */
  0x111b, /* VFMSUBSDZm */
  0x111c, /* VFMSUBSDZr */
/* Table7811 */
  0x1146, /* VFNMADDPDZ128v213rm */
  0x114c, /* VFNMADDPDZ128v213rr */
/* Table7813 */
  0x11df, /* VFNMADDSDZm */
  0x11e0, /* VFNMADDSDZr */
/* Table7815 */
  0x120a, /* VFNMSUBPDZ128v213rm */
  0x1210, /* VFNMSUBPDZ128v213rr */
/* Table7817 */
  0x12a3, /* VFNMSUBSDZm */
  0x12a4, /* VFNMSUBSDZr */
/* Table7819 */
  0xf3f, /* VFMADDSUBPDZ128v231rm */
  0xf45, /* VFMADDSUBPDZ128v231rr */
/* Table7821 */
  0xff1, /* VFMSUBADDPDZ128v231rm */
  0xff7, /* VFMSUBADDPDZ128v231rr */
/* Table7823 */
  0xe7b, /* VFMADDPDZ128v231rm */
  0xe81, /* VFMADDPDZ128v231rr */
/* Table7825 */
  0x108b, /* VFMSUBPDZ128v231rm */
  0x1091, /* VFMSUBPDZ128v231rr */
/* Table7827 */
  0x114f, /* VFNMADDPDZ128v231rm */
  0x1155, /* VFNMADDPDZ128v231rr */
/* Table7829 */
  0x1213, /* VFNMSUBPDZ128v231rm */
  0x1219, /* VFNMSUBPDZ128v231rr */
/* Table7831 */
  0x2082, /* VRCP28SDm */
  0x2085, /* VRCP28SDr */
/* Table7833 */
  0x2115, /* VRSQRT28SDm */
  0x2118, /* VRSQRT28SDr */
/* Table7835 */
  0x0, /*  */
  0x1cd5, /* VPMOVM2BZ256rr */
/* Table7837 */
  0x0, /*  */
  0x1cd8, /* VPMOVM2DZ256rr */
/* Table7839 */
  0x0, /*  */
  0x181b, /* VPBROADCASTMW2DZ256rr */
/* Table7841 */
  0xcb7, /* VBROADCASTSSZ256m */
  0xcba, /* VBROADCASTSSZ256r */
/* Table7843 */
  0x1554, /* VMOVNTDQAZ256rm */
  0x0, /*  */
/* Table7845 */
  0x1c06, /* VPMINSBZ256rm */
  0x1c09, /* VPMINSBZ256rr */
/* Table7847 */
  0x1c1f, /* VPMINSDZ256rm */
  0x1c25, /* VPMINSDZ256rr */
/* Table7849 */
  0x1cbc, /* VPMINUWZ256rm */
  0x1cbf, /* VPMINUWZ256rr */
/* Table7851 */
  0x1c85, /* VPMINUDZ256rm */
  0x1c8b, /* VPMINUDZ256rr */
/* Table7853 */
  0x1b3a, /* VPMAXSBZ256rm */
  0x1b3d, /* VPMAXSBZ256rr */
/* Table7855 */
  0x1b53, /* VPMAXSDZ256rm */
  0x1b59, /* VPMAXSDZ256rr */
/* Table7857 */
  0x1bf0, /* VPMAXUWZ256rm */
  0x1bf3, /* VPMAXUWZ256rr */
/* Table7859 */
  0x1bb9, /* VPMAXUDZ256rm */
  0x1bbf, /* VPMAXUDZ256rr */
/* Table7861 */
  0x1db3, /* VPMULLDZ256rm */
  0x1db9, /* VPMULLDZ256rr */
/* Table7863 */
  0x2054, /* VRCP14PSZ256m */
  0x205a, /* VRCP14PSZ256r */
/* Table7865 */
  0x20e7, /* VRSQRT14PSZ256m */
  0x20ed, /* VRSQRT14PSZ256r */
/* Table7867 */
  0x17b7, /* VPBLENDMDZ256rm */
  0x17bc, /* VPBLENDMDZ256rr */
/* Table7869 */
  0xc7c, /* VBLENDMPSZ256rm */
  0xc81, /* VBLENDMPSZ256rr */
/* Table7871 */
  0x17a3, /* VPBLENDMBZ256rm */
  0x17a6, /* VPBLENDMBZ256rr */
/* Table7873 */
  0x0, /*  */
  0x17fe, /* VPBROADCASTBrZ256r */
/* Table7875 */
  0x0, /*  */
  0x1833, /* VPBROADCASTWrZ256r */
/* Table7877 */
  0x0, /*  */
  0x180f, /* VPBROADCASTDrZ256r */
/* Table7879 */
  0xf2a, /* VFMADDSUB132PSZ256m */
  0x0, /*  */
/* Table7881 */
  0xfdc, /* VFMSUBADD132PSZ256m */
  0x0, /*  */
/* Table7883 */
  0xe66, /* VFMADD132PSZ256m */
  0x0, /*  */
/* Table7885 */
  0xfd0, /* VFMSUB132PSZ256m */
  0x0, /*  */
/* Table7887 */
  0x113a, /* VFNMADD132PSZ256m */
  0x0, /*  */
/* Table7889 */
  0x11fe, /* VFNMSUB132PSZ256m */
  0x0, /*  */
/* Table7891 */
  0xf95, /* VFMADDSUBPSZ256v213rm */
  0xf9b, /* VFMADDSUBPSZ256v213rr */
/* Table7893 */
  0x1047, /* VFMSUBADDPSZ256v213rm */
  0x104d, /* VFMSUBADDPSZ256v213rr */
/* Table7895 */
  0xed1, /* VFMADDPSZ256v213rm */
  0xed7, /* VFMADDPSZ256v213rr */
/* Table7897 */
  0x10e1, /* VFMSUBPSZ256v213rm */
  0x10e7, /* VFMSUBPSZ256v213rr */
/* Table7899 */
  0x11a5, /* VFNMADDPSZ256v213rm */
  0x11ab, /* VFNMADDPSZ256v213rr */
/* Table7901 */
  0x1269, /* VFNMSUBPSZ256v213rm */
  0x126f, /* VFNMSUBPSZ256v213rr */
/* Table7903 */
  0xf9e, /* VFMADDSUBPSZ256v231rm */
  0xfa4, /* VFMADDSUBPSZ256v231rr */
/* Table7905 */
  0x1050, /* VFMSUBADDPSZ256v231rm */
  0x1056, /* VFMSUBADDPSZ256v231rr */
/* Table7907 */
  0xeda, /* VFMADDPSZ256v231rm */
  0xee0, /* VFMADDPSZ256v231rr */
/* Table7909 */
  0x10ea, /* VFMSUBPSZ256v231rm */
  0x10f0, /* VFMSUBPSZ256v231rr */
/* Table7911 */
  0x11ae, /* VFNMADDPSZ256v231rm */
  0x11b4, /* VFNMADDPSZ256v231rr */
/* Table7913 */
  0x1272, /* VFNMSUBPSZ256v231rm */
  0x1278, /* VFNMSUBPSZ256v231rr */
/* Table7915 */
  0x0, /*  */
  0x1cde, /* VPMOVM2WZ256rr */
/* Table7917 */
  0x0, /*  */
  0x1818, /* VPBROADCASTMB2QZ256rr */
/* Table7919 */
  0x0, /*  */
  0x1cdb, /* VPMOVM2QZ256rr */
/* Table7921 */
  0xca3, /* VBROADCASTSDZ256m */
  0xca6, /* VBROADCASTSDZ256r */
/* Table7923 */
  0x18ad, /* VPCMPEQQZ256rm */
  0x18b1, /* VPCMPEQQZ256rr */
/* Table7925 */
  0x1901, /* VPCMPGTQZ256rm */
  0x1905, /* VPCMPGTQZ256rr */
/* Table7927 */
  0x1c3c, /* VPMINSQZ256rm */
  0x1c42, /* VPMINSQZ256rr */
/* Table7929 */
  0x1ca2, /* VPMINUQZ256rm */
  0x1ca8, /* VPMINUQZ256rr */
/* Table7931 */
  0x1b70, /* VPMAXSQZ256rm */
  0x1b76, /* VPMAXSQZ256rr */
/* Table7933 */
  0x1bd6, /* VPMAXUQZ256rm */
  0x1bdc, /* VPMAXUQZ256rr */
/* Table7935 */
  0x1dd0, /* VPMULLQZ256rm */
  0x1dd6, /* VPMULLQZ256rr */
/* Table7937 */
  0x2039, /* VRCP14PDZ256m */
  0x203f, /* VRCP14PDZ256r */
/* Table7939 */
  0x20cc, /* VRSQRT14PDZ256m */
  0x20d2, /* VRSQRT14PDZ256r */
/* Table7941 */
  0x17cf, /* VPBLENDMQZ256rm */
  0x17d4, /* VPBLENDMQZ256rr */
/* Table7943 */
  0xc64, /* VBLENDMPDZ256rm */
  0xc69, /* VBLENDMPDZ256rr */
/* Table7945 */
  0x17e5, /* VPBLENDMWZ256rm */
  0x17e8, /* VPBLENDMWZ256rr */
/* Table7947 */
  0x0, /*  */
  0x1826, /* VPBROADCASTQrZ256r */
/* Table7949 */
  0xf24, /* VFMADDSUB132PDZ256m */
  0x0, /*  */
/* Table7951 */
  0xfd6, /* VFMSUBADD132PDZ256m */
  0x0, /*  */
/* Table7953 */
  0xe60, /* VFMADD132PDZ256m */
  0x0, /*  */
/* Table7955 */
  0xfca, /* VFMSUB132PDZ256m */
  0x0, /*  */
/* Table7957 */
  0x1134, /* VFNMADD132PDZ256m */
  0x0, /*  */
/* Table7959 */
  0x11f8, /* VFNMSUB132PDZ256m */
  0x0, /*  */
/* Table7961 */
  0xf48, /* VFMADDSUBPDZ256v213rm */
  0xf4e, /* VFMADDSUBPDZ256v213rr */
/* Table7963 */
  0xffa, /* VFMSUBADDPDZ256v213rm */
  0x1000, /* VFMSUBADDPDZ256v213rr */
/* Table7965 */
  0xe84, /* VFMADDPDZ256v213rm */
  0xe8a, /* VFMADDPDZ256v213rr */
/* Table7967 */
  0x1094, /* VFMSUBPDZ256v213rm */
  0x109a, /* VFMSUBPDZ256v213rr */
/* Table7969 */
  0x1158, /* VFNMADDPDZ256v213rm */
  0x115e, /* VFNMADDPDZ256v213rr */
/* Table7971 */
  0x121c, /* VFNMSUBPDZ256v213rm */
  0x1222, /* VFNMSUBPDZ256v213rr */
/* Table7973 */
  0xf51, /* VFMADDSUBPDZ256v231rm */
  0xf57, /* VFMADDSUBPDZ256v231rr */
/* Table7975 */
  0x1003, /* VFMSUBADDPDZ256v231rm */
  0x1009, /* VFMSUBADDPDZ256v231rr */
/* Table7977 */
  0xe8d, /* VFMADDPDZ256v231rm */
  0xe93, /* VFMADDPDZ256v231rr */
/* Table7979 */
  0x109d, /* VFMSUBPDZ256v231rm */
  0x10a3, /* VFMSUBPDZ256v231rr */
/* Table7981 */
  0x1161, /* VFNMADDPDZ256v231rm */
  0x1167, /* VFNMADDPDZ256v231rr */
/* Table7983 */
  0x1225, /* VFNMSUBPDZ256v231rm */
  0x122b, /* VFNMSUBPDZ256v231rr */
/* Table7985 */
  0x1d40, /* VPMOVUSDBmr */
  0x1d42, /* VPMOVUSDBrr */
/* Table7987 */
  0x1d4a, /* VPMOVUSQBmr */
  0x1d4c, /* VPMOVUSQBrr */
/* Table7989 */
  0x1d45, /* VPMOVUSDWmr */
  0x1d47, /* VPMOVUSDWrr */
/* Table7991 */
  0x1d54, /* VPMOVUSQWmr */
  0x1d56, /* VPMOVUSQWrr */
/* Table7993 */
  0x1d4f, /* VPMOVUSQDmr */
  0x1d51, /* VPMOVUSQDrr */
/* Table7995 */
  0x1cf1, /* VPMOVSDBmr */
  0x1cf3, /* VPMOVSDBrr */
/* Table7997 */
  0x1cfb, /* VPMOVSQBmr */
  0x1cfd, /* VPMOVSQBrr */
/* Table7999 */
  0x1cf6, /* VPMOVSDWmr */
  0x1cf8, /* VPMOVSDWrr */
/* Table8001 */
  0x1d05, /* VPMOVSQWmr */
  0x1d07, /* VPMOVSQWrr */
/* Table8003 */
  0x1d00, /* VPMOVSQDmr */
  0x1d02, /* VPMOVSQDrr */
/* Table8005 */
  0x1fc6, /* VPTESTNMDZrm */
  0x1fc7, /* VPTESTNMDZrr */
/* Table8007 */
  0x0, /*  */
  0x1cd6, /* VPMOVM2BZrr */
/* Table8009 */
  0x1cca, /* VPMOVDBmr */
  0x1ccc, /* VPMOVDBrr */
/* Table8011 */
  0x1ce2, /* VPMOVQBmr */
  0x1ce4, /* VPMOVQBrr */
/* Table8013 */
  0x1ccf, /* VPMOVDWmr */
  0x1cd1, /* VPMOVDWrr */
/* Table8015 */
  0x1cec, /* VPMOVQWmr */
  0x1cee, /* VPMOVQWrr */
/* Table8017 */
  0x1ce7, /* VPMOVQDmr */
  0x1ce9, /* VPMOVQDrr */
/* Table8019 */
  0x0, /*  */
  0x1cd9, /* VPMOVM2DZrr */
/* Table8021 */
  0x0, /*  */
  0x181c, /* VPBROADCASTMW2DZrr */
/* Table8023 */
  0x1a5d, /* VPERMILPSZrm */
  0x1a5e, /* VPERMILPSZrr */
/* Table8025 */
  0xd2b, /* VCVTPH2PSZrm */
  0xd2c, /* VCVTPH2PSZrr */
/* Table8027 */
  0x1a6b, /* VPERMPSZrm */
  0x1a6c, /* VPERMPSZrr */
/* Table8029 */
  0xcbd, /* VBROADCASTSSZm */
  0xcc0, /* VBROADCASTSSZr */
/* Table8031 */
  0x1675, /* VPABSDZrm */
  0x167b, /* VPABSDZrr */
/* Table8033 */
  0x1d0c, /* VPMOVSXBDZrm */
  0x1d0f, /* VPMOVSXBDZrr */
/* Table8035 */
  0x1d16, /* VPMOVSXBQZrm */
  0x1d19, /* VPMOVSXBQZrr */
/* Table8037 */
  0x1d2e, /* VPMOVSXWDZrm */
  0x1d31, /* VPMOVSXWDZrr */
/* Table8039 */
  0x1d38, /* VPMOVSXWQZrm */
  0x1d3b, /* VPMOVSXWQZrr */
/* Table8041 */
  0x1d24, /* VPMOVSXDQZrm */
  0x1d27, /* VPMOVSXDQZrr */
/* Table8043 */
  0x1fc2, /* VPTESTMDZrm */
  0x1fc3, /* VPTESTMDZrr */
/* Table8045 */
  0x1555, /* VMOVNTDQAZrm */
  0x0, /*  */
/* Table8047 */
  0x1d5b, /* VPMOVZXBDZrm */
  0x1d5e, /* VPMOVZXBDZrr */
/* Table8049 */
  0x1d65, /* VPMOVZXBQZrm */
  0x1d68, /* VPMOVZXBQZrr */
/* Table8051 */
  0x1d7d, /* VPMOVZXWDZrm */
  0x1d80, /* VPMOVZXWDZrr */
/* Table8053 */
  0x1d87, /* VPMOVZXWQZrm */
  0x1d8a, /* VPMOVZXWQZrr */
/* Table8055 */
  0x1d73, /* VPMOVZXDQZrm */
  0x1d76, /* VPMOVZXDQZrr */
/* Table8057 */
  0x1a25, /* VPERMDZrm */
  0x1a26, /* VPERMDZrr */
/* Table8059 */
  0x1c0c, /* VPMINSBZrm */
  0x1c0f, /* VPMINSBZrr */
/* Table8061 */
  0x1c28, /* VPMINSDZrm */
  0x1c2e, /* VPMINSDZrr */
/* Table8063 */
  0x1cc2, /* VPMINUWZrm */
  0x1cc5, /* VPMINUWZrr */
/* Table8065 */
  0x1c8e, /* VPMINUDZrm */
  0x1c94, /* VPMINUDZrr */
/* Table8067 */
  0x1b40, /* VPMAXSBZrm */
  0x1b43, /* VPMAXSBZrr */
/* Table8069 */
  0x1b5c, /* VPMAXSDZrm */
  0x1b62, /* VPMAXSDZrr */
/* Table8071 */
  0x1bf6, /* VPMAXUWZrm */
  0x1bf9, /* VPMAXUWZrr */
/* Table8073 */
  0x1bc2, /* VPMAXUDZrm */
  0x1bc8, /* VPMAXUDZrr */
/* Table8075 */
  0x1dbc, /* VPMULLDZrm */
  0x1dc2, /* VPMULLDZrr */
/* Table8077 */
  0x1af8, /* VPLZCNTDrm */
  0x1afe, /* VPLZCNTDrr */
/* Table8079 */
  0x1f30, /* VPSRLVDZrm */
  0x1f33, /* VPSRLVDZrr */
/* Table8081 */
  0x1ef4, /* VPSRAVDZrm */
  0x1ef7, /* VPSRAVDZrr */
/* Table8083 */
  0x1ebc, /* VPSLLVDZrm */
  0x1ebf, /* VPSLLVDZrr */
/* Table8085 */
  0x205d, /* VRCP14PSZm */
  0x2063, /* VRCP14PSZr */
/* Table8087 */
  0x20f0, /* VRSQRT14PSZm */
  0x20f6, /* VRSQRT14PSZr */
/* Table8089 */
  0x180a, /* VPBROADCASTDZrm */
  0x180b, /* VPBROADCASTDZrr */
/* Table8091 */
  0xc9e, /* VBROADCASTI32X4rm */
  0x0, /*  */
/* Table8093 */
  0x17bf, /* VPBLENDMDZrm */
  0x17c4, /* VPBLENDMDZrr */
/* Table8095 */
  0xc84, /* VBLENDMPSZrm */
  0xc89, /* VBLENDMPSZrr */
/* Table8097 */
  0x17a9, /* VPBLENDMBZrm */
  0x17ac, /* VPBLENDMBZrr */
/* Table8099 */
  0x1a27, /* VPERMI2Drm */
  0x1a2a, /* VPERMI2Drr */
/* Table8101 */
  0x1a33, /* VPERMI2PSrm */
  0x1a36, /* VPERMI2PSrr */
/* Table8103 */
  0x0, /*  */
  0x1801, /* VPBROADCASTBrZr */
/* Table8105 */
  0x0, /*  */
  0x1836, /* VPBROADCASTWrZr */
/* Table8107 */
  0x0, /*  */
  0x1812, /* VPBROADCASTDrZr */
/* Table8109 */
  0x1a73, /* VPERMT2Drm */
  0x1a76, /* VPERMT2Drr */
/* Table8111 */
  0x1a7f, /* VPERMT2PSrm */
  0x1a82, /* VPERMT2PSrr */
/* Table8113 */
  0xf2c, /* VFMADDSUB132PSZm */
  0x0, /*  */
/* Table8115 */
  0xfde, /* VFMSUBADD132PSZm */
  0x0, /*  */
/* Table8117 */
  0xe68, /* VFMADD132PSZm */
  0x0, /*  */
/* Table8119 */
  0xfd2, /* VFMSUB132PSZm */
  0x0, /*  */
/* Table8121 */
  0x113c, /* VFNMADD132PSZm */
  0x0, /*  */
/* Table8123 */
  0x1200, /* VFNMSUB132PSZm */
  0x0, /*  */
/* Table8125 */
  0xfa7, /* VFMADDSUBPSZv213rm */
  0xfad, /* VFMADDSUBPSZv213rr */
/* Table8127 */
  0x1059, /* VFMSUBADDPSZv213rm */
  0x105f, /* VFMSUBADDPSZv213rr */
/* Table8129 */
  0xee3, /* VFMADDPSZv213rm */
  0xee9, /* VFMADDPSZv213rr */
/* Table8131 */
  0x10f3, /* VFMSUBPSZv213rm */
  0x10f9, /* VFMSUBPSZv213rr */
/* Table8133 */
  0x11b7, /* VFNMADDPSZv213rm */
  0x11bd, /* VFNMADDPSZv213rr */
/* Table8135 */
  0x127b, /* VFNMSUBPSZv213rm */
  0x1281, /* VFNMSUBPSZv213rr */
/* Table8137 */
  0xfb3, /* VFMADDSUBPSZv231rm */
  0xfb9, /* VFMADDSUBPSZv231rr */
/* Table8139 */
  0x1065, /* VFMSUBADDPSZv231rm */
  0x106b, /* VFMSUBADDPSZv231rr */
/* Table8141 */
  0xeef, /* VFMADDPSZv231rm */
  0xef5, /* VFMADDPSZv231rr */
/* Table8143 */
  0x10ff, /* VFMSUBPSZv231rm */
  0x1105, /* VFMSUBPSZv231rr */
/* Table8145 */
  0x11c3, /* VFNMADDPSZv231rm */
  0x11c9, /* VFNMADDPSZv231rr */
/* Table8147 */
  0x1287, /* VFNMSUBPSZv231rm */
  0x128d, /* VFNMSUBPSZv231rr */
/* Table8149 */
  0x1a0d, /* VPCONFLICTDrm */
  0x1a13, /* VPCONFLICTDrr */
/* Table8151 */
  0xe22, /* VEXP2PSm */
  0xe28, /* VEXP2PSr */
/* Table8153 */
  0x2076, /* VRCP28PSm */
  0x207c, /* VRCP28PSr */
/* Table8155 */
  0x2109, /* VRSQRT28PSm */
  0x210f, /* VRSQRT28PSr */
/* Table8157 */
  0x1fc8, /* VPTESTNMQZrm */
  0x1fc9, /* VPTESTNMQZrr */
/* Table8159 */
  0x0, /*  */
  0x1cdf, /* VPMOVM2WZrr */
/* Table8161 */
  0x0, /*  */
  0x1819, /* VPBROADCASTMB2QZrr */
/* Table8163 */
  0x0, /*  */
  0x1cdc, /* VPMOVM2QZrr */
/* Table8165 */
  0x1a51, /* VPERMILPDZrm */
  0x1a52, /* VPERMILPDZrr */
/* Table8167 */
  0x1a67, /* VPERMPDZrm */
  0x1a68, /* VPERMPDZrr */
/* Table8169 */
  0xca9, /* VBROADCASTSDZm */
  0xcac, /* VBROADCASTSDZr */
/* Table8171 */
  0x1682, /* VPABSQZrm */
  0x1688, /* VPABSQZrr */
/* Table8173 */
  0x1fc4, /* VPTESTMQZrm */
  0x1fc5, /* VPTESTMQZrr */
/* Table8175 */
  0x1d91, /* VPMULDQZrm */
  0x1d97, /* VPMULDQZrr */
/* Table8177 */
  0x18b3, /* VPCMPEQQZrm */
  0x18b7, /* VPCMPEQQZrr */
/* Table8179 */
  0x1a71, /* VPERMQZrm */
  0x1a72, /* VPERMQZrr */
/* Table8181 */
  0x1907, /* VPCMPGTQZrm */
  0x190b, /* VPCMPGTQZrr */
/* Table8183 */
  0x1c45, /* VPMINSQZrm */
  0x1c4b, /* VPMINSQZrr */
/* Table8185 */
  0x1cab, /* VPMINUQZrm */
  0x1cb1, /* VPMINUQZrr */
/* Table8187 */
  0x1b79, /* VPMAXSQZrm */
  0x1b7f, /* VPMAXSQZrr */
/* Table8189 */
  0x1bdf, /* VPMAXUQZrm */
  0x1be5, /* VPMAXUQZrr */
/* Table8191 */
  0x1dd9, /* VPMULLQZrm */
  0x1ddf, /* VPMULLQZrr */
/* Table8193 */
  0x1b01, /* VPLZCNTQrm */
  0x1b07, /* VPLZCNTQrr */
/* Table8195 */
  0x1f3a, /* VPSRLVQZrm */
  0x1f3d, /* VPSRLVQZrr */
/* Table8197 */
  0x1efc, /* VPSRAVQZrm */
  0x1eff, /* VPSRAVQZrr */
/* Table8199 */
  0x1ec6, /* VPSLLVQZrm */
  0x1ec9, /* VPSLLVQZrr */
/* Table8201 */
  0x2042, /* VRCP14PDZm */
  0x2048, /* VRCP14PDZr */
/* Table8203 */
  0x20d5, /* VRSQRT14PDZm */
  0x20db, /* VRSQRT14PDZr */
/* Table8205 */
  0x1821, /* VPBROADCASTQZrm */
  0x1822, /* VPBROADCASTQZrr */
/* Table8207 */
  0xca0, /* VBROADCASTI64X4rm */
  0x0, /*  */
/* Table8209 */
  0x17d7, /* VPBLENDMQZrm */
  0x17dc, /* VPBLENDMQZrr */
/* Table8211 */
  0xc6c, /* VBLENDMPDZrm */
  0xc71, /* VBLENDMPDZrr */
/* Table8213 */
  0x17eb, /* VPBLENDMWZrm */
  0x17ee, /* VPBLENDMWZrr */
/* Table8215 */
  0x1a39, /* VPERMI2Qrm */
  0x1a3c, /* VPERMI2Qrr */
/* Table8217 */
  0x1a2d, /* VPERMI2PDrm */
  0x1a30, /* VPERMI2PDrr */
/* Table8219 */
  0x0, /*  */
  0x1829, /* VPBROADCASTQrZr */
/* Table8221 */
  0x1a85, /* VPERMT2Qrm */
  0x1a88, /* VPERMT2Qrr */
/* Table8223 */
  0x1a79, /* VPERMT2PDrm */
  0x1a7c, /* VPERMT2PDrr */
/* Table8225 */
  0xf26, /* VFMADDSUB132PDZm */
  0x0, /*  */
/* Table8227 */
  0xfd8, /* VFMSUBADD132PDZm */
  0x0, /*  */
/* Table8229 */
  0xe62, /* VFMADD132PDZm */
  0x0, /*  */
/* Table8231 */
  0xfcc, /* VFMSUB132PDZm */
  0x0, /*  */
/* Table8233 */
  0x1136, /* VFNMADD132PDZm */
  0x0, /*  */
/* Table8235 */
  0x11fa, /* VFNMSUB132PDZm */
  0x0, /*  */
/* Table8237 */
  0xf5a, /* VFMADDSUBPDZv213rm */
  0xf60, /* VFMADDSUBPDZv213rr */
/* Table8239 */
  0x100c, /* VFMSUBADDPDZv213rm */
  0x1012, /* VFMSUBADDPDZv213rr */
/* Table8241 */
  0xe96, /* VFMADDPDZv213rm */
  0xe9c, /* VFMADDPDZv213rr */
/* Table8243 */
  0x10a6, /* VFMSUBPDZv213rm */
  0x10ac, /* VFMSUBPDZv213rr */
/* Table8245 */
  0x116a, /* VFNMADDPDZv213rm */
  0x1170, /* VFNMADDPDZv213rr */
/* Table8247 */
  0x122e, /* VFNMSUBPDZv213rm */
  0x1234, /* VFNMSUBPDZv213rr */
/* Table8249 */
  0xf66, /* VFMADDSUBPDZv231rm */
  0xf6c, /* VFMADDSUBPDZv231rr */
/* Table8251 */
  0x1018, /* VFMSUBADDPDZv231rm */
  0x101e, /* VFMSUBADDPDZv231rr */
/* Table8253 */
  0xea2, /* VFMADDPDZv231rm */
  0xea8, /* VFMADDPDZv231rr */
/* Table8255 */
  0x10b2, /* VFMSUBPDZv231rm */
  0x10b8, /* VFMSUBPDZv231rr */
/* Table8257 */
  0x1176, /* VFNMADDPDZv231rm */
  0x117c, /* VFNMADDPDZv231rr */
/* Table8259 */
  0x123a, /* VFNMSUBPDZv231rm */
  0x1240, /* VFNMSUBPDZv231rr */
/* Table8261 */
  0x1a16, /* VPCONFLICTQrm */
  0x1a1c, /* VPCONFLICTQrr */
/* Table8263 */
  0xe16, /* VEXP2PDm */
  0xe1c, /* VEXP2PDr */
/* Table8265 */
  0x206a, /* VRCP28PDm */
  0x2070, /* VRCP28PDr */
/* Table8267 */
  0x20fd, /* VRSQRT28PDm */
  0x2103, /* VRSQRT28PDr */
/* Table8269 */
  0xcb2, /* VBROADCASTSSZ128mk */
  0xcb5, /* VBROADCASTSSZ128rk */
/* Table8271 */
  0x1c01, /* VPMINSBZ128rmk */
  0x1c04, /* VPMINSBZ128rrk */
/* Table8273 */
  0x1c1a, /* VPMINSDZ128rmk */
  0x1c1d, /* VPMINSDZ128rrk */
/* Table8275 */
  0x1cb7, /* VPMINUWZ128rmk */
  0x1cba, /* VPMINUWZ128rrk */
/* Table8277 */
  0x1c80, /* VPMINUDZ128rmk */
  0x1c83, /* VPMINUDZ128rrk */
/* Table8279 */
  0x1b35, /* VPMAXSBZ128rmk */
  0x1b38, /* VPMAXSBZ128rrk */
/* Table8281 */
  0x1b4e, /* VPMAXSDZ128rmk */
  0x1b51, /* VPMAXSDZ128rrk */
/* Table8283 */
  0x1beb, /* VPMAXUWZ128rmk */
  0x1bee, /* VPMAXUWZ128rrk */
/* Table8285 */
  0x1bb4, /* VPMAXUDZ128rmk */
  0x1bb7, /* VPMAXUDZ128rrk */
/* Table8287 */
  0x1dae, /* VPMULLDZ128rmk */
  0x1db1, /* VPMULLDZ128rrk */
/* Table8289 */
  0x204f, /* VRCP14PSZ128mk */
  0x2052, /* VRCP14PSZ128rk */
/* Table8291 */
  0x20e2, /* VRSQRT14PSZ128mk */
  0x20e5, /* VRSQRT14PSZ128rk */
/* Table8293 */
  0x17b2, /* VPBLENDMDZ128rmk */
  0x17b5, /* VPBLENDMDZ128rrk */
/* Table8295 */
  0xc77, /* VBLENDMPSZ128rmk */
  0xc7a, /* VBLENDMPSZ128rrk */
/* Table8297 */
  0x179e, /* VPBLENDMBZ128rmk */
  0x17a1, /* VPBLENDMBZ128rrk */
/* Table8299 */
  0x0, /*  */
  0x17fc, /* VPBROADCASTBrZ128rk */
/* Table8301 */
  0x0, /*  */
  0x1831, /* VPBROADCASTWrZ128rk */
/* Table8303 */
  0x0, /*  */
  0x180d, /* VPBROADCASTDrZ128rk */
/* Table8305 */
  0xe3a, /* VEXPANDPSZ128rmk */
  0xe3c, /* VEXPANDPSZ128rrk */
/* Table8307 */
  0x1a8b, /* VPEXPANDDZ128rmk */
  0x1a8d, /* VPEXPANDDZ128rrk */
/* Table8309 */
  0xd02, /* VCOMPRESSPSZ128mrk */
  0xd03, /* VCOMPRESSPSZ128rrk */
/* Table8311 */
  0x19e3, /* VPCOMPRESSDZ128mrk */
  0x19e4, /* VPCOMPRESSDZ128rrk */
/* Table8313 */
  0xf87, /* VFMADDSUBPSZ128v213rmk */
  0xf8a, /* VFMADDSUBPSZ128v213rrk */
/* Table8315 */
  0x1039, /* VFMSUBADDPSZ128v213rmk */
  0x103c, /* VFMSUBADDPSZ128v213rrk */
/* Table8317 */
  0xec3, /* VFMADDPSZ128v213rmk */
  0xec6, /* VFMADDPSZ128v213rrk */
/* Table8319 */
  0x10d3, /* VFMSUBPSZ128v213rmk */
  0x10d6, /* VFMSUBPSZ128v213rrk */
/* Table8321 */
  0x1197, /* VFNMADDPSZ128v213rmk */
  0x119a, /* VFNMADDPSZ128v213rrk */
/* Table8323 */
  0x125b, /* VFNMSUBPSZ128v213rmk */
  0x125e, /* VFNMSUBPSZ128v213rrk */
/* Table8325 */
  0xf90, /* VFMADDSUBPSZ128v231rmk */
  0xf93, /* VFMADDSUBPSZ128v231rrk */
/* Table8327 */
  0x1042, /* VFMSUBADDPSZ128v231rmk */
  0x1045, /* VFMSUBADDPSZ128v231rrk */
/* Table8329 */
  0xecc, /* VFMADDPSZ128v231rmk */
  0xecf, /* VFMADDPSZ128v231rrk */
/* Table8331 */
  0x10dc, /* VFMSUBPSZ128v231rmk */
  0x10df, /* VFMSUBPSZ128v231rrk */
/* Table8333 */
  0x11a0, /* VFNMADDPSZ128v231rmk */
  0x11a3, /* VFNMADDPSZ128v231rrk */
/* Table8335 */
  0x1264, /* VFNMSUBPSZ128v231rmk */
  0x1267, /* VFNMSUBPSZ128v231rrk */
/* Table8337 */
  0x208c, /* VRCP28SSmk */
  0x2092, /* VRCP28SSrk */
/* Table8339 */
  0x211f, /* VRSQRT28SSmk */
  0x2125, /* VRSQRT28SSrk */
/* Table8341 */
  0x18aa, /* VPCMPEQQZ128rmk */
  0x18ac, /* VPCMPEQQZ128rrk */
/* Table8343 */
  0x18fe, /* VPCMPGTQZ128rmk */
  0x1900, /* VPCMPGTQZ128rrk */
/* Table8345 */
  0x1c37, /* VPMINSQZ128rmk */
  0x1c3a, /* VPMINSQZ128rrk */
/* Table8347 */
  0x1c9d, /* VPMINUQZ128rmk */
  0x1ca0, /* VPMINUQZ128rrk */
/* Table8349 */
  0x1b6b, /* VPMAXSQZ128rmk */
  0x1b6e, /* VPMAXSQZ128rrk */
/* Table8351 */
  0x1bd1, /* VPMAXUQZ128rmk */
  0x1bd4, /* VPMAXUQZ128rrk */
/* Table8353 */
  0x1dcb, /* VPMULLQZ128rmk */
  0x1dce, /* VPMULLQZ128rrk */
/* Table8355 */
  0x2034, /* VRCP14PDZ128mk */
  0x2037, /* VRCP14PDZ128rk */
/* Table8357 */
  0x20c7, /* VRSQRT14PDZ128mk */
  0x20ca, /* VRSQRT14PDZ128rk */
/* Table8359 */
  0x17ca, /* VPBLENDMQZ128rmk */
  0x17cd, /* VPBLENDMQZ128rrk */
/* Table8361 */
  0xc5f, /* VBLENDMPDZ128rmk */
  0xc62, /* VBLENDMPDZ128rrk */
/* Table8363 */
  0x17e0, /* VPBLENDMWZ128rmk */
  0x17e3, /* VPBLENDMWZ128rrk */
/* Table8365 */
  0x0, /*  */
  0x1824, /* VPBROADCASTQrZ128rk */
/* Table8367 */
  0xe2e, /* VEXPANDPDZ128rmk */
  0xe30, /* VEXPANDPDZ128rrk */
/* Table8369 */
  0x1a97, /* VPEXPANDQZ128rmk */
  0x1a99, /* VPEXPANDQZ128rrk */
/* Table8371 */
  0xcf9, /* VCOMPRESSPDZ128mrk */
  0xcfa, /* VCOMPRESSPDZ128rrk */
/* Table8373 */
  0x19ec, /* VPCOMPRESSQZ128mrk */
  0x19ed, /* VPCOMPRESSQZ128rrk */
/* Table8375 */
  0xf3a, /* VFMADDSUBPDZ128v213rmk */
  0xf3d, /* VFMADDSUBPDZ128v213rrk */
/* Table8377 */
  0xfec, /* VFMSUBADDPDZ128v213rmk */
  0xfef, /* VFMSUBADDPDZ128v213rrk */
/* Table8379 */
  0xe76, /* VFMADDPDZ128v213rmk */
  0xe79, /* VFMADDPDZ128v213rrk */
/* Table8381 */
  0x1086, /* VFMSUBPDZ128v213rmk */
  0x1089, /* VFMSUBPDZ128v213rrk */
/* Table8383 */
  0x114a, /* VFNMADDPDZ128v213rmk */
  0x114d, /* VFNMADDPDZ128v213rrk */
/* Table8385 */
  0x120e, /* VFNMSUBPDZ128v213rmk */
  0x1211, /* VFNMSUBPDZ128v213rrk */
/* Table8387 */
  0xf43, /* VFMADDSUBPDZ128v231rmk */
  0xf46, /* VFMADDSUBPDZ128v231rrk */
/* Table8389 */
  0xff5, /* VFMSUBADDPDZ128v231rmk */
  0xff8, /* VFMSUBADDPDZ128v231rrk */
/* Table8391 */
  0xe7f, /* VFMADDPDZ128v231rmk */
  0xe82, /* VFMADDPDZ128v231rrk */
/* Table8393 */
  0x108f, /* VFMSUBPDZ128v231rmk */
  0x1092, /* VFMSUBPDZ128v231rrk */
/* Table8395 */
  0x1153, /* VFNMADDPDZ128v231rmk */
  0x1156, /* VFNMADDPDZ128v231rrk */
/* Table8397 */
  0x1217, /* VFNMSUBPDZ128v231rmk */
  0x121a, /* VFNMSUBPDZ128v231rrk */
/* Table8399 */
  0x2083, /* VRCP28SDmk */
  0x2089, /* VRCP28SDrk */
/* Table8401 */
  0x2116, /* VRSQRT28SDmk */
  0x211c, /* VRSQRT28SDrk */
/* Table8403 */
  0xcb8, /* VBROADCASTSSZ256mk */
  0xcbb, /* VBROADCASTSSZ256rk */
/* Table8405 */
  0x1c07, /* VPMINSBZ256rmk */
  0x1c0a, /* VPMINSBZ256rrk */
/* Table8407 */
  0x1c23, /* VPMINSDZ256rmk */
  0x1c26, /* VPMINSDZ256rrk */
/* Table8409 */
  0x1cbd, /* VPMINUWZ256rmk */
  0x1cc0, /* VPMINUWZ256rrk */
/* Table8411 */
  0x1c89, /* VPMINUDZ256rmk */
  0x1c8c, /* VPMINUDZ256rrk */
/* Table8413 */
  0x1b3b, /* VPMAXSBZ256rmk */
  0x1b3e, /* VPMAXSBZ256rrk */
/* Table8415 */
  0x1b57, /* VPMAXSDZ256rmk */
  0x1b5a, /* VPMAXSDZ256rrk */
/* Table8417 */
  0x1bf1, /* VPMAXUWZ256rmk */
  0x1bf4, /* VPMAXUWZ256rrk */
/* Table8419 */
  0x1bbd, /* VPMAXUDZ256rmk */
  0x1bc0, /* VPMAXUDZ256rrk */
/* Table8421 */
  0x1db7, /* VPMULLDZ256rmk */
  0x1dba, /* VPMULLDZ256rrk */
/* Table8423 */
  0x2058, /* VRCP14PSZ256mk */
  0x205b, /* VRCP14PSZ256rk */
/* Table8425 */
  0x20eb, /* VRSQRT14PSZ256mk */
  0x20ee, /* VRSQRT14PSZ256rk */
/* Table8427 */
  0x17ba, /* VPBLENDMDZ256rmk */
  0x17bd, /* VPBLENDMDZ256rrk */
/* Table8429 */
  0xc7f, /* VBLENDMPSZ256rmk */
  0xc82, /* VBLENDMPSZ256rrk */
/* Table8431 */
  0x17a4, /* VPBLENDMBZ256rmk */
  0x17a7, /* VPBLENDMBZ256rrk */
/* Table8433 */
  0x0, /*  */
  0x17ff, /* VPBROADCASTBrZ256rk */
/* Table8435 */
  0x0, /*  */
  0x1834, /* VPBROADCASTWrZ256rk */
/* Table8437 */
  0x0, /*  */
  0x1810, /* VPBROADCASTDrZ256rk */
/* Table8439 */
  0xe3e, /* VEXPANDPSZ256rmk */
  0xe40, /* VEXPANDPSZ256rrk */
/* Table8441 */
  0x1a8f, /* VPEXPANDDZ256rmk */
  0x1a91, /* VPEXPANDDZ256rrk */
/* Table8443 */
  0xd05, /* VCOMPRESSPSZ256mrk */
  0xd06, /* VCOMPRESSPSZ256rrk */
/* Table8445 */
  0x19e6, /* VPCOMPRESSDZ256mrk */
  0x19e7, /* VPCOMPRESSDZ256rrk */
/* Table8447 */
  0xf99, /* VFMADDSUBPSZ256v213rmk */
  0xf9c, /* VFMADDSUBPSZ256v213rrk */
/* Table8449 */
  0x104b, /* VFMSUBADDPSZ256v213rmk */
  0x104e, /* VFMSUBADDPSZ256v213rrk */
/* Table8451 */
  0xed5, /* VFMADDPSZ256v213rmk */
  0xed8, /* VFMADDPSZ256v213rrk */
/* Table8453 */
  0x10e5, /* VFMSUBPSZ256v213rmk */
  0x10e8, /* VFMSUBPSZ256v213rrk */
/* Table8455 */
  0x11a9, /* VFNMADDPSZ256v213rmk */
  0x11ac, /* VFNMADDPSZ256v213rrk */
/* Table8457 */
  0x126d, /* VFNMSUBPSZ256v213rmk */
  0x1270, /* VFNMSUBPSZ256v213rrk */
/* Table8459 */
  0xfa2, /* VFMADDSUBPSZ256v231rmk */
  0xfa5, /* VFMADDSUBPSZ256v231rrk */
/* Table8461 */
  0x1054, /* VFMSUBADDPSZ256v231rmk */
  0x1057, /* VFMSUBADDPSZ256v231rrk */
/* Table8463 */
  0xede, /* VFMADDPSZ256v231rmk */
  0xee1, /* VFMADDPSZ256v231rrk */
/* Table8465 */
  0x10ee, /* VFMSUBPSZ256v231rmk */
  0x10f1, /* VFMSUBPSZ256v231rrk */
/* Table8467 */
  0x11b2, /* VFNMADDPSZ256v231rmk */
  0x11b5, /* VFNMADDPSZ256v231rrk */
/* Table8469 */
  0x1276, /* VFNMSUBPSZ256v231rmk */
  0x1279, /* VFNMSUBPSZ256v231rrk */
/* Table8471 */
  0xca4, /* VBROADCASTSDZ256mk */
  0xca7, /* VBROADCASTSDZ256rk */
/* Table8473 */
  0x18b0, /* VPCMPEQQZ256rmk */
  0x18b2, /* VPCMPEQQZ256rrk */
/* Table8475 */
  0x1904, /* VPCMPGTQZ256rmk */
  0x1906, /* VPCMPGTQZ256rrk */
/* Table8477 */
  0x1c40, /* VPMINSQZ256rmk */
  0x1c43, /* VPMINSQZ256rrk */
/* Table8479 */
  0x1ca6, /* VPMINUQZ256rmk */
  0x1ca9, /* VPMINUQZ256rrk */
/* Table8481 */
  0x1b74, /* VPMAXSQZ256rmk */
  0x1b77, /* VPMAXSQZ256rrk */
/* Table8483 */
  0x1bda, /* VPMAXUQZ256rmk */
  0x1bdd, /* VPMAXUQZ256rrk */
/* Table8485 */
  0x1dd4, /* VPMULLQZ256rmk */
  0x1dd7, /* VPMULLQZ256rrk */
/* Table8487 */
  0x203d, /* VRCP14PDZ256mk */
  0x2040, /* VRCP14PDZ256rk */
/* Table8489 */
  0x20d0, /* VRSQRT14PDZ256mk */
  0x20d3, /* VRSQRT14PDZ256rk */
/* Table8491 */
  0x17d2, /* VPBLENDMQZ256rmk */
  0x17d5, /* VPBLENDMQZ256rrk */
/* Table8493 */
  0xc67, /* VBLENDMPDZ256rmk */
  0xc6a, /* VBLENDMPDZ256rrk */
/* Table8495 */
  0x17e6, /* VPBLENDMWZ256rmk */
  0x17e9, /* VPBLENDMWZ256rrk */
/* Table8497 */
  0x0, /*  */
  0x1827, /* VPBROADCASTQrZ256rk */
/* Table8499 */
  0xe32, /* VEXPANDPDZ256rmk */
  0xe34, /* VEXPANDPDZ256rrk */
/* Table8501 */
  0x1a9b, /* VPEXPANDQZ256rmk */
  0x1a9d, /* VPEXPANDQZ256rrk */
/* Table8503 */
  0xcfc, /* VCOMPRESSPDZ256mrk */
  0xcfd, /* VCOMPRESSPDZ256rrk */
/* Table8505 */
  0x19ef, /* VPCOMPRESSQZ256mrk */
  0x19f0, /* VPCOMPRESSQZ256rrk */
/* Table8507 */
  0xf4c, /* VFMADDSUBPDZ256v213rmk */
  0xf4f, /* VFMADDSUBPDZ256v213rrk */
/* Table8509 */
  0xffe, /* VFMSUBADDPDZ256v213rmk */
  0x1001, /* VFMSUBADDPDZ256v213rrk */
/* Table8511 */
  0xe88, /* VFMADDPDZ256v213rmk */
  0xe8b, /* VFMADDPDZ256v213rrk */
/* Table8513 */
  0x1098, /* VFMSUBPDZ256v213rmk */
  0x109b, /* VFMSUBPDZ256v213rrk */
/* Table8515 */
  0x115c, /* VFNMADDPDZ256v213rmk */
  0x115f, /* VFNMADDPDZ256v213rrk */
/* Table8517 */
  0x1220, /* VFNMSUBPDZ256v213rmk */
  0x1223, /* VFNMSUBPDZ256v213rrk */
/* Table8519 */
  0xf55, /* VFMADDSUBPDZ256v231rmk */
  0xf58, /* VFMADDSUBPDZ256v231rrk */
/* Table8521 */
  0x1007, /* VFMSUBADDPDZ256v231rmk */
  0x100a, /* VFMSUBADDPDZ256v231rrk */
/* Table8523 */
  0xe91, /* VFMADDPDZ256v231rmk */
  0xe94, /* VFMADDPDZ256v231rrk */
/* Table8525 */
  0x10a1, /* VFMSUBPDZ256v231rmk */
  0x10a4, /* VFMSUBPDZ256v231rrk */
/* Table8527 */
  0x1165, /* VFNMADDPDZ256v231rmk */
  0x1168, /* VFNMADDPDZ256v231rrk */
/* Table8529 */
  0x1229, /* VFNMSUBPDZ256v231rmk */
  0x122c, /* VFNMSUBPDZ256v231rrk */
/* Table8531 */
  0x1d41, /* VPMOVUSDBmrk */
  0x1d43, /* VPMOVUSDBrrk */
/* Table8533 */
  0x1d4b, /* VPMOVUSQBmrk */
  0x1d4d, /* VPMOVUSQBrrk */
/* Table8535 */
  0x1d46, /* VPMOVUSDWmrk */
  0x1d48, /* VPMOVUSDWrrk */
/* Table8537 */
  0x1d55, /* VPMOVUSQWmrk */
  0x1d57, /* VPMOVUSQWrrk */
/* Table8539 */
  0x1d50, /* VPMOVUSQDmrk */
  0x1d52, /* VPMOVUSQDrrk */
/* Table8541 */
  0x1cf2, /* VPMOVSDBmrk */
  0x1cf4, /* VPMOVSDBrrk */
/* Table8543 */
  0x1cfc, /* VPMOVSQBmrk */
  0x1cfe, /* VPMOVSQBrrk */
/* Table8545 */
  0x1cf7, /* VPMOVSDWmrk */
  0x1cf9, /* VPMOVSDWrrk */
/* Table8547 */
  0x1d06, /* VPMOVSQWmrk */
  0x1d08, /* VPMOVSQWrrk */
/* Table8549 */
  0x1d01, /* VPMOVSQDmrk */
  0x1d03, /* VPMOVSQDrrk */
/* Table8551 */
  0x1ccb, /* VPMOVDBmrk */
  0x1ccd, /* VPMOVDBrrk */
/* Table8553 */
  0x1ce3, /* VPMOVQBmrk */
  0x1ce5, /* VPMOVQBrrk */
/* Table8555 */
  0x1cd0, /* VPMOVDWmrk */
  0x1cd2, /* VPMOVDWrrk */
/* Table8557 */
  0x1ced, /* VPMOVQWmrk */
  0x1cef, /* VPMOVQWrrk */
/* Table8559 */
  0x1ce8, /* VPMOVQDmrk */
  0x1cea, /* VPMOVQDrrk */
/* Table8561 */
  0xcbe, /* VBROADCASTSSZmk */
  0xcc1, /* VBROADCASTSSZrk */
/* Table8563 */
  0x1679, /* VPABSDZrmk */
  0x167c, /* VPABSDZrrk */
/* Table8565 */
  0x1d0d, /* VPMOVSXBDZrmk */
  0x1d10, /* VPMOVSXBDZrrk */
/* Table8567 */
  0x1d17, /* VPMOVSXBQZrmk */
  0x1d1a, /* VPMOVSXBQZrrk */
/* Table8569 */
  0x1d2f, /* VPMOVSXWDZrmk */
  0x1d32, /* VPMOVSXWDZrrk */
/* Table8571 */
  0x1d39, /* VPMOVSXWQZrmk */
  0x1d3c, /* VPMOVSXWQZrrk */
/* Table8573 */
  0x1d25, /* VPMOVSXDQZrmk */
  0x1d28, /* VPMOVSXDQZrrk */
/* Table8575 */
  0x1d5c, /* VPMOVZXBDZrmk */
  0x1d5f, /* VPMOVZXBDZrrk */
/* Table8577 */
  0x1d66, /* VPMOVZXBQZrmk */
  0x1d69, /* VPMOVZXBQZrrk */
/* Table8579 */
  0x1d7e, /* VPMOVZXWDZrmk */
  0x1d81, /* VPMOVZXWDZrrk */
/* Table8581 */
  0x1d88, /* VPMOVZXWQZrmk */
  0x1d8b, /* VPMOVZXWQZrrk */
/* Table8583 */
  0x1d74, /* VPMOVZXDQZrmk */
  0x1d77, /* VPMOVZXDQZrrk */
/* Table8585 */
  0x1c0d, /* VPMINSBZrmk */
  0x1c10, /* VPMINSBZrrk */
/* Table8587 */
  0x1c2c, /* VPMINSDZrmk */
  0x1c2f, /* VPMINSDZrrk */
/* Table8589 */
  0x1cc3, /* VPMINUWZrmk */
  0x1cc6, /* VPMINUWZrrk */
/* Table8591 */
  0x1c92, /* VPMINUDZrmk */
  0x1c95, /* VPMINUDZrrk */
/* Table8593 */
  0x1b41, /* VPMAXSBZrmk */
  0x1b44, /* VPMAXSBZrrk */
/* Table8595 */
  0x1b60, /* VPMAXSDZrmk */
  0x1b63, /* VPMAXSDZrrk */
/* Table8597 */
  0x1bf7, /* VPMAXUWZrmk */
  0x1bfa, /* VPMAXUWZrrk */
/* Table8599 */
  0x1bc6, /* VPMAXUDZrmk */
  0x1bc9, /* VPMAXUDZrrk */
/* Table8601 */
  0x1dc0, /* VPMULLDZrmk */
  0x1dc3, /* VPMULLDZrrk */
/* Table8603 */
  0x1afc, /* VPLZCNTDrmk */
  0x1aff, /* VPLZCNTDrrk */
/* Table8605 */
  0x1f31, /* VPSRLVDZrmk */
  0x1f34, /* VPSRLVDZrrk */
/* Table8607 */
  0x1ef5, /* VPSRAVDZrmk */
  0x1ef8, /* VPSRAVDZrrk */
/* Table8609 */
  0x1ebd, /* VPSLLVDZrmk */
  0x1ec0, /* VPSLLVDZrrk */
/* Table8611 */
  0x2061, /* VRCP14PSZmk */
  0x2064, /* VRCP14PSZrk */
/* Table8613 */
  0x20f4, /* VRSQRT14PSZmk */
  0x20f7, /* VRSQRT14PSZrk */
/* Table8615 */
  0x17c2, /* VPBLENDMDZrmk */
  0x17c5, /* VPBLENDMDZrrk */
/* Table8617 */
  0xc87, /* VBLENDMPSZrmk */
  0xc8a, /* VBLENDMPSZrrk */
/* Table8619 */
  0x17aa, /* VPBLENDMBZrmk */
  0x17ad, /* VPBLENDMBZrrk */
/* Table8621 */
  0x1a28, /* VPERMI2Drmk */
  0x1a2b, /* VPERMI2Drrk */
/* Table8623 */
  0x1a34, /* VPERMI2PSrmk */
  0x1a37, /* VPERMI2PSrrk */
/* Table8625 */
  0x0, /*  */
  0x1802, /* VPBROADCASTBrZrk */
/* Table8627 */
  0x0, /*  */
  0x1837, /* VPBROADCASTWrZrk */
/* Table8629 */
  0x0, /*  */
  0x1813, /* VPBROADCASTDrZrk */
/* Table8631 */
  0x1a74, /* VPERMT2Drmk */
  0x1a77, /* VPERMT2Drrk */
/* Table8633 */
  0x1a80, /* VPERMT2PSrmk */
  0x1a83, /* VPERMT2PSrrk */
/* Table8635 */
  0xe42, /* VEXPANDPSZrmk */
  0xe44, /* VEXPANDPSZrrk */
/* Table8637 */
  0x1a93, /* VPEXPANDDZrmk */
  0x1a95, /* VPEXPANDDZrrk */
/* Table8639 */
  0xd08, /* VCOMPRESSPSZmrk */
  0xd09, /* VCOMPRESSPSZrrk */
/* Table8641 */
  0x19e9, /* VPCOMPRESSDZmrk */
  0x19ea, /* VPCOMPRESSDZrrk */
/* Table8643 */
  0x1aad, /* VPGATHERDDZrm */
  0x0, /*  */
/* Table8645 */
  0x1ab3, /* VPGATHERQDZrm */
  0x0, /*  */
/* Table8647 */
  0x12ea, /* VGATHERDPSZrm */
  0x0, /*  */
/* Table8649 */
  0x12f8, /* VGATHERQPSZrm */
  0x0, /*  */
/* Table8651 */
  0x1e5a, /* VPSCATTERDDZmr */
  0x0, /*  */
/* Table8653 */
  0x1e5c, /* VPSCATTERQDZmr */
  0x0, /*  */
/* Table8655 */
  0x2133, /* VSCATTERDPSZmr */
  0x0, /*  */
/* Table8657 */
  0x213d, /* VSCATTERQPSZmr */
  0x0, /*  */
/* Table8659 */
  0xfab, /* VFMADDSUBPSZv213rmk */
  0xfb1, /* VFMADDSUBPSZv213rrk */
/* Table8661 */
  0x105d, /* VFMSUBADDPSZv213rmk */
  0x1063, /* VFMSUBADDPSZv213rrk */
/* Table8663 */
  0xee7, /* VFMADDPSZv213rmk */
  0xeed, /* VFMADDPSZv213rrk */
/* Table8665 */
  0x10f7, /* VFMSUBPSZv213rmk */
  0x10fd, /* VFMSUBPSZv213rrk */
/* Table8667 */
  0x11bb, /* VFNMADDPSZv213rmk */
  0x11c1, /* VFNMADDPSZv213rrk */
/* Table8669 */
  0x127f, /* VFNMSUBPSZv213rmk */
  0x1285, /* VFNMSUBPSZv213rrk */
/* Table8671 */
  0xfb7, /* VFMADDSUBPSZv231rmk */
  0xfba, /* VFMADDSUBPSZv231rrk */
/* Table8673 */
  0x1069, /* VFMSUBADDPSZv231rmk */
  0x106c, /* VFMSUBADDPSZv231rrk */
/* Table8675 */
  0xef3, /* VFMADDPSZv231rmk */
  0xef6, /* VFMADDPSZv231rrk */
/* Table8677 */
  0x1103, /* VFMSUBPSZv231rmk */
  0x1106, /* VFMSUBPSZv231rrk */
/* Table8679 */
  0x11c7, /* VFNMADDPSZv231rmk */
  0x11ca, /* VFNMADDPSZv231rrk */
/* Table8681 */
  0x128b, /* VFNMSUBPSZv231rmk */
  0x128e, /* VFNMSUBPSZv231rrk */
/* Table8683 */
  0x1a11, /* VPCONFLICTDrmk */
  0x1a14, /* VPCONFLICTDrrk */
/* Table8685 */
  0x0, /*  */
  0x12ed, /* VGATHERPF0DPSm */
  0x12f1, /* VGATHERPF1DPSm */
  0x0, /*  */
  0x0, /*  */
  0x2135, /* VSCATTERPF0DPSm */
  0x2139, /* VSCATTERPF1DPSm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table8701 */
  0x0, /*  */
  0x12ef, /* VGATHERPF0QPSm */
  0x12f3, /* VGATHERPF1QPSm */
  0x0, /*  */
  0x0, /*  */
  0x2137, /* VSCATTERPF0QPSm */
  0x213b, /* VSCATTERPF1QPSm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table8717 */
  0xe26, /* VEXP2PSmk */
  0xe2c, /* VEXP2PSrk */
/* Table8719 */
  0x207a, /* VRCP28PSmk */
  0x2080, /* VRCP28PSrk */
/* Table8721 */
  0x210d, /* VRSQRT28PSmk */
  0x2113, /* VRSQRT28PSrk */
/* Table8723 */
  0xcaa, /* VBROADCASTSDZmk */
  0xcad, /* VBROADCASTSDZrk */
/* Table8725 */
  0x1686, /* VPABSQZrmk */
  0x1689, /* VPABSQZrrk */
/* Table8727 */
  0x1d95, /* VPMULDQZrmk */
  0x1d98, /* VPMULDQZrrk */
/* Table8729 */
  0x18b6, /* VPCMPEQQZrmk */
  0x18b8, /* VPCMPEQQZrrk */
/* Table8731 */
  0x190a, /* VPCMPGTQZrmk */
  0x190c, /* VPCMPGTQZrrk */
/* Table8733 */
  0x1c49, /* VPMINSQZrmk */
  0x1c4c, /* VPMINSQZrrk */
/* Table8735 */
  0x1caf, /* VPMINUQZrmk */
  0x1cb2, /* VPMINUQZrrk */
/* Table8737 */
  0x1b7d, /* VPMAXSQZrmk */
  0x1b80, /* VPMAXSQZrrk */
/* Table8739 */
  0x1be3, /* VPMAXUQZrmk */
  0x1be6, /* VPMAXUQZrrk */
/* Table8741 */
  0x1ddd, /* VPMULLQZrmk */
  0x1de0, /* VPMULLQZrrk */
/* Table8743 */
  0x1b05, /* VPLZCNTQrmk */
  0x1b08, /* VPLZCNTQrrk */
/* Table8745 */
  0x1f3b, /* VPSRLVQZrmk */
  0x1f3e, /* VPSRLVQZrrk */
/* Table8747 */
  0x1efd, /* VPSRAVQZrmk */
  0x1f00, /* VPSRAVQZrrk */
/* Table8749 */
  0x1ec7, /* VPSLLVQZrmk */
  0x1eca, /* VPSLLVQZrrk */
/* Table8751 */
  0x2046, /* VRCP14PDZmk */
  0x2049, /* VRCP14PDZrk */
/* Table8753 */
  0x20d9, /* VRSQRT14PDZmk */
  0x20dc, /* VRSQRT14PDZrk */
/* Table8755 */
  0x17da, /* VPBLENDMQZrmk */
  0x17dd, /* VPBLENDMQZrrk */
/* Table8757 */
  0xc6f, /* VBLENDMPDZrmk */
  0xc72, /* VBLENDMPDZrrk */
/* Table8759 */
  0x17ec, /* VPBLENDMWZrmk */
  0x17ef, /* VPBLENDMWZrrk */
/* Table8761 */
  0x1a3a, /* VPERMI2Qrmk */
  0x1a3d, /* VPERMI2Qrrk */
/* Table8763 */
  0x1a2e, /* VPERMI2PDrmk */
  0x1a31, /* VPERMI2PDrrk */
/* Table8765 */
  0x0, /*  */
  0x182a, /* VPBROADCASTQrZrk */
/* Table8767 */
  0x1a86, /* VPERMT2Qrmk */
  0x1a89, /* VPERMT2Qrrk */
/* Table8769 */
  0x1a7a, /* VPERMT2PDrmk */
  0x1a7d, /* VPERMT2PDrrk */
/* Table8771 */
  0xe36, /* VEXPANDPDZrmk */
  0xe38, /* VEXPANDPDZrrk */
/* Table8773 */
  0x1a9f, /* VPEXPANDQZrmk */
  0x1aa1, /* VPEXPANDQZrrk */
/* Table8775 */
  0xcff, /* VCOMPRESSPDZmrk */
  0xd00, /* VCOMPRESSPDZrrk */
/* Table8777 */
  0x19f2, /* VPCOMPRESSQZmrk */
  0x19f3, /* VPCOMPRESSQZrrk */
/* Table8779 */
  0x1ab0, /* VPGATHERDQZrm */
  0x0, /*  */
/* Table8781 */
  0x1ab6, /* VPGATHERQQZrm */
  0x0, /*  */
/* Table8783 */
  0x12e7, /* VGATHERDPDZrm */
  0x0, /*  */
/* Table8785 */
  0x12f5, /* VGATHERQPDZrm */
  0x0, /*  */
/* Table8787 */
  0x1e5b, /* VPSCATTERDQZmr */
  0x0, /*  */
/* Table8789 */
  0x1e5d, /* VPSCATTERQQZmr */
  0x0, /*  */
/* Table8791 */
  0x2132, /* VSCATTERDPDZmr */
  0x0, /*  */
/* Table8793 */
  0x213c, /* VSCATTERQPDZmr */
  0x0, /*  */
/* Table8795 */
  0xf5e, /* VFMADDSUBPDZv213rmk */
  0xf64, /* VFMADDSUBPDZv213rrk */
/* Table8797 */
  0x1010, /* VFMSUBADDPDZv213rmk */
  0x1016, /* VFMSUBADDPDZv213rrk */
/* Table8799 */
  0xe9a, /* VFMADDPDZv213rmk */
  0xea0, /* VFMADDPDZv213rrk */
/* Table8801 */
  0x10aa, /* VFMSUBPDZv213rmk */
  0x10b0, /* VFMSUBPDZv213rrk */
/* Table8803 */
  0x116e, /* VFNMADDPDZv213rmk */
  0x1174, /* VFNMADDPDZv213rrk */
/* Table8805 */
  0x1232, /* VFNMSUBPDZv213rmk */
  0x1238, /* VFNMSUBPDZv213rrk */
/* Table8807 */
  0xf6a, /* VFMADDSUBPDZv231rmk */
  0xf6d, /* VFMADDSUBPDZv231rrk */
/* Table8809 */
  0x101c, /* VFMSUBADDPDZv231rmk */
  0x101f, /* VFMSUBADDPDZv231rrk */
/* Table8811 */
  0xea6, /* VFMADDPDZv231rmk */
  0xea9, /* VFMADDPDZv231rrk */
/* Table8813 */
  0x10b6, /* VFMSUBPDZv231rmk */
  0x10b9, /* VFMSUBPDZv231rrk */
/* Table8815 */
  0x117a, /* VFNMADDPDZv231rmk */
  0x117d, /* VFNMADDPDZv231rrk */
/* Table8817 */
  0x123e, /* VFNMSUBPDZv231rmk */
  0x1241, /* VFNMSUBPDZv231rrk */
/* Table8819 */
  0x1a1a, /* VPCONFLICTQrmk */
  0x1a1d, /* VPCONFLICTQrrk */
/* Table8821 */
  0x0, /*  */
  0x12ec, /* VGATHERPF0DPDm */
  0x12f0, /* VGATHERPF1DPDm */
  0x0, /*  */
  0x0, /*  */
  0x2134, /* VSCATTERPF0DPDm */
  0x2138, /* VSCATTERPF1DPDm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table8837 */
  0x0, /*  */
  0x12ee, /* VGATHERPF0QPDm */
  0x12f2, /* VGATHERPF1QPDm */
  0x0, /*  */
  0x0, /*  */
  0x2136, /* VSCATTERPF0QPDm */
  0x213a, /* VSCATTERPF1QPDm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table8853 */
  0xe1a, /* VEXP2PDmk */
  0xe20, /* VEXP2PDrk */
/* Table8855 */
  0x206e, /* VRCP28PDmk */
  0x2074, /* VRCP28PDrk */
/* Table8857 */
  0x2101, /* VRSQRT28PDmk */
  0x2107, /* VRSQRT28PDrk */
/* Table8859 */
  0x1c17, /* VPMINSDZ128rmb */
  0x0, /*  */
/* Table8861 */
  0x1c7d, /* VPMINUDZ128rmb */
  0x0, /*  */
/* Table8863 */
  0x1b4b, /* VPMAXSDZ128rmb */
  0x0, /*  */
/* Table8865 */
  0x1bb1, /* VPMAXUDZ128rmb */
  0x0, /*  */
/* Table8867 */
  0x1dab, /* VPMULLDZ128rmb */
  0x0, /*  */
/* Table8869 */
  0x204c, /* VRCP14PSZ128mb */
  0x0, /*  */
/* Table8871 */
  0x20df, /* VRSQRT14PSZ128mb */
  0x0, /*  */
/* Table8873 */
  0x17b0, /* VPBLENDMDZ128rmb */
  0x0, /*  */
/* Table8875 */
  0xc75, /* VBLENDMPSZ128rmb */
  0x0, /*  */
/* Table8877 */
  0xf29, /* VFMADDSUB132PSZ128mb */
  0x0, /*  */
/* Table8879 */
  0xfdb, /* VFMSUBADD132PSZ128mb */
  0x0, /*  */
/* Table8881 */
  0xe65, /* VFMADD132PSZ128mb */
  0x0, /*  */
/* Table8883 */
  0xfcf, /* VFMSUB132PSZ128mb */
  0x0, /*  */
/* Table8885 */
  0x1139, /* VFNMADD132PSZ128mb */
  0x0, /*  */
/* Table8887 */
  0x11fd, /* VFNMSUB132PSZ128mb */
  0x0, /*  */
/* Table8889 */
  0xf84, /* VFMADDSUBPSZ128v213rmb */
  0x0, /*  */
/* Table8891 */
  0x1036, /* VFMSUBADDPSZ128v213rmb */
  0x0, /*  */
/* Table8893 */
  0xec0, /* VFMADDPSZ128v213rmb */
  0x0, /*  */
/* Table8895 */
  0x10d0, /* VFMSUBPSZ128v213rmb */
  0x0, /*  */
/* Table8897 */
  0x1194, /* VFNMADDPSZ128v213rmb */
  0x0, /*  */
/* Table8899 */
  0x1258, /* VFNMSUBPSZ128v213rmb */
  0x0, /*  */
/* Table8901 */
  0xf8d, /* VFMADDSUBPSZ128v231rmb */
  0x0, /*  */
/* Table8903 */
  0x103f, /* VFMSUBADDPSZ128v231rmb */
  0x0, /*  */
/* Table8905 */
  0xec9, /* VFMADDPSZ128v231rmb */
  0x0, /*  */
/* Table8907 */
  0x10d9, /* VFMSUBPSZ128v231rmb */
  0x0, /*  */
/* Table8909 */
  0x119d, /* VFNMADDPSZ128v231rmb */
  0x0, /*  */
/* Table8911 */
  0x1261, /* VFNMSUBPSZ128v231rmb */
  0x0, /*  */
/* Table8913 */
  0x0, /*  */
  0x208f, /* VRCP28SSrb */
/* Table8915 */
  0x0, /*  */
  0x2122, /* VRSQRT28SSrb */
/* Table8917 */
  0x18a8, /* VPCMPEQQZ128rmb */
  0x0, /*  */
/* Table8919 */
  0x18fc, /* VPCMPGTQZ128rmb */
  0x0, /*  */
/* Table8921 */
  0x1c34, /* VPMINSQZ128rmb */
  0x0, /*  */
/* Table8923 */
  0x1c9a, /* VPMINUQZ128rmb */
  0x0, /*  */
/* Table8925 */
  0x1b68, /* VPMAXSQZ128rmb */
  0x0, /*  */
/* Table8927 */
  0x1bce, /* VPMAXUQZ128rmb */
  0x0, /*  */
/* Table8929 */
  0x1dc8, /* VPMULLQZ128rmb */
  0x0, /*  */
/* Table8931 */
  0x2031, /* VRCP14PDZ128mb */
  0x0, /*  */
/* Table8933 */
  0x20c4, /* VRSQRT14PDZ128mb */
  0x0, /*  */
/* Table8935 */
  0x17c8, /* VPBLENDMQZ128rmb */
  0x0, /*  */
/* Table8937 */
  0xc5d, /* VBLENDMPDZ128rmb */
  0x0, /*  */
/* Table8939 */
  0xf23, /* VFMADDSUB132PDZ128mb */
  0x0, /*  */
/* Table8941 */
  0xfd5, /* VFMSUBADD132PDZ128mb */
  0x0, /*  */
/* Table8943 */
  0xe5f, /* VFMADD132PDZ128mb */
  0x0, /*  */
/* Table8945 */
  0xfc9, /* VFMSUB132PDZ128mb */
  0x0, /*  */
/* Table8947 */
  0x1133, /* VFNMADD132PDZ128mb */
  0x0, /*  */
/* Table8949 */
  0x11f7, /* VFNMSUB132PDZ128mb */
  0x0, /*  */
/* Table8951 */
  0xf37, /* VFMADDSUBPDZ128v213rmb */
  0x0, /*  */
/* Table8953 */
  0xfe9, /* VFMSUBADDPDZ128v213rmb */
  0x0, /*  */
/* Table8955 */
  0xe73, /* VFMADDPDZ128v213rmb */
  0x0, /*  */
/* Table8957 */
  0x1083, /* VFMSUBPDZ128v213rmb */
  0x0, /*  */
/* Table8959 */
  0x1147, /* VFNMADDPDZ128v213rmb */
  0x0, /*  */
/* Table8961 */
  0x120b, /* VFNMSUBPDZ128v213rmb */
  0x0, /*  */
/* Table8963 */
  0xf40, /* VFMADDSUBPDZ128v231rmb */
  0x0, /*  */
/* Table8965 */
  0xff2, /* VFMSUBADDPDZ128v231rmb */
  0x0, /*  */
/* Table8967 */
  0xe7c, /* VFMADDPDZ128v231rmb */
  0x0, /*  */
/* Table8969 */
  0x108c, /* VFMSUBPDZ128v231rmb */
  0x0, /*  */
/* Table8971 */
  0x1150, /* VFNMADDPDZ128v231rmb */
  0x0, /*  */
/* Table8973 */
  0x1214, /* VFNMSUBPDZ128v231rmb */
  0x0, /*  */
/* Table8975 */
  0x0, /*  */
  0x2086, /* VRCP28SDrb */
/* Table8977 */
  0x0, /*  */
  0x2119, /* VRSQRT28SDrb */
/* Table8979 */
  0x1c20, /* VPMINSDZ256rmb */
  0x0, /*  */
/* Table8981 */
  0x1c86, /* VPMINUDZ256rmb */
  0x0, /*  */
/* Table8983 */
  0x1b54, /* VPMAXSDZ256rmb */
  0x0, /*  */
/* Table8985 */
  0x1bba, /* VPMAXUDZ256rmb */
  0x0, /*  */
/* Table8987 */
  0x1db4, /* VPMULLDZ256rmb */
  0x0, /*  */
/* Table8989 */
  0x2055, /* VRCP14PSZ256mb */
  0x0, /*  */
/* Table8991 */
  0x20e8, /* VRSQRT14PSZ256mb */
  0x0, /*  */
/* Table8993 */
  0x17b8, /* VPBLENDMDZ256rmb */
  0x0, /*  */
/* Table8995 */
  0xc7d, /* VBLENDMPSZ256rmb */
  0x0, /*  */
/* Table8997 */
  0xf2b, /* VFMADDSUB132PSZ256mb */
  0x0, /*  */
/* Table8999 */
  0xfdd, /* VFMSUBADD132PSZ256mb */
  0x0, /*  */
/* Table9001 */
  0xe67, /* VFMADD132PSZ256mb */
  0x0, /*  */
/* Table9003 */
  0xfd1, /* VFMSUB132PSZ256mb */
  0x0, /*  */
/* Table9005 */
  0x113b, /* VFNMADD132PSZ256mb */
  0x0, /*  */
/* Table9007 */
  0x11ff, /* VFNMSUB132PSZ256mb */
  0x0, /*  */
/* Table9009 */
  0xf96, /* VFMADDSUBPSZ256v213rmb */
  0x0, /*  */
/* Table9011 */
  0x1048, /* VFMSUBADDPSZ256v213rmb */
  0x0, /*  */
/* Table9013 */
  0xed2, /* VFMADDPSZ256v213rmb */
  0x0, /*  */
/* Table9015 */
  0x10e2, /* VFMSUBPSZ256v213rmb */
  0x0, /*  */
/* Table9017 */
  0x11a6, /* VFNMADDPSZ256v213rmb */
  0x0, /*  */
/* Table9019 */
  0x126a, /* VFNMSUBPSZ256v213rmb */
  0x0, /*  */
/* Table9021 */
  0xf9f, /* VFMADDSUBPSZ256v231rmb */
  0x0, /*  */
/* Table9023 */
  0x1051, /* VFMSUBADDPSZ256v231rmb */
  0x0, /*  */
/* Table9025 */
  0xedb, /* VFMADDPSZ256v231rmb */
  0x0, /*  */
/* Table9027 */
  0x10eb, /* VFMSUBPSZ256v231rmb */
  0x0, /*  */
/* Table9029 */
  0x11af, /* VFNMADDPSZ256v231rmb */
  0x0, /*  */
/* Table9031 */
  0x1273, /* VFNMSUBPSZ256v231rmb */
  0x0, /*  */
/* Table9033 */
  0x18ae, /* VPCMPEQQZ256rmb */
  0x0, /*  */
/* Table9035 */
  0x1902, /* VPCMPGTQZ256rmb */
  0x0, /*  */
/* Table9037 */
  0x1c3d, /* VPMINSQZ256rmb */
  0x0, /*  */
/* Table9039 */
  0x1ca3, /* VPMINUQZ256rmb */
  0x0, /*  */
/* Table9041 */
  0x1b71, /* VPMAXSQZ256rmb */
  0x0, /*  */
/* Table9043 */
  0x1bd7, /* VPMAXUQZ256rmb */
  0x0, /*  */
/* Table9045 */
  0x1dd1, /* VPMULLQZ256rmb */
  0x0, /*  */
/* Table9047 */
  0x203a, /* VRCP14PDZ256mb */
  0x0, /*  */
/* Table9049 */
  0x20cd, /* VRSQRT14PDZ256mb */
  0x0, /*  */
/* Table9051 */
  0x17d0, /* VPBLENDMQZ256rmb */
  0x0, /*  */
/* Table9053 */
  0xc65, /* VBLENDMPDZ256rmb */
  0x0, /*  */
/* Table9055 */
  0xf25, /* VFMADDSUB132PDZ256mb */
  0x0, /*  */
/* Table9057 */
  0xfd7, /* VFMSUBADD132PDZ256mb */
  0x0, /*  */
/* Table9059 */
  0xe61, /* VFMADD132PDZ256mb */
  0x0, /*  */
/* Table9061 */
  0xfcb, /* VFMSUB132PDZ256mb */
  0x0, /*  */
/* Table9063 */
  0x1135, /* VFNMADD132PDZ256mb */
  0x0, /*  */
/* Table9065 */
  0x11f9, /* VFNMSUB132PDZ256mb */
  0x0, /*  */
/* Table9067 */
  0xf49, /* VFMADDSUBPDZ256v213rmb */
  0x0, /*  */
/* Table9069 */
  0xffb, /* VFMSUBADDPDZ256v213rmb */
  0x0, /*  */
/* Table9071 */
  0xe85, /* VFMADDPDZ256v213rmb */
  0x0, /*  */
/* Table9073 */
  0x1095, /* VFMSUBPDZ256v213rmb */
  0x0, /*  */
/* Table9075 */
  0x1159, /* VFNMADDPDZ256v213rmb */
  0x0, /*  */
/* Table9077 */
  0x121d, /* VFNMSUBPDZ256v213rmb */
  0x0, /*  */
/* Table9079 */
  0xf52, /* VFMADDSUBPDZ256v231rmb */
  0x0, /*  */
/* Table9081 */
  0x1004, /* VFMSUBADDPDZ256v231rmb */
  0x0, /*  */
/* Table9083 */
  0xe8e, /* VFMADDPDZ256v231rmb */
  0x0, /*  */
/* Table9085 */
  0x109e, /* VFMSUBPDZ256v231rmb */
  0x0, /*  */
/* Table9087 */
  0x1162, /* VFNMADDPDZ256v231rmb */
  0x0, /*  */
/* Table9089 */
  0x1226, /* VFNMSUBPDZ256v231rmb */
  0x0, /*  */
/* Table9091 */
  0x1676, /* VPABSDZrmb */
  0x0, /*  */
/* Table9093 */
  0x1c29, /* VPMINSDZrmb */
  0x0, /*  */
/* Table9095 */
  0x1c8f, /* VPMINUDZrmb */
  0x0, /*  */
/* Table9097 */
  0x1b5d, /* VPMAXSDZrmb */
  0x0, /*  */
/* Table9099 */
  0x1bc3, /* VPMAXUDZrmb */
  0x0, /*  */
/* Table9101 */
  0x1dbd, /* VPMULLDZrmb */
  0x0, /*  */
/* Table9103 */
  0x1af9, /* VPLZCNTDrmb */
  0x0, /*  */
/* Table9105 */
  0x205e, /* VRCP14PSZmb */
  0x0, /*  */
/* Table9107 */
  0x20f1, /* VRSQRT14PSZmb */
  0x0, /*  */
/* Table9109 */
  0x17c0, /* VPBLENDMDZrmb */
  0x0, /*  */
/* Table9111 */
  0xc85, /* VBLENDMPSZrmb */
  0x0, /*  */
/* Table9113 */
  0xf2d, /* VFMADDSUB132PSZmb */
  0x0, /*  */
/* Table9115 */
  0xfdf, /* VFMSUBADD132PSZmb */
  0x0, /*  */
/* Table9117 */
  0xe69, /* VFMADD132PSZmb */
  0x0, /*  */
/* Table9119 */
  0xfd3, /* VFMSUB132PSZmb */
  0x0, /*  */
/* Table9121 */
  0x113d, /* VFNMADD132PSZmb */
  0x0, /*  */
/* Table9123 */
  0x1201, /* VFNMSUB132PSZmb */
  0x0, /*  */
/* Table9125 */
  0xfa8, /* VFMADDSUBPSZv213rmb */
  0xfae, /* VFMADDSUBPSZv213rrb */
/* Table9127 */
  0x105a, /* VFMSUBADDPSZv213rmb */
  0x1060, /* VFMSUBADDPSZv213rrb */
/* Table9129 */
  0xee4, /* VFMADDPSZv213rmb */
  0xeea, /* VFMADDPSZv213rrb */
/* Table9131 */
  0x10f4, /* VFMSUBPSZv213rmb */
  0x10fa, /* VFMSUBPSZv213rrb */
/* Table9133 */
  0x11b8, /* VFNMADDPSZv213rmb */
  0x11be, /* VFNMADDPSZv213rrb */
/* Table9135 */
  0x127c, /* VFNMSUBPSZv213rmb */
  0x1282, /* VFNMSUBPSZv213rrb */
/* Table9137 */
  0xfb4, /* VFMADDSUBPSZv231rmb */
  0x0, /*  */
/* Table9139 */
  0x1066, /* VFMSUBADDPSZv231rmb */
  0x0, /*  */
/* Table9141 */
  0xef0, /* VFMADDPSZv231rmb */
  0x0, /*  */
/* Table9143 */
  0x1100, /* VFMSUBPSZv231rmb */
  0x0, /*  */
/* Table9145 */
  0x11c4, /* VFNMADDPSZv231rmb */
  0x0, /*  */
/* Table9147 */
  0x1288, /* VFNMSUBPSZv231rmb */
  0x0, /*  */
/* Table9149 */
  0x1a0e, /* VPCONFLICTDrmb */
  0x0, /*  */
/* Table9151 */
  0xe23, /* VEXP2PSmb */
  0xe29, /* VEXP2PSrb */
/* Table9153 */
  0x2077, /* VRCP28PSmb */
  0x207d, /* VRCP28PSrb */
/* Table9155 */
  0x210a, /* VRSQRT28PSmb */
  0x2110, /* VRSQRT28PSrb */
/* Table9157 */
  0x1683, /* VPABSQZrmb */
  0x0, /*  */
/* Table9159 */
  0x1d92, /* VPMULDQZrmb */
  0x0, /*  */
/* Table9161 */
  0x18b4, /* VPCMPEQQZrmb */
  0x0, /*  */
/* Table9163 */
  0x1908, /* VPCMPGTQZrmb */
  0x0, /*  */
/* Table9165 */
  0x1c46, /* VPMINSQZrmb */
  0x0, /*  */
/* Table9167 */
  0x1cac, /* VPMINUQZrmb */
  0x0, /*  */
/* Table9169 */
  0x1b7a, /* VPMAXSQZrmb */
  0x0, /*  */
/* Table9171 */
  0x1be0, /* VPMAXUQZrmb */
  0x0, /*  */
/* Table9173 */
  0x1dda, /* VPMULLQZrmb */
  0x0, /*  */
/* Table9175 */
  0x1b02, /* VPLZCNTQrmb */
  0x0, /*  */
/* Table9177 */
  0x2043, /* VRCP14PDZmb */
  0x0, /*  */
/* Table9179 */
  0x20d6, /* VRSQRT14PDZmb */
  0x0, /*  */
/* Table9181 */
  0x17d8, /* VPBLENDMQZrmb */
  0x0, /*  */
/* Table9183 */
  0xc6d, /* VBLENDMPDZrmb */
  0x0, /*  */
/* Table9185 */
  0xf27, /* VFMADDSUB132PDZmb */
  0x0, /*  */
/* Table9187 */
  0xfd9, /* VFMSUBADD132PDZmb */
  0x0, /*  */
/* Table9189 */
  0xe63, /* VFMADD132PDZmb */
  0x0, /*  */
/* Table9191 */
  0xfcd, /* VFMSUB132PDZmb */
  0x0, /*  */
/* Table9193 */
  0x1137, /* VFNMADD132PDZmb */
  0x0, /*  */
/* Table9195 */
  0x11fb, /* VFNMSUB132PDZmb */
  0x0, /*  */
/* Table9197 */
  0xf5b, /* VFMADDSUBPDZv213rmb */
  0xf61, /* VFMADDSUBPDZv213rrb */
/* Table9199 */
  0x100d, /* VFMSUBADDPDZv213rmb */
  0x1013, /* VFMSUBADDPDZv213rrb */
/* Table9201 */
  0xe97, /* VFMADDPDZv213rmb */
  0xe9d, /* VFMADDPDZv213rrb */
/* Table9203 */
  0x10a7, /* VFMSUBPDZv213rmb */
  0x10ad, /* VFMSUBPDZv213rrb */
/* Table9205 */
  0x116b, /* VFNMADDPDZv213rmb */
  0x1171, /* VFNMADDPDZv213rrb */
/* Table9207 */
  0x122f, /* VFNMSUBPDZv213rmb */
  0x1235, /* VFNMSUBPDZv213rrb */
/* Table9209 */
  0xf67, /* VFMADDSUBPDZv231rmb */
  0x0, /*  */
/* Table9211 */
  0x1019, /* VFMSUBADDPDZv231rmb */
  0x0, /*  */
/* Table9213 */
  0xea3, /* VFMADDPDZv231rmb */
  0x0, /*  */
/* Table9215 */
  0x10b3, /* VFMSUBPDZv231rmb */
  0x0, /*  */
/* Table9217 */
  0x1177, /* VFNMADDPDZv231rmb */
  0x0, /*  */
/* Table9219 */
  0x123b, /* VFNMSUBPDZv231rmb */
  0x0, /*  */
/* Table9221 */
  0x1a17, /* VPCONFLICTQrmb */
  0x0, /*  */
/* Table9223 */
  0xe17, /* VEXP2PDmb */
  0xe1d, /* VEXP2PDrb */
/* Table9225 */
  0x206b, /* VRCP28PDmb */
  0x2071, /* VRCP28PDrb */
/* Table9227 */
  0x20fe, /* VRSQRT28PDmb */
  0x2104, /* VRSQRT28PDrb */
/* Table9229 */
  0x1c18, /* VPMINSDZ128rmbk */
  0x0, /*  */
/* Table9231 */
  0x1c7e, /* VPMINUDZ128rmbk */
  0x0, /*  */
/* Table9233 */
  0x1b4c, /* VPMAXSDZ128rmbk */
  0x0, /*  */
/* Table9235 */
  0x1bb2, /* VPMAXUDZ128rmbk */
  0x0, /*  */
/* Table9237 */
  0x1dac, /* VPMULLDZ128rmbk */
  0x0, /*  */
/* Table9239 */
  0x204d, /* VRCP14PSZ128mbk */
  0x0, /*  */
/* Table9241 */
  0x20e0, /* VRSQRT14PSZ128mbk */
  0x0, /*  */
/* Table9243 */
  0x17b1, /* VPBLENDMDZ128rmbk */
  0x0, /*  */
/* Table9245 */
  0xc76, /* VBLENDMPSZ128rmbk */
  0x0, /*  */
/* Table9247 */
  0xf85, /* VFMADDSUBPSZ128v213rmbk */
  0x0, /*  */
/* Table9249 */
  0x1037, /* VFMSUBADDPSZ128v213rmbk */
  0x0, /*  */
/* Table9251 */
  0xec1, /* VFMADDPSZ128v213rmbk */
  0x0, /*  */
/* Table9253 */
  0x10d1, /* VFMSUBPSZ128v213rmbk */
  0x0, /*  */
/* Table9255 */
  0x1195, /* VFNMADDPSZ128v213rmbk */
  0x0, /*  */
/* Table9257 */
  0x1259, /* VFNMSUBPSZ128v213rmbk */
  0x0, /*  */
/* Table9259 */
  0xf8e, /* VFMADDSUBPSZ128v231rmbk */
  0x0, /*  */
/* Table9261 */
  0x1040, /* VFMSUBADDPSZ128v231rmbk */
  0x0, /*  */
/* Table9263 */
  0xeca, /* VFMADDPSZ128v231rmbk */
  0x0, /*  */
/* Table9265 */
  0x10da, /* VFMSUBPSZ128v231rmbk */
  0x0, /*  */
/* Table9267 */
  0x119e, /* VFNMADDPSZ128v231rmbk */
  0x0, /*  */
/* Table9269 */
  0x1262, /* VFNMSUBPSZ128v231rmbk */
  0x0, /*  */
/* Table9271 */
  0x0, /*  */
  0x2090, /* VRCP28SSrbk */
/* Table9273 */
  0x0, /*  */
  0x2123, /* VRSQRT28SSrbk */
/* Table9275 */
  0x18a9, /* VPCMPEQQZ128rmbk */
  0x0, /*  */
/* Table9277 */
  0x18fd, /* VPCMPGTQZ128rmbk */
  0x0, /*  */
/* Table9279 */
  0x1c35, /* VPMINSQZ128rmbk */
  0x0, /*  */
/* Table9281 */
  0x1c9b, /* VPMINUQZ128rmbk */
  0x0, /*  */
/* Table9283 */
  0x1b69, /* VPMAXSQZ128rmbk */
  0x0, /*  */
/* Table9285 */
  0x1bcf, /* VPMAXUQZ128rmbk */
  0x0, /*  */
/* Table9287 */
  0x1dc9, /* VPMULLQZ128rmbk */
  0x0, /*  */
/* Table9289 */
  0x2032, /* VRCP14PDZ128mbk */
  0x0, /*  */
/* Table9291 */
  0x20c5, /* VRSQRT14PDZ128mbk */
  0x0, /*  */
/* Table9293 */
  0x17c9, /* VPBLENDMQZ128rmbk */
  0x0, /*  */
/* Table9295 */
  0xc5e, /* VBLENDMPDZ128rmbk */
  0x0, /*  */
/* Table9297 */
  0xf38, /* VFMADDSUBPDZ128v213rmbk */
  0x0, /*  */
/* Table9299 */
  0xfea, /* VFMSUBADDPDZ128v213rmbk */
  0x0, /*  */
/* Table9301 */
  0xe74, /* VFMADDPDZ128v213rmbk */
  0x0, /*  */
/* Table9303 */
  0x1084, /* VFMSUBPDZ128v213rmbk */
  0x0, /*  */
/* Table9305 */
  0x1148, /* VFNMADDPDZ128v213rmbk */
  0x0, /*  */
/* Table9307 */
  0x120c, /* VFNMSUBPDZ128v213rmbk */
  0x0, /*  */
/* Table9309 */
  0xf41, /* VFMADDSUBPDZ128v231rmbk */
  0x0, /*  */
/* Table9311 */
  0xff3, /* VFMSUBADDPDZ128v231rmbk */
  0x0, /*  */
/* Table9313 */
  0xe7d, /* VFMADDPDZ128v231rmbk */
  0x0, /*  */
/* Table9315 */
  0x108d, /* VFMSUBPDZ128v231rmbk */
  0x0, /*  */
/* Table9317 */
  0x1151, /* VFNMADDPDZ128v231rmbk */
  0x0, /*  */
/* Table9319 */
  0x1215, /* VFNMSUBPDZ128v231rmbk */
  0x0, /*  */
/* Table9321 */
  0x0, /*  */
  0x2087, /* VRCP28SDrbk */
/* Table9323 */
  0x0, /*  */
  0x211a, /* VRSQRT28SDrbk */
/* Table9325 */
  0x1c21, /* VPMINSDZ256rmbk */
  0x0, /*  */
/* Table9327 */
  0x1c87, /* VPMINUDZ256rmbk */
  0x0, /*  */
/* Table9329 */
  0x1b55, /* VPMAXSDZ256rmbk */
  0x0, /*  */
/* Table9331 */
  0x1bbb, /* VPMAXUDZ256rmbk */
  0x0, /*  */
/* Table9333 */
  0x1db5, /* VPMULLDZ256rmbk */
  0x0, /*  */
/* Table9335 */
  0x2056, /* VRCP14PSZ256mbk */
  0x0, /*  */
/* Table9337 */
  0x20e9, /* VRSQRT14PSZ256mbk */
  0x0, /*  */
/* Table9339 */
  0x17b9, /* VPBLENDMDZ256rmbk */
  0x0, /*  */
/* Table9341 */
  0xc7e, /* VBLENDMPSZ256rmbk */
  0x0, /*  */
/* Table9343 */
  0xf97, /* VFMADDSUBPSZ256v213rmbk */
  0x0, /*  */
/* Table9345 */
  0x1049, /* VFMSUBADDPSZ256v213rmbk */
  0x0, /*  */
/* Table9347 */
  0xed3, /* VFMADDPSZ256v213rmbk */
  0x0, /*  */
/* Table9349 */
  0x10e3, /* VFMSUBPSZ256v213rmbk */
  0x0, /*  */
/* Table9351 */
  0x11a7, /* VFNMADDPSZ256v213rmbk */
  0x0, /*  */
/* Table9353 */
  0x126b, /* VFNMSUBPSZ256v213rmbk */
  0x0, /*  */
/* Table9355 */
  0xfa0, /* VFMADDSUBPSZ256v231rmbk */
  0x0, /*  */
/* Table9357 */
  0x1052, /* VFMSUBADDPSZ256v231rmbk */
  0x0, /*  */
/* Table9359 */
  0xedc, /* VFMADDPSZ256v231rmbk */
  0x0, /*  */
/* Table9361 */
  0x10ec, /* VFMSUBPSZ256v231rmbk */
  0x0, /*  */
/* Table9363 */
  0x11b0, /* VFNMADDPSZ256v231rmbk */
  0x0, /*  */
/* Table9365 */
  0x1274, /* VFNMSUBPSZ256v231rmbk */
  0x0, /*  */
/* Table9367 */
  0x18af, /* VPCMPEQQZ256rmbk */
  0x0, /*  */
/* Table9369 */
  0x1903, /* VPCMPGTQZ256rmbk */
  0x0, /*  */
/* Table9371 */
  0x1c3e, /* VPMINSQZ256rmbk */
  0x0, /*  */
/* Table9373 */
  0x1ca4, /* VPMINUQZ256rmbk */
  0x0, /*  */
/* Table9375 */
  0x1b72, /* VPMAXSQZ256rmbk */
  0x0, /*  */
/* Table9377 */
  0x1bd8, /* VPMAXUQZ256rmbk */
  0x0, /*  */
/* Table9379 */
  0x1dd2, /* VPMULLQZ256rmbk */
  0x0, /*  */
/* Table9381 */
  0x203b, /* VRCP14PDZ256mbk */
  0x0, /*  */
/* Table9383 */
  0x20ce, /* VRSQRT14PDZ256mbk */
  0x0, /*  */
/* Table9385 */
  0x17d1, /* VPBLENDMQZ256rmbk */
  0x0, /*  */
/* Table9387 */
  0xc66, /* VBLENDMPDZ256rmbk */
  0x0, /*  */
/* Table9389 */
  0xf4a, /* VFMADDSUBPDZ256v213rmbk */
  0x0, /*  */
/* Table9391 */
  0xffc, /* VFMSUBADDPDZ256v213rmbk */
  0x0, /*  */
/* Table9393 */
  0xe86, /* VFMADDPDZ256v213rmbk */
  0x0, /*  */
/* Table9395 */
  0x1096, /* VFMSUBPDZ256v213rmbk */
  0x0, /*  */
/* Table9397 */
  0x115a, /* VFNMADDPDZ256v213rmbk */
  0x0, /*  */
/* Table9399 */
  0x121e, /* VFNMSUBPDZ256v213rmbk */
  0x0, /*  */
/* Table9401 */
  0xf53, /* VFMADDSUBPDZ256v231rmbk */
  0x0, /*  */
/* Table9403 */
  0x1005, /* VFMSUBADDPDZ256v231rmbk */
  0x0, /*  */
/* Table9405 */
  0xe8f, /* VFMADDPDZ256v231rmbk */
  0x0, /*  */
/* Table9407 */
  0x109f, /* VFMSUBPDZ256v231rmbk */
  0x0, /*  */
/* Table9409 */
  0x1163, /* VFNMADDPDZ256v231rmbk */
  0x0, /*  */
/* Table9411 */
  0x1227, /* VFNMSUBPDZ256v231rmbk */
  0x0, /*  */
/* Table9413 */
  0x1677, /* VPABSDZrmbk */
  0x0, /*  */
/* Table9415 */
  0x1c2a, /* VPMINSDZrmbk */
  0x0, /*  */
/* Table9417 */
  0x1c90, /* VPMINUDZrmbk */
  0x0, /*  */
/* Table9419 */
  0x1b5e, /* VPMAXSDZrmbk */
  0x0, /*  */
/* Table9421 */
  0x1bc4, /* VPMAXUDZrmbk */
  0x0, /*  */
/* Table9423 */
  0x1dbe, /* VPMULLDZrmbk */
  0x0, /*  */
/* Table9425 */
  0x1afa, /* VPLZCNTDrmbk */
  0x0, /*  */
/* Table9427 */
  0x205f, /* VRCP14PSZmbk */
  0x0, /*  */
/* Table9429 */
  0x20f2, /* VRSQRT14PSZmbk */
  0x0, /*  */
/* Table9431 */
  0x17c1, /* VPBLENDMDZrmbk */
  0x0, /*  */
/* Table9433 */
  0xc86, /* VBLENDMPSZrmbk */
  0x0, /*  */
/* Table9435 */
  0xfa9, /* VFMADDSUBPSZv213rmbk */
  0xfaf, /* VFMADDSUBPSZv213rrbk */
/* Table9437 */
  0x105b, /* VFMSUBADDPSZv213rmbk */
  0x1061, /* VFMSUBADDPSZv213rrbk */
/* Table9439 */
  0xee5, /* VFMADDPSZv213rmbk */
  0xeeb, /* VFMADDPSZv213rrbk */
/* Table9441 */
  0x10f5, /* VFMSUBPSZv213rmbk */
  0x10fb, /* VFMSUBPSZv213rrbk */
/* Table9443 */
  0x11b9, /* VFNMADDPSZv213rmbk */
  0x11bf, /* VFNMADDPSZv213rrbk */
/* Table9445 */
  0x127d, /* VFNMSUBPSZv213rmbk */
  0x1283, /* VFNMSUBPSZv213rrbk */
/* Table9447 */
  0xfb5, /* VFMADDSUBPSZv231rmbk */
  0x0, /*  */
/* Table9449 */
  0x1067, /* VFMSUBADDPSZv231rmbk */
  0x0, /*  */
/* Table9451 */
  0xef1, /* VFMADDPSZv231rmbk */
  0x0, /*  */
/* Table9453 */
  0x1101, /* VFMSUBPSZv231rmbk */
  0x0, /*  */
/* Table9455 */
  0x11c5, /* VFNMADDPSZv231rmbk */
  0x0, /*  */
/* Table9457 */
  0x1289, /* VFNMSUBPSZv231rmbk */
  0x0, /*  */
/* Table9459 */
  0x1a0f, /* VPCONFLICTDrmbk */
  0x0, /*  */
/* Table9461 */
  0xe24, /* VEXP2PSmbk */
  0xe2a, /* VEXP2PSrbk */
/* Table9463 */
  0x2078, /* VRCP28PSmbk */
  0x207e, /* VRCP28PSrbk */
/* Table9465 */
  0x210b, /* VRSQRT28PSmbk */
  0x2111, /* VRSQRT28PSrbk */
/* Table9467 */
  0x1684, /* VPABSQZrmbk */
  0x0, /*  */
/* Table9469 */
  0x1d93, /* VPMULDQZrmbk */
  0x0, /*  */
/* Table9471 */
  0x18b5, /* VPCMPEQQZrmbk */
  0x0, /*  */
/* Table9473 */
  0x1909, /* VPCMPGTQZrmbk */
  0x0, /*  */
/* Table9475 */
  0x1c47, /* VPMINSQZrmbk */
  0x0, /*  */
/* Table9477 */
  0x1cad, /* VPMINUQZrmbk */
  0x0, /*  */
/* Table9479 */
  0x1b7b, /* VPMAXSQZrmbk */
  0x0, /*  */
/* Table9481 */
  0x1be1, /* VPMAXUQZrmbk */
  0x0, /*  */
/* Table9483 */
  0x1ddb, /* VPMULLQZrmbk */
  0x0, /*  */
/* Table9485 */
  0x1b03, /* VPLZCNTQrmbk */
  0x0, /*  */
/* Table9487 */
  0x2044, /* VRCP14PDZmbk */
  0x0, /*  */
/* Table9489 */
  0x20d7, /* VRSQRT14PDZmbk */
  0x0, /*  */
/* Table9491 */
  0x17d9, /* VPBLENDMQZrmbk */
  0x0, /*  */
/* Table9493 */
  0xc6e, /* VBLENDMPDZrmbk */
  0x0, /*  */
/* Table9495 */
  0xf5c, /* VFMADDSUBPDZv213rmbk */
  0xf62, /* VFMADDSUBPDZv213rrbk */
/* Table9497 */
  0x100e, /* VFMSUBADDPDZv213rmbk */
  0x1014, /* VFMSUBADDPDZv213rrbk */
/* Table9499 */
  0xe98, /* VFMADDPDZv213rmbk */
  0xe9e, /* VFMADDPDZv213rrbk */
/* Table9501 */
  0x10a8, /* VFMSUBPDZv213rmbk */
  0x10ae, /* VFMSUBPDZv213rrbk */
/* Table9503 */
  0x116c, /* VFNMADDPDZv213rmbk */
  0x1172, /* VFNMADDPDZv213rrbk */
/* Table9505 */
  0x1230, /* VFNMSUBPDZv213rmbk */
  0x1236, /* VFNMSUBPDZv213rrbk */
/* Table9507 */
  0xf68, /* VFMADDSUBPDZv231rmbk */
  0x0, /*  */
/* Table9509 */
  0x101a, /* VFMSUBADDPDZv231rmbk */
  0x0, /*  */
/* Table9511 */
  0xea4, /* VFMADDPDZv231rmbk */
  0x0, /*  */
/* Table9513 */
  0x10b4, /* VFMSUBPDZv231rmbk */
  0x0, /*  */
/* Table9515 */
  0x1178, /* VFNMADDPDZv231rmbk */
  0x0, /*  */
/* Table9517 */
  0x123c, /* VFNMSUBPDZv231rmbk */
  0x0, /*  */
/* Table9519 */
  0x1a18, /* VPCONFLICTQrmbk */
  0x0, /*  */
/* Table9521 */
  0xe18, /* VEXP2PDmbk */
  0xe1e, /* VEXP2PDrbk */
/* Table9523 */
  0x206c, /* VRCP28PDmbk */
  0x2072, /* VRCP28PDrbk */
/* Table9525 */
  0x20ff, /* VRSQRT28PDmbk */
  0x2105, /* VRSQRT28PDrbk */
/* Table9527 */
  0x1c19, /* VPMINSDZ128rmbkz */
  0x0, /*  */
/* Table9529 */
  0x1c7f, /* VPMINUDZ128rmbkz */
  0x0, /*  */
/* Table9531 */
  0x1b4d, /* VPMAXSDZ128rmbkz */
  0x0, /*  */
/* Table9533 */
  0x1bb3, /* VPMAXUDZ128rmbkz */
  0x0, /*  */
/* Table9535 */
  0x1dad, /* VPMULLDZ128rmbkz */
  0x0, /*  */
/* Table9537 */
  0x204e, /* VRCP14PSZ128mbkz */
  0x0, /*  */
/* Table9539 */
  0x20e1, /* VRSQRT14PSZ128mbkz */
  0x0, /*  */
/* Table9541 */
  0xf86, /* VFMADDSUBPSZ128v213rmbkz */
  0x0, /*  */
/* Table9543 */
  0x1038, /* VFMSUBADDPSZ128v213rmbkz */
  0x0, /*  */
/* Table9545 */
  0xec2, /* VFMADDPSZ128v213rmbkz */
  0x0, /*  */
/* Table9547 */
  0x10d2, /* VFMSUBPSZ128v213rmbkz */
  0x0, /*  */
/* Table9549 */
  0x1196, /* VFNMADDPSZ128v213rmbkz */
  0x0, /*  */
/* Table9551 */
  0x125a, /* VFNMSUBPSZ128v213rmbkz */
  0x0, /*  */
/* Table9553 */
  0xf8f, /* VFMADDSUBPSZ128v231rmbkz */
  0x0, /*  */
/* Table9555 */
  0x1041, /* VFMSUBADDPSZ128v231rmbkz */
  0x0, /*  */
/* Table9557 */
  0xecb, /* VFMADDPSZ128v231rmbkz */
  0x0, /*  */
/* Table9559 */
  0x10db, /* VFMSUBPSZ128v231rmbkz */
  0x0, /*  */
/* Table9561 */
  0x119f, /* VFNMADDPSZ128v231rmbkz */
  0x0, /*  */
/* Table9563 */
  0x1263, /* VFNMSUBPSZ128v231rmbkz */
  0x0, /*  */
/* Table9565 */
  0x0, /*  */
  0x2091, /* VRCP28SSrbkz */
/* Table9567 */
  0x0, /*  */
  0x2124, /* VRSQRT28SSrbkz */
/* Table9569 */
  0x1c36, /* VPMINSQZ128rmbkz */
  0x0, /*  */
/* Table9571 */
  0x1c9c, /* VPMINUQZ128rmbkz */
  0x0, /*  */
/* Table9573 */
  0x1b6a, /* VPMAXSQZ128rmbkz */
  0x0, /*  */
/* Table9575 */
  0x1bd0, /* VPMAXUQZ128rmbkz */
  0x0, /*  */
/* Table9577 */
  0x1dca, /* VPMULLQZ128rmbkz */
  0x0, /*  */
/* Table9579 */
  0x2033, /* VRCP14PDZ128mbkz */
  0x0, /*  */
/* Table9581 */
  0x20c6, /* VRSQRT14PDZ128mbkz */
  0x0, /*  */
/* Table9583 */
  0xf39, /* VFMADDSUBPDZ128v213rmbkz */
  0x0, /*  */
/* Table9585 */
  0xfeb, /* VFMSUBADDPDZ128v213rmbkz */
  0x0, /*  */
/* Table9587 */
  0xe75, /* VFMADDPDZ128v213rmbkz */
  0x0, /*  */
/* Table9589 */
  0x1085, /* VFMSUBPDZ128v213rmbkz */
  0x0, /*  */
/* Table9591 */
  0x1149, /* VFNMADDPDZ128v213rmbkz */
  0x0, /*  */
/* Table9593 */
  0x120d, /* VFNMSUBPDZ128v213rmbkz */
  0x0, /*  */
/* Table9595 */
  0xf42, /* VFMADDSUBPDZ128v231rmbkz */
  0x0, /*  */
/* Table9597 */
  0xff4, /* VFMSUBADDPDZ128v231rmbkz */
  0x0, /*  */
/* Table9599 */
  0xe7e, /* VFMADDPDZ128v231rmbkz */
  0x0, /*  */
/* Table9601 */
  0x108e, /* VFMSUBPDZ128v231rmbkz */
  0x0, /*  */
/* Table9603 */
  0x1152, /* VFNMADDPDZ128v231rmbkz */
  0x0, /*  */
/* Table9605 */
  0x1216, /* VFNMSUBPDZ128v231rmbkz */
  0x0, /*  */
/* Table9607 */
  0x0, /*  */
  0x2088, /* VRCP28SDrbkz */
/* Table9609 */
  0x0, /*  */
  0x211b, /* VRSQRT28SDrbkz */
/* Table9611 */
  0x1c22, /* VPMINSDZ256rmbkz */
  0x0, /*  */
/* Table9613 */
  0x1c88, /* VPMINUDZ256rmbkz */
  0x0, /*  */
/* Table9615 */
  0x1b56, /* VPMAXSDZ256rmbkz */
  0x0, /*  */
/* Table9617 */
  0x1bbc, /* VPMAXUDZ256rmbkz */
  0x0, /*  */
/* Table9619 */
  0x1db6, /* VPMULLDZ256rmbkz */
  0x0, /*  */
/* Table9621 */
  0x2057, /* VRCP14PSZ256mbkz */
  0x0, /*  */
/* Table9623 */
  0x20ea, /* VRSQRT14PSZ256mbkz */
  0x0, /*  */
/* Table9625 */
  0xf98, /* VFMADDSUBPSZ256v213rmbkz */
  0x0, /*  */
/* Table9627 */
  0x104a, /* VFMSUBADDPSZ256v213rmbkz */
  0x0, /*  */
/* Table9629 */
  0xed4, /* VFMADDPSZ256v213rmbkz */
  0x0, /*  */
/* Table9631 */
  0x10e4, /* VFMSUBPSZ256v213rmbkz */
  0x0, /*  */
/* Table9633 */
  0x11a8, /* VFNMADDPSZ256v213rmbkz */
  0x0, /*  */
/* Table9635 */
  0x126c, /* VFNMSUBPSZ256v213rmbkz */
  0x0, /*  */
/* Table9637 */
  0xfa1, /* VFMADDSUBPSZ256v231rmbkz */
  0x0, /*  */
/* Table9639 */
  0x1053, /* VFMSUBADDPSZ256v231rmbkz */
  0x0, /*  */
/* Table9641 */
  0xedd, /* VFMADDPSZ256v231rmbkz */
  0x0, /*  */
/* Table9643 */
  0x10ed, /* VFMSUBPSZ256v231rmbkz */
  0x0, /*  */
/* Table9645 */
  0x11b1, /* VFNMADDPSZ256v231rmbkz */
  0x0, /*  */
/* Table9647 */
  0x1275, /* VFNMSUBPSZ256v231rmbkz */
  0x0, /*  */
/* Table9649 */
  0x1c3f, /* VPMINSQZ256rmbkz */
  0x0, /*  */
/* Table9651 */
  0x1ca5, /* VPMINUQZ256rmbkz */
  0x0, /*  */
/* Table9653 */
  0x1b73, /* VPMAXSQZ256rmbkz */
  0x0, /*  */
/* Table9655 */
  0x1bd9, /* VPMAXUQZ256rmbkz */
  0x0, /*  */
/* Table9657 */
  0x1dd3, /* VPMULLQZ256rmbkz */
  0x0, /*  */
/* Table9659 */
  0x203c, /* VRCP14PDZ256mbkz */
  0x0, /*  */
/* Table9661 */
  0x20cf, /* VRSQRT14PDZ256mbkz */
  0x0, /*  */
/* Table9663 */
  0xf4b, /* VFMADDSUBPDZ256v213rmbkz */
  0x0, /*  */
/* Table9665 */
  0xffd, /* VFMSUBADDPDZ256v213rmbkz */
  0x0, /*  */
/* Table9667 */
  0xe87, /* VFMADDPDZ256v213rmbkz */
  0x0, /*  */
/* Table9669 */
  0x1097, /* VFMSUBPDZ256v213rmbkz */
  0x0, /*  */
/* Table9671 */
  0x115b, /* VFNMADDPDZ256v213rmbkz */
  0x0, /*  */
/* Table9673 */
  0x121f, /* VFNMSUBPDZ256v213rmbkz */
  0x0, /*  */
/* Table9675 */
  0xf54, /* VFMADDSUBPDZ256v231rmbkz */
  0x0, /*  */
/* Table9677 */
  0x1006, /* VFMSUBADDPDZ256v231rmbkz */
  0x0, /*  */
/* Table9679 */
  0xe90, /* VFMADDPDZ256v231rmbkz */
  0x0, /*  */
/* Table9681 */
  0x10a0, /* VFMSUBPDZ256v231rmbkz */
  0x0, /*  */
/* Table9683 */
  0x1164, /* VFNMADDPDZ256v231rmbkz */
  0x0, /*  */
/* Table9685 */
  0x1228, /* VFNMSUBPDZ256v231rmbkz */
  0x0, /*  */
/* Table9687 */
  0x1678, /* VPABSDZrmbkz */
  0x0, /*  */
/* Table9689 */
  0x1c2b, /* VPMINSDZrmbkz */
  0x0, /*  */
/* Table9691 */
  0x1c91, /* VPMINUDZrmbkz */
  0x0, /*  */
/* Table9693 */
  0x1b5f, /* VPMAXSDZrmbkz */
  0x0, /*  */
/* Table9695 */
  0x1bc5, /* VPMAXUDZrmbkz */
  0x0, /*  */
/* Table9697 */
  0x1dbf, /* VPMULLDZrmbkz */
  0x0, /*  */
/* Table9699 */
  0x1afb, /* VPLZCNTDrmbkz */
  0x0, /*  */
/* Table9701 */
  0x2060, /* VRCP14PSZmbkz */
  0x0, /*  */
/* Table9703 */
  0x20f3, /* VRSQRT14PSZmbkz */
  0x0, /*  */
/* Table9705 */
  0xfaa, /* VFMADDSUBPSZv213rmbkz */
  0xfb0, /* VFMADDSUBPSZv213rrbkz */
/* Table9707 */
  0x105c, /* VFMSUBADDPSZv213rmbkz */
  0x1062, /* VFMSUBADDPSZv213rrbkz */
/* Table9709 */
  0xee6, /* VFMADDPSZv213rmbkz */
  0xeec, /* VFMADDPSZv213rrbkz */
/* Table9711 */
  0x10f6, /* VFMSUBPSZv213rmbkz */
  0x10fc, /* VFMSUBPSZv213rrbkz */
/* Table9713 */
  0x11ba, /* VFNMADDPSZv213rmbkz */
  0x11c0, /* VFNMADDPSZv213rrbkz */
/* Table9715 */
  0x127e, /* VFNMSUBPSZv213rmbkz */
  0x1284, /* VFNMSUBPSZv213rrbkz */
/* Table9717 */
  0xfb6, /* VFMADDSUBPSZv231rmbkz */
  0x0, /*  */
/* Table9719 */
  0x1068, /* VFMSUBADDPSZv231rmbkz */
  0x0, /*  */
/* Table9721 */
  0xef2, /* VFMADDPSZv231rmbkz */
  0x0, /*  */
/* Table9723 */
  0x1102, /* VFMSUBPSZv231rmbkz */
  0x0, /*  */
/* Table9725 */
  0x11c6, /* VFNMADDPSZv231rmbkz */
  0x0, /*  */
/* Table9727 */
  0x128a, /* VFNMSUBPSZv231rmbkz */
  0x0, /*  */
/* Table9729 */
  0x1a10, /* VPCONFLICTDrmbkz */
  0x0, /*  */
/* Table9731 */
  0xe25, /* VEXP2PSmbkz */
  0xe2b, /* VEXP2PSrbkz */
/* Table9733 */
  0x2079, /* VRCP28PSmbkz */
  0x207f, /* VRCP28PSrbkz */
/* Table9735 */
  0x210c, /* VRSQRT28PSmbkz */
  0x2112, /* VRSQRT28PSrbkz */
/* Table9737 */
  0x1685, /* VPABSQZrmbkz */
  0x0, /*  */
/* Table9739 */
  0x1d94, /* VPMULDQZrmbkz */
  0x0, /*  */
/* Table9741 */
  0x1c48, /* VPMINSQZrmbkz */
  0x0, /*  */
/* Table9743 */
  0x1cae, /* VPMINUQZrmbkz */
  0x0, /*  */
/* Table9745 */
  0x1b7c, /* VPMAXSQZrmbkz */
  0x0, /*  */
/* Table9747 */
  0x1be2, /* VPMAXUQZrmbkz */
  0x0, /*  */
/* Table9749 */
  0x1ddc, /* VPMULLQZrmbkz */
  0x0, /*  */
/* Table9751 */
  0x1b04, /* VPLZCNTQrmbkz */
  0x0, /*  */
/* Table9753 */
  0x2045, /* VRCP14PDZmbkz */
  0x0, /*  */
/* Table9755 */
  0x20d8, /* VRSQRT14PDZmbkz */
  0x0, /*  */
/* Table9757 */
  0xf5d, /* VFMADDSUBPDZv213rmbkz */
  0xf63, /* VFMADDSUBPDZv213rrbkz */
/* Table9759 */
  0x100f, /* VFMSUBADDPDZv213rmbkz */
  0x1015, /* VFMSUBADDPDZv213rrbkz */
/* Table9761 */
  0xe99, /* VFMADDPDZv213rmbkz */
  0xe9f, /* VFMADDPDZv213rrbkz */
/* Table9763 */
  0x10a9, /* VFMSUBPDZv213rmbkz */
  0x10af, /* VFMSUBPDZv213rrbkz */
/* Table9765 */
  0x116d, /* VFNMADDPDZv213rmbkz */
  0x1173, /* VFNMADDPDZv213rrbkz */
/* Table9767 */
  0x1231, /* VFNMSUBPDZv213rmbkz */
  0x1237, /* VFNMSUBPDZv213rrbkz */
/* Table9769 */
  0xf69, /* VFMADDSUBPDZv231rmbkz */
  0x0, /*  */
/* Table9771 */
  0x101b, /* VFMSUBADDPDZv231rmbkz */
  0x0, /*  */
/* Table9773 */
  0xea5, /* VFMADDPDZv231rmbkz */
  0x0, /*  */
/* Table9775 */
  0x10b5, /* VFMSUBPDZv231rmbkz */
  0x0, /*  */
/* Table9777 */
  0x1179, /* VFNMADDPDZv231rmbkz */
  0x0, /*  */
/* Table9779 */
  0x123d, /* VFNMSUBPDZv231rmbkz */
  0x0, /*  */
/* Table9781 */
  0x1a19, /* VPCONFLICTQrmbkz */
  0x0, /*  */
/* Table9783 */
  0xe19, /* VEXP2PDmbkz */
  0xe1f, /* VEXP2PDrbkz */
/* Table9785 */
  0x206d, /* VRCP28PDmbkz */
  0x2073, /* VRCP28PDrbkz */
/* Table9787 */
  0x2100, /* VRSQRT28PDmbkz */
  0x2106, /* VRSQRT28PDrbkz */
/* Table9789 */
  0xcb3, /* VBROADCASTSSZ128mkz */
  0xcb6, /* VBROADCASTSSZ128rkz */
/* Table9791 */
  0x1c02, /* VPMINSBZ128rmkz */
  0x1c05, /* VPMINSBZ128rrkz */
/* Table9793 */
  0x1c1b, /* VPMINSDZ128rmkz */
  0x1c1e, /* VPMINSDZ128rrkz */
/* Table9795 */
  0x1cb8, /* VPMINUWZ128rmkz */
  0x1cbb, /* VPMINUWZ128rrkz */
/* Table9797 */
  0x1c81, /* VPMINUDZ128rmkz */
  0x1c84, /* VPMINUDZ128rrkz */
/* Table9799 */
  0x1b36, /* VPMAXSBZ128rmkz */
  0x1b39, /* VPMAXSBZ128rrkz */
/* Table9801 */
  0x1b4f, /* VPMAXSDZ128rmkz */
  0x1b52, /* VPMAXSDZ128rrkz */
/* Table9803 */
  0x1bec, /* VPMAXUWZ128rmkz */
  0x1bef, /* VPMAXUWZ128rrkz */
/* Table9805 */
  0x1bb5, /* VPMAXUDZ128rmkz */
  0x1bb8, /* VPMAXUDZ128rrkz */
/* Table9807 */
  0x1daf, /* VPMULLDZ128rmkz */
  0x1db2, /* VPMULLDZ128rrkz */
/* Table9809 */
  0x2050, /* VRCP14PSZ128mkz */
  0x2053, /* VRCP14PSZ128rkz */
/* Table9811 */
  0x20e3, /* VRSQRT14PSZ128mkz */
  0x20e6, /* VRSQRT14PSZ128rkz */
/* Table9813 */
  0x17b3, /* VPBLENDMDZ128rmkz */
  0x17b6, /* VPBLENDMDZ128rrkz */
/* Table9815 */
  0xc78, /* VBLENDMPSZ128rmkz */
  0xc7b, /* VBLENDMPSZ128rrkz */
/* Table9817 */
  0x179f, /* VPBLENDMBZ128rmkz */
  0x17a2, /* VPBLENDMBZ128rrkz */
/* Table9819 */
  0x0, /*  */
  0x17fd, /* VPBROADCASTBrZ128rkz */
/* Table9821 */
  0x0, /*  */
  0x1832, /* VPBROADCASTWrZ128rkz */
/* Table9823 */
  0x0, /*  */
  0x180e, /* VPBROADCASTDrZ128rkz */
/* Table9825 */
  0xe3b, /* VEXPANDPSZ128rmkz */
  0xe3d, /* VEXPANDPSZ128rrkz */
/* Table9827 */
  0x1a8c, /* VPEXPANDDZ128rmkz */
  0x1a8e, /* VPEXPANDDZ128rrkz */
/* Table9829 */
  0x0, /*  */
  0xd04, /* VCOMPRESSPSZ128rrkz */
/* Table9831 */
  0x0, /*  */
  0x19e5, /* VPCOMPRESSDZ128rrkz */
/* Table9833 */
  0xf88, /* VFMADDSUBPSZ128v213rmkz */
  0xf8b, /* VFMADDSUBPSZ128v213rrkz */
/* Table9835 */
  0x103a, /* VFMSUBADDPSZ128v213rmkz */
  0x103d, /* VFMSUBADDPSZ128v213rrkz */
/* Table9837 */
  0xec4, /* VFMADDPSZ128v213rmkz */
  0xec7, /* VFMADDPSZ128v213rrkz */
/* Table9839 */
  0x10d4, /* VFMSUBPSZ128v213rmkz */
  0x10d7, /* VFMSUBPSZ128v213rrkz */
/* Table9841 */
  0x1198, /* VFNMADDPSZ128v213rmkz */
  0x119b, /* VFNMADDPSZ128v213rrkz */
/* Table9843 */
  0x125c, /* VFNMSUBPSZ128v213rmkz */
  0x125f, /* VFNMSUBPSZ128v213rrkz */
/* Table9845 */
  0xf91, /* VFMADDSUBPSZ128v231rmkz */
  0xf94, /* VFMADDSUBPSZ128v231rrkz */
/* Table9847 */
  0x1043, /* VFMSUBADDPSZ128v231rmkz */
  0x1046, /* VFMSUBADDPSZ128v231rrkz */
/* Table9849 */
  0xecd, /* VFMADDPSZ128v231rmkz */
  0xed0, /* VFMADDPSZ128v231rrkz */
/* Table9851 */
  0x10dd, /* VFMSUBPSZ128v231rmkz */
  0x10e0, /* VFMSUBPSZ128v231rrkz */
/* Table9853 */
  0x11a1, /* VFNMADDPSZ128v231rmkz */
  0x11a4, /* VFNMADDPSZ128v231rrkz */
/* Table9855 */
  0x1265, /* VFNMSUBPSZ128v231rmkz */
  0x1268, /* VFNMSUBPSZ128v231rrkz */
/* Table9857 */
  0x208d, /* VRCP28SSmkz */
  0x2093, /* VRCP28SSrkz */
/* Table9859 */
  0x2120, /* VRSQRT28SSmkz */
  0x2126, /* VRSQRT28SSrkz */
/* Table9861 */
  0x1c38, /* VPMINSQZ128rmkz */
  0x1c3b, /* VPMINSQZ128rrkz */
/* Table9863 */
  0x1c9e, /* VPMINUQZ128rmkz */
  0x1ca1, /* VPMINUQZ128rrkz */
/* Table9865 */
  0x1b6c, /* VPMAXSQZ128rmkz */
  0x1b6f, /* VPMAXSQZ128rrkz */
/* Table9867 */
  0x1bd2, /* VPMAXUQZ128rmkz */
  0x1bd5, /* VPMAXUQZ128rrkz */
/* Table9869 */
  0x1dcc, /* VPMULLQZ128rmkz */
  0x1dcf, /* VPMULLQZ128rrkz */
/* Table9871 */
  0x2035, /* VRCP14PDZ128mkz */
  0x2038, /* VRCP14PDZ128rkz */
/* Table9873 */
  0x20c8, /* VRSQRT14PDZ128mkz */
  0x20cb, /* VRSQRT14PDZ128rkz */
/* Table9875 */
  0x17cb, /* VPBLENDMQZ128rmkz */
  0x17ce, /* VPBLENDMQZ128rrkz */
/* Table9877 */
  0xc60, /* VBLENDMPDZ128rmkz */
  0xc63, /* VBLENDMPDZ128rrkz */
/* Table9879 */
  0x17e1, /* VPBLENDMWZ128rmkz */
  0x17e4, /* VPBLENDMWZ128rrkz */
/* Table9881 */
  0x0, /*  */
  0x1825, /* VPBROADCASTQrZ128rkz */
/* Table9883 */
  0xe2f, /* VEXPANDPDZ128rmkz */
  0xe31, /* VEXPANDPDZ128rrkz */
/* Table9885 */
  0x1a98, /* VPEXPANDQZ128rmkz */
  0x1a9a, /* VPEXPANDQZ128rrkz */
/* Table9887 */
  0x0, /*  */
  0xcfb, /* VCOMPRESSPDZ128rrkz */
/* Table9889 */
  0x0, /*  */
  0x19ee, /* VPCOMPRESSQZ128rrkz */
/* Table9891 */
  0xf3b, /* VFMADDSUBPDZ128v213rmkz */
  0xf3e, /* VFMADDSUBPDZ128v213rrkz */
/* Table9893 */
  0xfed, /* VFMSUBADDPDZ128v213rmkz */
  0xff0, /* VFMSUBADDPDZ128v213rrkz */
/* Table9895 */
  0xe77, /* VFMADDPDZ128v213rmkz */
  0xe7a, /* VFMADDPDZ128v213rrkz */
/* Table9897 */
  0x1087, /* VFMSUBPDZ128v213rmkz */
  0x108a, /* VFMSUBPDZ128v213rrkz */
/* Table9899 */
  0x114b, /* VFNMADDPDZ128v213rmkz */
  0x114e, /* VFNMADDPDZ128v213rrkz */
/* Table9901 */
  0x120f, /* VFNMSUBPDZ128v213rmkz */
  0x1212, /* VFNMSUBPDZ128v213rrkz */
/* Table9903 */
  0xf44, /* VFMADDSUBPDZ128v231rmkz */
  0xf47, /* VFMADDSUBPDZ128v231rrkz */
/* Table9905 */
  0xff6, /* VFMSUBADDPDZ128v231rmkz */
  0xff9, /* VFMSUBADDPDZ128v231rrkz */
/* Table9907 */
  0xe80, /* VFMADDPDZ128v231rmkz */
  0xe83, /* VFMADDPDZ128v231rrkz */
/* Table9909 */
  0x1090, /* VFMSUBPDZ128v231rmkz */
  0x1093, /* VFMSUBPDZ128v231rrkz */
/* Table9911 */
  0x1154, /* VFNMADDPDZ128v231rmkz */
  0x1157, /* VFNMADDPDZ128v231rrkz */
/* Table9913 */
  0x1218, /* VFNMSUBPDZ128v231rmkz */
  0x121b, /* VFNMSUBPDZ128v231rrkz */
/* Table9915 */
  0x2084, /* VRCP28SDmkz */
  0x208a, /* VRCP28SDrkz */
/* Table9917 */
  0x2117, /* VRSQRT28SDmkz */
  0x211d, /* VRSQRT28SDrkz */
/* Table9919 */
  0xcb9, /* VBROADCASTSSZ256mkz */
  0xcbc, /* VBROADCASTSSZ256rkz */
/* Table9921 */
  0x1c08, /* VPMINSBZ256rmkz */
  0x1c0b, /* VPMINSBZ256rrkz */
/* Table9923 */
  0x1c24, /* VPMINSDZ256rmkz */
  0x1c27, /* VPMINSDZ256rrkz */
/* Table9925 */
  0x1cbe, /* VPMINUWZ256rmkz */
  0x1cc1, /* VPMINUWZ256rrkz */
/* Table9927 */
  0x1c8a, /* VPMINUDZ256rmkz */
  0x1c8d, /* VPMINUDZ256rrkz */
/* Table9929 */
  0x1b3c, /* VPMAXSBZ256rmkz */
  0x1b3f, /* VPMAXSBZ256rrkz */
/* Table9931 */
  0x1b58, /* VPMAXSDZ256rmkz */
  0x1b5b, /* VPMAXSDZ256rrkz */
/* Table9933 */
  0x1bf2, /* VPMAXUWZ256rmkz */
  0x1bf5, /* VPMAXUWZ256rrkz */
/* Table9935 */
  0x1bbe, /* VPMAXUDZ256rmkz */
  0x1bc1, /* VPMAXUDZ256rrkz */
/* Table9937 */
  0x1db8, /* VPMULLDZ256rmkz */
  0x1dbb, /* VPMULLDZ256rrkz */
/* Table9939 */
  0x2059, /* VRCP14PSZ256mkz */
  0x205c, /* VRCP14PSZ256rkz */
/* Table9941 */
  0x20ec, /* VRSQRT14PSZ256mkz */
  0x20ef, /* VRSQRT14PSZ256rkz */
/* Table9943 */
  0x17bb, /* VPBLENDMDZ256rmkz */
  0x17be, /* VPBLENDMDZ256rrkz */
/* Table9945 */
  0xc80, /* VBLENDMPSZ256rmkz */
  0xc83, /* VBLENDMPSZ256rrkz */
/* Table9947 */
  0x17a5, /* VPBLENDMBZ256rmkz */
  0x17a8, /* VPBLENDMBZ256rrkz */
/* Table9949 */
  0x0, /*  */
  0x1800, /* VPBROADCASTBrZ256rkz */
/* Table9951 */
  0x0, /*  */
  0x1835, /* VPBROADCASTWrZ256rkz */
/* Table9953 */
  0x0, /*  */
  0x1811, /* VPBROADCASTDrZ256rkz */
/* Table9955 */
  0xe3f, /* VEXPANDPSZ256rmkz */
  0xe41, /* VEXPANDPSZ256rrkz */
/* Table9957 */
  0x1a90, /* VPEXPANDDZ256rmkz */
  0x1a92, /* VPEXPANDDZ256rrkz */
/* Table9959 */
  0x0, /*  */
  0xd07, /* VCOMPRESSPSZ256rrkz */
/* Table9961 */
  0x0, /*  */
  0x19e8, /* VPCOMPRESSDZ256rrkz */
/* Table9963 */
  0xf9a, /* VFMADDSUBPSZ256v213rmkz */
  0xf9d, /* VFMADDSUBPSZ256v213rrkz */
/* Table9965 */
  0x104c, /* VFMSUBADDPSZ256v213rmkz */
  0x104f, /* VFMSUBADDPSZ256v213rrkz */
/* Table9967 */
  0xed6, /* VFMADDPSZ256v213rmkz */
  0xed9, /* VFMADDPSZ256v213rrkz */
/* Table9969 */
  0x10e6, /* VFMSUBPSZ256v213rmkz */
  0x10e9, /* VFMSUBPSZ256v213rrkz */
/* Table9971 */
  0x11aa, /* VFNMADDPSZ256v213rmkz */
  0x11ad, /* VFNMADDPSZ256v213rrkz */
/* Table9973 */
  0x126e, /* VFNMSUBPSZ256v213rmkz */
  0x1271, /* VFNMSUBPSZ256v213rrkz */
/* Table9975 */
  0xfa3, /* VFMADDSUBPSZ256v231rmkz */
  0xfa6, /* VFMADDSUBPSZ256v231rrkz */
/* Table9977 */
  0x1055, /* VFMSUBADDPSZ256v231rmkz */
  0x1058, /* VFMSUBADDPSZ256v231rrkz */
/* Table9979 */
  0xedf, /* VFMADDPSZ256v231rmkz */
  0xee2, /* VFMADDPSZ256v231rrkz */
/* Table9981 */
  0x10ef, /* VFMSUBPSZ256v231rmkz */
  0x10f2, /* VFMSUBPSZ256v231rrkz */
/* Table9983 */
  0x11b3, /* VFNMADDPSZ256v231rmkz */
  0x11b6, /* VFNMADDPSZ256v231rrkz */
/* Table9985 */
  0x1277, /* VFNMSUBPSZ256v231rmkz */
  0x127a, /* VFNMSUBPSZ256v231rrkz */
/* Table9987 */
  0xca5, /* VBROADCASTSDZ256mkz */
  0xca8, /* VBROADCASTSDZ256rkz */
/* Table9989 */
  0x1c41, /* VPMINSQZ256rmkz */
  0x1c44, /* VPMINSQZ256rrkz */
/* Table9991 */
  0x1ca7, /* VPMINUQZ256rmkz */
  0x1caa, /* VPMINUQZ256rrkz */
/* Table9993 */
  0x1b75, /* VPMAXSQZ256rmkz */
  0x1b78, /* VPMAXSQZ256rrkz */
/* Table9995 */
  0x1bdb, /* VPMAXUQZ256rmkz */
  0x1bde, /* VPMAXUQZ256rrkz */
/* Table9997 */
  0x1dd5, /* VPMULLQZ256rmkz */
  0x1dd8, /* VPMULLQZ256rrkz */
/* Table9999 */
  0x203e, /* VRCP14PDZ256mkz */
  0x2041, /* VRCP14PDZ256rkz */
/* Table10001 */
  0x20d1, /* VRSQRT14PDZ256mkz */
  0x20d4, /* VRSQRT14PDZ256rkz */
/* Table10003 */
  0x17d3, /* VPBLENDMQZ256rmkz */
  0x17d6, /* VPBLENDMQZ256rrkz */
/* Table10005 */
  0xc68, /* VBLENDMPDZ256rmkz */
  0xc6b, /* VBLENDMPDZ256rrkz */
/* Table10007 */
  0x17e7, /* VPBLENDMWZ256rmkz */
  0x17ea, /* VPBLENDMWZ256rrkz */
/* Table10009 */
  0x0, /*  */
  0x1828, /* VPBROADCASTQrZ256rkz */
/* Table10011 */
  0xe33, /* VEXPANDPDZ256rmkz */
  0xe35, /* VEXPANDPDZ256rrkz */
/* Table10013 */
  0x1a9c, /* VPEXPANDQZ256rmkz */
  0x1a9e, /* VPEXPANDQZ256rrkz */
/* Table10015 */
  0x0, /*  */
  0xcfe, /* VCOMPRESSPDZ256rrkz */
/* Table10017 */
  0x0, /*  */
  0x19f1, /* VPCOMPRESSQZ256rrkz */
/* Table10019 */
  0xf4d, /* VFMADDSUBPDZ256v213rmkz */
  0xf50, /* VFMADDSUBPDZ256v213rrkz */
/* Table10021 */
  0xfff, /* VFMSUBADDPDZ256v213rmkz */
  0x1002, /* VFMSUBADDPDZ256v213rrkz */
/* Table10023 */
  0xe89, /* VFMADDPDZ256v213rmkz */
  0xe8c, /* VFMADDPDZ256v213rrkz */
/* Table10025 */
  0x1099, /* VFMSUBPDZ256v213rmkz */
  0x109c, /* VFMSUBPDZ256v213rrkz */
/* Table10027 */
  0x115d, /* VFNMADDPDZ256v213rmkz */
  0x1160, /* VFNMADDPDZ256v213rrkz */
/* Table10029 */
  0x1221, /* VFNMSUBPDZ256v213rmkz */
  0x1224, /* VFNMSUBPDZ256v213rrkz */
/* Table10031 */
  0xf56, /* VFMADDSUBPDZ256v231rmkz */
  0xf59, /* VFMADDSUBPDZ256v231rrkz */
/* Table10033 */
  0x1008, /* VFMSUBADDPDZ256v231rmkz */
  0x100b, /* VFMSUBADDPDZ256v231rrkz */
/* Table10035 */
  0xe92, /* VFMADDPDZ256v231rmkz */
  0xe95, /* VFMADDPDZ256v231rrkz */
/* Table10037 */
  0x10a2, /* VFMSUBPDZ256v231rmkz */
  0x10a5, /* VFMSUBPDZ256v231rrkz */
/* Table10039 */
  0x1166, /* VFNMADDPDZ256v231rmkz */
  0x1169, /* VFNMADDPDZ256v231rrkz */
/* Table10041 */
  0x122a, /* VFNMSUBPDZ256v231rmkz */
  0x122d, /* VFNMSUBPDZ256v231rrkz */
/* Table10043 */
  0x0, /*  */
  0x1d44, /* VPMOVUSDBrrkz */
/* Table10045 */
  0x0, /*  */
  0x1d4e, /* VPMOVUSQBrrkz */
/* Table10047 */
  0x0, /*  */
  0x1d49, /* VPMOVUSDWrrkz */
/* Table10049 */
  0x0, /*  */
  0x1d58, /* VPMOVUSQWrrkz */
/* Table10051 */
  0x0, /*  */
  0x1d53, /* VPMOVUSQDrrkz */
/* Table10053 */
  0x0, /*  */
  0x1cf5, /* VPMOVSDBrrkz */
/* Table10055 */
  0x0, /*  */
  0x1cff, /* VPMOVSQBrrkz */
/* Table10057 */
  0x0, /*  */
  0x1cfa, /* VPMOVSDWrrkz */
/* Table10059 */
  0x0, /*  */
  0x1d09, /* VPMOVSQWrrkz */
/* Table10061 */
  0x0, /*  */
  0x1d04, /* VPMOVSQDrrkz */
/* Table10063 */
  0x0, /*  */
  0x1cce, /* VPMOVDBrrkz */
/* Table10065 */
  0x0, /*  */
  0x1ce6, /* VPMOVQBrrkz */
/* Table10067 */
  0x0, /*  */
  0x1cd3, /* VPMOVDWrrkz */
/* Table10069 */
  0x0, /*  */
  0x1cf0, /* VPMOVQWrrkz */
/* Table10071 */
  0x0, /*  */
  0x1ceb, /* VPMOVQDrrkz */
/* Table10073 */
  0xcbf, /* VBROADCASTSSZmkz */
  0xcc2, /* VBROADCASTSSZrkz */
/* Table10075 */
  0x167a, /* VPABSDZrmkz */
  0x167d, /* VPABSDZrrkz */
/* Table10077 */
  0x1d0e, /* VPMOVSXBDZrmkz */
  0x1d11, /* VPMOVSXBDZrrkz */
/* Table10079 */
  0x1d18, /* VPMOVSXBQZrmkz */
  0x1d1b, /* VPMOVSXBQZrrkz */
/* Table10081 */
  0x1d30, /* VPMOVSXWDZrmkz */
  0x1d33, /* VPMOVSXWDZrrkz */
/* Table10083 */
  0x1d3a, /* VPMOVSXWQZrmkz */
  0x1d3d, /* VPMOVSXWQZrrkz */
/* Table10085 */
  0x1d26, /* VPMOVSXDQZrmkz */
  0x1d29, /* VPMOVSXDQZrrkz */
/* Table10087 */
  0x1d5d, /* VPMOVZXBDZrmkz */
  0x1d60, /* VPMOVZXBDZrrkz */
/* Table10089 */
  0x1d67, /* VPMOVZXBQZrmkz */
  0x1d6a, /* VPMOVZXBQZrrkz */
/* Table10091 */
  0x1d7f, /* VPMOVZXWDZrmkz */
  0x1d82, /* VPMOVZXWDZrrkz */
/* Table10093 */
  0x1d89, /* VPMOVZXWQZrmkz */
  0x1d8c, /* VPMOVZXWQZrrkz */
/* Table10095 */
  0x1d75, /* VPMOVZXDQZrmkz */
  0x1d78, /* VPMOVZXDQZrrkz */
/* Table10097 */
  0x1c0e, /* VPMINSBZrmkz */
  0x1c11, /* VPMINSBZrrkz */
/* Table10099 */
  0x1c2d, /* VPMINSDZrmkz */
  0x1c30, /* VPMINSDZrrkz */
/* Table10101 */
  0x1cc4, /* VPMINUWZrmkz */
  0x1cc7, /* VPMINUWZrrkz */
/* Table10103 */
  0x1c93, /* VPMINUDZrmkz */
  0x1c96, /* VPMINUDZrrkz */
/* Table10105 */
  0x1b42, /* VPMAXSBZrmkz */
  0x1b45, /* VPMAXSBZrrkz */
/* Table10107 */
  0x1b61, /* VPMAXSDZrmkz */
  0x1b64, /* VPMAXSDZrrkz */
/* Table10109 */
  0x1bf8, /* VPMAXUWZrmkz */
  0x1bfb, /* VPMAXUWZrrkz */
/* Table10111 */
  0x1bc7, /* VPMAXUDZrmkz */
  0x1bca, /* VPMAXUDZrrkz */
/* Table10113 */
  0x1dc1, /* VPMULLDZrmkz */
  0x1dc4, /* VPMULLDZrrkz */
/* Table10115 */
  0x1afd, /* VPLZCNTDrmkz */
  0x1b00, /* VPLZCNTDrrkz */
/* Table10117 */
  0x1f32, /* VPSRLVDZrmkz */
  0x1f35, /* VPSRLVDZrrkz */
/* Table10119 */
  0x1ef6, /* VPSRAVDZrmkz */
  0x1ef9, /* VPSRAVDZrrkz */
/* Table10121 */
  0x1ebe, /* VPSLLVDZrmkz */
  0x1ec1, /* VPSLLVDZrrkz */
/* Table10123 */
  0x2062, /* VRCP14PSZmkz */
  0x2065, /* VRCP14PSZrkz */
/* Table10125 */
  0x20f5, /* VRSQRT14PSZmkz */
  0x20f8, /* VRSQRT14PSZrkz */
/* Table10127 */
  0x1808, /* VPBROADCASTDZkrm */
  0x1809, /* VPBROADCASTDZkrr */
/* Table10129 */
  0xc9d, /* VBROADCASTI32X4krm */
  0x0, /*  */
/* Table10131 */
  0x17c3, /* VPBLENDMDZrmkz */
  0x17c6, /* VPBLENDMDZrrkz */
/* Table10133 */
  0xc88, /* VBLENDMPSZrmkz */
  0xc8b, /* VBLENDMPSZrrkz */
/* Table10135 */
  0x17ab, /* VPBLENDMBZrmkz */
  0x17ae, /* VPBLENDMBZrrkz */
/* Table10137 */
  0x1a29, /* VPERMI2Drmkz */
  0x1a2c, /* VPERMI2Drrkz */
/* Table10139 */
  0x1a35, /* VPERMI2PSrmkz */
  0x1a38, /* VPERMI2PSrrkz */
/* Table10141 */
  0x0, /*  */
  0x1803, /* VPBROADCASTBrZrkz */
/* Table10143 */
  0x0, /*  */
  0x1838, /* VPBROADCASTWrZrkz */
/* Table10145 */
  0x0, /*  */
  0x1814, /* VPBROADCASTDrZrkz */
/* Table10147 */
  0x1a75, /* VPERMT2Drmkz */
  0x1a78, /* VPERMT2Drrkz */
/* Table10149 */
  0x1a81, /* VPERMT2PSrmkz */
  0x1a84, /* VPERMT2PSrrkz */
/* Table10151 */
  0xe43, /* VEXPANDPSZrmkz */
  0xe45, /* VEXPANDPSZrrkz */
/* Table10153 */
  0x1a94, /* VPEXPANDDZrmkz */
  0x1a96, /* VPEXPANDDZrrkz */
/* Table10155 */
  0x0, /*  */
  0xd0a, /* VCOMPRESSPSZrrkz */
/* Table10157 */
  0x0, /*  */
  0x19eb, /* VPCOMPRESSDZrrkz */
/* Table10159 */
  0xfac, /* VFMADDSUBPSZv213rmkz */
  0xfb2, /* VFMADDSUBPSZv213rrkz */
/* Table10161 */
  0x105e, /* VFMSUBADDPSZv213rmkz */
  0x1064, /* VFMSUBADDPSZv213rrkz */
/* Table10163 */
  0xee8, /* VFMADDPSZv213rmkz */
  0xeee, /* VFMADDPSZv213rrkz */
/* Table10165 */
  0x10f8, /* VFMSUBPSZv213rmkz */
  0x10fe, /* VFMSUBPSZv213rrkz */
/* Table10167 */
  0x11bc, /* VFNMADDPSZv213rmkz */
  0x11c2, /* VFNMADDPSZv213rrkz */
/* Table10169 */
  0x1280, /* VFNMSUBPSZv213rmkz */
  0x1286, /* VFNMSUBPSZv213rrkz */
/* Table10171 */
  0xfb8, /* VFMADDSUBPSZv231rmkz */
  0xfbb, /* VFMADDSUBPSZv231rrkz */
/* Table10173 */
  0x106a, /* VFMSUBADDPSZv231rmkz */
  0x106d, /* VFMSUBADDPSZv231rrkz */
/* Table10175 */
  0xef4, /* VFMADDPSZv231rmkz */
  0xef7, /* VFMADDPSZv231rrkz */
/* Table10177 */
  0x1104, /* VFMSUBPSZv231rmkz */
  0x1107, /* VFMSUBPSZv231rrkz */
/* Table10179 */
  0x11c8, /* VFNMADDPSZv231rmkz */
  0x11cb, /* VFNMADDPSZv231rrkz */
/* Table10181 */
  0x128c, /* VFNMSUBPSZv231rmkz */
  0x128f, /* VFNMSUBPSZv231rrkz */
/* Table10183 */
  0x1a12, /* VPCONFLICTDrmkz */
  0x1a15, /* VPCONFLICTDrrkz */
/* Table10185 */
  0xe27, /* VEXP2PSmkz */
  0xe2d, /* VEXP2PSrkz */
/* Table10187 */
  0x207b, /* VRCP28PSmkz */
  0x2081, /* VRCP28PSrkz */
/* Table10189 */
  0x210e, /* VRSQRT28PSmkz */
  0x2114, /* VRSQRT28PSrkz */
/* Table10191 */
  0xcab, /* VBROADCASTSDZmkz */
  0xcae, /* VBROADCASTSDZrkz */
/* Table10193 */
  0x1687, /* VPABSQZrmkz */
  0x168a, /* VPABSQZrrkz */
/* Table10195 */
  0x1d96, /* VPMULDQZrmkz */
  0x1d99, /* VPMULDQZrrkz */
/* Table10197 */
  0x1c4a, /* VPMINSQZrmkz */
  0x1c4d, /* VPMINSQZrrkz */
/* Table10199 */
  0x1cb0, /* VPMINUQZrmkz */
  0x1cb3, /* VPMINUQZrrkz */
/* Table10201 */
  0x1b7e, /* VPMAXSQZrmkz */
  0x1b81, /* VPMAXSQZrrkz */
/* Table10203 */
  0x1be4, /* VPMAXUQZrmkz */
  0x1be7, /* VPMAXUQZrrkz */
/* Table10205 */
  0x1dde, /* VPMULLQZrmkz */
  0x1de1, /* VPMULLQZrrkz */
/* Table10207 */
  0x1b06, /* VPLZCNTQrmkz */
  0x1b09, /* VPLZCNTQrrkz */
/* Table10209 */
  0x1f3c, /* VPSRLVQZrmkz */
  0x1f3f, /* VPSRLVQZrrkz */
/* Table10211 */
  0x1efe, /* VPSRAVQZrmkz */
  0x1f01, /* VPSRAVQZrrkz */
/* Table10213 */
  0x1ec8, /* VPSLLVQZrmkz */
  0x1ecb, /* VPSLLVQZrrkz */
/* Table10215 */
  0x2047, /* VRCP14PDZmkz */
  0x204a, /* VRCP14PDZrkz */
/* Table10217 */
  0x20da, /* VRSQRT14PDZmkz */
  0x20dd, /* VRSQRT14PDZrkz */
/* Table10219 */
  0x181f, /* VPBROADCASTQZkrm */
  0x1820, /* VPBROADCASTQZkrr */
/* Table10221 */
  0xc9f, /* VBROADCASTI64X4krm */
  0x0, /*  */
/* Table10223 */
  0x17db, /* VPBLENDMQZrmkz */
  0x17de, /* VPBLENDMQZrrkz */
/* Table10225 */
  0xc70, /* VBLENDMPDZrmkz */
  0xc73, /* VBLENDMPDZrrkz */
/* Table10227 */
  0x17ed, /* VPBLENDMWZrmkz */
  0x17f0, /* VPBLENDMWZrrkz */
/* Table10229 */
  0x1a3b, /* VPERMI2Qrmkz */
  0x1a3e, /* VPERMI2Qrrkz */
/* Table10231 */
  0x1a2f, /* VPERMI2PDrmkz */
  0x1a32, /* VPERMI2PDrrkz */
/* Table10233 */
  0x0, /*  */
  0x182b, /* VPBROADCASTQrZrkz */
/* Table10235 */
  0x1a87, /* VPERMT2Qrmkz */
  0x1a8a, /* VPERMT2Qrrkz */
/* Table10237 */
  0x1a7b, /* VPERMT2PDrmkz */
  0x1a7e, /* VPERMT2PDrrkz */
/* Table10239 */
  0xe37, /* VEXPANDPDZrmkz */
  0xe39, /* VEXPANDPDZrrkz */
/* Table10241 */
  0x1aa0, /* VPEXPANDQZrmkz */
  0x1aa2, /* VPEXPANDQZrrkz */
/* Table10243 */
  0x0, /*  */
  0xd01, /* VCOMPRESSPDZrrkz */
/* Table10245 */
  0x0, /*  */
  0x19f4, /* VPCOMPRESSQZrrkz */
/* Table10247 */
  0xf5f, /* VFMADDSUBPDZv213rmkz */
  0xf65, /* VFMADDSUBPDZv213rrkz */
/* Table10249 */
  0x1011, /* VFMSUBADDPDZv213rmkz */
  0x1017, /* VFMSUBADDPDZv213rrkz */
/* Table10251 */
  0xe9b, /* VFMADDPDZv213rmkz */
  0xea1, /* VFMADDPDZv213rrkz */
/* Table10253 */
  0x10ab, /* VFMSUBPDZv213rmkz */
  0x10b1, /* VFMSUBPDZv213rrkz */
/* Table10255 */
  0x116f, /* VFNMADDPDZv213rmkz */
  0x1175, /* VFNMADDPDZv213rrkz */
/* Table10257 */
  0x1233, /* VFNMSUBPDZv213rmkz */
  0x1239, /* VFNMSUBPDZv213rrkz */
/* Table10259 */
  0xf6b, /* VFMADDSUBPDZv231rmkz */
  0xf6e, /* VFMADDSUBPDZv231rrkz */
/* Table10261 */
  0x101d, /* VFMSUBADDPDZv231rmkz */
  0x1020, /* VFMSUBADDPDZv231rrkz */
/* Table10263 */
  0xea7, /* VFMADDPDZv231rmkz */
  0xeaa, /* VFMADDPDZv231rrkz */
/* Table10265 */
  0x10b7, /* VFMSUBPDZv231rmkz */
  0x10ba, /* VFMSUBPDZv231rrkz */
/* Table10267 */
  0x117b, /* VFNMADDPDZv231rmkz */
  0x117e, /* VFNMADDPDZv231rrkz */
/* Table10269 */
  0x123f, /* VFNMSUBPDZv231rmkz */
  0x1242, /* VFNMSUBPDZv231rrkz */
/* Table10271 */
  0x1a1b, /* VPCONFLICTQrmkz */
  0x1a1e, /* VPCONFLICTQrrkz */
/* Table10273 */
  0xe1b, /* VEXP2PDmkz */
  0xe21, /* VEXP2PDrkz */
/* Table10275 */
  0x206f, /* VRCP28PDmkz */
  0x2075, /* VRCP28PDrkz */
/* Table10277 */
  0x2102, /* VRSQRT28PDmkz */
  0x2108, /* VRSQRT28PDrkz */
/* Table10279 */
  0x5b9, /* MMX_PALIGNR64irm */
  0x5ba, /* MMX_PALIGNR64irr */
/* Table10281 */
  0xa6c, /* SHA1RNDS4rmi */
  0xa6d, /* SHA1RNDS4rri */
/* Table10283 */
  0x9c5, /* ROUNDPSm */
  0x9c6, /* ROUNDPSr */
/* Table10285 */
  0x9c3, /* ROUNDPDm */
  0x9c4, /* ROUNDPDr */
/* Table10287 */
  0x9ca, /* ROUNDSSm */
  0x9cb, /* ROUNDSSr */
/* Table10289 */
  0x9c7, /* ROUNDSDm */
  0x9c8, /* ROUNDSDr */
/* Table10291 */
  0x103, /* BLENDPSrmi */
  0x104, /* BLENDPSrri */
/* Table10293 */
  0x101, /* BLENDPDrmi */
  0x102, /* BLENDPDrri */
/* Table10295 */
  0x7c0, /* PBLENDWrmi */
  0x7c1, /* PBLENDWrri */
/* Table10297 */
  0x7b1, /* PALIGNR128rm */
  0x7b2, /* PALIGNR128rr */
/* Table10299 */
  0x7ed, /* PEXTRBmr */
  0x7ee, /* PEXTRBrr */
/* Table10301 */
  0x7f3, /* PEXTRWmr */
  0x7f5, /* PEXTRWrr_REV */
/* Table10303 */
  0x7ef, /* PEXTRDmr */
  0x7f0, /* PEXTRDrr */
/* Table10305 */
  0x2ea, /* EXTRACTPSmr */
  0x2eb, /* EXTRACTPSrr */
/* Table10307 */
  0x82e, /* PINSRBrm */
  0x82f, /* PINSRBrr */
/* Table10309 */
  0x3a1, /* INSERTPSrm */
  0x3a2, /* INSERTPSrr */
/* Table10311 */
  0x830, /* PINSRDrm */
  0x831, /* PINSRDrr */
/* Table10313 */
  0x2de, /* DPPSrmi */
  0x2df, /* DPPSrri */
/* Table10315 */
  0x2dc, /* DPPDrmi */
  0x2dd, /* DPPDrri */
/* Table10317 */
  0x701, /* MPSADBWrmi */
  0x702, /* MPSADBWrri */
/* Table10319 */
  0x7c2, /* PCLMULQDQrm */
  0x7c3, /* PCLMULQDQrr */
/* Table10321 */
  0x7d2, /* PCMPESTRM128rm */
  0x7d3, /* PCMPESTRM128rr */
/* Table10323 */
  0x7ce, /* PCMPESTRIrm */
  0x7cf, /* PCMPESTRIrr */
/* Table10325 */
  0x7e2, /* PCMPISTRM128rm */
  0x7e3, /* PCMPISTRM128rr */
/* Table10327 */
  0x7de, /* PCMPISTRIrm */
  0x7df, /* PCMPISTRIrr */
/* Table10329 */
  0xae, /* AESKEYGENASSIST128rm */
  0xaf, /* AESKEYGENASSIST128rr */
/* Table10331 */
  0x7f1, /* PEXTRQmr */
  0x7f2, /* PEXTRQrr */
/* Table10333 */
  0x832, /* PINSRQrm */
  0x833, /* PINSRQrr */
/* Table10335 */
  0x9bf, /* RORX32mi */
  0x9c0, /* RORX32ri */
/* Table10337 */
  0x179b, /* VPBLENDDrmi */
  0x179c, /* VPBLENDDrri */
/* Table10339 */
  0x1a5f, /* VPERMILPSmi */
  0x1a60, /* VPERMILPSri */
/* Table10341 */
  0x1a53, /* VPERMILPDmi */
  0x1a54, /* VPERMILPDri */
/* Table10343 */
  0x20b7, /* VROUNDPSm */
  0x20b8, /* VROUNDPSr */
/* Table10345 */
  0x20b5, /* VROUNDPDm */
  0x20b6, /* VROUNDPDr */
/* Table10347 */
  0x20bc, /* VROUNDSSm */
  0x20bd, /* VROUNDSSr */
/* Table10349 */
  0x20b9, /* VROUNDSDm */
  0x20ba, /* VROUNDSDr */
/* Table10351 */
  0xc92, /* VBLENDPSrmi */
  0xc93, /* VBLENDPSrri */
/* Table10353 */
  0xc8e, /* VBLENDPDrmi */
  0xc8f, /* VBLENDPDrri */
/* Table10355 */
  0x17f7, /* VPBLENDWrmi */
  0x17f8, /* VPBLENDWrri */
/* Table10357 */
  0x1719, /* VPALIGNR128rm */
  0x171a, /* VPALIGNR128rr */
/* Table10359 */
  0x1aa3, /* VPEXTRBmr */
  0x1aa4, /* VPEXTRBrr */
/* Table10361 */
  0x1aa9, /* VPEXTRWmr */
  0x1aab, /* VPEXTRWrr_REV */
/* Table10363 */
  0x1aa5, /* VPEXTRDmr */
  0x1aa6, /* VPEXTRDrr */
/* Table10365 */
  0xe5a, /* VEXTRACTPSmr */
  0xe5b, /* VEXTRACTPSrr */
/* Table10367 */
  0xd40, /* VCVTPS2PHmr */
  0xd41, /* VCVTPS2PHrr */
/* Table10369 */
  0x1af0, /* VPINSRBrm */
  0x1af1, /* VPINSRBrr */
/* Table10371 */
  0x131e, /* VINSERTPSrm */
  0x131f, /* VINSERTPSrr */
/* Table10373 */
  0x1af2, /* VPINSRDrm */
  0x1af3, /* VPINSRDrr */
/* Table10375 */
  0x0, /*  */
  0x4a7, /* KSHIFTRBri */
/* Table10377 */
  0x0, /*  */
  0x4a8, /* KSHIFTRDri */
/* Table10379 */
  0x0, /*  */
  0x4a3, /* KSHIFTLBri */
/* Table10381 */
  0x0, /*  */
  0x4a4, /* KSHIFTLDri */
/* Table10383 */
  0xe10, /* VDPPSrmi */
  0xe11, /* VDPPSrri */
/* Table10385 */
  0xe0c, /* VDPPDrmi */
  0xe0d, /* VDPPDrri */
/* Table10387 */
  0x15f4, /* VMPSADBWrmi */
  0x15f5, /* VMPSADBWrri */
/* Table10389 */
  0x183b, /* VPCLMULQDQrm */
  0x183c, /* VPCLMULQDQrr */
/* Table10391 */
  0x1a45, /* VPERMIL2PSmr */
  0x1a49, /* VPERMIL2PSrr */
/* Table10393 */
  0x1a3f, /* VPERMIL2PDmr */
  0x1a43, /* VPERMIL2PDrr */
/* Table10395 */
  0xc9a, /* VBLENDVPSrm */
  0xc9b, /* VBLENDVPSrr */
/* Table10397 */
  0xc96, /* VBLENDVPDrm */
  0xc97, /* VBLENDVPDrr */
/* Table10399 */
  0x17f3, /* VPBLENDVBrm */
  0x17f4, /* VPBLENDVBrr */
/* Table10401 */
  0xf7b, /* VFMADDSUBPS4mr */
  0xf82, /* VFMADDSUBPS4rr_REV */
/* Table10403 */
  0xf2e, /* VFMADDSUBPD4mr */
  0xf35, /* VFMADDSUBPD4rr_REV */
/* Table10405 */
  0x102d, /* VFMSUBADDPS4mr */
  0x1034, /* VFMSUBADDPS4rr_REV */
/* Table10407 */
  0xfe0, /* VFMSUBADDPD4mr */
  0xfe7, /* VFMSUBADDPD4rr_REV */
/* Table10409 */
  0x18d1, /* VPCMPESTRM128rm */
  0x18d2, /* VPCMPESTRM128rr */
/* Table10411 */
  0x18cd, /* VPCMPESTRIrm */
  0x18ce, /* VPCMPESTRIrr */
/* Table10413 */
  0x1925, /* VPCMPISTRM128rm */
  0x1926, /* VPCMPISTRM128rr */
/* Table10415 */
  0x1921, /* VPCMPISTRIrm */
  0x1922, /* VPCMPISTRIrr */
/* Table10417 */
  0xeb7, /* VFMADDPS4mr */
  0xebe, /* VFMADDPS4rr_REV */
/* Table10419 */
  0xe6a, /* VFMADDPD4mr */
  0xe71, /* VFMADDPD4rr_REV */
/* Table10421 */
  0xf13, /* VFMADDSS4mr */
  0xf19, /* VFMADDSS4rr_REV */
/* Table10423 */
  0xf04, /* VFMADDSD4mr */
  0xf0a, /* VFMADDSD4rr_REV */
/* Table10425 */
  0x10c7, /* VFMSUBPS4mr */
  0x10ce, /* VFMSUBPS4rr_REV */
/* Table10427 */
  0x107a, /* VFMSUBPD4mr */
  0x1081, /* VFMSUBPD4rr_REV */
/* Table10429 */
  0x1123, /* VFMSUBSS4mr */
  0x1129, /* VFMSUBSS4rr_REV */
/* Table10431 */
  0x1114, /* VFMSUBSD4mr */
  0x111a, /* VFMSUBSD4rr_REV */
/* Table10433 */
  0x118b, /* VFNMADDPS4mr */
  0x1192, /* VFNMADDPS4rr_REV */
/* Table10435 */
  0x113e, /* VFNMADDPD4mr */
  0x1145, /* VFNMADDPD4rr_REV */
/* Table10437 */
  0x11e7, /* VFNMADDSS4mr */
  0x11ed, /* VFNMADDSS4rr_REV */
/* Table10439 */
  0x11d8, /* VFNMADDSD4mr */
  0x11de, /* VFNMADDSD4rr_REV */
/* Table10441 */
  0x124f, /* VFNMSUBPS4mr */
  0x1256, /* VFNMSUBPS4rr_REV */
/* Table10443 */
  0x1202, /* VFNMSUBPD4mr */
  0x1209, /* VFNMSUBPD4rr_REV */
/* Table10445 */
  0x12ab, /* VFNMSUBSS4mr */
  0x12b1, /* VFNMSUBSS4rr_REV */
/* Table10447 */
  0x129c, /* VFNMSUBSD4mr */
  0x12a2, /* VFNMSUBSD4rr_REV */
/* Table10449 */
  0xc41, /* VAESKEYGENASSIST128rm */
  0xc42, /* VAESKEYGENASSIST128rr */
/* Table10451 */
  0x9c1, /* RORX64mi */
  0x9c2, /* RORX64ri */
/* Table10453 */
  0x1aa7, /* VPEXTRQmr */
  0x1aa8, /* VPEXTRQrr */
/* Table10455 */
  0x1af4, /* VPINSRQrm */
  0x1af5, /* VPINSRQrr */
/* Table10457 */
  0x0, /*  */
  0x4aa, /* KSHIFTRWri */
/* Table10459 */
  0x0, /*  */
  0x4a9, /* KSHIFTRQri */
/* Table10461 */
  0x0, /*  */
  0x4a6, /* KSHIFTLWri */
/* Table10463 */
  0x0, /*  */
  0x4a5, /* KSHIFTLQri */
/* Table10465 */
  0x1a47, /* VPERMIL2PSrm */
  0x1a49, /* VPERMIL2PSrr */
/* Table10467 */
  0x1a41, /* VPERMIL2PDrm */
  0x1a43, /* VPERMIL2PDrr */
/* Table10469 */
  0xf7d, /* VFMADDSUBPS4rm */
  0xf7f, /* VFMADDSUBPS4rr */
/* Table10471 */
  0xf30, /* VFMADDSUBPD4rm */
  0xf32, /* VFMADDSUBPD4rr */
/* Table10473 */
  0x102f, /* VFMSUBADDPS4rm */
  0x1031, /* VFMSUBADDPS4rr */
/* Table10475 */
  0xfe2, /* VFMSUBADDPD4rm */
  0xfe4, /* VFMSUBADDPD4rr */
/* Table10477 */
  0xeb9, /* VFMADDPS4rm */
  0xebb, /* VFMADDPS4rr */
/* Table10479 */
  0xe6c, /* VFMADDPD4rm */
  0xe6e, /* VFMADDPD4rr */
/* Table10481 */
  0xf15, /* VFMADDSS4rm */
  0xf17, /* VFMADDSS4rr */
/* Table10483 */
  0xf06, /* VFMADDSD4rm */
  0xf08, /* VFMADDSD4rr */
/* Table10485 */
  0x10c9, /* VFMSUBPS4rm */
  0x10cb, /* VFMSUBPS4rr */
/* Table10487 */
  0x107c, /* VFMSUBPD4rm */
  0x107e, /* VFMSUBPD4rr */
/* Table10489 */
  0x1125, /* VFMSUBSS4rm */
  0x1127, /* VFMSUBSS4rr */
/* Table10491 */
  0x1116, /* VFMSUBSD4rm */
  0x1118, /* VFMSUBSD4rr */
/* Table10493 */
  0x118d, /* VFNMADDPS4rm */
  0x118f, /* VFNMADDPS4rr */
/* Table10495 */
  0x1140, /* VFNMADDPD4rm */
  0x1142, /* VFNMADDPD4rr */
/* Table10497 */
  0x11e9, /* VFNMADDSS4rm */
  0x11eb, /* VFNMADDSS4rr */
/* Table10499 */
  0x11da, /* VFNMADDSD4rm */
  0x11dc, /* VFNMADDSD4rr */
/* Table10501 */
  0x1251, /* VFNMSUBPS4rm */
  0x1253, /* VFNMSUBPS4rr */
/* Table10503 */
  0x1204, /* VFNMSUBPD4rm */
  0x1206, /* VFNMSUBPD4rr */
/* Table10505 */
  0x12ad, /* VFNMSUBSS4rm */
  0x12af, /* VFNMSUBSS4rr */
/* Table10507 */
  0x129e, /* VFNMSUBSD4rm */
  0x12a0, /* VFNMSUBSD4rr */
/* Table10509 */
  0x1799, /* VPBLENDDYrmi */
  0x179a, /* VPBLENDDYrri */
/* Table10511 */
  0x1a57, /* VPERMILPSYmi */
  0x1a58, /* VPERMILPSYri */
/* Table10513 */
  0x1a4b, /* VPERMILPDYmi */
  0x1a4c, /* VPERMILPDYri */
/* Table10515 */
  0x1a1f, /* VPERM2F128rm */
  0x1a20, /* VPERM2F128rr */
/* Table10517 */
  0x20c1, /* VROUNDYPSm */
  0x20c2, /* VROUNDYPSr */
/* Table10519 */
  0x20bf, /* VROUNDYPDm */
  0x20c0, /* VROUNDYPDr */
/* Table10521 */
  0xc90, /* VBLENDPSYrmi */
  0xc91, /* VBLENDPSYrri */
/* Table10523 */
  0xc8c, /* VBLENDPDYrmi */
  0xc8d, /* VBLENDPDYrri */
/* Table10525 */
  0x17f5, /* VPBLENDWYrmi */
  0x17f6, /* VPBLENDWYrri */
/* Table10527 */
  0x171b, /* VPALIGNR256rm */
  0x171c, /* VPALIGNR256rr */
/* Table10529 */
  0x130a, /* VINSERTF128rm */
  0x130b, /* VINSERTF128rr */
/* Table10531 */
  0xe46, /* VEXTRACTF128mr */
  0xe47, /* VEXTRACTF128rr */
/* Table10533 */
  0xd3c, /* VCVTPS2PHYmr */
  0xd3d, /* VCVTPS2PHYrr */
/* Table10535 */
  0x1314, /* VINSERTI128rm */
  0x1315, /* VINSERTI128rr */
/* Table10537 */
  0xe50, /* VEXTRACTI128mr */
  0xe51, /* VEXTRACTI128rr */
/* Table10539 */
  0xe0e, /* VDPPSYrmi */
  0xe0f, /* VDPPSYrri */
/* Table10541 */
  0x15f2, /* VMPSADBWYrmi */
  0x15f3, /* VMPSADBWYrri */
/* Table10543 */
  0x1a21, /* VPERM2I128rm */
  0x1a22, /* VPERM2I128rr */
/* Table10545 */
  0x1a46, /* VPERMIL2PSmrY */
  0x1a4a, /* VPERMIL2PSrrY */
/* Table10547 */
  0x1a40, /* VPERMIL2PDmrY */
  0x1a44, /* VPERMIL2PDrrY */
/* Table10549 */
  0xc98, /* VBLENDVPSYrm */
  0xc99, /* VBLENDVPSYrr */
/* Table10551 */
  0xc94, /* VBLENDVPDYrm */
  0xc95, /* VBLENDVPDYrr */
/* Table10553 */
  0x17f1, /* VPBLENDVBYrm */
  0x17f2, /* VPBLENDVBYrr */
/* Table10555 */
  0xf7c, /* VFMADDSUBPS4mrY */
  0xf81, /* VFMADDSUBPS4rrY_REV */
/* Table10557 */
  0xf2f, /* VFMADDSUBPD4mrY */
  0xf34, /* VFMADDSUBPD4rrY_REV */
/* Table10559 */
  0x102e, /* VFMSUBADDPS4mrY */
  0x1033, /* VFMSUBADDPS4rrY_REV */
/* Table10561 */
  0xfe1, /* VFMSUBADDPD4mrY */
  0xfe6, /* VFMSUBADDPD4rrY_REV */
/* Table10563 */
  0xeb8, /* VFMADDPS4mrY */
  0xebd, /* VFMADDPS4rrY_REV */
/* Table10565 */
  0xe6b, /* VFMADDPD4mrY */
  0xe70, /* VFMADDPD4rrY_REV */
/* Table10567 */
  0x10c8, /* VFMSUBPS4mrY */
  0x10cd, /* VFMSUBPS4rrY_REV */
/* Table10569 */
  0x107b, /* VFMSUBPD4mrY */
  0x1080, /* VFMSUBPD4rrY_REV */
/* Table10571 */
  0x118c, /* VFNMADDPS4mrY */
  0x1191, /* VFNMADDPS4rrY_REV */
/* Table10573 */
  0x113f, /* VFNMADDPD4mrY */
  0x1144, /* VFNMADDPD4rrY_REV */
/* Table10575 */
  0x1250, /* VFNMSUBPS4mrY */
  0x1255, /* VFNMSUBPS4rrY_REV */
/* Table10577 */
  0x1203, /* VFNMSUBPD4mrY */
  0x1208, /* VFNMSUBPD4rrY_REV */
/* Table10579 */
  0x1a6d, /* VPERMQYmi */
  0x1a6e, /* VPERMQYri */
/* Table10581 */
  0x1a63, /* VPERMPDYmi */
  0x1a64, /* VPERMPDYri */
/* Table10583 */
  0x1a48, /* VPERMIL2PSrmY */
  0x1a4a, /* VPERMIL2PSrrY */
/* Table10585 */
  0x1a42, /* VPERMIL2PDrmY */
  0x1a44, /* VPERMIL2PDrrY */
/* Table10587 */
  0xf7e, /* VFMADDSUBPS4rmY */
  0xf80, /* VFMADDSUBPS4rrY */
/* Table10589 */
  0xf31, /* VFMADDSUBPD4rmY */
  0xf33, /* VFMADDSUBPD4rrY */
/* Table10591 */
  0x1030, /* VFMSUBADDPS4rmY */
  0x1032, /* VFMSUBADDPS4rrY */
/* Table10593 */
  0xfe3, /* VFMSUBADDPD4rmY */
  0xfe5, /* VFMSUBADDPD4rrY */
/* Table10595 */
  0xeba, /* VFMADDPS4rmY */
  0xebc, /* VFMADDPS4rrY */
/* Table10597 */
  0xe6d, /* VFMADDPD4rmY */
  0xe6f, /* VFMADDPD4rrY */
/* Table10599 */
  0x10ca, /* VFMSUBPS4rmY */
  0x10cc, /* VFMSUBPS4rrY */
/* Table10601 */
  0x107d, /* VFMSUBPD4rmY */
  0x107f, /* VFMSUBPD4rrY */
/* Table10603 */
  0x118e, /* VFNMADDPS4rmY */
  0x1190, /* VFNMADDPS4rrY */
/* Table10605 */
  0x1141, /* VFNMADDPD4rmY */
  0x1143, /* VFNMADDPD4rrY */
/* Table10607 */
  0x1252, /* VFNMSUBPS4rmY */
  0x1254, /* VFNMSUBPS4rrY */
/* Table10609 */
  0x1205, /* VFNMSUBPD4rmY */
  0x1207, /* VFNMSUBPD4rrY */
/* Table10611 */
  0x20ac, /* VRNDSCALESSm */
  0x20af, /* VRNDSCALESSr */
/* Table10613 */
  0xe5c, /* VEXTRACTPSzmr */
  0xe5d, /* VEXTRACTPSzrr */
/* Table10615 */
  0x1963, /* VPCMPUDZ128rmi */
  0x196b, /* VPCMPUDZ128rri */
/* Table10617 */
  0x185b, /* VPCMPDZ128rmi */
  0x1863, /* VPCMPDZ128rri */
/* Table10619 */
  0x1320, /* VINSERTPSzrm */
  0x1321, /* VINSERTPSzrr */
/* Table10621 */
  0x194b, /* VPCMPUBZ128rmi */
  0x194f, /* VPCMPUBZ128rri */
/* Table10623 */
  0x1843, /* VPCMPBZ128rmi */
  0x1847, /* VPCMPBZ128rri */
/* Table10625 */
  0x20a3, /* VRNDSCALESDm */
  0x20a6, /* VRNDSCALESDr */
/* Table10627 */
  0x1987, /* VPCMPUQZ128rmi */
  0x198f, /* VPCMPUQZ128rri */
/* Table10629 */
  0x1927, /* VPCMPQZ128rmi */
  0x192f, /* VPCMPQZ128rri */
/* Table10631 */
  0x19ab, /* VPCMPUWZ128rmi */
  0x19af, /* VPCMPUWZ128rri */
/* Table10633 */
  0x19c3, /* VPCMPWZ128rmi */
  0x19c7, /* VPCMPWZ128rri */
/* Table10635 */
  0x196f, /* VPCMPUDZ256rmi */
  0x1977, /* VPCMPUDZ256rri */
/* Table10637 */
  0x1867, /* VPCMPDZ256rmi */
  0x186f, /* VPCMPDZ256rri */
/* Table10639 */
  0x1953, /* VPCMPUBZ256rmi */
  0x1957, /* VPCMPUBZ256rri */
/* Table10641 */
  0x184b, /* VPCMPBZ256rmi */
  0x184f, /* VPCMPBZ256rri */
/* Table10643 */
  0x1993, /* VPCMPUQZ256rmi */
  0x199b, /* VPCMPUQZ256rri */
/* Table10645 */
  0x1933, /* VPCMPQZ256rmi */
  0x193b, /* VPCMPQZ256rri */
/* Table10647 */
  0x19b3, /* VPCMPUWZ256rmi */
  0x19b7, /* VPCMPUWZ256rri */
/* Table10649 */
  0x19cb, /* VPCMPWZ256rmi */
  0x19cf, /* VPCMPWZ256rri */
/* Table10651 */
  0xc43, /* VALIGNDrmi */
  0xc44, /* VALIGNDrri */
/* Table10653 */
  0x1a5b, /* VPERMILPSZmi */
  0x1a5c, /* VPERMILPSZri */
/* Table10655 */
  0x20a1, /* VRNDSCALEPSZm */
  0x20a2, /* VRNDSCALEPSZr */
/* Table10657 */
  0x130c, /* VINSERTF32x4rm */
  0x130d, /* VINSERTF32x4rr */
/* Table10659 */
  0xe48, /* VEXTRACTF32x4rm */
  0xe49, /* VEXTRACTF32x4rr */
/* Table10661 */
  0x130e, /* VINSERTF32x8rm */
  0x130f, /* VINSERTF32x8rr */
/* Table10663 */
  0xd3e, /* VCVTPS2PHZmr */
  0xd3f, /* VCVTPS2PHZrr */
/* Table10665 */
  0x197b, /* VPCMPUDZrmi */
  0x1983, /* VPCMPUDZrri */
/* Table10667 */
  0x1873, /* VPCMPDZrmi */
  0x187b, /* VPCMPDZrri */
/* Table10669 */
  0x1316, /* VINSERTI32x4rm */
  0x1317, /* VINSERTI32x4rr */
/* Table10671 */
  0xe52, /* VEXTRACTI32x4rm */
  0xe53, /* VEXTRACTI32x4rr */
/* Table10673 */
  0x1318, /* VINSERTI32x8rm */
  0x1319, /* VINSERTI32x8rr */
/* Table10675 */
  0x195b, /* VPCMPUBZrmi */
  0x195f, /* VPCMPUBZrri */
/* Table10677 */
  0x1853, /* VPCMPBZrmi */
  0x1857, /* VPCMPBZrri */
/* Table10679 */
  0x1a6f, /* VPERMQZmi */
  0x1a70, /* VPERMQZri */
/* Table10681 */
  0x1a65, /* VPERMPDZmi */
  0x1a66, /* VPERMPDZri */
/* Table10683 */
  0xc47, /* VALIGNQrmi */
  0xc48, /* VALIGNQrri */
/* Table10685 */
  0x1a4f, /* VPERMILPDZmi */
  0x1a50, /* VPERMILPDZri */
/* Table10687 */
  0x209f, /* VRNDSCALEPDZm */
  0x20a0, /* VRNDSCALEPDZr */
/* Table10689 */
  0x1310, /* VINSERTF64x2rm */
  0x1311, /* VINSERTF64x2rr */
/* Table10691 */
  0x1312, /* VINSERTF64x4rm */
  0x1313, /* VINSERTF64x4rr */
/* Table10693 */
  0xe4c, /* VEXTRACTF64x4rm */
  0xe4d, /* VEXTRACTF64x4rr */
/* Table10695 */
  0x199f, /* VPCMPUQZrmi */
  0x19a7, /* VPCMPUQZrri */
/* Table10697 */
  0x193f, /* VPCMPQZrmi */
  0x1947, /* VPCMPQZrri */
/* Table10699 */
  0x131a, /* VINSERTI64x2rm */
  0x131b, /* VINSERTI64x2rr */
/* Table10701 */
  0x131c, /* VINSERTI64x4rm */
  0x131d, /* VINSERTI64x4rr */
/* Table10703 */
  0xe56, /* VEXTRACTI64x4rm */
  0xe57, /* VEXTRACTI64x4rr */
/* Table10705 */
  0x19bb, /* VPCMPUWZrmi */
  0x19bf, /* VPCMPUWZrri */
/* Table10707 */
  0x19d3, /* VPCMPWZrmi */
  0x19d7, /* VPCMPWZrri */
/* Table10709 */
  0x20ad, /* VRNDSCALESSmk */
  0x20b3, /* VRNDSCALESSrk */
/* Table10711 */
  0x1969, /* VPCMPUDZ128rmik */
  0x196d, /* VPCMPUDZ128rrik */
/* Table10713 */
  0x1861, /* VPCMPDZ128rmik */
  0x1865, /* VPCMPDZ128rrik */
/* Table10715 */
  0x194d, /* VPCMPUBZ128rmik */
  0x1951, /* VPCMPUBZ128rrik */
/* Table10717 */
  0x1845, /* VPCMPBZ128rmik */
  0x1849, /* VPCMPBZ128rrik */
/* Table10719 */
  0x20a4, /* VRNDSCALESDmk */
  0x20aa, /* VRNDSCALESDrk */
/* Table10721 */
  0x198d, /* VPCMPUQZ128rmik */
  0x1991, /* VPCMPUQZ128rrik */
/* Table10723 */
  0x192d, /* VPCMPQZ128rmik */
  0x1931, /* VPCMPQZ128rrik */
/* Table10725 */
  0x19ad, /* VPCMPUWZ128rmik */
  0x19b1, /* VPCMPUWZ128rrik */
/* Table10727 */
  0x19c5, /* VPCMPWZ128rmik */
  0x19c9, /* VPCMPWZ128rrik */
/* Table10729 */
  0x1975, /* VPCMPUDZ256rmik */
  0x1979, /* VPCMPUDZ256rrik */
/* Table10731 */
  0x186d, /* VPCMPDZ256rmik */
  0x1871, /* VPCMPDZ256rrik */
/* Table10733 */
  0x1955, /* VPCMPUBZ256rmik */
  0x1959, /* VPCMPUBZ256rrik */
/* Table10735 */
  0x184d, /* VPCMPBZ256rmik */
  0x1851, /* VPCMPBZ256rrik */
/* Table10737 */
  0x1999, /* VPCMPUQZ256rmik */
  0x199d, /* VPCMPUQZ256rrik */
/* Table10739 */
  0x1939, /* VPCMPQZ256rmik */
  0x193d, /* VPCMPQZ256rrik */
/* Table10741 */
  0x19b5, /* VPCMPUWZ256rmik */
  0x19b9, /* VPCMPUWZ256rrik */
/* Table10743 */
  0x19cd, /* VPCMPWZ256rmik */
  0x19d1, /* VPCMPWZ256rrik */
/* Table10745 */
  0x0, /*  */
  0xc45, /* VALIGNDrrik */
/* Table10747 */
  0x0, /*  */
  0xe4a, /* VEXTRACTF32x4rrk */
/* Table10749 */
  0x1981, /* VPCMPUDZrmik */
  0x1985, /* VPCMPUDZrrik */
/* Table10751 */
  0x1879, /* VPCMPDZrmik */
  0x187d, /* VPCMPDZrrik */
/* Table10753 */
  0x0, /*  */
  0xe54, /* VEXTRACTI32x4rrk */
/* Table10755 */
  0x195d, /* VPCMPUBZrmik */
  0x1961, /* VPCMPUBZrrik */
/* Table10757 */
  0x1855, /* VPCMPBZrmik */
  0x1859, /* VPCMPBZrrik */
/* Table10759 */
  0x0, /*  */
  0xc49, /* VALIGNQrrik */
/* Table10761 */
  0x0, /*  */
  0xe4e, /* VEXTRACTF64x4rrk */
/* Table10763 */
  0x19a5, /* VPCMPUQZrmik */
  0x19a9, /* VPCMPUQZrrik */
/* Table10765 */
  0x1945, /* VPCMPQZrmik */
  0x1949, /* VPCMPQZrrik */
/* Table10767 */
  0x0, /*  */
  0xe58, /* VEXTRACTI64x4rrk */
/* Table10769 */
  0x19bd, /* VPCMPUWZrmik */
  0x19c1, /* VPCMPUWZrrik */
/* Table10771 */
  0x19d5, /* VPCMPWZrmik */
  0x19d9, /* VPCMPWZrrik */
/* Table10773 */
  0x0, /*  */
  0x20b0, /* VRNDSCALESSrb */
/* Table10775 */
  0x1965, /* VPCMPUDZ128rmib */
  0x0, /*  */
/* Table10777 */
  0x185d, /* VPCMPDZ128rmib */
  0x0, /*  */
/* Table10779 */
  0x0, /*  */
  0x20a7, /* VRNDSCALESDrb */
/* Table10781 */
  0x1989, /* VPCMPUQZ128rmib */
  0x0, /*  */
/* Table10783 */
  0x1929, /* VPCMPQZ128rmib */
  0x0, /*  */
/* Table10785 */
  0x1971, /* VPCMPUDZ256rmib */
  0x0, /*  */
/* Table10787 */
  0x1869, /* VPCMPDZ256rmib */
  0x0, /*  */
/* Table10789 */
  0x1995, /* VPCMPUQZ256rmib */
  0x0, /*  */
/* Table10791 */
  0x1935, /* VPCMPQZ256rmib */
  0x0, /*  */
/* Table10793 */
  0x197d, /* VPCMPUDZrmib */
  0x0, /*  */
/* Table10795 */
  0x1875, /* VPCMPDZrmib */
  0x0, /*  */
/* Table10797 */
  0x19a1, /* VPCMPUQZrmib */
  0x0, /*  */
/* Table10799 */
  0x1941, /* VPCMPQZrmib */
  0x0, /*  */
/* Table10801 */
  0x0, /*  */
  0x20b1, /* VRNDSCALESSrbk */
/* Table10803 */
  0x1967, /* VPCMPUDZ128rmibk */
  0x0, /*  */
/* Table10805 */
  0x185f, /* VPCMPDZ128rmibk */
  0x0, /*  */
/* Table10807 */
  0x0, /*  */
  0x20a8, /* VRNDSCALESDrbk */
/* Table10809 */
  0x198b, /* VPCMPUQZ128rmibk */
  0x0, /*  */
/* Table10811 */
  0x192b, /* VPCMPQZ128rmibk */
  0x0, /*  */
/* Table10813 */
  0x1973, /* VPCMPUDZ256rmibk */
  0x0, /*  */
/* Table10815 */
  0x186b, /* VPCMPDZ256rmibk */
  0x0, /*  */
/* Table10817 */
  0x1997, /* VPCMPUQZ256rmibk */
  0x0, /*  */
/* Table10819 */
  0x1937, /* VPCMPQZ256rmibk */
  0x0, /*  */
/* Table10821 */
  0x197f, /* VPCMPUDZrmibk */
  0x0, /*  */
/* Table10823 */
  0x1877, /* VPCMPDZrmibk */
  0x0, /*  */
/* Table10825 */
  0x19a3, /* VPCMPUQZrmibk */
  0x0, /*  */
/* Table10827 */
  0x1943, /* VPCMPQZrmibk */
  0x0, /*  */
/* Table10829 */
  0x0, /*  */
  0x20b2, /* VRNDSCALESSrbkz */
/* Table10831 */
  0x0, /*  */
  0x20a9, /* VRNDSCALESDrbkz */
/* Table10833 */
  0x20ae, /* VRNDSCALESSmkz */
  0x20b4, /* VRNDSCALESSrkz */
/* Table10835 */
  0x20a5, /* VRNDSCALESDmkz */
  0x20ab, /* VRNDSCALESDrkz */
/* Table10837 */
  0x0, /*  */
  0xc46, /* VALIGNDrrikz */
/* Table10839 */
  0x0, /*  */
  0xe4b, /* VEXTRACTF32x4rrkz */
/* Table10841 */
  0x0, /*  */
  0xe55, /* VEXTRACTI32x4rrkz */
/* Table10843 */
  0x0, /*  */
  0xc4a, /* VALIGNQrrikz */
/* Table10845 */
  0x0, /*  */
  0xe4f, /* VEXTRACTF64x4rrkz */
/* Table10847 */
  0x0, /*  */
  0xe59, /* VEXTRACTI64x4rrkz */
/* Table10849 */
  0x1b18, /* VPMACSSWWrm */
  0x1b19, /* VPMACSSWWrr */
/* Table10851 */
  0x1b16, /* VPMACSSWDrm */
  0x1b17, /* VPMACSSWDrr */
/* Table10853 */
  0x1b14, /* VPMACSSDQLrm */
  0x1b15, /* VPMACSSDQLrr */
/* Table10855 */
  0x1b10, /* VPMACSSDDrm */
  0x1b11, /* VPMACSSDDrr */
/* Table10857 */
  0x1b12, /* VPMACSSDQHrm */
  0x1b13, /* VPMACSSDQHrr */
/* Table10859 */
  0x1b1c, /* VPMACSWWrm */
  0x1b1d, /* VPMACSWWrr */
/* Table10861 */
  0x1b1a, /* VPMACSWDrm */
  0x1b1b, /* VPMACSWDrr */
/* Table10863 */
  0x1b0e, /* VPMACSDQLrm */
  0x1b0f, /* VPMACSDQLrr */
/* Table10865 */
  0x1b0a, /* VPMACSDDrm */
  0x1b0b, /* VPMACSDDrr */
/* Table10867 */
  0x1b0c, /* VPMACSDQHrm */
  0x1b0d, /* VPMACSDQHrr */
/* Table10869 */
  0x183d, /* VPCMOVmr */
  0x1841, /* VPCMOVrr */
/* Table10871 */
  0x1e3f, /* VPPERMmr */
  0x1e41, /* VPPERMrr */
/* Table10873 */
  0x1b1e, /* VPMADCSSWDrm */
  0x1b1f, /* VPMADCSSWDrr */
/* Table10875 */
  0x1b20, /* VPMADCSWDrm */
  0x1b21, /* VPMADCSWDrr */
/* Table10877 */
  0x1e42, /* VPROTBmi */
  0x1e44, /* VPROTBri */
/* Table10879 */
  0x1e51, /* VPROTWmi */
  0x1e53, /* VPROTWri */
/* Table10881 */
  0x1e47, /* VPROTDmi */
  0x1e49, /* VPROTDri */
/* Table10883 */
  0x1e4c, /* VPROTQmi */
  0x1e4e, /* VPROTQri */
/* Table10885 */
  0x19db, /* VPCOMBmi */
  0x19dd, /* VPCOMBri */
/* Table10887 */
  0x1a09, /* VPCOMWmi */
  0x1a0b, /* VPCOMWri */
/* Table10889 */
  0x19df, /* VPCOMDmi */
  0x19e1, /* VPCOMDri */
/* Table10891 */
  0x19f5, /* VPCOMQmi */
  0x19f7, /* VPCOMQri */
/* Table10893 */
  0x19f9, /* VPCOMUBmi */
  0x19fb, /* VPCOMUBri */
/* Table10895 */
  0x1a05, /* VPCOMUWmi */
  0x1a07, /* VPCOMUWri */
/* Table10897 */
  0x19fd, /* VPCOMUDmi */
  0x19ff, /* VPCOMUDri */
/* Table10899 */
  0x1a01, /* VPCOMUQmi */
  0x1a03, /* VPCOMUQri */
/* Table10901 */
  0x183f, /* VPCMOVrm */
  0x1841, /* VPCMOVrr */
/* Table10903 */
  0x1e40, /* VPPERMrm */
  0x1e41, /* VPPERMrr */
/* Table10905 */
  0x183e, /* VPCMOVmrY */
  0x1842, /* VPCMOVrrY */
/* Table10907 */
  0x1840, /* VPCMOVrmY */
  0x1842, /* VPCMOVrrY */
/* Table10909 */
  0x0, /*  */
  0xed, /* BLCFILL32rm */
  0x109, /* BLSFILL32rm */
  0xfd, /* BLCS32rm */
  0xbb0, /* TZMSK32rm */
  0xf5, /* BLCIC32rm */
  0x111, /* BLSIC32rm */
  0xb6f, /* T1MSKC32rm */
  0x0, /*  */
  0xee, /* BLCFILL32rr */
  0x10a, /* BLSFILL32rr */
  0xfe, /* BLCS32rr */
  0xbb1, /* TZMSK32rr */
  0xf6, /* BLCIC32rr */
  0x112, /* BLSIC32rr */
  0xb70, /* T1MSKC32rr */
/* Table10925 */
  0x0, /*  */
  0xf9, /* BLCMSK32rm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0xf1, /* BLCI32rm */
  0x0, /*  */
  0x0, /*  */
  0xfa, /* BLCMSK32rr */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0xf2, /* BLCI32rr */
  0x0, /*  */
/* Table10941 */
  0x12be, /* VFRCZPSrm */
  0x12c0, /* VFRCZPSrr */
/* Table10943 */
  0x12ba, /* VFRCZPDrm */
  0x12bc, /* VFRCZPDrr */
/* Table10945 */
  0x12c4, /* VFRCZSSrm */
  0x12c5, /* VFRCZSSrr */
/* Table10947 */
  0x12c2, /* VFRCZSDrm */
  0x12c3, /* VFRCZSDrr */
/* Table10949 */
  0x1e43, /* VPROTBmr */
  0x1e46, /* VPROTBrr */
/* Table10951 */
  0x1e52, /* VPROTWmr */
  0x1e55, /* VPROTWrr */
/* Table10953 */
  0x1e48, /* VPROTDmr */
  0x1e4b, /* VPROTDrr */
/* Table10955 */
  0x1e4d, /* VPROTQmr */
  0x1e50, /* VPROTQrr */
/* Table10957 */
  0x1e6a, /* VPSHLBmr */
  0x1e6c, /* VPSHLBrr */
/* Table10959 */
  0x1e73, /* VPSHLWmr */
  0x1e75, /* VPSHLWrr */
/* Table10961 */
  0x1e6d, /* VPSHLDmr */
  0x1e6f, /* VPSHLDrr */
/* Table10963 */
  0x1e70, /* VPSHLQmr */
  0x1e72, /* VPSHLQrr */
/* Table10965 */
  0x1e5e, /* VPSHABmr */
  0x1e60, /* VPSHABrr */
/* Table10967 */
  0x1e67, /* VPSHAWmr */
  0x1e69, /* VPSHAWrr */
/* Table10969 */
  0x1e61, /* VPSHADmr */
  0x1e63, /* VPSHADrr */
/* Table10971 */
  0x1e64, /* VPSHAQmr */
  0x1e66, /* VPSHAQrr */
/* Table10973 */
  0x1abc, /* VPHADDBWrm */
  0x1abd, /* VPHADDBWrr */
/* Table10975 */
  0x1ab8, /* VPHADDBDrm */
  0x1ab9, /* VPHADDBDrr */
/* Table10977 */
  0x1aba, /* VPHADDBQrm */
  0x1abb, /* VPHADDBQrr */
/* Table10979 */
  0x1ad4, /* VPHADDWDrm */
  0x1ad5, /* VPHADDWDrr */
/* Table10981 */
  0x1ad6, /* VPHADDWQrm */
  0x1ad7, /* VPHADDWQrr */
/* Table10983 */
  0x1abe, /* VPHADDDQrm */
  0x1abf, /* VPHADDDQrr */
/* Table10985 */
  0x1acc, /* VPHADDUBWrm */
  0x1acd, /* VPHADDUBWrr */
/* Table10987 */
  0x1ac8, /* VPHADDUBDrm */
  0x1ac9, /* VPHADDUBDrr */
/* Table10989 */
  0x1aca, /* VPHADDUBQrm */
  0x1acb, /* VPHADDUBQrr */
/* Table10991 */
  0x1ad0, /* VPHADDUWDrm */
  0x1ad1, /* VPHADDUWDrr */
/* Table10993 */
  0x1ad2, /* VPHADDUWQrm */
  0x1ad3, /* VPHADDUWQrr */
/* Table10995 */
  0x1ace, /* VPHADDUDQrm */
  0x1acf, /* VPHADDUDQrr */
/* Table10997 */
  0x1ade, /* VPHSUBBWrm */
  0x1adf, /* VPHSUBBWrr */
/* Table10999 */
  0x1aea, /* VPHSUBWDrm */
  0x1aeb, /* VPHSUBWDrr */
/* Table11001 */
  0x1ae0, /* VPHSUBDQrm */
  0x1ae1, /* VPHSUBDQrr */
/* Table11003 */
  0x0, /*  */
  0xef, /* BLCFILL64rm */
  0x10b, /* BLSFILL64rm */
  0xff, /* BLCS64rm */
  0xbb2, /* TZMSK64rm */
  0xf7, /* BLCIC64rm */
  0x113, /* BLSIC64rm */
  0xb71, /* T1MSKC64rm */
  0x0, /*  */
  0xf0, /* BLCFILL64rr */
  0x10c, /* BLSFILL64rr */
  0x100, /* BLCS64rr */
  0xbb3, /* TZMSK64rr */
  0xf8, /* BLCIC64rr */
  0x114, /* BLSIC64rr */
  0xb72, /* T1MSKC64rr */
/* Table11019 */
  0x0, /*  */
  0xfb, /* BLCMSK64rm */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0xf3, /* BLCI64rm */
  0x0, /*  */
  0x0, /*  */
  0xfc, /* BLCMSK64rr */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0xf4, /* BLCI64rr */
  0x0, /*  */
/* Table11035 */
  0x1e45, /* VPROTBrm */
  0x1e46, /* VPROTBrr */
/* Table11037 */
  0x1e54, /* VPROTWrm */
  0x1e55, /* VPROTWrr */
/* Table11039 */
  0x1e4a, /* VPROTDrm */
  0x1e4b, /* VPROTDrr */
/* Table11041 */
  0x1e4f, /* VPROTQrm */
  0x1e50, /* VPROTQrr */
/* Table11043 */
  0x1e6b, /* VPSHLBrm */
  0x1e6c, /* VPSHLBrr */
/* Table11045 */
  0x1e74, /* VPSHLWrm */
  0x1e75, /* VPSHLWrr */
/* Table11047 */
  0x1e6e, /* VPSHLDrm */
  0x1e6f, /* VPSHLDrr */
/* Table11049 */
  0x1e71, /* VPSHLQrm */
  0x1e72, /* VPSHLQrr */
/* Table11051 */
  0x1e5f, /* VPSHABrm */
  0x1e60, /* VPSHABrr */
/* Table11053 */
  0x1e68, /* VPSHAWrm */
  0x1e69, /* VPSHAWrr */
/* Table11055 */
  0x1e62, /* VPSHADrm */
  0x1e63, /* VPSHADrr */
/* Table11057 */
  0x1e65, /* VPSHAQrm */
  0x1e66, /* VPSHAQrr */
/* Table11059 */
  0x12bf, /* VFRCZPSrmY */
  0x12c1, /* VFRCZPSrrY */
/* Table11061 */
  0x12bb, /* VFRCZPDrmY */
  0x12bd, /* VFRCZPDrrY */
/* Table11063 */
  0xe9, /* BEXTRI32mi */
  0xea, /* BEXTRI32ri */
/* Table11065 */
  0xeb, /* BEXTRI64mi */
  0xec, /* BEXTRI64ri */
/* Table11067 */
  0x89d, /* PREFETCH */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
  0x0, /*  */
/* Table11083 */
  0x301, /* FEMMS */
/* Table11084 */
  0x82c, /* PI2FWrm */
  0x82d, /* PI2FWrr */
/* Table11086 */
  0x82a, /* PI2FDrm */
  0x82b, /* PI2FDrr */
/* Table11088 */
  0x7f8, /* PF2IWrm */
  0x7f9, /* PF2IWrr */
/* Table11090 */
  0x7f6, /* PF2IDrm */
  0x7f7, /* PF2IDrr */
/* Table11092 */
  0x80a, /* PFNACCrm */
  0x80b, /* PFNACCrr */
/* Table11094 */
  0x80c, /* PFPNACCrm */
  0x80d, /* PFPNACCrr */
/* Table11096 */
  0x800, /* PFCMPGErm */
  0x801, /* PFCMPGErr */
/* Table11098 */
  0x806, /* PFMINrm */
  0x807, /* PFMINrr */
/* Table11100 */
  0x812, /* PFRCPrm */
  0x813, /* PFRCPrr */
/* Table11102 */
  0x816, /* PFRSQRTrm */
  0x817, /* PFRSQRTrr */
/* Table11104 */
  0x81a, /* PFSUBrm */
  0x81b, /* PFSUBrr */
/* Table11106 */
  0x7fc, /* PFADDrm */
  0x7fd, /* PFADDrr */
/* Table11108 */
  0x802, /* PFCMPGTrm */
  0x803, /* PFCMPGTrr */
/* Table11110 */
  0x804, /* PFMAXrm */
  0x805, /* PFMAXrr */
/* Table11112 */
  0x80e, /* PFRCPIT1rm */
  0x80f, /* PFRCPIT1rr */
/* Table11114 */
  0x814, /* PFRSQIT1rm */
  0x815, /* PFRSQIT1rr */
/* Table11116 */
  0x818, /* PFSUBRrm */
  0x819, /* PFSUBRrr */
/* Table11118 */
  0x7fa, /* PFACCrm */
  0x7fb, /* PFACCrr */
/* Table11120 */
  0x7fe, /* PFCMPEQrm */
  0x7ff, /* PFCMPEQrr */
/* Table11122 */
  0x808, /* PFMULrm */
  0x809, /* PFMULrr */
/* Table11124 */
  0x810, /* PFRCPIT2rm */
  0x811, /* PFRCPIT2rr */
/* Table11126 */
  0x86f, /* PMULHRWrm */
  0x870, /* PMULHRWrr */
/* Table11128 */
  0x8dd, /* PSWAPDrm */
  0x8de, /* PSWAPDrr */
/* Table11130 */
  0x7ba, /* PAVGUSBrm */
  0x7bb, /* PAVGUSBrr */
  0x0
};

static const struct OpcodeDecision x86DisassemblerOneByteOpcodes[] = {
 /* IC */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3 /* Table3 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7 /* Table7 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    10 /* Table10 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11 /* Table11 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    12 /* Table12 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    15 /* Table15 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    19 /* Table19 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    22 /* Table22 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    23 /* Table23 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    26 /* Table26 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    30 /* Table30 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    33 /* Table33 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    34 /* Table34 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    35 /* Table35 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    38 /* Table38 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    42 /* Table42 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    45 /* Table45 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    46 /* Table46 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    47 /* Table47 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    50 /* Table50 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    54 /* Table54 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    57 /* Table57 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    58 /* Table58 */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    61 /* Table61 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    65 /* Table65 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    68 /* Table68 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    69 /* Table69 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    72 /* Table72 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    76 /* Table76 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    79 /* Table79 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    80 /* Table80 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    83 /* Table83 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    87 /* Table87 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    90 /* Table90 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    91 /* Table91 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    96 /* Table96 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    97 /* Table97 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    98 /* Table98 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    100 /* Table100 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    103 /* Table103 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    104 /* Table104 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    106 /* Table106 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    107 /* Table107 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    110 /* Table110 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    112 /* Table112 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    145 /* Table145 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    161 /* Table161 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    177 /* Table177 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    195 /* Table195 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    199 /* Table199 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    203 /* Table203 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    207 /* Table207 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    209 /* Table209 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    211 /* Table211 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    213 /* Table213 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    215 /* Table215 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    233 /* Table233 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    234 /* Table234 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    235 /* Table235 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    237 /* Table237 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    238 /* Table238 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    241 /* Table241 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    242 /* Table242 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    243 /* Table243 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    244 /* Table244 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    246 /* Table246 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    248 /* Table248 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    250 /* Table250 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    252 /* Table252 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    254 /* Table254 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    256 /* Table256 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    275 /* Table275 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    291 /* Table291 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    292 /* Table292 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    293 /* Table293 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    295 /* Table295 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    369 /* Table369 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    442 /* Table442 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    443 /* Table443 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    444 /* Table444 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    447 /* Table447 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    448 /* Table448 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    465 /* Table465 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    497 /* Table497 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    513 /* Table513 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    514 /* Table514 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    515 /* Table515 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    928 /* Table928 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    930 /* Table930 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    932 /* Table932 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    933 /* Table933 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    934 /* Table934 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    935 /* Table935 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    938 /* Table938 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    940 /* Table940 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    963 /* Table963 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1001 /* Table1001 */
   }
  }
 }
,  /* IC_64BIT */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3 /* Table3 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7 /* Table7 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    10 /* Table10 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    15 /* Table15 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    19 /* Table19 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    22 /* Table22 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    26 /* Table26 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    30 /* Table30 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    33 /* Table33 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    38 /* Table38 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    42 /* Table42 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    45 /* Table45 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    50 /* Table50 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    54 /* Table54 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    57 /* Table57 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    61 /* Table61 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    65 /* Table65 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    68 /* Table68 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    72 /* Table72 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    76 /* Table76 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    79 /* Table79 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    83 /* Table83 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    87 /* Table87 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    90 /* Table90 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1017 /* Table1017 */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1020 /* Table1020 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1022 /* Table1022 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    104 /* Table104 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1023 /* Table1023 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    107 /* Table107 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    110 /* Table110 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    112 /* Table112 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    145 /* Table145 */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    177 /* Table177 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    195 /* Table195 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    199 /* Table199 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    203 /* Table203 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    207 /* Table207 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    209 /* Table209 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1024 /* Table1024 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    213 /* Table213 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1026 /* Table1026 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    233 /* Table233 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    234 /* Table234 */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1043 /* Table1043 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1044 /* Table1044 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1045 /* Table1045 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1046 /* Table1046 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1047 /* Table1047 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1048 /* Table1048 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    246 /* Table246 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    248 /* Table248 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    250 /* Table250 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    252 /* Table252 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    254 /* Table254 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    256 /* Table256 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    275 /* Table275 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1049 /* Table1049 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1050 /* Table1050 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    293 /* Table293 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    295 /* Table295 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    369 /* Table369 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1051 /* Table1051 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    443 /* Table443 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    444 /* Table444 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    448 /* Table448 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    465 /* Table465 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    497 /* Table497 */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1052 /* Table1052 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    930 /* Table930 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    932 /* Table932 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1053 /* Table1053 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    934 /* Table934 */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    938 /* Table938 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    940 /* Table940 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    963 /* Table963 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1054 /* Table1054 */
   }
  }
 }
,  /* IC_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1070 /* Table1070 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1072 /* Table1072 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1074 /* Table1074 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1075 /* Table1075 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1076 /* Table1076 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1077 /* Table1077 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1079 /* Table1079 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1081 /* Table1081 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1082 /* Table1082 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1083 /* Table1083 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1085 /* Table1085 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1087 /* Table1087 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1088 /* Table1088 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1089 /* Table1089 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1090 /* Table1090 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1092 /* Table1092 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1094 /* Table1094 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1095 /* Table1095 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1096 /* Table1096 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1097 /* Table1097 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1099 /* Table1099 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1101 /* Table1101 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    58 /* Table58 */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1102 /* Table1102 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1104 /* Table1104 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1106 /* Table1106 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    69 /* Table69 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1107 /* Table1107 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1109 /* Table1109 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1111 /* Table1111 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    80 /* Table80 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1112 /* Table1112 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1114 /* Table1114 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1116 /* Table1116 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    91 /* Table91 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1121 /* Table1121 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1122 /* Table1122 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1123 /* Table1123 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    100 /* Table100 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1125 /* Table1125 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1126 /* Table1126 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1128 /* Table1128 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1129 /* Table1129 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1131 /* Table1131 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1132 /* Table1132 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1133 /* Table1133 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    161 /* Table161 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1149 /* Table1149 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1165 /* Table1165 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1167 /* Table1167 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1169 /* Table1169 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1171 /* Table1171 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1173 /* Table1173 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1175 /* Table1175 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1177 /* Table1177 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1179 /* Table1179 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1196 /* Table1196 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1197 /* Table1197 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1198 /* Table1198 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1199 /* Table1199 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1200 /* Table1200 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    241 /* Table241 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1201 /* Table1201 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    243 /* Table243 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1202 /* Table1202 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1203 /* Table1203 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1204 /* Table1204 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1205 /* Table1205 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1206 /* Table1206 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1207 /* Table1207 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1208 /* Table1208 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1210 /* Table1210 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1226 /* Table1226 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1227 /* Table1227 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1228 /* Table1228 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1230 /* Table1230 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    1232 /* Table1232 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    442 /* Table442 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1304 /* Table1304 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1305 /* Table1305 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    447 /* Table447 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1306 /* Table1306 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1307 /* Table1307 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1323 /* Table1323 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    513 /* Table513 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    514 /* Table514 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    515 /* Table515 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    928 /* Table928 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1339 /* Table1339 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1340 /* Table1340 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1341 /* Table1341 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1342 /* Table1342 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1343 /* Table1343 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1344 /* Table1344 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1345 /* Table1345 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1346 /* Table1346 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1362 /* Table1362 */
   }
  }
 }
,  /* IC_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3 /* Table3 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7 /* Table7 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    10 /* Table10 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11 /* Table11 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    12 /* Table12 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    15 /* Table15 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    19 /* Table19 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    22 /* Table22 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    23 /* Table23 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    26 /* Table26 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    30 /* Table30 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    33 /* Table33 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    34 /* Table34 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    35 /* Table35 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    38 /* Table38 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    42 /* Table42 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    45 /* Table45 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    46 /* Table46 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    47 /* Table47 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    50 /* Table50 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    54 /* Table54 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    57 /* Table57 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    58 /* Table58 */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    61 /* Table61 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    65 /* Table65 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    68 /* Table68 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    69 /* Table69 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    72 /* Table72 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    76 /* Table76 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    79 /* Table79 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    80 /* Table80 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    83 /* Table83 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    87 /* Table87 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    90 /* Table90 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    91 /* Table91 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    96 /* Table96 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    97 /* Table97 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    98 /* Table98 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    100 /* Table100 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    103 /* Table103 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    104 /* Table104 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    106 /* Table106 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    107 /* Table107 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    110 /* Table110 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    112 /* Table112 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    145 /* Table145 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    161 /* Table161 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    177 /* Table177 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    195 /* Table195 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    199 /* Table199 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    203 /* Table203 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    207 /* Table207 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    209 /* Table209 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    211 /* Table211 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    213 /* Table213 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    215 /* Table215 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    233 /* Table233 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    234 /* Table234 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    235 /* Table235 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    237 /* Table237 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    238 /* Table238 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1378 /* Table1378 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1379 /* Table1379 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1380 /* Table1380 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1381 /* Table1381 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    246 /* Table246 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    248 /* Table248 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    250 /* Table250 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    252 /* Table252 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    254 /* Table254 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    256 /* Table256 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    275 /* Table275 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    291 /* Table291 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    292 /* Table292 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    293 /* Table293 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    295 /* Table295 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    369 /* Table369 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    442 /* Table442 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    443 /* Table443 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    444 /* Table444 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    447 /* Table447 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    448 /* Table448 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    465 /* Table465 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    497 /* Table497 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    513 /* Table513 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    514 /* Table514 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    515 /* Table515 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1382 /* Table1382 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    930 /* Table930 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    932 /* Table932 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    933 /* Table933 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    934 /* Table934 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    935 /* Table935 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    938 /* Table938 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    940 /* Table940 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    963 /* Table963 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1001 /* Table1001 */
   }
  }
 }
,  /* IC_OPSIZE_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1070 /* Table1070 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1072 /* Table1072 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1074 /* Table1074 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1075 /* Table1075 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1076 /* Table1076 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1077 /* Table1077 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1079 /* Table1079 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1081 /* Table1081 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1082 /* Table1082 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1083 /* Table1083 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1085 /* Table1085 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1087 /* Table1087 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1088 /* Table1088 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1089 /* Table1089 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1090 /* Table1090 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1092 /* Table1092 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1094 /* Table1094 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1095 /* Table1095 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1096 /* Table1096 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1097 /* Table1097 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1099 /* Table1099 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1101 /* Table1101 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    58 /* Table58 */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1102 /* Table1102 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1104 /* Table1104 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1106 /* Table1106 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    69 /* Table69 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1107 /* Table1107 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1109 /* Table1109 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1111 /* Table1111 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    80 /* Table80 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1112 /* Table1112 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1114 /* Table1114 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1116 /* Table1116 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    91 /* Table91 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1117 /* Table1117 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1118 /* Table1118 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1121 /* Table1121 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1122 /* Table1122 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1123 /* Table1123 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    100 /* Table100 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1125 /* Table1125 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1126 /* Table1126 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1128 /* Table1128 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1129 /* Table1129 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1131 /* Table1131 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1132 /* Table1132 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1133 /* Table1133 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    161 /* Table161 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1149 /* Table1149 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1165 /* Table1165 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1167 /* Table1167 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1169 /* Table1169 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1171 /* Table1171 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1173 /* Table1173 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1175 /* Table1175 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1177 /* Table1177 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1179 /* Table1179 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1196 /* Table1196 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1197 /* Table1197 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1198 /* Table1198 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1199 /* Table1199 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1200 /* Table1200 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1378 /* Table1378 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1383 /* Table1383 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1380 /* Table1380 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1384 /* Table1384 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1203 /* Table1203 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1204 /* Table1204 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1205 /* Table1205 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1206 /* Table1206 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1207 /* Table1207 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1208 /* Table1208 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1210 /* Table1210 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1226 /* Table1226 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1227 /* Table1227 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1228 /* Table1228 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1230 /* Table1230 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    1232 /* Table1232 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    442 /* Table442 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1304 /* Table1304 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1305 /* Table1305 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    447 /* Table447 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1306 /* Table1306 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1307 /* Table1307 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1323 /* Table1323 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    513 /* Table513 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    514 /* Table514 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    515 /* Table515 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1382 /* Table1382 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1339 /* Table1339 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1340 /* Table1340 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1341 /* Table1341 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1342 /* Table1342 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1343 /* Table1343 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1344 /* Table1344 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1345 /* Table1345 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1346 /* Table1346 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1362 /* Table1362 */
   }
  }
 }
,  /* IC_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3 /* Table3 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7 /* Table7 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    10 /* Table10 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11 /* Table11 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    12 /* Table12 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    15 /* Table15 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    19 /* Table19 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    22 /* Table22 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    23 /* Table23 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    26 /* Table26 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    30 /* Table30 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    33 /* Table33 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    34 /* Table34 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    35 /* Table35 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    38 /* Table38 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    42 /* Table42 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    45 /* Table45 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    46 /* Table46 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    47 /* Table47 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    50 /* Table50 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    54 /* Table54 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    57 /* Table57 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    58 /* Table58 */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    61 /* Table61 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    65 /* Table65 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    68 /* Table68 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    69 /* Table69 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    72 /* Table72 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    76 /* Table76 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    79 /* Table79 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    80 /* Table80 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    83 /* Table83 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    87 /* Table87 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    90 /* Table90 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    91 /* Table91 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    96 /* Table96 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    97 /* Table97 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    98 /* Table98 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    100 /* Table100 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    103 /* Table103 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    104 /* Table104 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    106 /* Table106 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    107 /* Table107 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    110 /* Table110 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    112 /* Table112 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    145 /* Table145 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    161 /* Table161 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    177 /* Table177 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    195 /* Table195 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    199 /* Table199 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    203 /* Table203 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    207 /* Table207 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    209 /* Table209 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    211 /* Table211 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    213 /* Table213 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    215 /* Table215 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    233 /* Table233 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    234 /* Table234 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    235 /* Table235 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    237 /* Table237 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    238 /* Table238 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    241 /* Table241 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    242 /* Table242 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    243 /* Table243 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    244 /* Table244 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    246 /* Table246 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    248 /* Table248 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    250 /* Table250 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    252 /* Table252 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    254 /* Table254 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    256 /* Table256 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    275 /* Table275 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    291 /* Table291 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    292 /* Table292 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    293 /* Table293 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    295 /* Table295 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    369 /* Table369 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    442 /* Table442 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    443 /* Table443 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    444 /* Table444 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    447 /* Table447 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    448 /* Table448 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    465 /* Table465 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    497 /* Table497 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    513 /* Table513 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    514 /* Table514 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    515 /* Table515 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    928 /* Table928 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    930 /* Table930 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    932 /* Table932 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    933 /* Table933 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    934 /* Table934 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    935 /* Table935 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    938 /* Table938 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    940 /* Table940 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    963 /* Table963 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1001 /* Table1001 */
   }
  }
 }
,  /* IC_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3 /* Table3 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7 /* Table7 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    10 /* Table10 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11 /* Table11 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    12 /* Table12 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    15 /* Table15 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    19 /* Table19 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    22 /* Table22 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    23 /* Table23 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    26 /* Table26 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    30 /* Table30 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    33 /* Table33 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    34 /* Table34 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    35 /* Table35 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    38 /* Table38 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    42 /* Table42 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    45 /* Table45 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    46 /* Table46 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    47 /* Table47 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    50 /* Table50 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    54 /* Table54 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    57 /* Table57 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    58 /* Table58 */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    61 /* Table61 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    65 /* Table65 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    68 /* Table68 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    69 /* Table69 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    72 /* Table72 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    76 /* Table76 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    79 /* Table79 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    80 /* Table80 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    83 /* Table83 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    87 /* Table87 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    90 /* Table90 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    91 /* Table91 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    92 /* Table92 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    93 /* Table93 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    94 /* Table94 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    95 /* Table95 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    96 /* Table96 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    97 /* Table97 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    98 /* Table98 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    100 /* Table100 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    103 /* Table103 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    104 /* Table104 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    106 /* Table106 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    107 /* Table107 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    110 /* Table110 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    112 /* Table112 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    145 /* Table145 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    161 /* Table161 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    177 /* Table177 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    195 /* Table195 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    199 /* Table199 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    203 /* Table203 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    207 /* Table207 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    209 /* Table209 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    211 /* Table211 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    213 /* Table213 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    215 /* Table215 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1385 /* Table1385 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    232 /* Table232 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    233 /* Table233 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    234 /* Table234 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    235 /* Table235 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    237 /* Table237 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    238 /* Table238 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    241 /* Table241 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    242 /* Table242 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    243 /* Table243 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    244 /* Table244 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    246 /* Table246 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    248 /* Table248 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    250 /* Table250 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    252 /* Table252 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    254 /* Table254 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    256 /* Table256 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    275 /* Table275 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    291 /* Table291 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    292 /* Table292 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    293 /* Table293 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    295 /* Table295 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    369 /* Table369 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    442 /* Table442 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    443 /* Table443 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    444 /* Table444 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    447 /* Table447 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    448 /* Table448 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    465 /* Table465 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    497 /* Table497 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    513 /* Table513 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    514 /* Table514 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    515 /* Table515 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    928 /* Table928 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    930 /* Table930 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    932 /* Table932 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    933 /* Table933 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    934 /* Table934 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    935 /* Table935 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    938 /* Table938 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    940 /* Table940 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    963 /* Table963 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1001 /* Table1001 */
   }
  }
 }
,  /* IC_64BIT_REXW */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1386 /* Table1386 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1388 /* Table1388 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1390 /* Table1390 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1391 /* Table1391 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1393 /* Table1393 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1395 /* Table1395 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1396 /* Table1396 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1398 /* Table1398 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1400 /* Table1400 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1401 /* Table1401 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1403 /* Table1403 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1405 /* Table1405 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1406 /* Table1406 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1408 /* Table1408 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1410 /* Table1410 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1411 /* Table1411 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1413 /* Table1413 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1415 /* Table1415 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1416 /* Table1416 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1418 /* Table1418 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1420 /* Table1420 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1421 /* Table1421 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1423 /* Table1423 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1425 /* Table1425 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1017 /* Table1017 */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1426 /* Table1426 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1022 /* Table1022 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1428 /* Table1428 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1023 /* Table1023 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1430 /* Table1430 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    110 /* Table110 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    112 /* Table112 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1432 /* Table1432 */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1448 /* Table1448 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1464 /* Table1464 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1466 /* Table1466 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1468 /* Table1468 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1470 /* Table1470 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1472 /* Table1472 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1474 /* Table1474 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1476 /* Table1476 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1026 /* Table1026 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1479 /* Table1479 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1480 /* Table1480 */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1043 /* Table1043 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1044 /* Table1044 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1045 /* Table1045 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1481 /* Table1481 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1047 /* Table1047 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1482 /* Table1482 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1483 /* Table1483 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1484 /* Table1484 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1485 /* Table1485 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1486 /* Table1486 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1487 /* Table1487 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1488 /* Table1488 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1490 /* Table1490 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1049 /* Table1049 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1050 /* Table1050 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    293 /* Table293 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    295 /* Table295 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    1506 /* Table1506 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1051 /* Table1051 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1578 /* Table1578 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1579 /* Table1579 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1580 /* Table1580 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1581 /* Table1581 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1597 /* Table1597 */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1052 /* Table1052 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    930 /* Table930 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    932 /* Table932 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1053 /* Table1053 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    934 /* Table934 */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    938 /* Table938 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    940 /* Table940 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1613 /* Table1613 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1629 /* Table1629 */
   }
  }
 }
,  /* IC_64BIT_REXW_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1386 /* Table1386 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1388 /* Table1388 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1390 /* Table1390 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1391 /* Table1391 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1393 /* Table1393 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1395 /* Table1395 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1396 /* Table1396 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1398 /* Table1398 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1400 /* Table1400 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1401 /* Table1401 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1403 /* Table1403 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1405 /* Table1405 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1406 /* Table1406 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1408 /* Table1408 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1410 /* Table1410 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1411 /* Table1411 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1413 /* Table1413 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1415 /* Table1415 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1416 /* Table1416 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1418 /* Table1418 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1420 /* Table1420 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1421 /* Table1421 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1423 /* Table1423 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1425 /* Table1425 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1017 /* Table1017 */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1426 /* Table1426 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1645 /* Table1645 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1428 /* Table1428 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1023 /* Table1023 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1430 /* Table1430 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1131 /* Table1131 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1132 /* Table1132 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1432 /* Table1432 */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1448 /* Table1448 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1464 /* Table1464 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1466 /* Table1466 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1468 /* Table1468 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1470 /* Table1470 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1472 /* Table1472 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1474 /* Table1474 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1476 /* Table1476 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1179 /* Table1179 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1479 /* Table1479 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1480 /* Table1480 */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1199 /* Table1199 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1200 /* Table1200 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1045 /* Table1045 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1646 /* Table1646 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1047 /* Table1047 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1647 /* Table1647 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1483 /* Table1483 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1484 /* Table1484 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1485 /* Table1485 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1486 /* Table1486 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1487 /* Table1487 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1488 /* Table1488 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1490 /* Table1490 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1226 /* Table1226 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1227 /* Table1227 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1228 /* Table1228 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1230 /* Table1230 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    1648 /* Table1648 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1051 /* Table1051 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1578 /* Table1578 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1579 /* Table1579 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1580 /* Table1580 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1581 /* Table1581 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1597 /* Table1597 */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1052 /* Table1052 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1339 /* Table1339 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1340 /* Table1340 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1341 /* Table1341 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1342 /* Table1342 */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1344 /* Table1344 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1345 /* Table1345 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1613 /* Table1613 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1720 /* Table1720 */
   }
  }
 }
,  /* IC_64BIT_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1070 /* Table1070 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1072 /* Table1072 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1074 /* Table1074 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1077 /* Table1077 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1079 /* Table1079 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1081 /* Table1081 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1083 /* Table1083 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1085 /* Table1085 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1087 /* Table1087 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1090 /* Table1090 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1092 /* Table1092 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1094 /* Table1094 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1097 /* Table1097 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1099 /* Table1099 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1101 /* Table1101 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1102 /* Table1102 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1104 /* Table1104 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1106 /* Table1106 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1107 /* Table1107 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1109 /* Table1109 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1111 /* Table1111 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1112 /* Table1112 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1114 /* Table1114 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1116 /* Table1116 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1017 /* Table1017 */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1020 /* Table1020 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1645 /* Table1645 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1126 /* Table1126 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1023 /* Table1023 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1129 /* Table1129 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1131 /* Table1131 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1132 /* Table1132 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1133 /* Table1133 */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1149 /* Table1149 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1165 /* Table1165 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1167 /* Table1167 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1169 /* Table1169 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1171 /* Table1171 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1173 /* Table1173 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1175 /* Table1175 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1177 /* Table1177 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1179 /* Table1179 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1196 /* Table1196 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1197 /* Table1197 */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1199 /* Table1199 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1200 /* Table1200 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1045 /* Table1045 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1736 /* Table1736 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1047 /* Table1047 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1737 /* Table1737 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1203 /* Table1203 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1204 /* Table1204 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1205 /* Table1205 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1206 /* Table1206 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1207 /* Table1207 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1208 /* Table1208 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1210 /* Table1210 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1226 /* Table1226 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1227 /* Table1227 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1228 /* Table1228 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1230 /* Table1230 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    1232 /* Table1232 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1051 /* Table1051 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1304 /* Table1304 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1305 /* Table1305 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1306 /* Table1306 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1307 /* Table1307 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1323 /* Table1323 */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1052 /* Table1052 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1339 /* Table1339 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1340 /* Table1340 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1341 /* Table1341 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1342 /* Table1342 */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1344 /* Table1344 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1345 /* Table1345 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1346 /* Table1346 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1738 /* Table1738 */
   }
  }
 }
,  /* IC_64BIT_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3 /* Table3 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7 /* Table7 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    10 /* Table10 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    15 /* Table15 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    19 /* Table19 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    22 /* Table22 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    26 /* Table26 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    30 /* Table30 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    33 /* Table33 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    38 /* Table38 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    42 /* Table42 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    45 /* Table45 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    50 /* Table50 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    54 /* Table54 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    57 /* Table57 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    61 /* Table61 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    65 /* Table65 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    68 /* Table68 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    72 /* Table72 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    76 /* Table76 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    79 /* Table79 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    83 /* Table83 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    87 /* Table87 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    90 /* Table90 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1017 /* Table1017 */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1020 /* Table1020 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1022 /* Table1022 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    104 /* Table104 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1023 /* Table1023 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    107 /* Table107 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    110 /* Table110 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    112 /* Table112 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    145 /* Table145 */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    177 /* Table177 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    195 /* Table195 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    199 /* Table199 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    203 /* Table203 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    207 /* Table207 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    209 /* Table209 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1024 /* Table1024 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    213 /* Table213 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1026 /* Table1026 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    233 /* Table233 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    234 /* Table234 */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1043 /* Table1043 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1044 /* Table1044 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    241 /* Table241 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    242 /* Table242 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    243 /* Table243 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    244 /* Table244 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    246 /* Table246 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    248 /* Table248 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    250 /* Table250 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    252 /* Table252 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    254 /* Table254 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    256 /* Table256 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    275 /* Table275 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1049 /* Table1049 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1050 /* Table1050 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    293 /* Table293 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    295 /* Table295 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    369 /* Table369 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1051 /* Table1051 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    443 /* Table443 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    444 /* Table444 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    448 /* Table448 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    465 /* Table465 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    497 /* Table497 */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    928 /* Table928 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    930 /* Table930 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    932 /* Table932 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1053 /* Table1053 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    934 /* Table934 */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    938 /* Table938 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    940 /* Table940 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    963 /* Table963 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1054 /* Table1054 */
   }
  }
 }
,  /* IC_64BIT_OPSIZE_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1070 /* Table1070 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1072 /* Table1072 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1074 /* Table1074 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1077 /* Table1077 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1079 /* Table1079 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1081 /* Table1081 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1083 /* Table1083 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1085 /* Table1085 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1087 /* Table1087 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1090 /* Table1090 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1092 /* Table1092 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1094 /* Table1094 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1097 /* Table1097 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1099 /* Table1099 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1101 /* Table1101 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1102 /* Table1102 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1104 /* Table1104 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1106 /* Table1106 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1107 /* Table1107 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1109 /* Table1109 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1111 /* Table1111 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1112 /* Table1112 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1114 /* Table1114 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1116 /* Table1116 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1017 /* Table1017 */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1020 /* Table1020 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1645 /* Table1645 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1126 /* Table1126 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1023 /* Table1023 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1129 /* Table1129 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1131 /* Table1131 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1132 /* Table1132 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1133 /* Table1133 */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1149 /* Table1149 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1165 /* Table1165 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1167 /* Table1167 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1169 /* Table1169 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1171 /* Table1171 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1173 /* Table1173 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1175 /* Table1175 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1177 /* Table1177 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1179 /* Table1179 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1195 /* Table1195 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1196 /* Table1196 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1197 /* Table1197 */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1199 /* Table1199 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1200 /* Table1200 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1045 /* Table1045 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1201 /* Table1201 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1047 /* Table1047 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1202 /* Table1202 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1203 /* Table1203 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1204 /* Table1204 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1205 /* Table1205 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1206 /* Table1206 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1207 /* Table1207 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1208 /* Table1208 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1209 /* Table1209 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1210 /* Table1210 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1226 /* Table1226 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1227 /* Table1227 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1228 /* Table1228 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1230 /* Table1230 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    1232 /* Table1232 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1051 /* Table1051 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1304 /* Table1304 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1305 /* Table1305 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1306 /* Table1306 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1307 /* Table1307 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1323 /* Table1323 */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1052 /* Table1052 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1339 /* Table1339 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1340 /* Table1340 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1341 /* Table1341 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1342 /* Table1342 */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1344 /* Table1344 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1345 /* Table1345 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1346 /* Table1346 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1738 /* Table1738 */
   }
  }
 }
,  /* IC_64BIT_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3 /* Table3 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7 /* Table7 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    10 /* Table10 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    15 /* Table15 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    19 /* Table19 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    22 /* Table22 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    26 /* Table26 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    30 /* Table30 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    33 /* Table33 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    38 /* Table38 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    42 /* Table42 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    45 /* Table45 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    50 /* Table50 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    54 /* Table54 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    57 /* Table57 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    61 /* Table61 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    65 /* Table65 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    68 /* Table68 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    72 /* Table72 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    76 /* Table76 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    79 /* Table79 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    83 /* Table83 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    87 /* Table87 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    90 /* Table90 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1017 /* Table1017 */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1020 /* Table1020 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1022 /* Table1022 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    104 /* Table104 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1023 /* Table1023 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    107 /* Table107 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    110 /* Table110 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    112 /* Table112 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    145 /* Table145 */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    177 /* Table177 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    195 /* Table195 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    199 /* Table199 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    203 /* Table203 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    207 /* Table207 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    209 /* Table209 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1024 /* Table1024 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    213 /* Table213 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1026 /* Table1026 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    233 /* Table233 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    234 /* Table234 */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1043 /* Table1043 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1044 /* Table1044 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1045 /* Table1045 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1046 /* Table1046 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1047 /* Table1047 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1048 /* Table1048 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    246 /* Table246 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    248 /* Table248 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    250 /* Table250 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    252 /* Table252 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    254 /* Table254 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    256 /* Table256 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    275 /* Table275 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1049 /* Table1049 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1050 /* Table1050 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    293 /* Table293 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    295 /* Table295 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    369 /* Table369 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1051 /* Table1051 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    443 /* Table443 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    444 /* Table444 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    448 /* Table448 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    465 /* Table465 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    497 /* Table497 */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1052 /* Table1052 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    930 /* Table930 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    932 /* Table932 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1053 /* Table1053 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    934 /* Table934 */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    938 /* Table938 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    940 /* Table940 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    963 /* Table963 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1054 /* Table1054 */
   }
  }
 }
,  /* IC_64BIT_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3 /* Table3 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7 /* Table7 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    10 /* Table10 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    15 /* Table15 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    19 /* Table19 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    22 /* Table22 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    26 /* Table26 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    30 /* Table30 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    33 /* Table33 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    38 /* Table38 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    42 /* Table42 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    45 /* Table45 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    50 /* Table50 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    54 /* Table54 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    57 /* Table57 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    61 /* Table61 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    65 /* Table65 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    68 /* Table68 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    72 /* Table72 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    76 /* Table76 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    79 /* Table79 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    83 /* Table83 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    87 /* Table87 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    90 /* Table90 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1017 /* Table1017 */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1020 /* Table1020 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1022 /* Table1022 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    104 /* Table104 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1023 /* Table1023 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    107 /* Table107 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    110 /* Table110 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    112 /* Table112 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    145 /* Table145 */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    177 /* Table177 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    195 /* Table195 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    199 /* Table199 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    203 /* Table203 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    207 /* Table207 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    209 /* Table209 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1024 /* Table1024 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    213 /* Table213 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1026 /* Table1026 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1385 /* Table1385 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1042 /* Table1042 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    233 /* Table233 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    234 /* Table234 */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1043 /* Table1043 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1044 /* Table1044 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1045 /* Table1045 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1046 /* Table1046 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1047 /* Table1047 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1048 /* Table1048 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    246 /* Table246 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    248 /* Table248 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    250 /* Table250 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    252 /* Table252 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    254 /* Table254 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    256 /* Table256 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    258 /* Table258 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    275 /* Table275 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1049 /* Table1049 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1050 /* Table1050 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    293 /* Table293 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    295 /* Table295 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    369 /* Table369 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1051 /* Table1051 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    443 /* Table443 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    444 /* Table444 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    448 /* Table448 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    465 /* Table465 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    497 /* Table497 */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1052 /* Table1052 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    930 /* Table930 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    932 /* Table932 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1053 /* Table1053 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    934 /* Table934 */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    938 /* Table938 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    940 /* Table940 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    963 /* Table963 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1054 /* Table1054 */
   }
  }
 }
,  /* IC_64BIT_REXW_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1386 /* Table1386 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1388 /* Table1388 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1390 /* Table1390 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1391 /* Table1391 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1393 /* Table1393 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1395 /* Table1395 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1396 /* Table1396 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1398 /* Table1398 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1400 /* Table1400 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1401 /* Table1401 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1403 /* Table1403 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1405 /* Table1405 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1406 /* Table1406 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1408 /* Table1408 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1410 /* Table1410 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1411 /* Table1411 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1413 /* Table1413 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1415 /* Table1415 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1416 /* Table1416 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1418 /* Table1418 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1420 /* Table1420 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1421 /* Table1421 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1423 /* Table1423 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1425 /* Table1425 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1017 /* Table1017 */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1426 /* Table1426 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1022 /* Table1022 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1428 /* Table1428 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1023 /* Table1023 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1430 /* Table1430 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    110 /* Table110 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    112 /* Table112 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1432 /* Table1432 */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1448 /* Table1448 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1464 /* Table1464 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1466 /* Table1466 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1468 /* Table1468 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1470 /* Table1470 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1472 /* Table1472 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1474 /* Table1474 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1476 /* Table1476 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1026 /* Table1026 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1479 /* Table1479 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1480 /* Table1480 */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1043 /* Table1043 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1044 /* Table1044 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1045 /* Table1045 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1481 /* Table1481 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1047 /* Table1047 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1482 /* Table1482 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1483 /* Table1483 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1484 /* Table1484 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1485 /* Table1485 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1486 /* Table1486 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1487 /* Table1487 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1488 /* Table1488 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1490 /* Table1490 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1049 /* Table1049 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1050 /* Table1050 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    293 /* Table293 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    295 /* Table295 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    1506 /* Table1506 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1051 /* Table1051 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1578 /* Table1578 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1579 /* Table1579 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1580 /* Table1580 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1581 /* Table1581 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1597 /* Table1597 */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1052 /* Table1052 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    930 /* Table930 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    932 /* Table932 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1053 /* Table1053 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    934 /* Table934 */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    938 /* Table938 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    940 /* Table940 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1613 /* Table1613 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1629 /* Table1629 */
   }
  }
 }
,  /* IC_64BIT_REXW_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1386 /* Table1386 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1388 /* Table1388 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1390 /* Table1390 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1391 /* Table1391 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1393 /* Table1393 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1395 /* Table1395 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1396 /* Table1396 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1398 /* Table1398 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1400 /* Table1400 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1401 /* Table1401 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1403 /* Table1403 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1405 /* Table1405 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1406 /* Table1406 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1408 /* Table1408 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1410 /* Table1410 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1411 /* Table1411 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1413 /* Table1413 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1415 /* Table1415 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1416 /* Table1416 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1418 /* Table1418 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1420 /* Table1420 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1421 /* Table1421 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1423 /* Table1423 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1425 /* Table1425 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1017 /* Table1017 */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1018 /* Table1018 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1019 /* Table1019 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1426 /* Table1426 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1022 /* Table1022 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1428 /* Table1428 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1023 /* Table1023 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1430 /* Table1430 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    110 /* Table110 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    112 /* Table112 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1432 /* Table1432 */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1448 /* Table1448 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1464 /* Table1464 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1466 /* Table1466 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1468 /* Table1468 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1470 /* Table1470 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1472 /* Table1472 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1474 /* Table1474 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1476 /* Table1476 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1026 /* Table1026 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1479 /* Table1479 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1480 /* Table1480 */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1043 /* Table1043 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1044 /* Table1044 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1045 /* Table1045 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1481 /* Table1481 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1047 /* Table1047 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1482 /* Table1482 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1483 /* Table1483 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1484 /* Table1484 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1485 /* Table1485 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1486 /* Table1486 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1487 /* Table1487 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1488 /* Table1488 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1490 /* Table1490 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1049 /* Table1049 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1050 /* Table1050 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    293 /* Table293 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    295 /* Table295 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    1506 /* Table1506 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1051 /* Table1051 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1578 /* Table1578 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1579 /* Table1579 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1580 /* Table1580 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1581 /* Table1581 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1597 /* Table1597 */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1052 /* Table1052 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    930 /* Table930 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    932 /* Table932 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1053 /* Table1053 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    934 /* Table934 */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    938 /* Table938 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    940 /* Table940 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1613 /* Table1613 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1629 /* Table1629 */
   }
  }
 }
,  /* IC_64BIT_REXW_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1 /* Table1 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1386 /* Table1386 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5 /* Table5 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1388 /* Table1388 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    9 /* Table9 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1390 /* Table1390 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    13 /* Table13 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1391 /* Table1391 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    17 /* Table17 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1393 /* Table1393 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    21 /* Table21 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1395 /* Table1395 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    24 /* Table24 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1396 /* Table1396 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    28 /* Table28 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1398 /* Table1398 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    32 /* Table32 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1400 /* Table1400 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    36 /* Table36 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1401 /* Table1401 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    40 /* Table40 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1403 /* Table1403 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    44 /* Table44 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1405 /* Table1405 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    48 /* Table48 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1406 /* Table1406 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    52 /* Table52 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1408 /* Table1408 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    56 /* Table56 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1410 /* Table1410 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    59 /* Table59 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1411 /* Table1411 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    63 /* Table63 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1413 /* Table1413 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    67 /* Table67 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1415 /* Table1415 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    70 /* Table70 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1416 /* Table1416 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    74 /* Table74 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1418 /* Table1418 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    78 /* Table78 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1420 /* Table1420 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    81 /* Table81 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1421 /* Table1421 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    85 /* Table85 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1423 /* Table1423 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    89 /* Table89 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1425 /* Table1425 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1017 /* Table1017 */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1119 /* Table1119 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1120 /* Table1120 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1426 /* Table1426 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    102 /* Table102 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1645 /* Table1645 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1428 /* Table1428 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1023 /* Table1023 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1430 /* Table1430 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    109 /* Table109 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1131 /* Table1131 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    111 /* Table111 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1132 /* Table1132 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    113 /* Table113 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    114 /* Table114 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    115 /* Table115 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    116 /* Table116 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    117 /* Table117 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    118 /* Table118 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    119 /* Table119 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    120 /* Table120 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    121 /* Table121 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    122 /* Table122 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    123 /* Table123 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    124 /* Table124 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    125 /* Table125 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    126 /* Table126 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    127 /* Table127 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    128 /* Table128 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    129 /* Table129 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1432 /* Table1432 */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1448 /* Table1448 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    193 /* Table193 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1464 /* Table1464 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    197 /* Table197 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1466 /* Table1466 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    201 /* Table201 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1468 /* Table1468 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    205 /* Table205 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1470 /* Table1470 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1472 /* Table1472 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1474 /* Table1474 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1476 /* Table1476 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1179 /* Table1179 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    231 /* Table231 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1478 /* Table1478 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1479 /* Table1479 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1480 /* Table1480 */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    236 /* Table236 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1199 /* Table1199 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1200 /* Table1200 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    239 /* Table239 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    240 /* Table240 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1045 /* Table1045 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1481 /* Table1481 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1047 /* Table1047 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1482 /* Table1482 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    245 /* Table245 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1483 /* Table1483 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    247 /* Table247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1484 /* Table1484 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    249 /* Table249 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1485 /* Table1485 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    251 /* Table251 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1486 /* Table1486 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    253 /* Table253 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1487 /* Table1487 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    255 /* Table255 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1488 /* Table1488 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    257 /* Table257 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1489 /* Table1489 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    259 /* Table259 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1490 /* Table1490 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1226 /* Table1226 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1227 /* Table1227 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1228 /* Table1228 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1230 /* Table1230 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    297 /* Table297 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    1648 /* Table1648 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    441 /* Table441 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1051 /* Table1051 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1578 /* Table1578 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1579 /* Table1579 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    445 /* Table445 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    446 /* Table446 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1580 /* Table1580 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    449 /* Table449 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1581 /* Table1581 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    481 /* Table481 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1597 /* Table1597 */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    516 /* Table516 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    517 /* Table517 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    533 /* Table533 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    605 /* Table605 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    677 /* Table677 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    749 /* Table749 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    765 /* Table765 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    781 /* Table781 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    853 /* Table853 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    925 /* Table925 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    926 /* Table926 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    927 /* Table927 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1052 /* Table1052 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    929 /* Table929 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1339 /* Table1339 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    931 /* Table931 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1340 /* Table1340 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    933 /* Table933 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1342 /* Table1342 */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    936 /* Table936 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    937 /* Table937 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1344 /* Table1344 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    939 /* Table939 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1345 /* Table1345 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    941 /* Table941 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    942 /* Table942 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    943 /* Table943 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    944 /* Table944 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    945 /* Table945 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    946 /* Table946 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    947 /* Table947 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1613 /* Table1613 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    979 /* Table979 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    980 /* Table980 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    981 /* Table981 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    982 /* Table982 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    983 /* Table983 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    984 /* Table984 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    985 /* Table985 */
   },
   /* 0xff */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1720 /* Table1720 */
   }
  }
 }
,  /* IC_OF */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
, };
static const uint8_t index_x86DisassemblerOneByteOpcodes[] = {
1, 2, 3, 4, 0, 5, 6, 7, 0, 0, 8, 9, 10, 11, 12, 13, 14, 0, 0, 15, 16, 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, };
static const struct OpcodeDecision x86DisassemblerTwoByteOpcodes[] = {
 /* IC */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1754 /* Table1754 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    1770 /* Table1770 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1842 /* Table1842 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1844 /* Table1844 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1848 /* Table1848 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1868 /* Table1868 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1870 /* Table1870 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1872 /* Table1872 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1874 /* Table1874 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1876 /* Table1876 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1878 /* Table1878 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1880 /* Table1880 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1882 /* Table1882 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1884 /* Table1884 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1900 /* Table1900 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1902 /* Table1902 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1904 /* Table1904 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1906 /* Table1906 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1908 /* Table1908 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1910 /* Table1910 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1912 /* Table1912 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1914 /* Table1914 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1916 /* Table1916 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1918 /* Table1918 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1920 /* Table1920 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1922 /* Table1922 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1924 /* Table1924 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1926 /* Table1926 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1928 /* Table1928 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1930 /* Table1930 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1932 /* Table1932 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1934 /* Table1934 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1936 /* Table1936 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1943 /* Table1943 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1945 /* Table1945 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1947 /* Table1947 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1949 /* Table1949 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1951 /* Table1951 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1953 /* Table1953 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1955 /* Table1955 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1957 /* Table1957 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1959 /* Table1959 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1961 /* Table1961 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1963 /* Table1963 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1965 /* Table1965 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1967 /* Table1967 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1969 /* Table1969 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1971 /* Table1971 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1973 /* Table1973 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1975 /* Table1975 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1977 /* Table1977 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1979 /* Table1979 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1985 /* Table1985 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1987 /* Table1987 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1989 /* Table1989 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1991 /* Table1991 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1993 /* Table1993 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1995 /* Table1995 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1997 /* Table1997 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1999 /* Table1999 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2001 /* Table2001 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2003 /* Table2003 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2005 /* Table2005 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2007 /* Table2007 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2009 /* Table2009 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2011 /* Table2011 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2013 /* Table2013 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2015 /* Table2015 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2017 /* Table2017 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2019 /* Table2019 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2021 /* Table2021 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2023 /* Table2023 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2025 /* Table2025 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2027 /* Table2027 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2029 /* Table2029 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2031 /* Table2031 */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2033 /* Table2033 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2035 /* Table2035 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2037 /* Table2037 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2039 /* Table2039 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2055 /* Table2055 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2071 /* Table2071 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2087 /* Table2087 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2089 /* Table2089 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2091 /* Table2091 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2094 /* Table2094 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2096 /* Table2096 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2098 /* Table2098 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2100 /* Table2100 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2102 /* Table2102 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2103 /* Table2103 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2104 /* Table2104 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2105 /* Table2105 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2106 /* Table2106 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2107 /* Table2107 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2108 /* Table2108 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2109 /* Table2109 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2110 /* Table2110 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2111 /* Table2111 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2112 /* Table2112 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2113 /* Table2113 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2114 /* Table2114 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2115 /* Table2115 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2116 /* Table2116 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2117 /* Table2117 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2150 /* Table2150 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2151 /* Table2151 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2153 /* Table2153 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2155 /* Table2155 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2157 /* Table2157 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2303 /* Table2303 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2304 /* Table2304 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2306 /* Table2306 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2308 /* Table2308 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2310 /* Table2310 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2312 /* Table2312 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2384 /* Table2384 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2388 /* Table2388 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2390 /* Table2390 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2392 /* Table2392 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2394 /* Table2394 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2396 /* Table2396 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2398 /* Table2398 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2400 /* Table2400 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2403 /* Table2403 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2419 /* Table2419 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2421 /* Table2421 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2423 /* Table2423 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2425 /* Table2425 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2427 /* Table2427 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2431 /* Table2431 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2433 /* Table2433 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2435 /* Table2435 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2437 /* Table2437 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2439 /* Table2439 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2441 /* Table2441 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2443 /* Table2443 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2460 /* Table2460 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2462 /* Table2462 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2464 /* Table2464 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2466 /* Table2466 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2468 /* Table2468 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2470 /* Table2470 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2472 /* Table2472 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2474 /* Table2474 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2476 /* Table2476 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2478 /* Table2478 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2480 /* Table2480 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2482 /* Table2482 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2484 /* Table2484 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2486 /* Table2486 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2488 /* Table2488 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2490 /* Table2490 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2492 /* Table2492 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2494 /* Table2494 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2496 /* Table2496 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2498 /* Table2498 */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2500 /* Table2500 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2502 /* Table2502 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2504 /* Table2504 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2506 /* Table2506 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2508 /* Table2508 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2510 /* Table2510 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2512 /* Table2512 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2514 /* Table2514 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2516 /* Table2516 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2518 /* Table2518 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2520 /* Table2520 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2522 /* Table2522 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2524 /* Table2524 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2526 /* Table2526 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2528 /* Table2528 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2530 /* Table2530 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2532 /* Table2532 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2534 /* Table2534 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2536 /* Table2536 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2538 /* Table2538 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2540 /* Table2540 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2542 /* Table2542 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2544 /* Table2544 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1754 /* Table1754 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2546 /* Table2546 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1842 /* Table1842 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1844 /* Table1844 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1848 /* Table1848 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1868 /* Table1868 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1870 /* Table1870 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1872 /* Table1872 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1874 /* Table1874 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1876 /* Table1876 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1878 /* Table1878 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1880 /* Table1880 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1882 /* Table1882 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1884 /* Table1884 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1900 /* Table1900 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1902 /* Table1902 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1904 /* Table1904 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1906 /* Table1906 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1908 /* Table1908 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1910 /* Table1910 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1912 /* Table1912 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2618 /* Table2618 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2620 /* Table2620 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2622 /* Table2622 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2624 /* Table2624 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1922 /* Table1922 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1924 /* Table1924 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1926 /* Table1926 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1928 /* Table1928 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1930 /* Table1930 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1932 /* Table1932 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1934 /* Table1934 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1936 /* Table1936 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1943 /* Table1943 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1945 /* Table1945 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1947 /* Table1947 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1949 /* Table1949 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1951 /* Table1951 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1953 /* Table1953 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1955 /* Table1955 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1957 /* Table1957 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1959 /* Table1959 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1961 /* Table1961 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1963 /* Table1963 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1965 /* Table1965 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1967 /* Table1967 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1969 /* Table1969 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1971 /* Table1971 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1973 /* Table1973 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1975 /* Table1975 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1977 /* Table1977 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1979 /* Table1979 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1985 /* Table1985 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1987 /* Table1987 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1989 /* Table1989 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1991 /* Table1991 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1993 /* Table1993 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1995 /* Table1995 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1997 /* Table1997 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1999 /* Table1999 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2001 /* Table2001 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2003 /* Table2003 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2005 /* Table2005 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2007 /* Table2007 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2009 /* Table2009 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2011 /* Table2011 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2013 /* Table2013 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2015 /* Table2015 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2017 /* Table2017 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2019 /* Table2019 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2021 /* Table2021 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2023 /* Table2023 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2025 /* Table2025 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2027 /* Table2027 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2029 /* Table2029 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2031 /* Table2031 */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2033 /* Table2033 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2035 /* Table2035 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2037 /* Table2037 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2039 /* Table2039 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2055 /* Table2055 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2071 /* Table2071 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2087 /* Table2087 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2089 /* Table2089 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2091 /* Table2091 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2626 /* Table2626 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2628 /* Table2628 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2098 /* Table2098 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2100 /* Table2100 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2102 /* Table2102 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2103 /* Table2103 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2104 /* Table2104 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2105 /* Table2105 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2106 /* Table2106 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2107 /* Table2107 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2108 /* Table2108 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2109 /* Table2109 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2110 /* Table2110 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2111 /* Table2111 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2112 /* Table2112 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2113 /* Table2113 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2114 /* Table2114 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2115 /* Table2115 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2116 /* Table2116 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2117 /* Table2117 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2630 /* Table2630 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2631 /* Table2631 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2153 /* Table2153 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2155 /* Table2155 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2157 /* Table2157 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2632 /* Table2632 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2633 /* Table2633 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2306 /* Table2306 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2308 /* Table2308 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2310 /* Table2310 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2312 /* Table2312 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2384 /* Table2384 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2388 /* Table2388 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2390 /* Table2390 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2392 /* Table2392 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2394 /* Table2394 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2396 /* Table2396 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2398 /* Table2398 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2400 /* Table2400 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2403 /* Table2403 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2419 /* Table2419 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2421 /* Table2421 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2423 /* Table2423 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2425 /* Table2425 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2427 /* Table2427 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2431 /* Table2431 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2433 /* Table2433 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2435 /* Table2435 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2437 /* Table2437 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2439 /* Table2439 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2441 /* Table2441 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2443 /* Table2443 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2460 /* Table2460 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2462 /* Table2462 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2464 /* Table2464 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2466 /* Table2466 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2468 /* Table2468 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2470 /* Table2470 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2472 /* Table2472 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2474 /* Table2474 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2476 /* Table2476 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2478 /* Table2478 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2480 /* Table2480 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2482 /* Table2482 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2484 /* Table2484 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2486 /* Table2486 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2488 /* Table2488 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2490 /* Table2490 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2492 /* Table2492 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2494 /* Table2494 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2496 /* Table2496 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2498 /* Table2498 */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2500 /* Table2500 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2502 /* Table2502 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2504 /* Table2504 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2506 /* Table2506 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2508 /* Table2508 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2510 /* Table2510 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2512 /* Table2512 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2514 /* Table2514 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2516 /* Table2516 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2518 /* Table2518 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2520 /* Table2520 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2522 /* Table2522 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2524 /* Table2524 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2526 /* Table2526 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2528 /* Table2528 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2634 /* Table2634 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2532 /* Table2532 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2534 /* Table2534 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2536 /* Table2536 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2538 /* Table2538 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2540 /* Table2540 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2542 /* Table2542 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2544 /* Table2544 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2636 /* Table2636 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2652 /* Table2652 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2724 /* Table2724 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2726 /* Table2726 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1848 /* Table1848 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2728 /* Table2728 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2730 /* Table2730 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2732 /* Table2732 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2734 /* Table2734 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2736 /* Table2736 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2738 /* Table2738 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2740 /* Table2740 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2742 /* Table2742 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2744 /* Table2744 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2760 /* Table2760 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2762 /* Table2762 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2764 /* Table2764 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2766 /* Table2766 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2768 /* Table2768 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2770 /* Table2770 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2772 /* Table2772 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1914 /* Table1914 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1916 /* Table1916 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1918 /* Table1918 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1920 /* Table1920 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2774 /* Table2774 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2776 /* Table2776 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2778 /* Table2778 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2780 /* Table2780 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2782 /* Table2782 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2784 /* Table2784 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2786 /* Table2786 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2788 /* Table2788 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1943 /* Table1943 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2790 /* Table2790 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2792 /* Table2792 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2794 /* Table2794 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2796 /* Table2796 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2798 /* Table2798 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2800 /* Table2800 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2802 /* Table2802 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2804 /* Table2804 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2806 /* Table2806 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2808 /* Table2808 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2810 /* Table2810 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2812 /* Table2812 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2814 /* Table2814 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2816 /* Table2816 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2818 /* Table2818 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2820 /* Table2820 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2822 /* Table2822 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2824 /* Table2824 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2826 /* Table2826 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2828 /* Table2828 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2830 /* Table2830 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2832 /* Table2832 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2834 /* Table2834 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2836 /* Table2836 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2838 /* Table2838 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2840 /* Table2840 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2842 /* Table2842 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2844 /* Table2844 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2846 /* Table2846 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2848 /* Table2848 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2850 /* Table2850 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2852 /* Table2852 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2854 /* Table2854 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2856 /* Table2856 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2858 /* Table2858 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2860 /* Table2860 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2862 /* Table2862 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2864 /* Table2864 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2866 /* Table2866 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2868 /* Table2868 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2870 /* Table2870 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2872 /* Table2872 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2874 /* Table2874 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2876 /* Table2876 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2878 /* Table2878 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2880 /* Table2880 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2882 /* Table2882 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2884 /* Table2884 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2900 /* Table2900 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2916 /* Table2916 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2932 /* Table2932 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2934 /* Table2934 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2936 /* Table2936 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2938 /* Table2938 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2940 /* Table2940 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2942 /* Table2942 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2944 /* Table2944 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2946 /* Table2946 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2948 /* Table2948 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2950 /* Table2950 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2951 /* Table2951 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2952 /* Table2952 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2953 /* Table2953 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2954 /* Table2954 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2955 /* Table2955 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2956 /* Table2956 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2957 /* Table2957 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2958 /* Table2958 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2959 /* Table2959 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2960 /* Table2960 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2961 /* Table2961 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2962 /* Table2962 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2963 /* Table2963 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2964 /* Table2964 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2965 /* Table2965 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2966 /* Table2966 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2967 /* Table2967 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2968 /* Table2968 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2970 /* Table2970 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2972 /* Table2972 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2974 /* Table2974 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2975 /* Table2975 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2976 /* Table2976 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2978 /* Table2978 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2980 /* Table2980 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2982 /* Table2982 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3054 /* Table3054 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3056 /* Table3056 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3058 /* Table3058 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3060 /* Table3060 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3062 /* Table3062 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3064 /* Table3064 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3066 /* Table3066 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2400 /* Table2400 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3068 /* Table3068 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3084 /* Table3084 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3086 /* Table3086 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3088 /* Table3088 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3090 /* Table3090 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2427 /* Table2427 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3092 /* Table3092 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3094 /* Table3094 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2435 /* Table2435 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3096 /* Table3096 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3098 /* Table3098 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3100 /* Table3100 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3102 /* Table3102 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3118 /* Table3118 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3120 /* Table3120 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3122 /* Table3122 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3124 /* Table3124 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3126 /* Table3126 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3128 /* Table3128 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3130 /* Table3130 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3132 /* Table3132 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3134 /* Table3134 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3136 /* Table3136 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3138 /* Table3138 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3140 /* Table3140 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3142 /* Table3142 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3144 /* Table3144 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3146 /* Table3146 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3148 /* Table3148 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3150 /* Table3150 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3152 /* Table3152 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3154 /* Table3154 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3156 /* Table3156 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3158 /* Table3158 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3160 /* Table3160 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3162 /* Table3162 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3164 /* Table3164 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3166 /* Table3166 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3168 /* Table3168 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3170 /* Table3170 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3172 /* Table3172 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3174 /* Table3174 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3176 /* Table3176 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3178 /* Table3178 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3180 /* Table3180 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3182 /* Table3182 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3184 /* Table3184 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3186 /* Table3186 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3188 /* Table3188 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3190 /* Table3190 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3192 /* Table3192 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3194 /* Table3194 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3196 /* Table3196 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3198 /* Table3198 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3200 /* Table3200 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3202 /* Table3202 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3204 /* Table3204 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3206 /* Table3206 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3208 /* Table3208 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1754 /* Table1754 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    1770 /* Table1770 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1842 /* Table1842 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1844 /* Table1844 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1848 /* Table1848 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1868 /* Table1868 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1870 /* Table1870 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1872 /* Table1872 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1874 /* Table1874 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1876 /* Table1876 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1878 /* Table1878 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1880 /* Table1880 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1882 /* Table1882 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1884 /* Table1884 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1900 /* Table1900 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1902 /* Table1902 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1904 /* Table1904 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1906 /* Table1906 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1908 /* Table1908 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1910 /* Table1910 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1912 /* Table1912 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1914 /* Table1914 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1916 /* Table1916 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1918 /* Table1918 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1920 /* Table1920 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1922 /* Table1922 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1924 /* Table1924 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1926 /* Table1926 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1928 /* Table1928 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1930 /* Table1930 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1932 /* Table1932 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1934 /* Table1934 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1936 /* Table1936 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1943 /* Table1943 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1945 /* Table1945 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1947 /* Table1947 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1949 /* Table1949 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1951 /* Table1951 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1953 /* Table1953 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1955 /* Table1955 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1957 /* Table1957 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1959 /* Table1959 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1961 /* Table1961 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1963 /* Table1963 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1965 /* Table1965 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1967 /* Table1967 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1969 /* Table1969 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1971 /* Table1971 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1973 /* Table1973 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1975 /* Table1975 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1977 /* Table1977 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1979 /* Table1979 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1985 /* Table1985 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1987 /* Table1987 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1989 /* Table1989 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1991 /* Table1991 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1993 /* Table1993 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1995 /* Table1995 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1997 /* Table1997 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1999 /* Table1999 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2001 /* Table2001 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2003 /* Table2003 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2005 /* Table2005 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2007 /* Table2007 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2009 /* Table2009 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2011 /* Table2011 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2013 /* Table2013 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2015 /* Table2015 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2017 /* Table2017 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2019 /* Table2019 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2021 /* Table2021 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2023 /* Table2023 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2025 /* Table2025 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2027 /* Table2027 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2029 /* Table2029 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2031 /* Table2031 */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2033 /* Table2033 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2035 /* Table2035 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2037 /* Table2037 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2039 /* Table2039 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2055 /* Table2055 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2071 /* Table2071 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2087 /* Table2087 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2089 /* Table2089 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2091 /* Table2091 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2094 /* Table2094 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2096 /* Table2096 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2098 /* Table2098 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2100 /* Table2100 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2102 /* Table2102 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2103 /* Table2103 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2104 /* Table2104 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2105 /* Table2105 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2106 /* Table2106 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2107 /* Table2107 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2108 /* Table2108 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2109 /* Table2109 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2110 /* Table2110 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2111 /* Table2111 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2112 /* Table2112 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2113 /* Table2113 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2114 /* Table2114 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2115 /* Table2115 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2116 /* Table2116 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2117 /* Table2117 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2150 /* Table2150 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2151 /* Table2151 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2153 /* Table2153 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2155 /* Table2155 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2157 /* Table2157 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2303 /* Table2303 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2304 /* Table2304 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2306 /* Table2306 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2308 /* Table2308 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2310 /* Table2310 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2312 /* Table2312 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2384 /* Table2384 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2388 /* Table2388 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2390 /* Table2390 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2392 /* Table2392 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2394 /* Table2394 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2396 /* Table2396 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2398 /* Table2398 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2400 /* Table2400 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2403 /* Table2403 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2419 /* Table2419 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2421 /* Table2421 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2423 /* Table2423 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2425 /* Table2425 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2427 /* Table2427 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2431 /* Table2431 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2433 /* Table2433 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2435 /* Table2435 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2437 /* Table2437 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2439 /* Table2439 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2441 /* Table2441 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2443 /* Table2443 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2460 /* Table2460 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2462 /* Table2462 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2464 /* Table2464 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2466 /* Table2466 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2468 /* Table2468 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2470 /* Table2470 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2472 /* Table2472 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2474 /* Table2474 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2476 /* Table2476 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2478 /* Table2478 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2480 /* Table2480 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2482 /* Table2482 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2484 /* Table2484 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2486 /* Table2486 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2488 /* Table2488 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2490 /* Table2490 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2492 /* Table2492 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2494 /* Table2494 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2496 /* Table2496 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2498 /* Table2498 */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2500 /* Table2500 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2502 /* Table2502 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2504 /* Table2504 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2506 /* Table2506 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2508 /* Table2508 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2510 /* Table2510 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2512 /* Table2512 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2514 /* Table2514 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2516 /* Table2516 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2518 /* Table2518 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2520 /* Table2520 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2522 /* Table2522 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2524 /* Table2524 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2526 /* Table2526 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2528 /* Table2528 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2530 /* Table2530 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2532 /* Table2532 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2534 /* Table2534 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2536 /* Table2536 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2538 /* Table2538 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2540 /* Table2540 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2542 /* Table2542 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2544 /* Table2544 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_OPSIZE_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2636 /* Table2636 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2652 /* Table2652 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2724 /* Table2724 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2726 /* Table2726 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1848 /* Table1848 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2728 /* Table2728 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2730 /* Table2730 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2732 /* Table2732 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2734 /* Table2734 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2736 /* Table2736 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2738 /* Table2738 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2740 /* Table2740 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2742 /* Table2742 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2744 /* Table2744 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2760 /* Table2760 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2762 /* Table2762 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2764 /* Table2764 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2766 /* Table2766 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2768 /* Table2768 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2770 /* Table2770 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2772 /* Table2772 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1914 /* Table1914 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1916 /* Table1916 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1918 /* Table1918 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1920 /* Table1920 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2774 /* Table2774 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2776 /* Table2776 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2778 /* Table2778 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2780 /* Table2780 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2782 /* Table2782 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2784 /* Table2784 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2786 /* Table2786 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2788 /* Table2788 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1943 /* Table1943 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2790 /* Table2790 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2792 /* Table2792 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2794 /* Table2794 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2796 /* Table2796 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2798 /* Table2798 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2800 /* Table2800 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2802 /* Table2802 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2804 /* Table2804 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2806 /* Table2806 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2808 /* Table2808 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2810 /* Table2810 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2812 /* Table2812 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2814 /* Table2814 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2816 /* Table2816 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2818 /* Table2818 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2820 /* Table2820 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2822 /* Table2822 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2824 /* Table2824 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2826 /* Table2826 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2828 /* Table2828 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2830 /* Table2830 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2832 /* Table2832 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2834 /* Table2834 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2836 /* Table2836 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2838 /* Table2838 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2840 /* Table2840 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2842 /* Table2842 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2844 /* Table2844 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2846 /* Table2846 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2848 /* Table2848 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2850 /* Table2850 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2852 /* Table2852 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2854 /* Table2854 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2856 /* Table2856 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2858 /* Table2858 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2860 /* Table2860 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2862 /* Table2862 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2864 /* Table2864 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2866 /* Table2866 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2868 /* Table2868 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2870 /* Table2870 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2872 /* Table2872 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2874 /* Table2874 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2876 /* Table2876 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2878 /* Table2878 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2880 /* Table2880 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2882 /* Table2882 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2884 /* Table2884 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2900 /* Table2900 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2916 /* Table2916 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2932 /* Table2932 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2934 /* Table2934 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2936 /* Table2936 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2938 /* Table2938 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2940 /* Table2940 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2942 /* Table2942 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2944 /* Table2944 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2946 /* Table2946 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2948 /* Table2948 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2950 /* Table2950 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2951 /* Table2951 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2952 /* Table2952 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2953 /* Table2953 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2954 /* Table2954 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2955 /* Table2955 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2956 /* Table2956 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2957 /* Table2957 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2958 /* Table2958 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2959 /* Table2959 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2960 /* Table2960 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2961 /* Table2961 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2962 /* Table2962 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2963 /* Table2963 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2964 /* Table2964 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2965 /* Table2965 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2966 /* Table2966 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2967 /* Table2967 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2968 /* Table2968 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2970 /* Table2970 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2972 /* Table2972 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2974 /* Table2974 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2975 /* Table2975 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2976 /* Table2976 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2978 /* Table2978 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2980 /* Table2980 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2982 /* Table2982 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3054 /* Table3054 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3056 /* Table3056 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3058 /* Table3058 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3060 /* Table3060 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3062 /* Table3062 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3064 /* Table3064 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3066 /* Table3066 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2400 /* Table2400 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3068 /* Table3068 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3084 /* Table3084 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3086 /* Table3086 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3088 /* Table3088 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3090 /* Table3090 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2427 /* Table2427 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3092 /* Table3092 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3094 /* Table3094 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2435 /* Table2435 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3096 /* Table3096 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3098 /* Table3098 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3100 /* Table3100 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3102 /* Table3102 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3118 /* Table3118 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3120 /* Table3120 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3122 /* Table3122 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3124 /* Table3124 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3126 /* Table3126 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3128 /* Table3128 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3130 /* Table3130 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3132 /* Table3132 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3134 /* Table3134 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3136 /* Table3136 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3138 /* Table3138 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3140 /* Table3140 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3142 /* Table3142 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3144 /* Table3144 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3146 /* Table3146 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3148 /* Table3148 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3150 /* Table3150 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3152 /* Table3152 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3154 /* Table3154 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3156 /* Table3156 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3158 /* Table3158 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3160 /* Table3160 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3162 /* Table3162 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3164 /* Table3164 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3166 /* Table3166 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3168 /* Table3168 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3170 /* Table3170 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3172 /* Table3172 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3174 /* Table3174 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3176 /* Table3176 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3178 /* Table3178 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3180 /* Table3180 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3182 /* Table3182 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3184 /* Table3184 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3186 /* Table3186 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3188 /* Table3188 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3190 /* Table3190 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3192 /* Table3192 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3194 /* Table3194 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3196 /* Table3196 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3198 /* Table3198 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3200 /* Table3200 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3202 /* Table3202 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3204 /* Table3204 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3206 /* Table3206 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3208 /* Table3208 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1754 /* Table1754 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    1770 /* Table1770 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1842 /* Table1842 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1844 /* Table1844 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1848 /* Table1848 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3210 /* Table3210 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3212 /* Table3212 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3214 /* Table3214 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1874 /* Table1874 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1876 /* Table1876 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1878 /* Table1878 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1880 /* Table1880 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1882 /* Table1882 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1884 /* Table1884 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1900 /* Table1900 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1902 /* Table1902 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1904 /* Table1904 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1906 /* Table1906 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1908 /* Table1908 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1910 /* Table1910 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1912 /* Table1912 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1914 /* Table1914 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1916 /* Table1916 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1918 /* Table1918 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1920 /* Table1920 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1922 /* Table1922 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1924 /* Table1924 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3216 /* Table3216 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3218 /* Table3218 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3220 /* Table3220 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3222 /* Table3222 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1934 /* Table1934 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1936 /* Table1936 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1943 /* Table1943 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1945 /* Table1945 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1947 /* Table1947 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1949 /* Table1949 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1951 /* Table1951 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1953 /* Table1953 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1955 /* Table1955 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1957 /* Table1957 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1959 /* Table1959 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1961 /* Table1961 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1963 /* Table1963 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1965 /* Table1965 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1967 /* Table1967 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1969 /* Table1969 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1971 /* Table1971 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1973 /* Table1973 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1975 /* Table1975 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1977 /* Table1977 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3224 /* Table3224 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1985 /* Table1985 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1987 /* Table1987 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1989 /* Table1989 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1991 /* Table1991 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3226 /* Table3226 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3228 /* Table3228 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3230 /* Table3230 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1999 /* Table1999 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3232 /* Table3232 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3234 /* Table3234 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3236 /* Table3236 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3238 /* Table3238 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2009 /* Table2009 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2011 /* Table2011 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2013 /* Table2013 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2015 /* Table2015 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2017 /* Table2017 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2019 /* Table2019 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2021 /* Table2021 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2023 /* Table2023 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2025 /* Table2025 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2027 /* Table2027 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2029 /* Table2029 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2031 /* Table2031 */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2033 /* Table2033 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2035 /* Table2035 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3240 /* Table3240 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2039 /* Table2039 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2055 /* Table2055 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2071 /* Table2071 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2087 /* Table2087 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2089 /* Table2089 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2091 /* Table2091 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3242 /* Table3242 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3244 /* Table3244 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3246 /* Table3246 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3248 /* Table3248 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2098 /* Table2098 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2100 /* Table2100 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2102 /* Table2102 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2103 /* Table2103 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2104 /* Table2104 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2105 /* Table2105 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2106 /* Table2106 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2107 /* Table2107 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2108 /* Table2108 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2109 /* Table2109 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2110 /* Table2110 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2111 /* Table2111 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2112 /* Table2112 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2113 /* Table2113 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2114 /* Table2114 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2115 /* Table2115 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2116 /* Table2116 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2117 /* Table2117 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2150 /* Table2150 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2151 /* Table2151 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2153 /* Table2153 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2155 /* Table2155 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2157 /* Table2157 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2303 /* Table2303 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2304 /* Table2304 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2306 /* Table2306 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2308 /* Table2308 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2310 /* Table2310 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2312 /* Table2312 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2384 /* Table2384 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2388 /* Table2388 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2390 /* Table2390 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2392 /* Table2392 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2394 /* Table2394 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2396 /* Table2396 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2398 /* Table2398 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2400 /* Table2400 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2403 /* Table2403 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2419 /* Table2419 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2421 /* Table2421 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2423 /* Table2423 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2425 /* Table2425 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2427 /* Table2427 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2431 /* Table2431 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3250 /* Table3250 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2435 /* Table2435 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2437 /* Table2437 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2439 /* Table2439 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2441 /* Table2441 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2443 /* Table2443 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3252 /* Table3252 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2460 /* Table2460 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2462 /* Table2462 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2464 /* Table2464 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2466 /* Table2466 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2468 /* Table2468 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3254 /* Table3254 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2470 /* Table2470 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2472 /* Table2472 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2474 /* Table2474 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2476 /* Table2476 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2478 /* Table2478 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2480 /* Table2480 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2482 /* Table2482 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2484 /* Table2484 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2486 /* Table2486 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2488 /* Table2488 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2490 /* Table2490 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2492 /* Table2492 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2494 /* Table2494 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2496 /* Table2496 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2498 /* Table2498 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3256 /* Table3256 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2500 /* Table2500 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2502 /* Table2502 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2504 /* Table2504 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2506 /* Table2506 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2508 /* Table2508 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2510 /* Table2510 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2512 /* Table2512 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2514 /* Table2514 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2516 /* Table2516 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3258 /* Table3258 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2518 /* Table2518 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2520 /* Table2520 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2522 /* Table2522 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2524 /* Table2524 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2526 /* Table2526 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2528 /* Table2528 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2530 /* Table2530 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2532 /* Table2532 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2534 /* Table2534 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2536 /* Table2536 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2538 /* Table2538 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2540 /* Table2540 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2542 /* Table2542 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2544 /* Table2544 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1754 /* Table1754 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    1770 /* Table1770 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1842 /* Table1842 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1844 /* Table1844 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1848 /* Table1848 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3260 /* Table3260 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3262 /* Table3262 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3264 /* Table3264 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1874 /* Table1874 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1876 /* Table1876 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1878 /* Table1878 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3266 /* Table3266 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1882 /* Table1882 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1884 /* Table1884 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1900 /* Table1900 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1902 /* Table1902 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1904 /* Table1904 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1906 /* Table1906 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1908 /* Table1908 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1910 /* Table1910 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1912 /* Table1912 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1914 /* Table1914 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1916 /* Table1916 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1918 /* Table1918 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1920 /* Table1920 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1922 /* Table1922 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1924 /* Table1924 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3268 /* Table3268 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3270 /* Table3270 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3272 /* Table3272 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3274 /* Table3274 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1934 /* Table1934 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1936 /* Table1936 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1943 /* Table1943 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1945 /* Table1945 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1947 /* Table1947 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1949 /* Table1949 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1951 /* Table1951 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1953 /* Table1953 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1955 /* Table1955 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1957 /* Table1957 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1959 /* Table1959 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1961 /* Table1961 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1963 /* Table1963 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1965 /* Table1965 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1967 /* Table1967 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1969 /* Table1969 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1971 /* Table1971 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1973 /* Table1973 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1975 /* Table1975 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1977 /* Table1977 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3276 /* Table3276 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3278 /* Table3278 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3280 /* Table3280 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1985 /* Table1985 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1987 /* Table1987 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1989 /* Table1989 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1991 /* Table1991 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3282 /* Table3282 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3284 /* Table3284 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3286 /* Table3286 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3288 /* Table3288 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3290 /* Table3290 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3292 /* Table3292 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3294 /* Table3294 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3296 /* Table3296 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2009 /* Table2009 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2011 /* Table2011 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2013 /* Table2013 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2015 /* Table2015 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2017 /* Table2017 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2019 /* Table2019 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2021 /* Table2021 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2023 /* Table2023 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2025 /* Table2025 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2027 /* Table2027 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2029 /* Table2029 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2031 /* Table2031 */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2033 /* Table2033 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3298 /* Table3298 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3300 /* Table3300 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2039 /* Table2039 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2055 /* Table2055 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2071 /* Table2071 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2087 /* Table2087 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2089 /* Table2089 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2091 /* Table2091 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2094 /* Table2094 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2096 /* Table2096 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3302 /* Table3302 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3304 /* Table3304 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2102 /* Table2102 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2103 /* Table2103 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2104 /* Table2104 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2105 /* Table2105 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2106 /* Table2106 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2107 /* Table2107 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2108 /* Table2108 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2109 /* Table2109 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2110 /* Table2110 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2111 /* Table2111 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2112 /* Table2112 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2113 /* Table2113 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2114 /* Table2114 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2115 /* Table2115 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2116 /* Table2116 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2117 /* Table2117 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2150 /* Table2150 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2151 /* Table2151 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2153 /* Table2153 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2155 /* Table2155 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2157 /* Table2157 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2303 /* Table2303 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2304 /* Table2304 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2306 /* Table2306 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2308 /* Table2308 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2310 /* Table2310 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2312 /* Table2312 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2384 /* Table2384 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2388 /* Table2388 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2390 /* Table2390 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2392 /* Table2392 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2394 /* Table2394 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2396 /* Table2396 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2398 /* Table2398 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2400 /* Table2400 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3306 /* Table3306 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2403 /* Table2403 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2419 /* Table2419 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3308 /* Table3308 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3310 /* Table3310 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2425 /* Table2425 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2427 /* Table2427 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2431 /* Table2431 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3312 /* Table3312 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2435 /* Table2435 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2437 /* Table2437 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2439 /* Table2439 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2441 /* Table2441 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3314 /* Table3314 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2460 /* Table2460 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2462 /* Table2462 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2464 /* Table2464 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2466 /* Table2466 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2468 /* Table2468 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3330 /* Table3330 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2470 /* Table2470 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2472 /* Table2472 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2474 /* Table2474 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2476 /* Table2476 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2478 /* Table2478 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2480 /* Table2480 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2482 /* Table2482 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2484 /* Table2484 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2486 /* Table2486 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2488 /* Table2488 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2490 /* Table2490 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2492 /* Table2492 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2494 /* Table2494 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2496 /* Table2496 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2498 /* Table2498 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3332 /* Table3332 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2500 /* Table2500 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2502 /* Table2502 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2504 /* Table2504 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2506 /* Table2506 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2508 /* Table2508 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2510 /* Table2510 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2512 /* Table2512 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2514 /* Table2514 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2516 /* Table2516 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2518 /* Table2518 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2520 /* Table2520 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2522 /* Table2522 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2524 /* Table2524 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2526 /* Table2526 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2528 /* Table2528 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2530 /* Table2530 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2532 /* Table2532 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2534 /* Table2534 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2536 /* Table2536 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2538 /* Table2538 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2540 /* Table2540 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2542 /* Table2542 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2544 /* Table2544 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_XS_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3334 /* Table3334 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3336 /* Table3336 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3338 /* Table3338 */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3340 /* Table3340 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    3356 /* Table3356 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3428 /* Table3428 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3430 /* Table3430 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3432 /* Table3432 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1868 /* Table1868 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1870 /* Table1870 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1872 /* Table1872 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1874 /* Table1874 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1876 /* Table1876 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1878 /* Table1878 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1880 /* Table1880 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1882 /* Table1882 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1884 /* Table1884 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1900 /* Table1900 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1902 /* Table1902 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1904 /* Table1904 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1906 /* Table1906 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1908 /* Table1908 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1910 /* Table1910 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1912 /* Table1912 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2618 /* Table2618 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2620 /* Table2620 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2622 /* Table2622 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2624 /* Table2624 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1922 /* Table1922 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1924 /* Table1924 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1926 /* Table1926 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1928 /* Table1928 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1930 /* Table1930 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1932 /* Table1932 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1934 /* Table1934 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1936 /* Table1936 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3433 /* Table3433 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3434 /* Table3434 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3436 /* Table3436 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3438 /* Table3438 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3440 /* Table3440 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3442 /* Table3442 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3444 /* Table3444 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3446 /* Table3446 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3448 /* Table3448 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3450 /* Table3450 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3452 /* Table3452 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3454 /* Table3454 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3456 /* Table3456 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3458 /* Table3458 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3460 /* Table3460 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3462 /* Table3462 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3464 /* Table3464 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1977 /* Table1977 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1979 /* Table1979 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1985 /* Table1985 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1987 /* Table1987 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1989 /* Table1989 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1991 /* Table1991 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1993 /* Table1993 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1995 /* Table1995 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1997 /* Table1997 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1999 /* Table1999 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2001 /* Table2001 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2003 /* Table2003 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2005 /* Table2005 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2007 /* Table2007 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2009 /* Table2009 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2011 /* Table2011 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2013 /* Table2013 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2015 /* Table2015 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2017 /* Table2017 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2019 /* Table2019 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2021 /* Table2021 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2023 /* Table2023 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2025 /* Table2025 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2027 /* Table2027 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2029 /* Table2029 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2031 /* Table2031 */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3466 /* Table3466 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2035 /* Table2035 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2037 /* Table2037 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2039 /* Table2039 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2055 /* Table2055 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2071 /* Table2071 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2087 /* Table2087 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2089 /* Table2089 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2091 /* Table2091 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2626 /* Table2626 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2628 /* Table2628 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3468 /* Table3468 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2100 /* Table2100 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2102 /* Table2102 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2103 /* Table2103 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2104 /* Table2104 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2105 /* Table2105 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2106 /* Table2106 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2107 /* Table2107 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2108 /* Table2108 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2109 /* Table2109 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2110 /* Table2110 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2111 /* Table2111 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2112 /* Table2112 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2113 /* Table2113 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2114 /* Table2114 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2115 /* Table2115 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2116 /* Table2116 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2117 /* Table2117 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2630 /* Table2630 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2631 /* Table2631 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3470 /* Table3470 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3472 /* Table3472 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3474 /* Table3474 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2632 /* Table2632 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2633 /* Table2633 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3476 /* Table3476 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3478 /* Table3478 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3480 /* Table3480 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    3482 /* Table3482 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3554 /* Table3554 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3556 /* Table3556 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3558 /* Table3558 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3560 /* Table3560 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3562 /* Table3562 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3564 /* Table3564 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3566 /* Table3566 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3568 /* Table3568 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3570 /* Table3570 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3586 /* Table3586 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3588 /* Table3588 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3590 /* Table3590 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3592 /* Table3592 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3594 /* Table3594 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3596 /* Table3596 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2433 /* Table2433 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3598 /* Table3598 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2437 /* Table2437 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2439 /* Table2439 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2441 /* Table2441 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3600 /* Table3600 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2460 /* Table2460 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2462 /* Table2462 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2464 /* Table2464 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2466 /* Table2466 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2468 /* Table2468 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2470 /* Table2470 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2472 /* Table2472 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2474 /* Table2474 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2476 /* Table2476 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2478 /* Table2478 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2480 /* Table2480 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2482 /* Table2482 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2484 /* Table2484 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2486 /* Table2486 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2488 /* Table2488 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2490 /* Table2490 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2492 /* Table2492 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2494 /* Table2494 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2496 /* Table2496 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2498 /* Table2498 */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2500 /* Table2500 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2502 /* Table2502 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2504 /* Table2504 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2506 /* Table2506 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2508 /* Table2508 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2510 /* Table2510 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2512 /* Table2512 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2514 /* Table2514 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2516 /* Table2516 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2518 /* Table2518 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2520 /* Table2520 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2522 /* Table2522 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2524 /* Table2524 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2526 /* Table2526 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2528 /* Table2528 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2634 /* Table2634 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2532 /* Table2532 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2534 /* Table2534 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2536 /* Table2536 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2538 /* Table2538 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2540 /* Table2540 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2542 /* Table2542 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2544 /* Table2544 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3340 /* Table3340 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    3356 /* Table3356 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3428 /* Table3428 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3430 /* Table3430 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3432 /* Table3432 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2728 /* Table2728 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2730 /* Table2730 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2732 /* Table2732 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2734 /* Table2734 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2736 /* Table2736 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2738 /* Table2738 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2740 /* Table2740 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2742 /* Table2742 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2744 /* Table2744 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2760 /* Table2760 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2762 /* Table2762 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2764 /* Table2764 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2766 /* Table2766 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2768 /* Table2768 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2770 /* Table2770 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2772 /* Table2772 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2618 /* Table2618 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2620 /* Table2620 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2622 /* Table2622 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2624 /* Table2624 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2774 /* Table2774 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2776 /* Table2776 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2778 /* Table2778 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2780 /* Table2780 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2782 /* Table2782 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2784 /* Table2784 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2786 /* Table2786 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2788 /* Table2788 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3433 /* Table3433 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3434 /* Table3434 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3436 /* Table3436 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3438 /* Table3438 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3440 /* Table3440 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3442 /* Table3442 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3444 /* Table3444 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3446 /* Table3446 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3448 /* Table3448 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3450 /* Table3450 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3452 /* Table3452 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3454 /* Table3454 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3456 /* Table3456 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3458 /* Table3458 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3460 /* Table3460 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3462 /* Table3462 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3464 /* Table3464 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2822 /* Table2822 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2824 /* Table2824 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2826 /* Table2826 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2828 /* Table2828 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2830 /* Table2830 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2832 /* Table2832 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2834 /* Table2834 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2836 /* Table2836 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2838 /* Table2838 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2840 /* Table2840 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2842 /* Table2842 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2844 /* Table2844 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2846 /* Table2846 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2848 /* Table2848 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2850 /* Table2850 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2852 /* Table2852 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2854 /* Table2854 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2856 /* Table2856 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2858 /* Table2858 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2860 /* Table2860 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2862 /* Table2862 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2864 /* Table2864 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2866 /* Table2866 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2868 /* Table2868 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2870 /* Table2870 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2872 /* Table2872 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2874 /* Table2874 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2876 /* Table2876 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3466 /* Table3466 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2880 /* Table2880 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2882 /* Table2882 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2884 /* Table2884 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2900 /* Table2900 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2916 /* Table2916 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2932 /* Table2932 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2934 /* Table2934 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2936 /* Table2936 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3617 /* Table3617 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3619 /* Table3619 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2942 /* Table2942 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2944 /* Table2944 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3468 /* Table3468 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2948 /* Table2948 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2950 /* Table2950 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2951 /* Table2951 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2952 /* Table2952 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2953 /* Table2953 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2954 /* Table2954 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2955 /* Table2955 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2956 /* Table2956 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2957 /* Table2957 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2958 /* Table2958 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2959 /* Table2959 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2960 /* Table2960 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2961 /* Table2961 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2962 /* Table2962 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2963 /* Table2963 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2964 /* Table2964 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2965 /* Table2965 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2966 /* Table2966 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2967 /* Table2967 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3470 /* Table3470 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3472 /* Table3472 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3474 /* Table3474 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2974 /* Table2974 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2975 /* Table2975 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3476 /* Table3476 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3478 /* Table3478 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3480 /* Table3480 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    3621 /* Table3621 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3554 /* Table3554 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3556 /* Table3556 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3558 /* Table3558 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3560 /* Table3560 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3562 /* Table3562 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3564 /* Table3564 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3566 /* Table3566 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3568 /* Table3568 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3570 /* Table3570 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3586 /* Table3586 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3588 /* Table3588 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3590 /* Table3590 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3592 /* Table3592 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3594 /* Table3594 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3596 /* Table3596 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3094 /* Table3094 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3598 /* Table3598 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3096 /* Table3096 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3098 /* Table3098 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3100 /* Table3100 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3693 /* Table3693 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3118 /* Table3118 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3120 /* Table3120 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3122 /* Table3122 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3124 /* Table3124 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3126 /* Table3126 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3128 /* Table3128 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3130 /* Table3130 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3132 /* Table3132 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3134 /* Table3134 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3136 /* Table3136 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3138 /* Table3138 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3140 /* Table3140 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3142 /* Table3142 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3144 /* Table3144 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3146 /* Table3146 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3148 /* Table3148 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3150 /* Table3150 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3152 /* Table3152 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3154 /* Table3154 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3156 /* Table3156 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3158 /* Table3158 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3160 /* Table3160 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3162 /* Table3162 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3164 /* Table3164 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3166 /* Table3166 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3168 /* Table3168 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3170 /* Table3170 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3172 /* Table3172 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3174 /* Table3174 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3176 /* Table3176 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3178 /* Table3178 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3180 /* Table3180 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3182 /* Table3182 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3184 /* Table3184 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3186 /* Table3186 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3188 /* Table3188 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3190 /* Table3190 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3192 /* Table3192 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3709 /* Table3709 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3196 /* Table3196 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3198 /* Table3198 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3200 /* Table3200 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3202 /* Table3202 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3204 /* Table3204 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3206 /* Table3206 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3208 /* Table3208 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2636 /* Table2636 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    3711 /* Table3711 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2724 /* Table2724 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2726 /* Table2726 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1848 /* Table1848 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2728 /* Table2728 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2730 /* Table2730 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2732 /* Table2732 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2734 /* Table2734 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2736 /* Table2736 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2738 /* Table2738 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2740 /* Table2740 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2742 /* Table2742 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2744 /* Table2744 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2760 /* Table2760 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2762 /* Table2762 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2764 /* Table2764 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2766 /* Table2766 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2768 /* Table2768 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2770 /* Table2770 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2772 /* Table2772 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2618 /* Table2618 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2620 /* Table2620 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2622 /* Table2622 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2624 /* Table2624 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2774 /* Table2774 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2776 /* Table2776 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2778 /* Table2778 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2780 /* Table2780 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2782 /* Table2782 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2784 /* Table2784 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2786 /* Table2786 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2788 /* Table2788 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1943 /* Table1943 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2790 /* Table2790 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2792 /* Table2792 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2794 /* Table2794 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2796 /* Table2796 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2798 /* Table2798 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2800 /* Table2800 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2802 /* Table2802 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2804 /* Table2804 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2806 /* Table2806 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2808 /* Table2808 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2810 /* Table2810 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2812 /* Table2812 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2814 /* Table2814 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2816 /* Table2816 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2818 /* Table2818 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2820 /* Table2820 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2822 /* Table2822 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2824 /* Table2824 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2826 /* Table2826 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2828 /* Table2828 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2830 /* Table2830 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2832 /* Table2832 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2834 /* Table2834 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2836 /* Table2836 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2838 /* Table2838 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2840 /* Table2840 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2842 /* Table2842 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2844 /* Table2844 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2846 /* Table2846 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2848 /* Table2848 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2850 /* Table2850 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2852 /* Table2852 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2854 /* Table2854 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2856 /* Table2856 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2858 /* Table2858 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2860 /* Table2860 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2862 /* Table2862 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2864 /* Table2864 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2866 /* Table2866 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2868 /* Table2868 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2870 /* Table2870 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2872 /* Table2872 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2874 /* Table2874 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2876 /* Table2876 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2878 /* Table2878 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2880 /* Table2880 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2882 /* Table2882 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2884 /* Table2884 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2900 /* Table2900 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2916 /* Table2916 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2932 /* Table2932 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2934 /* Table2934 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2936 /* Table2936 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3617 /* Table3617 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3619 /* Table3619 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2942 /* Table2942 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2944 /* Table2944 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2946 /* Table2946 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2948 /* Table2948 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2950 /* Table2950 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2951 /* Table2951 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2952 /* Table2952 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2953 /* Table2953 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2954 /* Table2954 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2955 /* Table2955 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2956 /* Table2956 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2957 /* Table2957 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2958 /* Table2958 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2959 /* Table2959 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2960 /* Table2960 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2961 /* Table2961 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2962 /* Table2962 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2963 /* Table2963 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2964 /* Table2964 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2965 /* Table2965 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2966 /* Table2966 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2967 /* Table2967 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2968 /* Table2968 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2970 /* Table2970 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2972 /* Table2972 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2974 /* Table2974 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2975 /* Table2975 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2976 /* Table2976 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2978 /* Table2978 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2980 /* Table2980 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2982 /* Table2982 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3054 /* Table3054 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3056 /* Table3056 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3058 /* Table3058 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3060 /* Table3060 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3062 /* Table3062 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3064 /* Table3064 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3066 /* Table3066 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2400 /* Table2400 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3068 /* Table3068 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3084 /* Table3084 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3086 /* Table3086 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3088 /* Table3088 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3090 /* Table3090 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2427 /* Table2427 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3092 /* Table3092 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3094 /* Table3094 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2435 /* Table2435 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3096 /* Table3096 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3098 /* Table3098 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3100 /* Table3100 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3102 /* Table3102 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3118 /* Table3118 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3120 /* Table3120 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3122 /* Table3122 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3124 /* Table3124 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3126 /* Table3126 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3128 /* Table3128 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3130 /* Table3130 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3132 /* Table3132 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3134 /* Table3134 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3136 /* Table3136 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3138 /* Table3138 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3140 /* Table3140 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3142 /* Table3142 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3144 /* Table3144 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3146 /* Table3146 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3148 /* Table3148 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3150 /* Table3150 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3152 /* Table3152 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3154 /* Table3154 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3156 /* Table3156 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3158 /* Table3158 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3160 /* Table3160 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3162 /* Table3162 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3164 /* Table3164 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3166 /* Table3166 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3168 /* Table3168 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3170 /* Table3170 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3172 /* Table3172 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3174 /* Table3174 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3176 /* Table3176 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3178 /* Table3178 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3180 /* Table3180 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3182 /* Table3182 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3184 /* Table3184 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3186 /* Table3186 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3188 /* Table3188 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3190 /* Table3190 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3192 /* Table3192 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3709 /* Table3709 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3196 /* Table3196 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3198 /* Table3198 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3200 /* Table3200 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3202 /* Table3202 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3204 /* Table3204 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3206 /* Table3206 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3208 /* Table3208 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1754 /* Table1754 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2546 /* Table2546 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1842 /* Table1842 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1844 /* Table1844 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1848 /* Table1848 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1868 /* Table1868 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1870 /* Table1870 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1872 /* Table1872 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1874 /* Table1874 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1876 /* Table1876 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1878 /* Table1878 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1880 /* Table1880 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1882 /* Table1882 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1884 /* Table1884 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1900 /* Table1900 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1902 /* Table1902 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1904 /* Table1904 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1906 /* Table1906 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1908 /* Table1908 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1910 /* Table1910 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1912 /* Table1912 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2618 /* Table2618 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2620 /* Table2620 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2622 /* Table2622 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2624 /* Table2624 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1922 /* Table1922 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1924 /* Table1924 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1926 /* Table1926 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1928 /* Table1928 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1930 /* Table1930 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1932 /* Table1932 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1934 /* Table1934 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1936 /* Table1936 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1943 /* Table1943 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1945 /* Table1945 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1947 /* Table1947 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1949 /* Table1949 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1951 /* Table1951 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1953 /* Table1953 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1955 /* Table1955 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1957 /* Table1957 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1959 /* Table1959 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1961 /* Table1961 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1963 /* Table1963 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1965 /* Table1965 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1967 /* Table1967 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1969 /* Table1969 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1971 /* Table1971 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1973 /* Table1973 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1975 /* Table1975 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1977 /* Table1977 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1979 /* Table1979 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1985 /* Table1985 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1987 /* Table1987 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1989 /* Table1989 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1991 /* Table1991 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1993 /* Table1993 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1995 /* Table1995 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1997 /* Table1997 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1999 /* Table1999 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2001 /* Table2001 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2003 /* Table2003 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2005 /* Table2005 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2007 /* Table2007 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2009 /* Table2009 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2011 /* Table2011 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2013 /* Table2013 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2015 /* Table2015 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2017 /* Table2017 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2019 /* Table2019 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2021 /* Table2021 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2023 /* Table2023 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2025 /* Table2025 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2027 /* Table2027 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2029 /* Table2029 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2031 /* Table2031 */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2033 /* Table2033 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2035 /* Table2035 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2037 /* Table2037 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2039 /* Table2039 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2055 /* Table2055 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2071 /* Table2071 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2087 /* Table2087 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2089 /* Table2089 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2091 /* Table2091 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2626 /* Table2626 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2628 /* Table2628 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2098 /* Table2098 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2100 /* Table2100 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2102 /* Table2102 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2103 /* Table2103 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2104 /* Table2104 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2105 /* Table2105 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2106 /* Table2106 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2107 /* Table2107 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2108 /* Table2108 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2109 /* Table2109 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2110 /* Table2110 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2111 /* Table2111 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2112 /* Table2112 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2113 /* Table2113 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2114 /* Table2114 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2115 /* Table2115 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2116 /* Table2116 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2117 /* Table2117 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2630 /* Table2630 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2631 /* Table2631 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2153 /* Table2153 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2155 /* Table2155 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2157 /* Table2157 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2632 /* Table2632 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2633 /* Table2633 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2306 /* Table2306 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2308 /* Table2308 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2310 /* Table2310 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2312 /* Table2312 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2384 /* Table2384 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2388 /* Table2388 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2390 /* Table2390 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2392 /* Table2392 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2394 /* Table2394 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2396 /* Table2396 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2398 /* Table2398 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2400 /* Table2400 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2403 /* Table2403 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2419 /* Table2419 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2421 /* Table2421 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2423 /* Table2423 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2425 /* Table2425 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2427 /* Table2427 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2431 /* Table2431 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2433 /* Table2433 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2435 /* Table2435 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2437 /* Table2437 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2439 /* Table2439 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2441 /* Table2441 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2443 /* Table2443 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2460 /* Table2460 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2462 /* Table2462 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2464 /* Table2464 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2466 /* Table2466 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2468 /* Table2468 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2470 /* Table2470 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2472 /* Table2472 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2474 /* Table2474 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2476 /* Table2476 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2478 /* Table2478 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2480 /* Table2480 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2482 /* Table2482 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2484 /* Table2484 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2486 /* Table2486 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2488 /* Table2488 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2490 /* Table2490 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2492 /* Table2492 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2494 /* Table2494 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2496 /* Table2496 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2498 /* Table2498 */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2500 /* Table2500 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2502 /* Table2502 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2504 /* Table2504 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2506 /* Table2506 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2508 /* Table2508 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2510 /* Table2510 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2512 /* Table2512 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2514 /* Table2514 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2516 /* Table2516 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2518 /* Table2518 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2520 /* Table2520 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2522 /* Table2522 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2524 /* Table2524 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2526 /* Table2526 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2528 /* Table2528 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2634 /* Table2634 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2532 /* Table2532 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2534 /* Table2534 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2536 /* Table2536 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2538 /* Table2538 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2540 /* Table2540 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2542 /* Table2542 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2544 /* Table2544 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_OPSIZE_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2636 /* Table2636 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    3711 /* Table3711 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2724 /* Table2724 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2726 /* Table2726 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1848 /* Table1848 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2728 /* Table2728 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2730 /* Table2730 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2732 /* Table2732 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2734 /* Table2734 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2736 /* Table2736 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2738 /* Table2738 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2740 /* Table2740 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2742 /* Table2742 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2744 /* Table2744 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2760 /* Table2760 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2762 /* Table2762 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2764 /* Table2764 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2766 /* Table2766 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2768 /* Table2768 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2770 /* Table2770 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2772 /* Table2772 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2618 /* Table2618 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2620 /* Table2620 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2622 /* Table2622 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2624 /* Table2624 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2774 /* Table2774 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2776 /* Table2776 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2778 /* Table2778 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2780 /* Table2780 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2782 /* Table2782 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2784 /* Table2784 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2786 /* Table2786 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2788 /* Table2788 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1943 /* Table1943 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2790 /* Table2790 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2792 /* Table2792 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2794 /* Table2794 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2796 /* Table2796 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2798 /* Table2798 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2800 /* Table2800 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2802 /* Table2802 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2804 /* Table2804 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2806 /* Table2806 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2808 /* Table2808 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2810 /* Table2810 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2812 /* Table2812 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2814 /* Table2814 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2816 /* Table2816 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2818 /* Table2818 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2820 /* Table2820 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2822 /* Table2822 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2824 /* Table2824 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2826 /* Table2826 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2828 /* Table2828 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2830 /* Table2830 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2832 /* Table2832 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2834 /* Table2834 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2836 /* Table2836 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2838 /* Table2838 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2840 /* Table2840 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2842 /* Table2842 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2844 /* Table2844 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2846 /* Table2846 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2848 /* Table2848 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2850 /* Table2850 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2852 /* Table2852 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2854 /* Table2854 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2856 /* Table2856 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2858 /* Table2858 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2860 /* Table2860 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2862 /* Table2862 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2864 /* Table2864 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2866 /* Table2866 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2868 /* Table2868 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2870 /* Table2870 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2872 /* Table2872 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2874 /* Table2874 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2876 /* Table2876 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2878 /* Table2878 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2880 /* Table2880 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2882 /* Table2882 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2884 /* Table2884 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2900 /* Table2900 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2916 /* Table2916 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2932 /* Table2932 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2934 /* Table2934 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2936 /* Table2936 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3617 /* Table3617 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3619 /* Table3619 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2942 /* Table2942 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2944 /* Table2944 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2946 /* Table2946 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2948 /* Table2948 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2950 /* Table2950 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2951 /* Table2951 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2952 /* Table2952 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2953 /* Table2953 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2954 /* Table2954 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2955 /* Table2955 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2956 /* Table2956 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2957 /* Table2957 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2958 /* Table2958 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2959 /* Table2959 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2960 /* Table2960 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2961 /* Table2961 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2962 /* Table2962 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2963 /* Table2963 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2964 /* Table2964 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2965 /* Table2965 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2966 /* Table2966 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2967 /* Table2967 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2968 /* Table2968 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2970 /* Table2970 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2972 /* Table2972 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2974 /* Table2974 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2975 /* Table2975 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2976 /* Table2976 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2978 /* Table2978 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2980 /* Table2980 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2982 /* Table2982 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3054 /* Table3054 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3056 /* Table3056 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3058 /* Table3058 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3060 /* Table3060 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3062 /* Table3062 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3064 /* Table3064 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3066 /* Table3066 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2400 /* Table2400 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3068 /* Table3068 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3084 /* Table3084 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3086 /* Table3086 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3088 /* Table3088 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3090 /* Table3090 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2427 /* Table2427 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3092 /* Table3092 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3094 /* Table3094 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2435 /* Table2435 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3096 /* Table3096 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3098 /* Table3098 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3100 /* Table3100 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3102 /* Table3102 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3118 /* Table3118 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3120 /* Table3120 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3122 /* Table3122 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3124 /* Table3124 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3126 /* Table3126 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3128 /* Table3128 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3130 /* Table3130 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3132 /* Table3132 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3134 /* Table3134 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3136 /* Table3136 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3138 /* Table3138 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3140 /* Table3140 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3142 /* Table3142 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3144 /* Table3144 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3146 /* Table3146 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3148 /* Table3148 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3150 /* Table3150 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3152 /* Table3152 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3154 /* Table3154 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3156 /* Table3156 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3158 /* Table3158 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3160 /* Table3160 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3162 /* Table3162 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3164 /* Table3164 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3166 /* Table3166 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3168 /* Table3168 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3170 /* Table3170 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3172 /* Table3172 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3174 /* Table3174 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3176 /* Table3176 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3178 /* Table3178 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3180 /* Table3180 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3182 /* Table3182 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3184 /* Table3184 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3186 /* Table3186 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3188 /* Table3188 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3190 /* Table3190 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3192 /* Table3192 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3709 /* Table3709 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3196 /* Table3196 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3198 /* Table3198 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3200 /* Table3200 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3202 /* Table3202 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3204 /* Table3204 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3206 /* Table3206 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3208 /* Table3208 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1754 /* Table1754 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2546 /* Table2546 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1842 /* Table1842 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1844 /* Table1844 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1848 /* Table1848 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3210 /* Table3210 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3212 /* Table3212 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3214 /* Table3214 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1874 /* Table1874 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1876 /* Table1876 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1878 /* Table1878 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1880 /* Table1880 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1882 /* Table1882 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1884 /* Table1884 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1900 /* Table1900 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1902 /* Table1902 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1904 /* Table1904 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1906 /* Table1906 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1908 /* Table1908 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1910 /* Table1910 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1912 /* Table1912 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2618 /* Table2618 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2620 /* Table2620 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2622 /* Table2622 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2624 /* Table2624 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1922 /* Table1922 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1924 /* Table1924 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3216 /* Table3216 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3218 /* Table3218 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3220 /* Table3220 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3222 /* Table3222 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1934 /* Table1934 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1936 /* Table1936 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1943 /* Table1943 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1945 /* Table1945 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1947 /* Table1947 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1949 /* Table1949 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1951 /* Table1951 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1953 /* Table1953 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1955 /* Table1955 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1957 /* Table1957 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1959 /* Table1959 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1961 /* Table1961 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1963 /* Table1963 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1965 /* Table1965 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1967 /* Table1967 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1969 /* Table1969 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1971 /* Table1971 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1973 /* Table1973 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1975 /* Table1975 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1977 /* Table1977 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3224 /* Table3224 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1985 /* Table1985 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1987 /* Table1987 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1989 /* Table1989 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1991 /* Table1991 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3226 /* Table3226 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3228 /* Table3228 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3230 /* Table3230 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1999 /* Table1999 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3232 /* Table3232 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3234 /* Table3234 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3236 /* Table3236 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3238 /* Table3238 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2009 /* Table2009 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2011 /* Table2011 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2013 /* Table2013 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2015 /* Table2015 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2017 /* Table2017 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2019 /* Table2019 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2021 /* Table2021 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2023 /* Table2023 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2025 /* Table2025 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2027 /* Table2027 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2029 /* Table2029 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2031 /* Table2031 */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2033 /* Table2033 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2035 /* Table2035 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3240 /* Table3240 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2039 /* Table2039 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2055 /* Table2055 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2071 /* Table2071 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2087 /* Table2087 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2089 /* Table2089 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2091 /* Table2091 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3783 /* Table3783 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3785 /* Table3785 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3246 /* Table3246 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3248 /* Table3248 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2098 /* Table2098 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2100 /* Table2100 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2102 /* Table2102 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2103 /* Table2103 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2104 /* Table2104 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2105 /* Table2105 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2106 /* Table2106 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2107 /* Table2107 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2108 /* Table2108 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2109 /* Table2109 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2110 /* Table2110 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2111 /* Table2111 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2112 /* Table2112 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2113 /* Table2113 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2114 /* Table2114 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2115 /* Table2115 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2116 /* Table2116 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2117 /* Table2117 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2630 /* Table2630 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2631 /* Table2631 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2153 /* Table2153 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2155 /* Table2155 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2157 /* Table2157 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2632 /* Table2632 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2633 /* Table2633 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2306 /* Table2306 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2308 /* Table2308 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2310 /* Table2310 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2312 /* Table2312 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2384 /* Table2384 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2388 /* Table2388 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2390 /* Table2390 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2392 /* Table2392 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2394 /* Table2394 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2396 /* Table2396 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2398 /* Table2398 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2400 /* Table2400 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2403 /* Table2403 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2419 /* Table2419 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2421 /* Table2421 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2423 /* Table2423 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2425 /* Table2425 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2427 /* Table2427 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2431 /* Table2431 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3250 /* Table3250 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2435 /* Table2435 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2437 /* Table2437 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2439 /* Table2439 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2441 /* Table2441 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2443 /* Table2443 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3252 /* Table3252 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2460 /* Table2460 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2462 /* Table2462 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2464 /* Table2464 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2466 /* Table2466 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2468 /* Table2468 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3254 /* Table3254 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2470 /* Table2470 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2472 /* Table2472 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2474 /* Table2474 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2476 /* Table2476 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2478 /* Table2478 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2480 /* Table2480 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2482 /* Table2482 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2484 /* Table2484 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2486 /* Table2486 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2488 /* Table2488 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2490 /* Table2490 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2492 /* Table2492 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2494 /* Table2494 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2496 /* Table2496 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2498 /* Table2498 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3256 /* Table3256 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2500 /* Table2500 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2502 /* Table2502 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2504 /* Table2504 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2506 /* Table2506 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2508 /* Table2508 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2510 /* Table2510 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2512 /* Table2512 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2514 /* Table2514 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2516 /* Table2516 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3258 /* Table3258 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2518 /* Table2518 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2520 /* Table2520 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2522 /* Table2522 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2524 /* Table2524 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2526 /* Table2526 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2528 /* Table2528 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2634 /* Table2634 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2532 /* Table2532 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2534 /* Table2534 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2536 /* Table2536 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2538 /* Table2538 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2540 /* Table2540 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2542 /* Table2542 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2544 /* Table2544 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1754 /* Table1754 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2546 /* Table2546 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1842 /* Table1842 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1844 /* Table1844 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1848 /* Table1848 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3260 /* Table3260 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3262 /* Table3262 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3264 /* Table3264 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1874 /* Table1874 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1876 /* Table1876 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1878 /* Table1878 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3266 /* Table3266 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1882 /* Table1882 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1884 /* Table1884 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1900 /* Table1900 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1902 /* Table1902 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1904 /* Table1904 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1906 /* Table1906 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1908 /* Table1908 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1910 /* Table1910 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1912 /* Table1912 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2618 /* Table2618 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2620 /* Table2620 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2622 /* Table2622 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2624 /* Table2624 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1922 /* Table1922 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1924 /* Table1924 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3268 /* Table3268 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3270 /* Table3270 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3272 /* Table3272 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3274 /* Table3274 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1934 /* Table1934 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1936 /* Table1936 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1943 /* Table1943 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1945 /* Table1945 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1947 /* Table1947 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1949 /* Table1949 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1951 /* Table1951 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1953 /* Table1953 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1955 /* Table1955 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1957 /* Table1957 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1959 /* Table1959 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1961 /* Table1961 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1963 /* Table1963 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1965 /* Table1965 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1967 /* Table1967 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1969 /* Table1969 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1971 /* Table1971 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1973 /* Table1973 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1975 /* Table1975 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1977 /* Table1977 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3276 /* Table3276 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3278 /* Table3278 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3280 /* Table3280 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1985 /* Table1985 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1987 /* Table1987 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1989 /* Table1989 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1991 /* Table1991 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3282 /* Table3282 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3284 /* Table3284 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3286 /* Table3286 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3288 /* Table3288 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3290 /* Table3290 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3292 /* Table3292 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3294 /* Table3294 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3296 /* Table3296 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2009 /* Table2009 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2011 /* Table2011 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2013 /* Table2013 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2015 /* Table2015 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2017 /* Table2017 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2019 /* Table2019 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2021 /* Table2021 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2023 /* Table2023 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2025 /* Table2025 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2027 /* Table2027 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2029 /* Table2029 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2031 /* Table2031 */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2033 /* Table2033 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3298 /* Table3298 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3300 /* Table3300 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2039 /* Table2039 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2055 /* Table2055 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2071 /* Table2071 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2087 /* Table2087 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2089 /* Table2089 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2091 /* Table2091 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2626 /* Table2626 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2628 /* Table2628 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3302 /* Table3302 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3304 /* Table3304 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2102 /* Table2102 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2103 /* Table2103 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2104 /* Table2104 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2105 /* Table2105 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2106 /* Table2106 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2107 /* Table2107 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2108 /* Table2108 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2109 /* Table2109 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2110 /* Table2110 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2111 /* Table2111 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2112 /* Table2112 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2113 /* Table2113 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2114 /* Table2114 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2115 /* Table2115 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2116 /* Table2116 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2117 /* Table2117 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2630 /* Table2630 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2631 /* Table2631 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2153 /* Table2153 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2155 /* Table2155 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2157 /* Table2157 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2632 /* Table2632 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2633 /* Table2633 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2306 /* Table2306 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2308 /* Table2308 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2310 /* Table2310 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    3787 /* Table3787 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2384 /* Table2384 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2388 /* Table2388 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2390 /* Table2390 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2392 /* Table2392 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2394 /* Table2394 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2396 /* Table2396 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2398 /* Table2398 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2400 /* Table2400 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3306 /* Table3306 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2403 /* Table2403 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2419 /* Table2419 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3308 /* Table3308 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3310 /* Table3310 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2425 /* Table2425 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2427 /* Table2427 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2431 /* Table2431 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3312 /* Table3312 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2435 /* Table2435 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2437 /* Table2437 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2439 /* Table2439 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2441 /* Table2441 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3314 /* Table3314 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2459 /* Table2459 */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2460 /* Table2460 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2462 /* Table2462 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2464 /* Table2464 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2466 /* Table2466 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2468 /* Table2468 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3330 /* Table3330 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2470 /* Table2470 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2472 /* Table2472 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2474 /* Table2474 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2476 /* Table2476 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2478 /* Table2478 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2480 /* Table2480 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2482 /* Table2482 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2484 /* Table2484 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2486 /* Table2486 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2488 /* Table2488 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2490 /* Table2490 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2492 /* Table2492 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2494 /* Table2494 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2496 /* Table2496 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2498 /* Table2498 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3332 /* Table3332 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2500 /* Table2500 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2502 /* Table2502 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2504 /* Table2504 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2506 /* Table2506 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2508 /* Table2508 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2510 /* Table2510 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2512 /* Table2512 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2514 /* Table2514 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2516 /* Table2516 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2518 /* Table2518 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2520 /* Table2520 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2522 /* Table2522 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2524 /* Table2524 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2526 /* Table2526 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2528 /* Table2528 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2634 /* Table2634 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2532 /* Table2532 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2534 /* Table2534 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2536 /* Table2536 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2538 /* Table2538 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2540 /* Table2540 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2542 /* Table2542 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2544 /* Table2544 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_XS_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3334 /* Table3334 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3336 /* Table3336 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3338 /* Table3338 */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3340 /* Table3340 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    3356 /* Table3356 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3428 /* Table3428 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3430 /* Table3430 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3432 /* Table3432 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3260 /* Table3260 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3262 /* Table3262 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3264 /* Table3264 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1874 /* Table1874 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1876 /* Table1876 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1878 /* Table1878 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3266 /* Table3266 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1882 /* Table1882 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1884 /* Table1884 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1900 /* Table1900 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1902 /* Table1902 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1904 /* Table1904 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1906 /* Table1906 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1908 /* Table1908 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1910 /* Table1910 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1912 /* Table1912 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2618 /* Table2618 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2620 /* Table2620 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2622 /* Table2622 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2624 /* Table2624 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1922 /* Table1922 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1924 /* Table1924 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3859 /* Table3859 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3270 /* Table3270 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3861 /* Table3861 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3863 /* Table3863 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1934 /* Table1934 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1936 /* Table1936 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3433 /* Table3433 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3434 /* Table3434 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3436 /* Table3436 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3438 /* Table3438 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3440 /* Table3440 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3442 /* Table3442 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3444 /* Table3444 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3446 /* Table3446 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3448 /* Table3448 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3450 /* Table3450 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3452 /* Table3452 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3454 /* Table3454 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3456 /* Table3456 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3458 /* Table3458 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3460 /* Table3460 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3462 /* Table3462 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3464 /* Table3464 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1977 /* Table1977 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3276 /* Table3276 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3278 /* Table3278 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3280 /* Table3280 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1985 /* Table1985 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1987 /* Table1987 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1989 /* Table1989 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1991 /* Table1991 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3282 /* Table3282 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3284 /* Table3284 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3286 /* Table3286 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3288 /* Table3288 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3290 /* Table3290 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3292 /* Table3292 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3294 /* Table3294 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3296 /* Table3296 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2009 /* Table2009 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2011 /* Table2011 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2013 /* Table2013 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2015 /* Table2015 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2017 /* Table2017 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2019 /* Table2019 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2021 /* Table2021 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2023 /* Table2023 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2025 /* Table2025 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2027 /* Table2027 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2029 /* Table2029 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2031 /* Table2031 */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3466 /* Table3466 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3298 /* Table3298 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3300 /* Table3300 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2039 /* Table2039 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2055 /* Table2055 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2071 /* Table2071 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2087 /* Table2087 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2089 /* Table2089 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2091 /* Table2091 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2626 /* Table2626 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2628 /* Table2628 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3468 /* Table3468 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3304 /* Table3304 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2102 /* Table2102 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2103 /* Table2103 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2104 /* Table2104 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2105 /* Table2105 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2106 /* Table2106 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2107 /* Table2107 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2108 /* Table2108 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2109 /* Table2109 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2110 /* Table2110 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2111 /* Table2111 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2112 /* Table2112 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2113 /* Table2113 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2114 /* Table2114 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2115 /* Table2115 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2116 /* Table2116 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2117 /* Table2117 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2630 /* Table2630 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2631 /* Table2631 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3470 /* Table3470 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3472 /* Table3472 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3474 /* Table3474 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2632 /* Table2632 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2633 /* Table2633 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3476 /* Table3476 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3478 /* Table3478 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3480 /* Table3480 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    3865 /* Table3865 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3554 /* Table3554 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3556 /* Table3556 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3558 /* Table3558 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3560 /* Table3560 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3562 /* Table3562 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3564 /* Table3564 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3566 /* Table3566 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3568 /* Table3568 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3937 /* Table3937 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3570 /* Table3570 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3586 /* Table3586 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3939 /* Table3939 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3941 /* Table3941 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3592 /* Table3592 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3594 /* Table3594 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3596 /* Table3596 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3312 /* Table3312 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3598 /* Table3598 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2437 /* Table2437 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2439 /* Table2439 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2441 /* Table2441 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3943 /* Table3943 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2460 /* Table2460 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2462 /* Table2462 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2464 /* Table2464 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2466 /* Table2466 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2468 /* Table2468 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3330 /* Table3330 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2470 /* Table2470 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2472 /* Table2472 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2474 /* Table2474 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2476 /* Table2476 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2478 /* Table2478 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2480 /* Table2480 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2482 /* Table2482 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2484 /* Table2484 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2486 /* Table2486 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2488 /* Table2488 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2490 /* Table2490 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2492 /* Table2492 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2494 /* Table2494 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2496 /* Table2496 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2498 /* Table2498 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3332 /* Table3332 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2500 /* Table2500 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2502 /* Table2502 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2504 /* Table2504 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2506 /* Table2506 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2508 /* Table2508 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2510 /* Table2510 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2512 /* Table2512 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2514 /* Table2514 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2516 /* Table2516 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2518 /* Table2518 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2520 /* Table2520 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2522 /* Table2522 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2524 /* Table2524 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2526 /* Table2526 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2528 /* Table2528 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2634 /* Table2634 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2532 /* Table2532 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2534 /* Table2534 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2536 /* Table2536 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2538 /* Table2538 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2540 /* Table2540 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2542 /* Table2542 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2544 /* Table2544 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3340 /* Table3340 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    3356 /* Table3356 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3428 /* Table3428 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3430 /* Table3430 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3432 /* Table3432 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3210 /* Table3210 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3212 /* Table3212 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3214 /* Table3214 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1874 /* Table1874 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1876 /* Table1876 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1878 /* Table1878 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1880 /* Table1880 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1882 /* Table1882 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1884 /* Table1884 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1900 /* Table1900 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1902 /* Table1902 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1904 /* Table1904 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1906 /* Table1906 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1908 /* Table1908 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1910 /* Table1910 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1912 /* Table1912 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2618 /* Table2618 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2620 /* Table2620 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2622 /* Table2622 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2624 /* Table2624 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1922 /* Table1922 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1924 /* Table1924 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3959 /* Table3959 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3218 /* Table3218 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3961 /* Table3961 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3963 /* Table3963 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1934 /* Table1934 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1936 /* Table1936 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3433 /* Table3433 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3434 /* Table3434 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3436 /* Table3436 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3438 /* Table3438 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3440 /* Table3440 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3442 /* Table3442 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3444 /* Table3444 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3446 /* Table3446 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3448 /* Table3448 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3450 /* Table3450 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3452 /* Table3452 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3454 /* Table3454 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3456 /* Table3456 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3458 /* Table3458 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3460 /* Table3460 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3462 /* Table3462 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3464 /* Table3464 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1977 /* Table1977 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3224 /* Table3224 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1985 /* Table1985 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1987 /* Table1987 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1989 /* Table1989 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1991 /* Table1991 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3226 /* Table3226 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3228 /* Table3228 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3230 /* Table3230 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1999 /* Table1999 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3232 /* Table3232 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3234 /* Table3234 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3236 /* Table3236 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3238 /* Table3238 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2009 /* Table2009 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2011 /* Table2011 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2013 /* Table2013 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2015 /* Table2015 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2017 /* Table2017 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2019 /* Table2019 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2021 /* Table2021 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2023 /* Table2023 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2025 /* Table2025 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2027 /* Table2027 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2029 /* Table2029 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2031 /* Table2031 */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3466 /* Table3466 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2035 /* Table2035 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3240 /* Table3240 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2039 /* Table2039 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2055 /* Table2055 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2071 /* Table2071 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2087 /* Table2087 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2089 /* Table2089 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2091 /* Table2091 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3783 /* Table3783 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3785 /* Table3785 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3246 /* Table3246 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3248 /* Table3248 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3468 /* Table3468 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2100 /* Table2100 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2102 /* Table2102 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2103 /* Table2103 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2104 /* Table2104 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2105 /* Table2105 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2106 /* Table2106 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2107 /* Table2107 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2108 /* Table2108 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2109 /* Table2109 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2110 /* Table2110 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2111 /* Table2111 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2112 /* Table2112 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2113 /* Table2113 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2114 /* Table2114 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2115 /* Table2115 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2116 /* Table2116 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2117 /* Table2117 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2630 /* Table2630 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2631 /* Table2631 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3470 /* Table3470 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3472 /* Table3472 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3474 /* Table3474 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2632 /* Table2632 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2633 /* Table2633 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3476 /* Table3476 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3478 /* Table3478 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3480 /* Table3480 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    3482 /* Table3482 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3554 /* Table3554 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3556 /* Table3556 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3558 /* Table3558 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3560 /* Table3560 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3562 /* Table3562 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3564 /* Table3564 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3566 /* Table3566 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3568 /* Table3568 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3570 /* Table3570 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3586 /* Table3586 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3588 /* Table3588 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3590 /* Table3590 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3592 /* Table3592 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3594 /* Table3594 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3596 /* Table3596 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3250 /* Table3250 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3598 /* Table3598 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2437 /* Table2437 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2439 /* Table2439 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2441 /* Table2441 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3600 /* Table3600 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3252 /* Table3252 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2460 /* Table2460 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2462 /* Table2462 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2464 /* Table2464 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2466 /* Table2466 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2468 /* Table2468 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3254 /* Table3254 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2470 /* Table2470 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2472 /* Table2472 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2474 /* Table2474 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2476 /* Table2476 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2478 /* Table2478 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2480 /* Table2480 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2482 /* Table2482 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2484 /* Table2484 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2486 /* Table2486 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2488 /* Table2488 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2490 /* Table2490 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2492 /* Table2492 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2494 /* Table2494 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2496 /* Table2496 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2498 /* Table2498 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3256 /* Table3256 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2500 /* Table2500 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2502 /* Table2502 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2504 /* Table2504 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2506 /* Table2506 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2508 /* Table2508 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2510 /* Table2510 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2512 /* Table2512 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2514 /* Table2514 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2516 /* Table2516 */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3258 /* Table3258 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2518 /* Table2518 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2520 /* Table2520 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2522 /* Table2522 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2524 /* Table2524 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2526 /* Table2526 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2528 /* Table2528 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2634 /* Table2634 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2532 /* Table2532 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2534 /* Table2534 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2536 /* Table2536 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2538 /* Table2538 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2540 /* Table2540 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2542 /* Table2542 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2544 /* Table2544 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3340 /* Table3340 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    3356 /* Table3356 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3428 /* Table3428 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3430 /* Table3430 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1846 /* Table1846 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1847 /* Table1847 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3432 /* Table3432 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1849 /* Table1849 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1850 /* Table1850 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1851 /* Table1851 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    1852 /* Table1852 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2728 /* Table2728 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2730 /* Table2730 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2732 /* Table2732 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2734 /* Table2734 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2736 /* Table2736 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2738 /* Table2738 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2740 /* Table2740 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2742 /* Table2742 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2744 /* Table2744 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2760 /* Table2760 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2762 /* Table2762 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2764 /* Table2764 */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2766 /* Table2766 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2768 /* Table2768 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2770 /* Table2770 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2772 /* Table2772 */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2618 /* Table2618 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2620 /* Table2620 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2622 /* Table2622 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2624 /* Table2624 */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2774 /* Table2774 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2776 /* Table2776 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2778 /* Table2778 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2780 /* Table2780 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2782 /* Table2782 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2784 /* Table2784 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2786 /* Table2786 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2788 /* Table2788 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1938 /* Table1938 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1939 /* Table1939 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1940 /* Table1940 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1941 /* Table1941 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1942 /* Table1942 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3433 /* Table3433 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    1944 /* Table1944 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3434 /* Table3434 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3436 /* Table3436 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3438 /* Table3438 */
   },
   /* 0x43 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3440 /* Table3440 */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3442 /* Table3442 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3444 /* Table3444 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3446 /* Table3446 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3448 /* Table3448 */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3450 /* Table3450 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3452 /* Table3452 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3454 /* Table3454 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3456 /* Table3456 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3458 /* Table3458 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3460 /* Table3460 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3462 /* Table3462 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3464 /* Table3464 */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2822 /* Table2822 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2824 /* Table2824 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1981 /* Table1981 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    1983 /* Table1983 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2826 /* Table2826 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2828 /* Table2828 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2830 /* Table2830 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2832 /* Table2832 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2834 /* Table2834 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2836 /* Table2836 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2838 /* Table2838 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2840 /* Table2840 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2842 /* Table2842 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2844 /* Table2844 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2846 /* Table2846 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2848 /* Table2848 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2850 /* Table2850 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2852 /* Table2852 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2854 /* Table2854 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2856 /* Table2856 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2858 /* Table2858 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2860 /* Table2860 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2862 /* Table2862 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2864 /* Table2864 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2866 /* Table2866 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2868 /* Table2868 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2870 /* Table2870 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2872 /* Table2872 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2874 /* Table2874 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2876 /* Table2876 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3965 /* Table3965 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2880 /* Table2880 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2882 /* Table2882 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2884 /* Table2884 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2900 /* Table2900 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    2916 /* Table2916 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2932 /* Table2932 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2934 /* Table2934 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2936 /* Table2936 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2093 /* Table2093 */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3617 /* Table3617 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3619 /* Table3619 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2942 /* Table2942 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2944 /* Table2944 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3967 /* Table3967 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2948 /* Table2948 */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2950 /* Table2950 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2951 /* Table2951 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2952 /* Table2952 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2953 /* Table2953 */
   },
   /* 0x84 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2954 /* Table2954 */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2955 /* Table2955 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2956 /* Table2956 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2957 /* Table2957 */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2958 /* Table2958 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2959 /* Table2959 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2960 /* Table2960 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2961 /* Table2961 */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2962 /* Table2962 */
   },
   /* 0x8d */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2963 /* Table2963 */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2964 /* Table2964 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2965 /* Table2965 */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2118 /* Table2118 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2120 /* Table2120 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2122 /* Table2122 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2124 /* Table2124 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2126 /* Table2126 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2128 /* Table2128 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2130 /* Table2130 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2132 /* Table2132 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2134 /* Table2134 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2136 /* Table2136 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2138 /* Table2138 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2140 /* Table2140 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2142 /* Table2142 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2144 /* Table2144 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2146 /* Table2146 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2148 /* Table2148 */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2966 /* Table2966 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2967 /* Table2967 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2152 /* Table2152 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3470 /* Table3470 */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3472 /* Table3472 */
   },
   /* 0xa5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3474 /* Table3474 */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2159 /* Table2159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    2231 /* Table2231 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2974 /* Table2974 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2975 /* Table2975 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2305 /* Table2305 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3476 /* Table3476 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3478 /* Table3478 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3480 /* Table3480 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITMISC,
    3621 /* Table3621 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3554 /* Table3554 */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2386 /* Table2386 */
   },
   /* 0xb1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3556 /* Table3556 */
   },
   /* 0xb2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3558 /* Table3558 */
   },
   /* 0xb3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3560 /* Table3560 */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3562 /* Table3562 */
   },
   /* 0xb5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3564 /* Table3564 */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3566 /* Table3566 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3568 /* Table3568 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    2402 /* Table2402 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3570 /* Table3570 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3586 /* Table3586 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3588 /* Table3588 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3590 /* Table3590 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3592 /* Table3592 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3594 /* Table3594 */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    2429 /* Table2429 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3596 /* Table3596 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3094 /* Table3094 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3598 /* Table3598 */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3096 /* Table3096 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3098 /* Table3098 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3100 /* Table3100 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    3693 /* Table3693 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    3616 /* Table3616 */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3118 /* Table3118 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3120 /* Table3120 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3122 /* Table3122 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3124 /* Table3124 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3126 /* Table3126 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3128 /* Table3128 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3130 /* Table3130 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3132 /* Table3132 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3134 /* Table3134 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3136 /* Table3136 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3138 /* Table3138 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3140 /* Table3140 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3142 /* Table3142 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3144 /* Table3144 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3146 /* Table3146 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3148 /* Table3148 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3150 /* Table3150 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3152 /* Table3152 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3154 /* Table3154 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3156 /* Table3156 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3158 /* Table3158 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3160 /* Table3160 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3162 /* Table3162 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3164 /* Table3164 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3166 /* Table3166 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3168 /* Table3168 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3170 /* Table3170 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3172 /* Table3172 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3174 /* Table3174 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3176 /* Table3176 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3178 /* Table3178 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3180 /* Table3180 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3182 /* Table3182 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3184 /* Table3184 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3186 /* Table3186 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3188 /* Table3188 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3190 /* Table3190 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3192 /* Table3192 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3709 /* Table3709 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3196 /* Table3196 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3198 /* Table3198 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3200 /* Table3200 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3202 /* Table3202 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3204 /* Table3204 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3206 /* Table3206 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3208 /* Table3208 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3969 /* Table3969 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3971 /* Table3971 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3973 /* Table3973 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3975 /* Table3975 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3977 /* Table3977 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3979 /* Table3979 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3981 /* Table3981 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3983 /* Table3983 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3985 /* Table3985 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3987 /* Table3987 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3989 /* Table3989 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3991 /* Table3991 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3993 /* Table3993 */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3995 /* Table3995 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3997 /* Table3997 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3999 /* Table3999 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4001 /* Table4001 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4003 /* Table4003 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4005 /* Table4005 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4007 /* Table4007 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4009 /* Table4009 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4011 /* Table4011 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4013 /* Table4013 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4015 /* Table4015 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4017 /* Table4017 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4019 /* Table4019 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4021 /* Table4021 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4023 /* Table4023 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4025 /* Table4025 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4027 /* Table4027 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    4029 /* Table4029 */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4030 /* Table4030 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4032 /* Table4032 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4034 /* Table4034 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4036 /* Table4036 */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4038 /* Table4038 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4040 /* Table4040 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4056 /* Table4056 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4058 /* Table4058 */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4060 /* Table4060 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4062 /* Table4062 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4064 /* Table4064 */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4066 /* Table4066 */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4068 /* Table4068 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4070 /* Table4070 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4072 /* Table4072 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4074 /* Table4074 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4076 /* Table4076 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4078 /* Table4078 */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4080 /* Table4080 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4082 /* Table4082 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4084 /* Table4084 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4086 /* Table4086 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4088 /* Table4088 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4090 /* Table4090 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4092 /* Table4092 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4094 /* Table4094 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4096 /* Table4096 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4098 /* Table4098 */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4100 /* Table4100 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4102 /* Table4102 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4104 /* Table4104 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4106 /* Table4106 */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4108 /* Table4108 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4110 /* Table4110 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4112 /* Table4112 */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4114 /* Table4114 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4116 /* Table4116 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4118 /* Table4118 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4120 /* Table4120 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4122 /* Table4122 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4124 /* Table4124 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4126 /* Table4126 */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4128 /* Table4128 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4130 /* Table4130 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4132 /* Table4132 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4134 /* Table4134 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4136 /* Table4136 */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4138 /* Table4138 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4140 /* Table4140 */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4142 /* Table4142 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4144 /* Table4144 */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4146 /* Table4146 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4148 /* Table4148 */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4150 /* Table4150 */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4152 /* Table4152 */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4154 /* Table4154 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4156 /* Table4156 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4158 /* Table4158 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4160 /* Table4160 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4162 /* Table4162 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4164 /* Table4164 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4166 /* Table4166 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4168 /* Table4168 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4170 /* Table4170 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4172 /* Table4172 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4174 /* Table4174 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4176 /* Table4176 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4178 /* Table4178 */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4180 /* Table4180 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4182 /* Table4182 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4184 /* Table4184 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4186 /* Table4186 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4188 /* Table4188 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4190 /* Table4190 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4192 /* Table4192 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4194 /* Table4194 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4196 /* Table4196 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4198 /* Table4198 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4200 /* Table4200 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4202 /* Table4202 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4204 /* Table4204 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4206 /* Table4206 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4208 /* Table4208 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4210 /* Table4210 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4212 /* Table4212 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4214 /* Table4214 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4216 /* Table4216 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4218 /* Table4218 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4220 /* Table4220 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4222 /* Table4222 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4224 /* Table4224 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4226 /* Table4226 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4228 /* Table4228 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4230 /* Table4230 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4232 /* Table4232 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4234 /* Table4234 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4236 /* Table4236 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4238 /* Table4238 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4240 /* Table4240 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4242 /* Table4242 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4244 /* Table4244 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4260 /* Table4260 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4276 /* Table4276 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4292 /* Table4292 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4294 /* Table4294 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4296 /* Table4296 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4298 /* Table4298 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4300 /* Table4300 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4302 /* Table4302 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4304 /* Table4304 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4306 /* Table4306 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4308 /* Table4308 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4310 /* Table4310 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4312 /* Table4312 */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4314 /* Table4314 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4316 /* Table4316 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4318 /* Table4318 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4320 /* Table4320 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4322 /* Table4322 */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4324 /* Table4324 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4326 /* Table4326 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4328 /* Table4328 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4330 /* Table4330 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4332 /* Table4332 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4334 /* Table4334 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4336 /* Table4336 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4338 /* Table4338 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4340 /* Table4340 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4342 /* Table4342 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4344 /* Table4344 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4346 /* Table4346 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4348 /* Table4348 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4350 /* Table4350 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4352 /* Table4352 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4354 /* Table4354 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4356 /* Table4356 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4358 /* Table4358 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4360 /* Table4360 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4362 /* Table4362 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4364 /* Table4364 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4366 /* Table4366 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4368 /* Table4368 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4370 /* Table4370 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4372 /* Table4372 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4374 /* Table4374 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4376 /* Table4376 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4378 /* Table4378 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4380 /* Table4380 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4382 /* Table4382 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4384 /* Table4384 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4386 /* Table4386 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4388 /* Table4388 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4390 /* Table4390 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4392 /* Table4392 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4394 /* Table4394 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4396 /* Table4396 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4398 /* Table4398 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4400 /* Table4400 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4402 /* Table4402 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4404 /* Table4404 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4406 /* Table4406 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4408 /* Table4408 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4410 /* Table4410 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4412 /* Table4412 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4414 /* Table4414 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_W */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3969 /* Table3969 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3971 /* Table3971 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3973 /* Table3973 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3975 /* Table3975 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3977 /* Table3977 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3979 /* Table3979 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3981 /* Table3981 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3983 /* Table3983 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3985 /* Table3985 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3987 /* Table3987 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3989 /* Table3989 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3991 /* Table3991 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3993 /* Table3993 */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4416 /* Table4416 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3997 /* Table3997 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3999 /* Table3999 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4001 /* Table4001 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4003 /* Table4003 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4005 /* Table4005 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4007 /* Table4007 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4009 /* Table4009 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4011 /* Table4011 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4013 /* Table4013 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4015 /* Table4015 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4017 /* Table4017 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4019 /* Table4019 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4021 /* Table4021 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4023 /* Table4023 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4025 /* Table4025 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4027 /* Table4027 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    4029 /* Table4029 */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4418 /* Table4418 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4420 /* Table4420 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4034 /* Table4034 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4036 /* Table4036 */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4422 /* Table4422 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4040 /* Table4040 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4056 /* Table4056 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4058 /* Table4058 */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_W_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4060 /* Table4060 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4062 /* Table4062 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4064 /* Table4064 */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4066 /* Table4066 */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4424 /* Table4424 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4426 /* Table4426 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4428 /* Table4428 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4074 /* Table4074 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4076 /* Table4076 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4078 /* Table4078 */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4080 /* Table4080 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4082 /* Table4082 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4084 /* Table4084 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4086 /* Table4086 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4088 /* Table4088 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4090 /* Table4090 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4092 /* Table4092 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4094 /* Table4094 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4096 /* Table4096 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4098 /* Table4098 */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4100 /* Table4100 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4102 /* Table4102 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4104 /* Table4104 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4106 /* Table4106 */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_W_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4108 /* Table4108 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4110 /* Table4110 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4112 /* Table4112 */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4430 /* Table4430 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4432 /* Table4432 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4434 /* Table4434 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4120 /* Table4120 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4122 /* Table4122 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4124 /* Table4124 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4126 /* Table4126 */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4128 /* Table4128 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4130 /* Table4130 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4132 /* Table4132 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4134 /* Table4134 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4136 /* Table4136 */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4138 /* Table4138 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4140 /* Table4140 */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4436 /* Table4436 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4438 /* Table4438 */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4146 /* Table4146 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4148 /* Table4148 */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4150 /* Table4150 */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4152 /* Table4152 */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4154 /* Table4154 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4156 /* Table4156 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4158 /* Table4158 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4160 /* Table4160 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4162 /* Table4162 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4164 /* Table4164 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4166 /* Table4166 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4168 /* Table4168 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4170 /* Table4170 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4172 /* Table4172 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4174 /* Table4174 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4176 /* Table4176 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4178 /* Table4178 */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4440 /* Table4440 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4182 /* Table4182 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4184 /* Table4184 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4186 /* Table4186 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4188 /* Table4188 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4190 /* Table4190 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4192 /* Table4192 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4194 /* Table4194 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4196 /* Table4196 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4198 /* Table4198 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4200 /* Table4200 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4202 /* Table4202 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4204 /* Table4204 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4206 /* Table4206 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4208 /* Table4208 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4210 /* Table4210 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4212 /* Table4212 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4214 /* Table4214 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4216 /* Table4216 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4218 /* Table4218 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4220 /* Table4220 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4222 /* Table4222 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4224 /* Table4224 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4226 /* Table4226 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4228 /* Table4228 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4230 /* Table4230 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4232 /* Table4232 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4234 /* Table4234 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4236 /* Table4236 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4442 /* Table4442 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4240 /* Table4240 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4242 /* Table4242 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4244 /* Table4244 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4260 /* Table4260 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4276 /* Table4276 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4292 /* Table4292 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4294 /* Table4294 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4296 /* Table4296 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4298 /* Table4298 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4300 /* Table4300 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4444 /* Table4444 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4304 /* Table4304 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4446 /* Table4446 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4448 /* Table4448 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4310 /* Table4310 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4312 /* Table4312 */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4450 /* Table4450 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4316 /* Table4316 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4318 /* Table4318 */
   },
   /* 0xc5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4320 /* Table4320 */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4322 /* Table4322 */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4324 /* Table4324 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4326 /* Table4326 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4328 /* Table4328 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4330 /* Table4330 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4332 /* Table4332 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4334 /* Table4334 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4336 /* Table4336 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4338 /* Table4338 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4340 /* Table4340 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4342 /* Table4342 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4344 /* Table4344 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4346 /* Table4346 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4348 /* Table4348 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4350 /* Table4350 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4352 /* Table4352 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4354 /* Table4354 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4356 /* Table4356 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4358 /* Table4358 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4360 /* Table4360 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4362 /* Table4362 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4364 /* Table4364 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4366 /* Table4366 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4368 /* Table4368 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4370 /* Table4370 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4372 /* Table4372 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4374 /* Table4374 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4376 /* Table4376 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4378 /* Table4378 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4380 /* Table4380 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4382 /* Table4382 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4384 /* Table4384 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4386 /* Table4386 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4388 /* Table4388 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4390 /* Table4390 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4392 /* Table4392 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4394 /* Table4394 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4396 /* Table4396 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4398 /* Table4398 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4400 /* Table4400 */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4402 /* Table4402 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4404 /* Table4404 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4406 /* Table4406 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4408 /* Table4408 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4410 /* Table4410 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4412 /* Table4412 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4414 /* Table4414 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4452 /* Table4452 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4454 /* Table4454 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4456 /* Table4456 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4458 /* Table4458 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4460 /* Table4460 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4462 /* Table4462 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4464 /* Table4464 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3991 /* Table3991 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3993 /* Table3993 */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4466 /* Table4466 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4468 /* Table4468 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4470 /* Table4470 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4472 /* Table4472 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4474 /* Table4474 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4476 /* Table4476 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4478 /* Table4478 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4480 /* Table4480 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4482 /* Table4482 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4484 /* Table4484 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4486 /* Table4486 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4488 /* Table4488 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4490 /* Table4490 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4492 /* Table4492 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4494 /* Table4494 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4496 /* Table4496 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4498 /* Table4498 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4500 /* Table4500 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4502 /* Table4502 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4504 /* Table4504 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4506 /* Table4506 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    4508 /* Table4508 */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4509 /* Table4509 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4511 /* Table4511 */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4060 /* Table4060 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4062 /* Table4062 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4513 /* Table4513 */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4515 /* Table4515 */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4068 /* Table4068 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4070 /* Table4070 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4072 /* Table4072 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4074 /* Table4074 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4076 /* Table4076 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4078 /* Table4078 */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4080 /* Table4080 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4082 /* Table4082 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4084 /* Table4084 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4517 /* Table4517 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4088 /* Table4088 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4090 /* Table4090 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4092 /* Table4092 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4094 /* Table4094 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4519 /* Table4519 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4521 /* Table4521 */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4523 /* Table4523 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4104 /* Table4104 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4525 /* Table4525 */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4108 /* Table4108 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4110 /* Table4110 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4527 /* Table4527 */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4114 /* Table4114 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4116 /* Table4116 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4118 /* Table4118 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4120 /* Table4120 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4122 /* Table4122 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4124 /* Table4124 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4126 /* Table4126 */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4128 /* Table4128 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4130 /* Table4130 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4132 /* Table4132 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4134 /* Table4134 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4529 /* Table4529 */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4531 /* Table4531 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4533 /* Table4533 */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4146 /* Table4146 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4535 /* Table4535 */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4537 /* Table4537 */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4539 /* Table4539 */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4541 /* Table4541 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4543 /* Table4543 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4545 /* Table4545 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4547 /* Table4547 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4549 /* Table4549 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4551 /* Table4551 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4553 /* Table4553 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4176 /* Table4176 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4178 /* Table4178 */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4555 /* Table4555 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4557 /* Table4557 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4559 /* Table4559 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4561 /* Table4561 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4563 /* Table4563 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4565 /* Table4565 */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4567 /* Table4567 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4569 /* Table4569 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4571 /* Table4571 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4573 /* Table4573 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4575 /* Table4575 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4577 /* Table4577 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4579 /* Table4579 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4581 /* Table4581 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4583 /* Table4583 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4585 /* Table4585 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4587 /* Table4587 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4589 /* Table4589 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4591 /* Table4591 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4593 /* Table4593 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4595 /* Table4595 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4597 /* Table4597 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4599 /* Table4599 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4601 /* Table4601 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4603 /* Table4603 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4605 /* Table4605 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4607 /* Table4607 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4609 /* Table4609 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4611 /* Table4611 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4613 /* Table4613 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4615 /* Table4615 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4617 /* Table4617 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4619 /* Table4619 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4621 /* Table4621 */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4623 /* Table4623 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4625 /* Table4625 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4627 /* Table4627 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4643 /* Table4643 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4659 /* Table4659 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4675 /* Table4675 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4677 /* Table4677 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4679 /* Table4679 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4681 /* Table4681 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4683 /* Table4683 */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4685 /* Table4685 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4687 /* Table4687 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4689 /* Table4689 */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4691 /* Table4691 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4693 /* Table4693 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4695 /* Table4695 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4697 /* Table4697 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4699 /* Table4699 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4701 /* Table4701 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4703 /* Table4703 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4705 /* Table4705 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4707 /* Table4707 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4709 /* Table4709 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4711 /* Table4711 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4713 /* Table4713 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4715 /* Table4715 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4717 /* Table4717 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4719 /* Table4719 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4721 /* Table4721 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4723 /* Table4723 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4725 /* Table4725 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4727 /* Table4727 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4729 /* Table4729 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4731 /* Table4731 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4733 /* Table4733 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4735 /* Table4735 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4737 /* Table4737 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4739 /* Table4739 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4741 /* Table4741 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4743 /* Table4743 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4745 /* Table4745 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4747 /* Table4747 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4749 /* Table4749 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4751 /* Table4751 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4753 /* Table4753 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4755 /* Table4755 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4757 /* Table4757 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4759 /* Table4759 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4761 /* Table4761 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4763 /* Table4763 */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4765 /* Table4765 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4767 /* Table4767 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4769 /* Table4769 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4771 /* Table4771 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4773 /* Table4773 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4775 /* Table4775 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4777 /* Table4777 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L_W */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4452 /* Table4452 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4454 /* Table4454 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4456 /* Table4456 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4458 /* Table4458 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4460 /* Table4460 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4462 /* Table4462 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4464 /* Table4464 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3991 /* Table3991 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    3993 /* Table3993 */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4779 /* Table4779 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4781 /* Table4781 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4783 /* Table4783 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4785 /* Table4785 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4787 /* Table4787 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4476 /* Table4476 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4478 /* Table4478 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4480 /* Table4480 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4482 /* Table4482 */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4484 /* Table4484 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4486 /* Table4486 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4488 /* Table4488 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4490 /* Table4490 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4492 /* Table4492 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4494 /* Table4494 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4496 /* Table4496 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4498 /* Table4498 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4500 /* Table4500 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4502 /* Table4502 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4504 /* Table4504 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4506 /* Table4506 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    4508 /* Table4508 */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4509 /* Table4509 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4511 /* Table4511 */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L_W_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4060 /* Table4060 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4062 /* Table4062 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4513 /* Table4513 */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4515 /* Table4515 */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4424 /* Table4424 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4426 /* Table4426 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4428 /* Table4428 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4074 /* Table4074 */
   },
   /* 0x52 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4076 /* Table4076 */
   },
   /* 0x53 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4078 /* Table4078 */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4080 /* Table4080 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4082 /* Table4082 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4084 /* Table4084 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4517 /* Table4517 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4088 /* Table4088 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4090 /* Table4090 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4092 /* Table4092 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4094 /* Table4094 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4519 /* Table4519 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4521 /* Table4521 */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4523 /* Table4523 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4104 /* Table4104 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4525 /* Table4525 */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L_W_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4108 /* Table4108 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4110 /* Table4110 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4527 /* Table4527 */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4430 /* Table4430 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4432 /* Table4432 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4434 /* Table4434 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4120 /* Table4120 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4122 /* Table4122 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4124 /* Table4124 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4126 /* Table4126 */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4128 /* Table4128 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4130 /* Table4130 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4132 /* Table4132 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4134 /* Table4134 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4529 /* Table4529 */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4531 /* Table4531 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4533 /* Table4533 */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4146 /* Table4146 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4535 /* Table4535 */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4537 /* Table4537 */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4539 /* Table4539 */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4541 /* Table4541 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4543 /* Table4543 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4545 /* Table4545 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4547 /* Table4547 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4549 /* Table4549 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4551 /* Table4551 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4553 /* Table4553 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4176 /* Table4176 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4178 /* Table4178 */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4789 /* Table4789 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4791 /* Table4791 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4793 /* Table4793 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4795 /* Table4795 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4797 /* Table4797 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4565 /* Table4565 */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4567 /* Table4567 */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4569 /* Table4569 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4571 /* Table4571 */
   },
   /* 0x55 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4573 /* Table4573 */
   },
   /* 0x56 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4575 /* Table4575 */
   },
   /* 0x57 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4577 /* Table4577 */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4579 /* Table4579 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4581 /* Table4581 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4583 /* Table4583 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4585 /* Table4585 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4587 /* Table4587 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4589 /* Table4589 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4591 /* Table4591 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4593 /* Table4593 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4595 /* Table4595 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4597 /* Table4597 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4599 /* Table4599 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4601 /* Table4601 */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4603 /* Table4603 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4605 /* Table4605 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4607 /* Table4607 */
   },
   /* 0x67 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4609 /* Table4609 */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4611 /* Table4611 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4613 /* Table4613 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4615 /* Table4615 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4617 /* Table4617 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4619 /* Table4619 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4621 /* Table4621 */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4623 /* Table4623 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4625 /* Table4625 */
   },
   /* 0x71 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4627 /* Table4627 */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4643 /* Table4643 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    4659 /* Table4659 */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4675 /* Table4675 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4677 /* Table4677 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4679 /* Table4679 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4681 /* Table4681 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4683 /* Table4683 */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4685 /* Table4685 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4687 /* Table4687 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4689 /* Table4689 */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4691 /* Table4691 */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4693 /* Table4693 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4695 /* Table4695 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4697 /* Table4697 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4699 /* Table4699 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4701 /* Table4701 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4703 /* Table4703 */
   },
   /* 0xd8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4705 /* Table4705 */
   },
   /* 0xd9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4707 /* Table4707 */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4709 /* Table4709 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4711 /* Table4711 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4713 /* Table4713 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4715 /* Table4715 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4717 /* Table4717 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4719 /* Table4719 */
   },
   /* 0xe0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4721 /* Table4721 */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4723 /* Table4723 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4725 /* Table4725 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4727 /* Table4727 */
   },
   /* 0xe4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4729 /* Table4729 */
   },
   /* 0xe5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4731 /* Table4731 */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4733 /* Table4733 */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4735 /* Table4735 */
   },
   /* 0xe8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4737 /* Table4737 */
   },
   /* 0xe9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4739 /* Table4739 */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4741 /* Table4741 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4743 /* Table4743 */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4745 /* Table4745 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4747 /* Table4747 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4749 /* Table4749 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4751 /* Table4751 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4753 /* Table4753 */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4755 /* Table4755 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4757 /* Table4757 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4759 /* Table4759 */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4761 /* Table4761 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4763 /* Table4763 */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4765 /* Table4765 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4767 /* Table4767 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4769 /* Table4769 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4771 /* Table4771 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4773 /* Table4773 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4775 /* Table4775 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4777 /* Table4777 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4799 /* Table4799 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4801 /* Table4801 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4803 /* Table4803 */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4805 /* Table4805 */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4807 /* Table4807 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4809 /* Table4809 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4811 /* Table4811 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4813 /* Table4813 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4815 /* Table4815 */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4817 /* Table4817 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4819 /* Table4819 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4821 /* Table4821 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4823 /* Table4823 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4825 /* Table4825 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4827 /* Table4827 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4829 /* Table4829 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4831 /* Table4831 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4833 /* Table4833 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4835 /* Table4835 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4837 /* Table4837 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4839 /* Table4839 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4841 /* Table4841 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4843 /* Table4843 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4845 /* Table4845 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4847 /* Table4847 */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4849 /* Table4849 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4851 /* Table4851 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4853 /* Table4853 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4855 /* Table4855 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4857 /* Table4857 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4859 /* Table4859 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4861 /* Table4861 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4863 /* Table4863 */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4865 /* Table4865 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4867 /* Table4867 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4869 /* Table4869 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4871 /* Table4871 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4873 /* Table4873 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4875 /* Table4875 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4877 /* Table4877 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4879 /* Table4879 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4881 /* Table4881 */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4883 /* Table4883 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4885 /* Table4885 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4887 /* Table4887 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4889 /* Table4889 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4891 /* Table4891 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4893 /* Table4893 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4895 /* Table4895 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4897 /* Table4897 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4899 /* Table4899 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4901 /* Table4901 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4903 /* Table4903 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4905 /* Table4905 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4907 /* Table4907 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4909 /* Table4909 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4911 /* Table4911 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4913 /* Table4913 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4915 /* Table4915 */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4917 /* Table4917 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4919 /* Table4919 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4921 /* Table4921 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4923 /* Table4923 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4925 /* Table4925 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4927 /* Table4927 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4929 /* Table4929 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4931 /* Table4931 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4933 /* Table4933 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4935 /* Table4935 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4799 /* Table4799 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4801 /* Table4801 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4803 /* Table4803 */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4805 /* Table4805 */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4807 /* Table4807 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4809 /* Table4809 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4811 /* Table4811 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4813 /* Table4813 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4815 /* Table4815 */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4817 /* Table4817 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4819 /* Table4819 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4821 /* Table4821 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4823 /* Table4823 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4825 /* Table4825 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4827 /* Table4827 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4829 /* Table4829 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4831 /* Table4831 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4833 /* Table4833 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4937 /* Table4937 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4939 /* Table4939 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4941 /* Table4941 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4841 /* Table4841 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4843 /* Table4843 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4845 /* Table4845 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4847 /* Table4847 */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4849 /* Table4849 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4851 /* Table4851 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4853 /* Table4853 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4855 /* Table4855 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4943 /* Table4943 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4945 /* Table4945 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4947 /* Table4947 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4949 /* Table4949 */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4951 /* Table4951 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4953 /* Table4953 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4867 /* Table4867 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4955 /* Table4955 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4957 /* Table4957 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4959 /* Table4959 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4961 /* Table4961 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4963 /* Table4963 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4965 /* Table4965 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4967 /* Table4967 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4969 /* Table4969 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4971 /* Table4971 */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4973 /* Table4973 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4975 /* Table4975 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4977 /* Table4977 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4979 /* Table4979 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4981 /* Table4981 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4983 /* Table4983 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4985 /* Table4985 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4987 /* Table4987 */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4989 /* Table4989 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4991 /* Table4991 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4993 /* Table4993 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4995 /* Table4995 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4997 /* Table4997 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4999 /* Table4999 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5001 /* Table5001 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5003 /* Table5003 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5005 /* Table5005 */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5007 /* Table5007 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5009 /* Table5009 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5011 /* Table5011 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5013 /* Table5013 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5015 /* Table5015 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5017 /* Table5017 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5019 /* Table5019 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4885 /* Table4885 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4887 /* Table4887 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4889 /* Table4889 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5021 /* Table5021 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5023 /* Table5023 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4895 /* Table4895 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4897 /* Table4897 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4899 /* Table4899 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5025 /* Table5025 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5027 /* Table5027 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5029 /* Table5029 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4905 /* Table4905 */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5031 /* Table5031 */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4907 /* Table4907 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5033 /* Table5033 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4911 /* Table4911 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5035 /* Table5035 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4915 /* Table4915 */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4917 /* Table4917 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5037 /* Table5037 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4921 /* Table4921 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5039 /* Table5039 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4925 /* Table4925 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4927 /* Table4927 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4929 /* Table4929 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5041 /* Table5041 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4931 /* Table4931 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4933 /* Table4933 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4935 /* Table4935 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5043 /* Table5043 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5045 /* Table5045 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5047 /* Table5047 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5049 /* Table5049 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5051 /* Table5051 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5053 /* Table5053 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5055 /* Table5055 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5057 /* Table5057 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5059 /* Table5059 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5061 /* Table5061 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5063 /* Table5063 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5065 /* Table5065 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5067 /* Table5067 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5069 /* Table5069 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5071 /* Table5071 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5073 /* Table5073 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5075 /* Table5075 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5077 /* Table5077 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5079 /* Table5079 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5081 /* Table5081 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5083 /* Table5083 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5085 /* Table5085 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5087 /* Table5087 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5089 /* Table5089 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5091 /* Table5091 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5093 /* Table5093 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5095 /* Table5095 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5097 /* Table5097 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5099 /* Table5099 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5101 /* Table5101 */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5103 /* Table5103 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5105 /* Table5105 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5107 /* Table5107 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5109 /* Table5109 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5111 /* Table5111 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5113 /* Table5113 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5115 /* Table5115 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5117 /* Table5117 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5119 /* Table5119 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5121 /* Table5121 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4799 /* Table4799 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4801 /* Table4801 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4803 /* Table4803 */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4805 /* Table4805 */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4807 /* Table4807 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4809 /* Table4809 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4811 /* Table4811 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4813 /* Table4813 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4815 /* Table4815 */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4817 /* Table4817 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4819 /* Table4819 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4821 /* Table4821 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4823 /* Table4823 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4825 /* Table4825 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4827 /* Table4827 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4829 /* Table4829 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4831 /* Table4831 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4833 /* Table4833 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4835 /* Table4835 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4837 /* Table4837 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4839 /* Table4839 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4841 /* Table4841 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4843 /* Table4843 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4845 /* Table4845 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4847 /* Table4847 */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4849 /* Table4849 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4851 /* Table4851 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4853 /* Table4853 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4855 /* Table4855 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5123 /* Table5123 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4859 /* Table4859 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4861 /* Table4861 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4863 /* Table4863 */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5125 /* Table5125 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4867 /* Table4867 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4869 /* Table4869 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4871 /* Table4871 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4873 /* Table4873 */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5127 /* Table5127 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4877 /* Table4877 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4879 /* Table4879 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4881 /* Table4881 */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5129 /* Table5129 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5131 /* Table5131 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5133 /* Table5133 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5135 /* Table5135 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5137 /* Table5137 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5139 /* Table5139 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5141 /* Table5141 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5143 /* Table5143 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5145 /* Table5145 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5147 /* Table5147 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5149 /* Table5149 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5151 /* Table5151 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5153 /* Table5153 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4885 /* Table4885 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4887 /* Table4887 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4889 /* Table4889 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4891 /* Table4891 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5155 /* Table5155 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4895 /* Table4895 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4897 /* Table4897 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4899 /* Table4899 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4901 /* Table4901 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5157 /* Table5157 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5159 /* Table5159 */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4905 /* Table4905 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4907 /* Table4907 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5161 /* Table5161 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4911 /* Table4911 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5163 /* Table5163 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4915 /* Table4915 */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4917 /* Table4917 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5165 /* Table5165 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4921 /* Table4921 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5167 /* Table5167 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4925 /* Table4925 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4927 /* Table4927 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4929 /* Table4929 */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5169 /* Table5169 */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4931 /* Table4931 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4933 /* Table4933 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    4935 /* Table4935 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2 */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5171 /* Table5171 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5173 /* Table5173 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5175 /* Table5175 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5177 /* Table5177 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5179 /* Table5179 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5181 /* Table5181 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5183 /* Table5183 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5185 /* Table5185 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5187 /* Table5187 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5189 /* Table5189 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5191 /* Table5191 */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5193 /* Table5193 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5195 /* Table5195 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5197 /* Table5197 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5199 /* Table5199 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5201 /* Table5201 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5203 /* Table5203 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5205 /* Table5205 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5207 /* Table5207 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5209 /* Table5209 */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5211 /* Table5211 */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5213 /* Table5213 */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5215 /* Table5215 */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5217 /* Table5217 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5219 /* Table5219 */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5221 /* Table5221 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5223 /* Table5223 */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5225 /* Table5225 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5227 /* Table5227 */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5229 /* Table5229 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5231 /* Table5231 */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5233 /* Table5233 */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5235 /* Table5235 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5237 /* Table5237 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5239 /* Table5239 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5241 /* Table5241 */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5243 /* Table5243 */
   },
   /* 0x70 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5245 /* Table5245 */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    5247 /* Table5247 */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5263 /* Table5263 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5265 /* Table5265 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5267 /* Table5267 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5269 /* Table5269 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5271 /* Table5271 */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5273 /* Table5273 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5275 /* Table5275 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5277 /* Table5277 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5279 /* Table5279 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5281 /* Table5281 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5283 /* Table5283 */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5285 /* Table5285 */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5287 /* Table5287 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5289 /* Table5289 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5291 /* Table5291 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5293 /* Table5293 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5295 /* Table5295 */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5297 /* Table5297 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5299 /* Table5299 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5301 /* Table5301 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5303 /* Table5303 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5305 /* Table5305 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5307 /* Table5307 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5309 /* Table5309 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5311 /* Table5311 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5313 /* Table5313 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5315 /* Table5315 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5317 /* Table5317 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5319 /* Table5319 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5321 /* Table5321 */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5323 /* Table5323 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5325 /* Table5325 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5327 /* Table5327 */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5329 /* Table5329 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5331 /* Table5331 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5333 /* Table5333 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5335 /* Table5335 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5337 /* Table5337 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5339 /* Table5339 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5341 /* Table5341 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5343 /* Table5343 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5345 /* Table5345 */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5347 /* Table5347 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5349 /* Table5349 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5351 /* Table5351 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5353 /* Table5353 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5355 /* Table5355 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5357 /* Table5357 */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5359 /* Table5359 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    5361 /* Table5361 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    5377 /* Table5377 */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5393 /* Table5393 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5395 /* Table5395 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5397 /* Table5397 */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5399 /* Table5399 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5401 /* Table5401 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5403 /* Table5403 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5405 /* Table5405 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5407 /* Table5407 */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5409 /* Table5409 */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5411 /* Table5411 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5413 /* Table5413 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5415 /* Table5415 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5417 /* Table5417 */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5419 /* Table5419 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5421 /* Table5421 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5423 /* Table5423 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5425 /* Table5425 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5427 /* Table5427 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5429 /* Table5429 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5431 /* Table5431 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5433 /* Table5433 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5435 /* Table5435 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5437 /* Table5437 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5439 /* Table5439 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5441 /* Table5441 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_XS_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5443 /* Table5443 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5445 /* Table5445 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5447 /* Table5447 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5449 /* Table5449 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5451 /* Table5451 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5453 /* Table5453 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5455 /* Table5455 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5457 /* Table5457 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5459 /* Table5459 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5461 /* Table5461 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_XD_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5463 /* Table5463 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5465 /* Table5465 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5467 /* Table5467 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5469 /* Table5469 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5471 /* Table5471 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5473 /* Table5473 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5475 /* Table5475 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5477 /* Table5477 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5479 /* Table5479 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5481 /* Table5481 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5483 /* Table5483 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5485 /* Table5485 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5487 /* Table5487 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5489 /* Table5489 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5491 /* Table5491 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5493 /* Table5493 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5495 /* Table5495 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5497 /* Table5497 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5499 /* Table5499 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5501 /* Table5501 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5503 /* Table5503 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5505 /* Table5505 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5507 /* Table5507 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5509 /* Table5509 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5511 /* Table5511 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5421 /* Table5421 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5423 /* Table5423 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5425 /* Table5425 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5427 /* Table5427 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5429 /* Table5429 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5431 /* Table5431 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5433 /* Table5433 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5435 /* Table5435 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5437 /* Table5437 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5439 /* Table5439 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5441 /* Table5441 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_XS_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5443 /* Table5443 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5445 /* Table5445 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5513 /* Table5513 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5515 /* Table5515 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5517 /* Table5517 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5519 /* Table5519 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5521 /* Table5521 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5523 /* Table5523 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5525 /* Table5525 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5527 /* Table5527 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_XD_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5529 /* Table5529 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5531 /* Table5531 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5533 /* Table5533 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5535 /* Table5535 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5537 /* Table5537 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5539 /* Table5539 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5541 /* Table5541 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5543 /* Table5543 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5545 /* Table5545 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5547 /* Table5547 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5549 /* Table5549 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5551 /* Table5551 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5553 /* Table5553 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5555 /* Table5555 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5557 /* Table5557 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5559 /* Table5559 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5561 /* Table5561 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5563 /* Table5563 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5565 /* Table5565 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5567 /* Table5567 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5569 /* Table5569 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5571 /* Table5571 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5573 /* Table5573 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5575 /* Table5575 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5577 /* Table5577 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5579 /* Table5579 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5581 /* Table5581 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5583 /* Table5583 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5585 /* Table5585 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5587 /* Table5587 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5589 /* Table5589 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5591 /* Table5591 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5593 /* Table5593 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5595 /* Table5595 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5597 /* Table5597 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5599 /* Table5599 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5601 /* Table5601 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5603 /* Table5603 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5605 /* Table5605 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5607 /* Table5607 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_XS_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5609 /* Table5609 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5611 /* Table5611 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_XD_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5613 /* Table5613 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5615 /* Table5615 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5617 /* Table5617 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5619 /* Table5619 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5621 /* Table5621 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5623 /* Table5623 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5625 /* Table5625 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5627 /* Table5627 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5629 /* Table5629 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5631 /* Table5631 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5633 /* Table5633 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5635 /* Table5635 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5637 /* Table5637 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5639 /* Table5639 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5641 /* Table5641 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5643 /* Table5643 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5645 /* Table5645 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5647 /* Table5647 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5649 /* Table5649 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5651 /* Table5651 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5653 /* Table5653 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5655 /* Table5655 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5657 /* Table5657 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5659 /* Table5659 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5661 /* Table5661 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5421 /* Table5421 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5423 /* Table5423 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5425 /* Table5425 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5427 /* Table5427 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5429 /* Table5429 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5431 /* Table5431 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5433 /* Table5433 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5435 /* Table5435 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5437 /* Table5437 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5439 /* Table5439 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5441 /* Table5441 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_XS_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5443 /* Table5443 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5445 /* Table5445 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5513 /* Table5513 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5515 /* Table5515 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5517 /* Table5517 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5519 /* Table5519 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5521 /* Table5521 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5523 /* Table5523 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5663 /* Table5663 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5665 /* Table5665 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_XD_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5667 /* Table5667 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5669 /* Table5669 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5671 /* Table5671 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5673 /* Table5673 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5675 /* Table5675 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5677 /* Table5677 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5679 /* Table5679 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5681 /* Table5681 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5683 /* Table5683 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5685 /* Table5685 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5687 /* Table5687 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5689 /* Table5689 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5691 /* Table5691 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5693 /* Table5693 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5695 /* Table5695 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5697 /* Table5697 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5699 /* Table5699 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5701 /* Table5701 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5703 /* Table5703 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5705 /* Table5705 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5707 /* Table5707 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5709 /* Table5709 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5711 /* Table5711 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5713 /* Table5713 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5715 /* Table5715 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5717 /* Table5717 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5719 /* Table5719 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5721 /* Table5721 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5723 /* Table5723 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5725 /* Table5725 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5727 /* Table5727 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5729 /* Table5729 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_XS_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5731 /* Table5731 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5733 /* Table5733 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_XD_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5735 /* Table5735 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5737 /* Table5737 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5739 /* Table5739 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5741 /* Table5741 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5743 /* Table5743 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5745 /* Table5745 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    5747 /* Table5747 */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5763 /* Table5763 */
   },
   /* 0x75 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5765 /* Table5765 */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5767 /* Table5767 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5769 /* Table5769 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5771 /* Table5771 */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5773 /* Table5773 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5775 /* Table5775 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5777 /* Table5777 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5779 /* Table5779 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5781 /* Table5781 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5783 /* Table5783 */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5785 /* Table5785 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5787 /* Table5787 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5789 /* Table5789 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5791 /* Table5791 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5793 /* Table5793 */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5795 /* Table5795 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5797 /* Table5797 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5799 /* Table5799 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5801 /* Table5801 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5803 /* Table5803 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5805 /* Table5805 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_XS_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5807 /* Table5807 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5809 /* Table5809 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_XD_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5811 /* Table5811 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5813 /* Table5813 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5815 /* Table5815 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5817 /* Table5817 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5819 /* Table5819 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5821 /* Table5821 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5823 /* Table5823 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5825 /* Table5825 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5827 /* Table5827 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5829 /* Table5829 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5831 /* Table5831 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5833 /* Table5833 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5835 /* Table5835 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5837 /* Table5837 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    5839 /* Table5839 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    5855 /* Table5855 */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5871 /* Table5871 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5873 /* Table5873 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5875 /* Table5875 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5877 /* Table5877 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5879 /* Table5879 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5881 /* Table5881 */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5883 /* Table5883 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5885 /* Table5885 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5887 /* Table5887 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5889 /* Table5889 */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5891 /* Table5891 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5893 /* Table5893 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5895 /* Table5895 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5897 /* Table5897 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5899 /* Table5899 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5901 /* Table5901 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5903 /* Table5903 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5905 /* Table5905 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_XS_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5907 /* Table5907 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5909 /* Table5909 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5911 /* Table5911 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5913 /* Table5913 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5915 /* Table5915 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5917 /* Table5917 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5919 /* Table5919 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5921 /* Table5921 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5923 /* Table5923 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5925 /* Table5925 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5927 /* Table5927 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5929 /* Table5929 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5931 /* Table5931 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5933 /* Table5933 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_XD_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5935 /* Table5935 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5937 /* Table5937 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5939 /* Table5939 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5941 /* Table5941 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5943 /* Table5943 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5945 /* Table5945 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5947 /* Table5947 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5949 /* Table5949 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5951 /* Table5951 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5953 /* Table5953 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5955 /* Table5955 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5957 /* Table5957 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5959 /* Table5959 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5961 /* Table5961 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5963 /* Table5963 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5965 /* Table5965 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5967 /* Table5967 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5969 /* Table5969 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5971 /* Table5971 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5973 /* Table5973 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5975 /* Table5975 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5977 /* Table5977 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5979 /* Table5979 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5981 /* Table5981 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5983 /* Table5983 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5985 /* Table5985 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5987 /* Table5987 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5989 /* Table5989 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5991 /* Table5991 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5993 /* Table5993 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5995 /* Table5995 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5997 /* Table5997 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    5999 /* Table5999 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6001 /* Table6001 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6003 /* Table6003 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6005 /* Table6005 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6007 /* Table6007 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6009 /* Table6009 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6011 /* Table6011 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6013 /* Table6013 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6015 /* Table6015 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6017 /* Table6017 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6019 /* Table6019 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6021 /* Table6021 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6023 /* Table6023 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6025 /* Table6025 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6027 /* Table6027 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6029 /* Table6029 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6031 /* Table6031 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6033 /* Table6033 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6035 /* Table6035 */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6037 /* Table6037 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6039 /* Table6039 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6041 /* Table6041 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6043 /* Table6043 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6045 /* Table6045 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6047 /* Table6047 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_XD_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6049 /* Table6049 */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6051 /* Table6051 */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6053 /* Table6053 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6055 /* Table6055 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6057 /* Table6057 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6059 /* Table6059 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6061 /* Table6061 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6063 /* Table6063 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6065 /* Table6065 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6067 /* Table6067 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6069 /* Table6069 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_XD_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6071 /* Table6071 */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6073 /* Table6073 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6075 /* Table6075 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6077 /* Table6077 */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6079 /* Table6079 */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6081 /* Table6081 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6083 /* Table6083 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6085 /* Table6085 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6087 /* Table6087 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6089 /* Table6089 */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6091 /* Table6091 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6093 /* Table6093 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6095 /* Table6095 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6097 /* Table6097 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6099 /* Table6099 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6101 /* Table6101 */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6103 /* Table6103 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6105 /* Table6105 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6107 /* Table6107 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6109 /* Table6109 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6111 /* Table6111 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6113 /* Table6113 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6115 /* Table6115 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6117 /* Table6117 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_XS_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6119 /* Table6119 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6121 /* Table6121 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6123 /* Table6123 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6125 /* Table6125 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6127 /* Table6127 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6129 /* Table6129 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6131 /* Table6131 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6133 /* Table6133 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6135 /* Table6135 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6137 /* Table6137 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6139 /* Table6139 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6141 /* Table6141 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6143 /* Table6143 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6145 /* Table6145 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_XD_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6147 /* Table6147 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6149 /* Table6149 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6151 /* Table6151 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6153 /* Table6153 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6155 /* Table6155 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6157 /* Table6157 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6159 /* Table6159 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6161 /* Table6161 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6163 /* Table6163 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6165 /* Table6165 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6167 /* Table6167 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6169 /* Table6169 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6171 /* Table6171 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6173 /* Table6173 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6175 /* Table6175 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6177 /* Table6177 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6179 /* Table6179 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6181 /* Table6181 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6183 /* Table6183 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6185 /* Table6185 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6187 /* Table6187 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6189 /* Table6189 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6191 /* Table6191 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6193 /* Table6193 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6195 /* Table6195 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6197 /* Table6197 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6199 /* Table6199 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6201 /* Table6201 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6203 /* Table6203 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6205 /* Table6205 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6207 /* Table6207 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6209 /* Table6209 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6211 /* Table6211 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6213 /* Table6213 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6215 /* Table6215 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6217 /* Table6217 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6219 /* Table6219 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6221 /* Table6221 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6223 /* Table6223 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6225 /* Table6225 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6227 /* Table6227 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6229 /* Table6229 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6231 /* Table6231 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6233 /* Table6233 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6235 /* Table6235 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6237 /* Table6237 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6239 /* Table6239 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6241 /* Table6241 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6243 /* Table6243 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6245 /* Table6245 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6247 /* Table6247 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6249 /* Table6249 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6251 /* Table6251 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6253 /* Table6253 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6255 /* Table6255 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6257 /* Table6257 */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6259 /* Table6259 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6261 /* Table6261 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6263 /* Table6263 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6265 /* Table6265 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6267 /* Table6267 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6269 /* Table6269 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6271 /* Table6271 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6273 /* Table6273 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6275 /* Table6275 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6277 /* Table6277 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6279 /* Table6279 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6281 /* Table6281 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6283 /* Table6283 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6285 /* Table6285 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6287 /* Table6287 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6289 /* Table6289 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6291 /* Table6291 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6293 /* Table6293 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6295 /* Table6295 */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6297 /* Table6297 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6299 /* Table6299 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6301 /* Table6301 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6303 /* Table6303 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6305 /* Table6305 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6307 /* Table6307 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6309 /* Table6309 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6311 /* Table6311 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_XS_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6313 /* Table6313 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6315 /* Table6315 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6317 /* Table6317 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6319 /* Table6319 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6321 /* Table6321 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6323 /* Table6323 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6325 /* Table6325 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6327 /* Table6327 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6329 /* Table6329 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6331 /* Table6331 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6333 /* Table6333 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6335 /* Table6335 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_XD_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6337 /* Table6337 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6339 /* Table6339 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6341 /* Table6341 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6343 /* Table6343 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6345 /* Table6345 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6347 /* Table6347 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6349 /* Table6349 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6351 /* Table6351 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6353 /* Table6353 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6355 /* Table6355 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6357 /* Table6357 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6359 /* Table6359 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6361 /* Table6361 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6363 /* Table6363 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6365 /* Table6365 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6367 /* Table6367 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6369 /* Table6369 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6371 /* Table6371 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6373 /* Table6373 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6375 /* Table6375 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6377 /* Table6377 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6379 /* Table6379 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6381 /* Table6381 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6383 /* Table6383 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6385 /* Table6385 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6387 /* Table6387 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6389 /* Table6389 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6391 /* Table6391 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6393 /* Table6393 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6395 /* Table6395 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6397 /* Table6397 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6399 /* Table6399 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6401 /* Table6401 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6403 /* Table6403 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6405 /* Table6405 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6407 /* Table6407 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6409 /* Table6409 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6411 /* Table6411 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6413 /* Table6413 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6415 /* Table6415 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6417 /* Table6417 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6419 /* Table6419 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6421 /* Table6421 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6423 /* Table6423 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6425 /* Table6425 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6427 /* Table6427 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6429 /* Table6429 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6431 /* Table6431 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6433 /* Table6433 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6435 /* Table6435 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6437 /* Table6437 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6439 /* Table6439 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6441 /* Table6441 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6443 /* Table6443 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6445 /* Table6445 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6447 /* Table6447 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6449 /* Table6449 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6451 /* Table6451 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6453 /* Table6453 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6455 /* Table6455 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6457 /* Table6457 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6459 /* Table6459 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6461 /* Table6461 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6463 /* Table6463 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6465 /* Table6465 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6467 /* Table6467 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6469 /* Table6469 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6471 /* Table6471 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6473 /* Table6473 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6475 /* Table6475 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6477 /* Table6477 */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6479 /* Table6479 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6481 /* Table6481 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6483 /* Table6483 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6485 /* Table6485 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6487 /* Table6487 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6489 /* Table6489 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6491 /* Table6491 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6493 /* Table6493 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6495 /* Table6495 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6497 /* Table6497 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6499 /* Table6499 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6501 /* Table6501 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_XS_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6503 /* Table6503 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6505 /* Table6505 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6507 /* Table6507 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6509 /* Table6509 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6511 /* Table6511 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6513 /* Table6513 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6515 /* Table6515 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6517 /* Table6517 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_XD_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6519 /* Table6519 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6521 /* Table6521 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6523 /* Table6523 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6525 /* Table6525 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6527 /* Table6527 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6529 /* Table6529 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6531 /* Table6531 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6533 /* Table6533 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6535 /* Table6535 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6537 /* Table6537 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6539 /* Table6539 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6541 /* Table6541 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6543 /* Table6543 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6545 /* Table6545 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6547 /* Table6547 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6549 /* Table6549 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6551 /* Table6551 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6553 /* Table6553 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6555 /* Table6555 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_XS_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6503 /* Table6503 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6505 /* Table6505 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6507 /* Table6507 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6509 /* Table6509 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6511 /* Table6511 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6513 /* Table6513 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6557 /* Table6557 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6559 /* Table6559 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_XD_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6561 /* Table6561 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6563 /* Table6563 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6565 /* Table6565 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6567 /* Table6567 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6569 /* Table6569 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6571 /* Table6571 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6573 /* Table6573 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6575 /* Table6575 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6577 /* Table6577 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6579 /* Table6579 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6581 /* Table6581 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6583 /* Table6583 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6585 /* Table6585 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6587 /* Table6587 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6589 /* Table6589 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6591 /* Table6591 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6593 /* Table6593 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6595 /* Table6595 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6597 /* Table6597 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6599 /* Table6599 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6601 /* Table6601 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6603 /* Table6603 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6605 /* Table6605 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6607 /* Table6607 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6609 /* Table6609 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6611 /* Table6611 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6613 /* Table6613 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6615 /* Table6615 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6617 /* Table6617 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6619 /* Table6619 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6621 /* Table6621 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6623 /* Table6623 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6625 /* Table6625 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6627 /* Table6627 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6629 /* Table6629 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6631 /* Table6631 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6633 /* Table6633 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6635 /* Table6635 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_XS_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6637 /* Table6637 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6639 /* Table6639 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_XD_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6641 /* Table6641 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6643 /* Table6643 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6645 /* Table6645 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6647 /* Table6647 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6649 /* Table6649 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6651 /* Table6651 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6653 /* Table6653 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6655 /* Table6655 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6657 /* Table6657 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6659 /* Table6659 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6661 /* Table6661 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6663 /* Table6663 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6665 /* Table6665 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6667 /* Table6667 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6669 /* Table6669 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6671 /* Table6671 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6673 /* Table6673 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6675 /* Table6675 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6677 /* Table6677 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_XS_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6503 /* Table6503 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6505 /* Table6505 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6507 /* Table6507 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6509 /* Table6509 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6511 /* Table6511 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6513 /* Table6513 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6679 /* Table6679 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6681 /* Table6681 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_XD_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6683 /* Table6683 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6685 /* Table6685 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6687 /* Table6687 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6689 /* Table6689 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6691 /* Table6691 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6693 /* Table6693 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6695 /* Table6695 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6697 /* Table6697 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6699 /* Table6699 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6701 /* Table6701 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6703 /* Table6703 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6705 /* Table6705 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6707 /* Table6707 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6709 /* Table6709 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6711 /* Table6711 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6713 /* Table6713 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6715 /* Table6715 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6717 /* Table6717 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6719 /* Table6719 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6721 /* Table6721 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6723 /* Table6723 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6725 /* Table6725 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6727 /* Table6727 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6729 /* Table6729 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6731 /* Table6731 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6733 /* Table6733 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6735 /* Table6735 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6737 /* Table6737 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6739 /* Table6739 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6741 /* Table6741 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6743 /* Table6743 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6745 /* Table6745 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_XS_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6747 /* Table6747 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6749 /* Table6749 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_XD_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6751 /* Table6751 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6753 /* Table6753 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6755 /* Table6755 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    6757 /* Table6757 */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6773 /* Table6773 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6775 /* Table6775 */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6777 /* Table6777 */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6779 /* Table6779 */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6781 /* Table6781 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6783 /* Table6783 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6785 /* Table6785 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6787 /* Table6787 */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6789 /* Table6789 */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6791 /* Table6791 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6793 /* Table6793 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6795 /* Table6795 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6797 /* Table6797 */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6799 /* Table6799 */
   },
   /* 0xf9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6801 /* Table6801 */
   },
   /* 0xfa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6803 /* Table6803 */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6805 /* Table6805 */
   },
   /* 0xfd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6807 /* Table6807 */
   },
   /* 0xfe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6809 /* Table6809 */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_XS_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6811 /* Table6811 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6813 /* Table6813 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_XD_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6815 /* Table6815 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6817 /* Table6817 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6819 /* Table6819 */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6821 /* Table6821 */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6823 /* Table6823 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6825 /* Table6825 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6827 /* Table6827 */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6829 /* Table6829 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6831 /* Table6831 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6833 /* Table6833 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6835 /* Table6835 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6837 /* Table6837 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6839 /* Table6839 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6841 /* Table6841 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    6843 /* Table6843 */
   },
   /* 0x73 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    6859 /* Table6859 */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6875 /* Table6875 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6877 /* Table6877 */
   },
   /* 0xd4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6879 /* Table6879 */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6881 /* Table6881 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6883 /* Table6883 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6885 /* Table6885 */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6887 /* Table6887 */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6889 /* Table6889 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6891 /* Table6891 */
   },
   /* 0xf4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6893 /* Table6893 */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6895 /* Table6895 */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 },
 /* IC_OF */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
, };
static const uint8_t index_x86DisassemblerTwoByteOpcodes[] = {
1, 2, 3, 4, 0, 5, 6, 7, 0, 8, 9, 10, 11, 12, 13, 14, 15, 0, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 0, 80, 81, 82, 83, 84, 0, 85, 0, 0, 86, 87, 88, 0, 0, 89, 0, 0, 0, 90, 91, 0, 92, 93, 94, 0, 95, 96, 97, 98, 0, 99, 0, 0, 100, 101, 102, 0, 0, 103, 0, 0, 0, 104, 105, 0, 0, 106, 0, 0, 0, 107, 108, 109, 0, 110, 0, 0, 111, 112, 113, 0, 0, 114, 0, 0, 0, 115, 116, 0, 0, 117, 0, 0, 0, 118, 119, 120, 121, 122, 0, 123, 124, 125, 126, 127, 128, 129, 0, 130, 131, 132, 133, 134, 135, 136, 0, 137, 138, 139, };
static const struct OpcodeDecision x86DisassemblerThreeByte38Opcodes[] = {
 /* IC */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6897 /* Table6897 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6899 /* Table6899 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6901 /* Table6901 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6903 /* Table6903 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6905 /* Table6905 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6907 /* Table6907 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6909 /* Table6909 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6911 /* Table6911 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6913 /* Table6913 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6915 /* Table6915 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6917 /* Table6917 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6919 /* Table6919 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6921 /* Table6921 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6923 /* Table6923 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6925 /* Table6925 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6939 /* Table6939 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6941 /* Table6941 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6897 /* Table6897 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6899 /* Table6899 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6901 /* Table6901 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6903 /* Table6903 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6905 /* Table6905 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6907 /* Table6907 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6909 /* Table6909 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6911 /* Table6911 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6913 /* Table6913 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6915 /* Table6915 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6917 /* Table6917 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6919 /* Table6919 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6921 /* Table6921 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6923 /* Table6923 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6925 /* Table6925 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6939 /* Table6939 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6941 /* Table6941 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6943 /* Table6943 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6945 /* Table6945 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6947 /* Table6947 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6949 /* Table6949 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6951 /* Table6951 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6953 /* Table6953 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6955 /* Table6955 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6957 /* Table6957 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6959 /* Table6959 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6961 /* Table6961 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6963 /* Table6963 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6965 /* Table6965 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6967 /* Table6967 */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6969 /* Table6969 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6971 /* Table6971 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6973 /* Table6973 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6975 /* Table6975 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6977 /* Table6977 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6979 /* Table6979 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6981 /* Table6981 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6983 /* Table6983 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6985 /* Table6985 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6987 /* Table6987 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6989 /* Table6989 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6991 /* Table6991 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6993 /* Table6993 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6995 /* Table6995 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6997 /* Table6997 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6999 /* Table6999 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7001 /* Table7001 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7003 /* Table7003 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7005 /* Table7005 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7007 /* Table7007 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7009 /* Table7009 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7011 /* Table7011 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7013 /* Table7013 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7015 /* Table7015 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7017 /* Table7017 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7019 /* Table7019 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7021 /* Table7021 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7023 /* Table7023 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7025 /* Table7025 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7027 /* Table7027 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7029 /* Table7029 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7031 /* Table7031 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7033 /* Table7033 */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7035 /* Table7035 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7037 /* Table7037 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7039 /* Table7039 */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7041 /* Table7041 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7043 /* Table7043 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7045 /* Table7045 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7047 /* Table7047 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7049 /* Table7049 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7051 /* Table7051 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7053 /* Table7053 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7055 /* Table7055 */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6897 /* Table6897 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6899 /* Table6899 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6901 /* Table6901 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6903 /* Table6903 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6905 /* Table6905 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6907 /* Table6907 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6909 /* Table6909 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6911 /* Table6911 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6913 /* Table6913 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6915 /* Table6915 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6917 /* Table6917 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6919 /* Table6919 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6921 /* Table6921 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6923 /* Table6923 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6925 /* Table6925 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6939 /* Table6939 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6941 /* Table6941 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_OPSIZE_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6943 /* Table6943 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6945 /* Table6945 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6947 /* Table6947 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6949 /* Table6949 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6951 /* Table6951 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6953 /* Table6953 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6955 /* Table6955 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6957 /* Table6957 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6959 /* Table6959 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6961 /* Table6961 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6963 /* Table6963 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6965 /* Table6965 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6967 /* Table6967 */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6969 /* Table6969 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6971 /* Table6971 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6973 /* Table6973 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6975 /* Table6975 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6977 /* Table6977 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6979 /* Table6979 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6981 /* Table6981 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6983 /* Table6983 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6985 /* Table6985 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6987 /* Table6987 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6989 /* Table6989 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6991 /* Table6991 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6993 /* Table6993 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6995 /* Table6995 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6997 /* Table6997 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6999 /* Table6999 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7001 /* Table7001 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7003 /* Table7003 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7005 /* Table7005 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7007 /* Table7007 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7009 /* Table7009 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7011 /* Table7011 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7013 /* Table7013 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7015 /* Table7015 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7017 /* Table7017 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7019 /* Table7019 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7021 /* Table7021 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7023 /* Table7023 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7025 /* Table7025 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7027 /* Table7027 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7029 /* Table7029 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7031 /* Table7031 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7033 /* Table7033 */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7035 /* Table7035 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7037 /* Table7037 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7039 /* Table7039 */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7041 /* Table7041 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7043 /* Table7043 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7045 /* Table7045 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7047 /* Table7047 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7049 /* Table7049 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7051 /* Table7051 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7053 /* Table7053 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7055 /* Table7055 */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6897 /* Table6897 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6899 /* Table6899 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6901 /* Table6901 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6903 /* Table6903 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6905 /* Table6905 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6907 /* Table6907 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6909 /* Table6909 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6911 /* Table6911 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6913 /* Table6913 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6915 /* Table6915 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6917 /* Table6917 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6919 /* Table6919 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6921 /* Table6921 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6923 /* Table6923 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6925 /* Table6925 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7057 /* Table7057 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7059 /* Table7059 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6897 /* Table6897 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6899 /* Table6899 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6901 /* Table6901 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6903 /* Table6903 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6905 /* Table6905 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6907 /* Table6907 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6909 /* Table6909 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6911 /* Table6911 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6913 /* Table6913 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6915 /* Table6915 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6917 /* Table6917 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6919 /* Table6919 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6921 /* Table6921 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6923 /* Table6923 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6925 /* Table6925 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6939 /* Table6939 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6941 /* Table6941 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7061 /* Table7061 */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_XD_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7063 /* Table7063 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6897 /* Table6897 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6899 /* Table6899 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6901 /* Table6901 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6903 /* Table6903 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6905 /* Table6905 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6907 /* Table6907 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6909 /* Table6909 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6911 /* Table6911 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6913 /* Table6913 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6915 /* Table6915 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6917 /* Table6917 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6919 /* Table6919 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6921 /* Table6921 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6923 /* Table6923 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6925 /* Table6925 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7065 /* Table7065 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7067 /* Table7067 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6943 /* Table6943 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6945 /* Table6945 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6947 /* Table6947 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6949 /* Table6949 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6951 /* Table6951 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6953 /* Table6953 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6955 /* Table6955 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6957 /* Table6957 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6959 /* Table6959 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6961 /* Table6961 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6963 /* Table6963 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6965 /* Table6965 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6967 /* Table6967 */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6969 /* Table6969 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6971 /* Table6971 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6973 /* Table6973 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6975 /* Table6975 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6977 /* Table6977 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6979 /* Table6979 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6981 /* Table6981 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6983 /* Table6983 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6985 /* Table6985 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6987 /* Table6987 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6989 /* Table6989 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6991 /* Table6991 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6993 /* Table6993 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6995 /* Table6995 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6997 /* Table6997 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6999 /* Table6999 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7001 /* Table7001 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7003 /* Table7003 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7005 /* Table7005 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7007 /* Table7007 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7009 /* Table7009 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7011 /* Table7011 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7013 /* Table7013 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7015 /* Table7015 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7017 /* Table7017 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7019 /* Table7019 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7021 /* Table7021 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7023 /* Table7023 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7025 /* Table7025 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7027 /* Table7027 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7029 /* Table7029 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7031 /* Table7031 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7033 /* Table7033 */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7069 /* Table7069 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7071 /* Table7071 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7073 /* Table7073 */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7041 /* Table7041 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7043 /* Table7043 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7045 /* Table7045 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7047 /* Table7047 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7049 /* Table7049 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7065 /* Table7065 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7067 /* Table7067 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7055 /* Table7055 */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6943 /* Table6943 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6945 /* Table6945 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6947 /* Table6947 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6949 /* Table6949 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6951 /* Table6951 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6953 /* Table6953 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6955 /* Table6955 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6957 /* Table6957 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6959 /* Table6959 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6961 /* Table6961 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6963 /* Table6963 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6965 /* Table6965 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6967 /* Table6967 */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6969 /* Table6969 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6971 /* Table6971 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6973 /* Table6973 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6975 /* Table6975 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6977 /* Table6977 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6979 /* Table6979 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6981 /* Table6981 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6983 /* Table6983 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6985 /* Table6985 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6987 /* Table6987 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6989 /* Table6989 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6991 /* Table6991 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6993 /* Table6993 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6995 /* Table6995 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6997 /* Table6997 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6999 /* Table6999 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7001 /* Table7001 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7003 /* Table7003 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7005 /* Table7005 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7007 /* Table7007 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7009 /* Table7009 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7011 /* Table7011 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7013 /* Table7013 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7015 /* Table7015 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7017 /* Table7017 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7019 /* Table7019 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7021 /* Table7021 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7023 /* Table7023 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7025 /* Table7025 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7027 /* Table7027 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7029 /* Table7029 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7031 /* Table7031 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7033 /* Table7033 */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7069 /* Table7069 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7071 /* Table7071 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7073 /* Table7073 */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7041 /* Table7041 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7043 /* Table7043 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7045 /* Table7045 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7047 /* Table7047 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7049 /* Table7049 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7051 /* Table7051 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7053 /* Table7053 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7055 /* Table7055 */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6897 /* Table6897 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6899 /* Table6899 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6901 /* Table6901 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6903 /* Table6903 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6905 /* Table6905 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6907 /* Table6907 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6909 /* Table6909 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6911 /* Table6911 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6913 /* Table6913 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6915 /* Table6915 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6917 /* Table6917 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6919 /* Table6919 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6921 /* Table6921 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6923 /* Table6923 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6925 /* Table6925 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6939 /* Table6939 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6941 /* Table6941 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_OPSIZE_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6943 /* Table6943 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6945 /* Table6945 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6947 /* Table6947 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6949 /* Table6949 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6951 /* Table6951 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6953 /* Table6953 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6955 /* Table6955 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6957 /* Table6957 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6959 /* Table6959 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6961 /* Table6961 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6963 /* Table6963 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6965 /* Table6965 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6967 /* Table6967 */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6969 /* Table6969 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6971 /* Table6971 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6973 /* Table6973 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6975 /* Table6975 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6977 /* Table6977 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6979 /* Table6979 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6981 /* Table6981 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6983 /* Table6983 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6985 /* Table6985 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6987 /* Table6987 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6989 /* Table6989 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6991 /* Table6991 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6993 /* Table6993 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6995 /* Table6995 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6997 /* Table6997 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6999 /* Table6999 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7001 /* Table7001 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7003 /* Table7003 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7005 /* Table7005 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7007 /* Table7007 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7009 /* Table7009 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7011 /* Table7011 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7013 /* Table7013 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7015 /* Table7015 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7017 /* Table7017 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7019 /* Table7019 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7021 /* Table7021 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7023 /* Table7023 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7025 /* Table7025 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7027 /* Table7027 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7029 /* Table7029 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7031 /* Table7031 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7033 /* Table7033 */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7069 /* Table7069 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7071 /* Table7071 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7073 /* Table7073 */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7041 /* Table7041 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7043 /* Table7043 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7045 /* Table7045 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7047 /* Table7047 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7049 /* Table7049 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7051 /* Table7051 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7053 /* Table7053 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7055 /* Table7055 */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6897 /* Table6897 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6899 /* Table6899 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6901 /* Table6901 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6903 /* Table6903 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6905 /* Table6905 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6907 /* Table6907 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6909 /* Table6909 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6911 /* Table6911 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6913 /* Table6913 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6915 /* Table6915 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6917 /* Table6917 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6919 /* Table6919 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6921 /* Table6921 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6923 /* Table6923 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6925 /* Table6925 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7057 /* Table7057 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7059 /* Table7059 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6897 /* Table6897 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6899 /* Table6899 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6901 /* Table6901 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6903 /* Table6903 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6905 /* Table6905 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6907 /* Table6907 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6909 /* Table6909 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6911 /* Table6911 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6913 /* Table6913 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6915 /* Table6915 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6917 /* Table6917 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6919 /* Table6919 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6921 /* Table6921 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6923 /* Table6923 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6925 /* Table6925 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6939 /* Table6939 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6941 /* Table6941 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7061 /* Table7061 */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_XD_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7063 /* Table7063 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6897 /* Table6897 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6899 /* Table6899 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6901 /* Table6901 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6903 /* Table6903 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6905 /* Table6905 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6907 /* Table6907 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6909 /* Table6909 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6911 /* Table6911 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6913 /* Table6913 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6915 /* Table6915 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6917 /* Table6917 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6919 /* Table6919 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6921 /* Table6921 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6923 /* Table6923 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6925 /* Table6925 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7065 /* Table7065 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7067 /* Table7067 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7075 /* Table7075 */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6897 /* Table6897 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6899 /* Table6899 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6901 /* Table6901 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6903 /* Table6903 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6905 /* Table6905 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6907 /* Table6907 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6909 /* Table6909 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6911 /* Table6911 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6913 /* Table6913 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6915 /* Table6915 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6917 /* Table6917 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6919 /* Table6919 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6921 /* Table6921 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6923 /* Table6923 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6925 /* Table6925 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7077 /* Table7077 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7079 /* Table7079 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6943 /* Table6943 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6945 /* Table6945 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6947 /* Table6947 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6949 /* Table6949 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6951 /* Table6951 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6953 /* Table6953 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6955 /* Table6955 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6957 /* Table6957 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6959 /* Table6959 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6961 /* Table6961 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6963 /* Table6963 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6965 /* Table6965 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6967 /* Table6967 */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6969 /* Table6969 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6971 /* Table6971 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6973 /* Table6973 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6975 /* Table6975 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6977 /* Table6977 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6979 /* Table6979 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6981 /* Table6981 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6983 /* Table6983 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6985 /* Table6985 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6987 /* Table6987 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6989 /* Table6989 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6991 /* Table6991 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6993 /* Table6993 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6995 /* Table6995 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6997 /* Table6997 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6999 /* Table6999 */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7001 /* Table7001 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7003 /* Table7003 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7005 /* Table7005 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7007 /* Table7007 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7009 /* Table7009 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7011 /* Table7011 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7013 /* Table7013 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7015 /* Table7015 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7017 /* Table7017 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7019 /* Table7019 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7021 /* Table7021 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7023 /* Table7023 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7025 /* Table7025 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7027 /* Table7027 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7029 /* Table7029 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7031 /* Table7031 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7033 /* Table7033 */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7069 /* Table7069 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7071 /* Table7071 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7073 /* Table7073 */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6927 /* Table6927 */
   },
   /* 0xc9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6929 /* Table6929 */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6931 /* Table6931 */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6933 /* Table6933 */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6935 /* Table6935 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    6937 /* Table6937 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7041 /* Table7041 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7043 /* Table7043 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7045 /* Table7045 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7047 /* Table7047 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7049 /* Table7049 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7065 /* Table7065 */
   },
   /* 0xf1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7067 /* Table7067 */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7081 /* Table7081 */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7083 /* Table7083 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    7085 /* Table7085 */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7101 /* Table7101 */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7103 /* Table7103 */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7105 /* Table7105 */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7107 /* Table7107 */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7109 /* Table7109 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7111 /* Table7111 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7113 /* Table7113 */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7115 /* Table7115 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7117 /* Table7117 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7119 /* Table7119 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7121 /* Table7121 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7123 /* Table7123 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7125 /* Table7125 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7127 /* Table7127 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7129 /* Table7129 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7131 /* Table7131 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7133 /* Table7133 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7135 /* Table7135 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7137 /* Table7137 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7139 /* Table7139 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7141 /* Table7141 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7143 /* Table7143 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7145 /* Table7145 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7147 /* Table7147 */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7149 /* Table7149 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7151 /* Table7151 */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7153 /* Table7153 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7155 /* Table7155 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7157 /* Table7157 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7159 /* Table7159 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7161 /* Table7161 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7163 /* Table7163 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7165 /* Table7165 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7167 /* Table7167 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7169 /* Table7169 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7171 /* Table7171 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7173 /* Table7173 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7175 /* Table7175 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7177 /* Table7177 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7179 /* Table7179 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7181 /* Table7181 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7183 /* Table7183 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7185 /* Table7185 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7187 /* Table7187 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7189 /* Table7189 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7191 /* Table7191 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7193 /* Table7193 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7195 /* Table7195 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7197 /* Table7197 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7199 /* Table7199 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7201 /* Table7201 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7203 /* Table7203 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7205 /* Table7205 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7207 /* Table7207 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7209 /* Table7209 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7211 /* Table7211 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7213 /* Table7213 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7215 /* Table7215 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7217 /* Table7217 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7219 /* Table7219 */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7221 /* Table7221 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7223 /* Table7223 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7225 /* Table7225 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7227 /* Table7227 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7229 /* Table7229 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7231 /* Table7231 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7233 /* Table7233 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7235 /* Table7235 */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7237 /* Table7237 */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7239 /* Table7239 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7241 /* Table7241 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7243 /* Table7243 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7245 /* Table7245 */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7247 /* Table7247 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7249 /* Table7249 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7251 /* Table7251 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7253 /* Table7253 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7255 /* Table7255 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7257 /* Table7257 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7259 /* Table7259 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7261 /* Table7261 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7263 /* Table7263 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7265 /* Table7265 */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7267 /* Table7267 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7269 /* Table7269 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7271 /* Table7271 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7273 /* Table7273 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7275 /* Table7275 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7277 /* Table7277 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7279 /* Table7279 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7281 /* Table7281 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7283 /* Table7283 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7285 /* Table7285 */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7287 /* Table7287 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7289 /* Table7289 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7291 /* Table7291 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7293 /* Table7293 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7295 /* Table7295 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7297 /* Table7297 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7299 /* Table7299 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7301 /* Table7301 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7303 /* Table7303 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7305 /* Table7305 */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7307 /* Table7307 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7309 /* Table7309 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7311 /* Table7311 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7313 /* Table7313 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7315 /* Table7315 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7317 /* Table7317 */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_W */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7319 /* Table7319 */
   },
   /* 0xf3 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    7321 /* Table7321 */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7337 /* Table7337 */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7339 /* Table7339 */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_W_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7341 /* Table7341 */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7343 /* Table7343 */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_W_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7345 /* Table7345 */
   },
   /* 0xf6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7347 /* Table7347 */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7349 /* Table7349 */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7115 /* Table7115 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7117 /* Table7117 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7119 /* Table7119 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7121 /* Table7121 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7123 /* Table7123 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7125 /* Table7125 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7127 /* Table7127 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7129 /* Table7129 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7131 /* Table7131 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7133 /* Table7133 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7135 /* Table7135 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7137 /* Table7137 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7139 /* Table7139 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7141 /* Table7141 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7143 /* Table7143 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7145 /* Table7145 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7147 /* Table7147 */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7149 /* Table7149 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7151 /* Table7151 */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7153 /* Table7153 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7155 /* Table7155 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7157 /* Table7157 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7159 /* Table7159 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7161 /* Table7161 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7163 /* Table7163 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7165 /* Table7165 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7167 /* Table7167 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7169 /* Table7169 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7171 /* Table7171 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7173 /* Table7173 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7175 /* Table7175 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7177 /* Table7177 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7179 /* Table7179 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7181 /* Table7181 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7183 /* Table7183 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7185 /* Table7185 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7187 /* Table7187 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7189 /* Table7189 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7191 /* Table7191 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7193 /* Table7193 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7195 /* Table7195 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7197 /* Table7197 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7199 /* Table7199 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7201 /* Table7201 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7203 /* Table7203 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7205 /* Table7205 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7207 /* Table7207 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7209 /* Table7209 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7211 /* Table7211 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7213 /* Table7213 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7215 /* Table7215 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7217 /* Table7217 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7219 /* Table7219 */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7351 /* Table7351 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7223 /* Table7223 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7353 /* Table7353 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7227 /* Table7227 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7229 /* Table7229 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7231 /* Table7231 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7233 /* Table7233 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7355 /* Table7355 */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7357 /* Table7357 */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7359 /* Table7359 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7361 /* Table7361 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7363 /* Table7363 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7365 /* Table7365 */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7367 /* Table7367 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7369 /* Table7369 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7371 /* Table7371 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7373 /* Table7373 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7375 /* Table7375 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7377 /* Table7377 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7379 /* Table7379 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7381 /* Table7381 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7383 /* Table7383 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7385 /* Table7385 */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7387 /* Table7387 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7389 /* Table7389 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7391 /* Table7391 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7393 /* Table7393 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7395 /* Table7395 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7397 /* Table7397 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7399 /* Table7399 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7401 /* Table7401 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7403 /* Table7403 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7405 /* Table7405 */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7407 /* Table7407 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7409 /* Table7409 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7411 /* Table7411 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7413 /* Table7413 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7415 /* Table7415 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7417 /* Table7417 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7419 /* Table7419 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7421 /* Table7421 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7423 /* Table7423 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7425 /* Table7425 */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7307 /* Table7307 */
   },
   /* 0xdc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7309 /* Table7309 */
   },
   /* 0xdd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7311 /* Table7311 */
   },
   /* 0xde */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7313 /* Table7313 */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7315 /* Table7315 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7427 /* Table7427 */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7429 /* Table7429 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7431 /* Table7431 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7433 /* Table7433 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7435 /* Table7435 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7437 /* Table7437 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7439 /* Table7439 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7441 /* Table7441 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7443 /* Table7443 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7445 /* Table7445 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7447 /* Table7447 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7449 /* Table7449 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7451 /* Table7451 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7453 /* Table7453 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7455 /* Table7455 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7457 /* Table7457 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7459 /* Table7459 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7461 /* Table7461 */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7463 /* Table7463 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7465 /* Table7465 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7467 /* Table7467 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7469 /* Table7469 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7471 /* Table7471 */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7473 /* Table7473 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7475 /* Table7475 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7477 /* Table7477 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7479 /* Table7479 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7481 /* Table7481 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7483 /* Table7483 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7485 /* Table7485 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7487 /* Table7487 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7489 /* Table7489 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7491 /* Table7491 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7493 /* Table7493 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7495 /* Table7495 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7497 /* Table7497 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7499 /* Table7499 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7501 /* Table7501 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7503 /* Table7503 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7505 /* Table7505 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7507 /* Table7507 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7509 /* Table7509 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7511 /* Table7511 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7513 /* Table7513 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7515 /* Table7515 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7517 /* Table7517 */
   },
   /* 0x36 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7519 /* Table7519 */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7521 /* Table7521 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7523 /* Table7523 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7525 /* Table7525 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7527 /* Table7527 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7529 /* Table7529 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7531 /* Table7531 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7533 /* Table7533 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7535 /* Table7535 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7537 /* Table7537 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7539 /* Table7539 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7541 /* Table7541 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7543 /* Table7543 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7545 /* Table7545 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7547 /* Table7547 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7549 /* Table7549 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7551 /* Table7551 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7553 /* Table7553 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7555 /* Table7555 */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7557 /* Table7557 */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7559 /* Table7559 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7561 /* Table7561 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7563 /* Table7563 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7565 /* Table7565 */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7567 /* Table7567 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7569 /* Table7569 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7571 /* Table7571 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7253 /* Table7253 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7573 /* Table7573 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7257 /* Table7257 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7575 /* Table7575 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7261 /* Table7261 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7577 /* Table7577 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7265 /* Table7265 */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7579 /* Table7579 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7581 /* Table7581 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7583 /* Table7583 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7273 /* Table7273 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7585 /* Table7585 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7277 /* Table7277 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7587 /* Table7587 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7281 /* Table7281 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7589 /* Table7589 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7285 /* Table7285 */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7591 /* Table7591 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7593 /* Table7593 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7595 /* Table7595 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7293 /* Table7293 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7597 /* Table7597 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7297 /* Table7297 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7599 /* Table7599 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7301 /* Table7301 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7601 /* Table7601 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7305 /* Table7305 */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7429 /* Table7429 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7431 /* Table7431 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7433 /* Table7433 */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7435 /* Table7435 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7437 /* Table7437 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7439 /* Table7439 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7441 /* Table7441 */
   },
   /* 0x07 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7443 /* Table7443 */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7445 /* Table7445 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7447 /* Table7447 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7449 /* Table7449 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7451 /* Table7451 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7453 /* Table7453 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7455 /* Table7455 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7457 /* Table7457 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7459 /* Table7459 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7461 /* Table7461 */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7463 /* Table7463 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7465 /* Table7465 */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7467 /* Table7467 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7469 /* Table7469 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7471 /* Table7471 */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7473 /* Table7473 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7475 /* Table7475 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7477 /* Table7477 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7479 /* Table7479 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7481 /* Table7481 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7483 /* Table7483 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7485 /* Table7485 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7487 /* Table7487 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7489 /* Table7489 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7491 /* Table7491 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7493 /* Table7493 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7495 /* Table7495 */
   },
   /* 0x2b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7497 /* Table7497 */
   },
   /* 0x2c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7499 /* Table7499 */
   },
   /* 0x2d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7501 /* Table7501 */
   },
   /* 0x2e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7503 /* Table7503 */
   },
   /* 0x2f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7505 /* Table7505 */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7507 /* Table7507 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7509 /* Table7509 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7511 /* Table7511 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7513 /* Table7513 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7515 /* Table7515 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7517 /* Table7517 */
   },
   /* 0x36 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7519 /* Table7519 */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7521 /* Table7521 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7523 /* Table7523 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7525 /* Table7525 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7527 /* Table7527 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7529 /* Table7529 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7531 /* Table7531 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7533 /* Table7533 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7535 /* Table7535 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7537 /* Table7537 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7539 /* Table7539 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7603 /* Table7603 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7543 /* Table7543 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7605 /* Table7605 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7547 /* Table7547 */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7549 /* Table7549 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7551 /* Table7551 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7553 /* Table7553 */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7607 /* Table7607 */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7609 /* Table7609 */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7611 /* Table7611 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7613 /* Table7613 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7615 /* Table7615 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7617 /* Table7617 */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7619 /* Table7619 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7621 /* Table7621 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7623 /* Table7623 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7373 /* Table7373 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7625 /* Table7625 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7377 /* Table7377 */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7627 /* Table7627 */
   },
   /* 0x9d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7381 /* Table7381 */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7629 /* Table7629 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7385 /* Table7385 */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7631 /* Table7631 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7633 /* Table7633 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7635 /* Table7635 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7393 /* Table7393 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7637 /* Table7637 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7397 /* Table7397 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7639 /* Table7639 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7401 /* Table7401 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7641 /* Table7641 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7405 /* Table7405 */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7643 /* Table7643 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7645 /* Table7645 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7647 /* Table7647 */
   },
   /* 0xb9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7413 /* Table7413 */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7649 /* Table7649 */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7417 /* Table7417 */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7651 /* Table7651 */
   },
   /* 0xbd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7421 /* Table7421 */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7653 /* Table7653 */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7425 /* Table7425 */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7655 /* Table7655 */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7657 /* Table7657 */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7659 /* Table7659 */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7661 /* Table7661 */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7663 /* Table7663 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7665 /* Table7665 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7667 /* Table7667 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7669 /* Table7669 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7671 /* Table7671 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7673 /* Table7673 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7675 /* Table7675 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7677 /* Table7677 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7679 /* Table7679 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7681 /* Table7681 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7683 /* Table7683 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7685 /* Table7685 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7687 /* Table7687 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7689 /* Table7689 */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7691 /* Table7691 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7693 /* Table7693 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7695 /* Table7695 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7697 /* Table7697 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7699 /* Table7699 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7701 /* Table7701 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7703 /* Table7703 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7705 /* Table7705 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7707 /* Table7707 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7709 /* Table7709 */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7711 /* Table7711 */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7713 /* Table7713 */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7715 /* Table7715 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7717 /* Table7717 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7719 /* Table7719 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7721 /* Table7721 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7723 /* Table7723 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7725 /* Table7725 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7727 /* Table7727 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7729 /* Table7729 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7731 /* Table7731 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7733 /* Table7733 */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7735 /* Table7735 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7737 /* Table7737 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7739 /* Table7739 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7741 /* Table7741 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7743 /* Table7743 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7745 /* Table7745 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7747 /* Table7747 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7749 /* Table7749 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7751 /* Table7751 */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7753 /* Table7753 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7755 /* Table7755 */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7659 /* Table7659 */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7661 /* Table7661 */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7757 /* Table7757 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7663 /* Table7663 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7759 /* Table7759 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7665 /* Table7665 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7761 /* Table7761 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7669 /* Table7669 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7763 /* Table7763 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7673 /* Table7673 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7765 /* Table7765 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7677 /* Table7677 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7767 /* Table7767 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7769 /* Table7769 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7771 /* Table7771 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7773 /* Table7773 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7775 /* Table7775 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7777 /* Table7777 */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7779 /* Table7779 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7781 /* Table7781 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7783 /* Table7783 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7697 /* Table7697 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7699 /* Table7699 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7785 /* Table7785 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7787 /* Table7787 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7789 /* Table7789 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7791 /* Table7791 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7793 /* Table7793 */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7795 /* Table7795 */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7797 /* Table7797 */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7799 /* Table7799 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7801 /* Table7801 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7803 /* Table7803 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7805 /* Table7805 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7807 /* Table7807 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7809 /* Table7809 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7811 /* Table7811 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7813 /* Table7813 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7815 /* Table7815 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7817 /* Table7817 */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7819 /* Table7819 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7821 /* Table7821 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7823 /* Table7823 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7825 /* Table7825 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7827 /* Table7827 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7829 /* Table7829 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7831 /* Table7831 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7833 /* Table7833 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7835 /* Table7835 */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7837 /* Table7837 */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7839 /* Table7839 */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7841 /* Table7841 */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7843 /* Table7843 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7845 /* Table7845 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7847 /* Table7847 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7849 /* Table7849 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7851 /* Table7851 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7853 /* Table7853 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7855 /* Table7855 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7857 /* Table7857 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7859 /* Table7859 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7861 /* Table7861 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7863 /* Table7863 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7865 /* Table7865 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7867 /* Table7867 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7869 /* Table7869 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7871 /* Table7871 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7873 /* Table7873 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7875 /* Table7875 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7877 /* Table7877 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7879 /* Table7879 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7881 /* Table7881 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7883 /* Table7883 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7885 /* Table7885 */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7887 /* Table7887 */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7889 /* Table7889 */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7891 /* Table7891 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7893 /* Table7893 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7895 /* Table7895 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7897 /* Table7897 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7899 /* Table7899 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7901 /* Table7901 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7903 /* Table7903 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7905 /* Table7905 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7907 /* Table7907 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7909 /* Table7909 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7911 /* Table7911 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7913 /* Table7913 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7915 /* Table7915 */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7917 /* Table7917 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7919 /* Table7919 */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7659 /* Table7659 */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7661 /* Table7661 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7921 /* Table7921 */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7923 /* Table7923 */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7663 /* Table7663 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7925 /* Table7925 */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7665 /* Table7665 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7927 /* Table7927 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7669 /* Table7669 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7929 /* Table7929 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7673 /* Table7673 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7931 /* Table7931 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7677 /* Table7677 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7933 /* Table7933 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7935 /* Table7935 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7937 /* Table7937 */
   },
   /* 0x4d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7685 /* Table7685 */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7939 /* Table7939 */
   },
   /* 0x4f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7689 /* Table7689 */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7941 /* Table7941 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7943 /* Table7943 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7945 /* Table7945 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7697 /* Table7697 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7699 /* Table7699 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7947 /* Table7947 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7949 /* Table7949 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7951 /* Table7951 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7953 /* Table7953 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7955 /* Table7955 */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7957 /* Table7957 */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7959 /* Table7959 */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7961 /* Table7961 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7963 /* Table7963 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7965 /* Table7965 */
   },
   /* 0xa9 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7721 /* Table7721 */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7967 /* Table7967 */
   },
   /* 0xab */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7725 /* Table7725 */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7969 /* Table7969 */
   },
   /* 0xad */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7729 /* Table7729 */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7971 /* Table7971 */
   },
   /* 0xaf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7733 /* Table7733 */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7973 /* Table7973 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7975 /* Table7975 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7977 /* Table7977 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7979 /* Table7979 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7981 /* Table7981 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7983 /* Table7983 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7747 /* Table7747 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7749 /* Table7749 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7985 /* Table7985 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7987 /* Table7987 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7989 /* Table7989 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7991 /* Table7991 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7993 /* Table7993 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7995 /* Table7995 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7997 /* Table7997 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    7999 /* Table7999 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8001 /* Table8001 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8003 /* Table8003 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8005 /* Table8005 */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8007 /* Table8007 */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8009 /* Table8009 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8011 /* Table8011 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8013 /* Table8013 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8015 /* Table8015 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8017 /* Table8017 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8019 /* Table8019 */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8021 /* Table8021 */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8023 /* Table8023 */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8025 /* Table8025 */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8027 /* Table8027 */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8029 /* Table8029 */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8031 /* Table8031 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8033 /* Table8033 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8035 /* Table8035 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8037 /* Table8037 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8039 /* Table8039 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8041 /* Table8041 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8043 /* Table8043 */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8045 /* Table8045 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8047 /* Table8047 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8049 /* Table8049 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8051 /* Table8051 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8053 /* Table8053 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8055 /* Table8055 */
   },
   /* 0x36 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8057 /* Table8057 */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8059 /* Table8059 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8061 /* Table8061 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8063 /* Table8063 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8065 /* Table8065 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8067 /* Table8067 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8069 /* Table8069 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8071 /* Table8071 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8073 /* Table8073 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8075 /* Table8075 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8077 /* Table8077 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8079 /* Table8079 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8081 /* Table8081 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8083 /* Table8083 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8085 /* Table8085 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8087 /* Table8087 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8089 /* Table8089 */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8091 /* Table8091 */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8093 /* Table8093 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8095 /* Table8095 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8097 /* Table8097 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8099 /* Table8099 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8101 /* Table8101 */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8103 /* Table8103 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8105 /* Table8105 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8107 /* Table8107 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8109 /* Table8109 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8111 /* Table8111 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8113 /* Table8113 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8115 /* Table8115 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8117 /* Table8117 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8119 /* Table8119 */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8121 /* Table8121 */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8123 /* Table8123 */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8125 /* Table8125 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8127 /* Table8127 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8129 /* Table8129 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8131 /* Table8131 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8133 /* Table8133 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8135 /* Table8135 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8137 /* Table8137 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8139 /* Table8139 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8141 /* Table8141 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8143 /* Table8143 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8145 /* Table8145 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8147 /* Table8147 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8149 /* Table8149 */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8151 /* Table8151 */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8153 /* Table8153 */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8155 /* Table8155 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8157 /* Table8157 */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8159 /* Table8159 */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8161 /* Table8161 */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8163 /* Table8163 */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8165 /* Table8165 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8167 /* Table8167 */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8169 /* Table8169 */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8171 /* Table8171 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8173 /* Table8173 */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8175 /* Table8175 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8177 /* Table8177 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8179 /* Table8179 */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8181 /* Table8181 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8183 /* Table8183 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8185 /* Table8185 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8187 /* Table8187 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8189 /* Table8189 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8191 /* Table8191 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8193 /* Table8193 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8195 /* Table8195 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8197 /* Table8197 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8199 /* Table8199 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8201 /* Table8201 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8203 /* Table8203 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8205 /* Table8205 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8207 /* Table8207 */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8209 /* Table8209 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8211 /* Table8211 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8213 /* Table8213 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8215 /* Table8215 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8217 /* Table8217 */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8219 /* Table8219 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8221 /* Table8221 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8223 /* Table8223 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8225 /* Table8225 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8227 /* Table8227 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8229 /* Table8229 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8231 /* Table8231 */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8233 /* Table8233 */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8235 /* Table8235 */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8237 /* Table8237 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8239 /* Table8239 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8241 /* Table8241 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8243 /* Table8243 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8245 /* Table8245 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8247 /* Table8247 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8249 /* Table8249 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8251 /* Table8251 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8253 /* Table8253 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8255 /* Table8255 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8257 /* Table8257 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8259 /* Table8259 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8261 /* Table8261 */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8263 /* Table8263 */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8265 /* Table8265 */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8267 /* Table8267 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8269 /* Table8269 */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8271 /* Table8271 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8273 /* Table8273 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8275 /* Table8275 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8277 /* Table8277 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8279 /* Table8279 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8281 /* Table8281 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8283 /* Table8283 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8285 /* Table8285 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8287 /* Table8287 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8289 /* Table8289 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8291 /* Table8291 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8293 /* Table8293 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8295 /* Table8295 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8297 /* Table8297 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8299 /* Table8299 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8301 /* Table8301 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8303 /* Table8303 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8305 /* Table8305 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8307 /* Table8307 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8309 /* Table8309 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8311 /* Table8311 */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8313 /* Table8313 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8315 /* Table8315 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8317 /* Table8317 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8319 /* Table8319 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8321 /* Table8321 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8323 /* Table8323 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8325 /* Table8325 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8327 /* Table8327 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8329 /* Table8329 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8331 /* Table8331 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8333 /* Table8333 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8335 /* Table8335 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8337 /* Table8337 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8339 /* Table8339 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8341 /* Table8341 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8343 /* Table8343 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8345 /* Table8345 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8347 /* Table8347 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8349 /* Table8349 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8351 /* Table8351 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8353 /* Table8353 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8355 /* Table8355 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8357 /* Table8357 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8359 /* Table8359 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8361 /* Table8361 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8363 /* Table8363 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8365 /* Table8365 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8367 /* Table8367 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8369 /* Table8369 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8371 /* Table8371 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8373 /* Table8373 */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8375 /* Table8375 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8377 /* Table8377 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8379 /* Table8379 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8381 /* Table8381 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8383 /* Table8383 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8385 /* Table8385 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8387 /* Table8387 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8389 /* Table8389 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8391 /* Table8391 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8393 /* Table8393 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8395 /* Table8395 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8397 /* Table8397 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8399 /* Table8399 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8401 /* Table8401 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8403 /* Table8403 */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8405 /* Table8405 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8407 /* Table8407 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8409 /* Table8409 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8411 /* Table8411 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8413 /* Table8413 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8415 /* Table8415 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8417 /* Table8417 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8419 /* Table8419 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8421 /* Table8421 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8423 /* Table8423 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8425 /* Table8425 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8427 /* Table8427 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8429 /* Table8429 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8431 /* Table8431 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8433 /* Table8433 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8435 /* Table8435 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8437 /* Table8437 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8439 /* Table8439 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8441 /* Table8441 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8443 /* Table8443 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8445 /* Table8445 */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8447 /* Table8447 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8449 /* Table8449 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8451 /* Table8451 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8453 /* Table8453 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8455 /* Table8455 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8457 /* Table8457 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8459 /* Table8459 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8461 /* Table8461 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8463 /* Table8463 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8465 /* Table8465 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8467 /* Table8467 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8469 /* Table8469 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8471 /* Table8471 */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8473 /* Table8473 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8475 /* Table8475 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8477 /* Table8477 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8479 /* Table8479 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8481 /* Table8481 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8483 /* Table8483 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8485 /* Table8485 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8487 /* Table8487 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8489 /* Table8489 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8491 /* Table8491 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8493 /* Table8493 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8495 /* Table8495 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8497 /* Table8497 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8499 /* Table8499 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8501 /* Table8501 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8503 /* Table8503 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8505 /* Table8505 */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8507 /* Table8507 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8509 /* Table8509 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8511 /* Table8511 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8513 /* Table8513 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8515 /* Table8515 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8517 /* Table8517 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8519 /* Table8519 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8521 /* Table8521 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8523 /* Table8523 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8525 /* Table8525 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8527 /* Table8527 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8529 /* Table8529 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_XS_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8531 /* Table8531 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8533 /* Table8533 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8535 /* Table8535 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8537 /* Table8537 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8539 /* Table8539 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8541 /* Table8541 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8543 /* Table8543 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8545 /* Table8545 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8547 /* Table8547 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8549 /* Table8549 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8551 /* Table8551 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8553 /* Table8553 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8555 /* Table8555 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8557 /* Table8557 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8559 /* Table8559 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8561 /* Table8561 */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8563 /* Table8563 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8565 /* Table8565 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8567 /* Table8567 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8569 /* Table8569 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8571 /* Table8571 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8573 /* Table8573 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8575 /* Table8575 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8577 /* Table8577 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8579 /* Table8579 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8581 /* Table8581 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8583 /* Table8583 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8585 /* Table8585 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8587 /* Table8587 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8589 /* Table8589 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8591 /* Table8591 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8593 /* Table8593 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8595 /* Table8595 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8597 /* Table8597 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8599 /* Table8599 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8601 /* Table8601 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8603 /* Table8603 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8605 /* Table8605 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8607 /* Table8607 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8609 /* Table8609 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8611 /* Table8611 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8613 /* Table8613 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8615 /* Table8615 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8617 /* Table8617 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8619 /* Table8619 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8621 /* Table8621 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8623 /* Table8623 */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8625 /* Table8625 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8627 /* Table8627 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8629 /* Table8629 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8631 /* Table8631 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8633 /* Table8633 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8635 /* Table8635 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8637 /* Table8637 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8639 /* Table8639 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8641 /* Table8641 */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8643 /* Table8643 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8645 /* Table8645 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8647 /* Table8647 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8649 /* Table8649 */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8651 /* Table8651 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8653 /* Table8653 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8655 /* Table8655 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8657 /* Table8657 */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8659 /* Table8659 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8661 /* Table8661 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8663 /* Table8663 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8665 /* Table8665 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8667 /* Table8667 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8669 /* Table8669 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8671 /* Table8671 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8673 /* Table8673 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8675 /* Table8675 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8677 /* Table8677 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8679 /* Table8679 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8681 /* Table8681 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8683 /* Table8683 */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    8685 /* Table8685 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    8701 /* Table8701 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8717 /* Table8717 */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8719 /* Table8719 */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8721 /* Table8721 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8723 /* Table8723 */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8725 /* Table8725 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8727 /* Table8727 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8729 /* Table8729 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8731 /* Table8731 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8733 /* Table8733 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8735 /* Table8735 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8737 /* Table8737 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8739 /* Table8739 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8741 /* Table8741 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8743 /* Table8743 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8745 /* Table8745 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8747 /* Table8747 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8749 /* Table8749 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8751 /* Table8751 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8753 /* Table8753 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8755 /* Table8755 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8757 /* Table8757 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8759 /* Table8759 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8761 /* Table8761 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8763 /* Table8763 */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8765 /* Table8765 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8767 /* Table8767 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8769 /* Table8769 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8771 /* Table8771 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8773 /* Table8773 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8775 /* Table8775 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8777 /* Table8777 */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8779 /* Table8779 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8781 /* Table8781 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8783 /* Table8783 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8785 /* Table8785 */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8787 /* Table8787 */
   },
   /* 0xa1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8789 /* Table8789 */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8791 /* Table8791 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8793 /* Table8793 */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8795 /* Table8795 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8797 /* Table8797 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8799 /* Table8799 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8801 /* Table8801 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8803 /* Table8803 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8805 /* Table8805 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8807 /* Table8807 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8809 /* Table8809 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8811 /* Table8811 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8813 /* Table8813 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8815 /* Table8815 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8817 /* Table8817 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8819 /* Table8819 */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    8821 /* Table8821 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    8837 /* Table8837 */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8853 /* Table8853 */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8855 /* Table8855 */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8857 /* Table8857 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8859 /* Table8859 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8861 /* Table8861 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8863 /* Table8863 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8865 /* Table8865 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8867 /* Table8867 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8869 /* Table8869 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8871 /* Table8871 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8873 /* Table8873 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8875 /* Table8875 */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8877 /* Table8877 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8879 /* Table8879 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8881 /* Table8881 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8883 /* Table8883 */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8885 /* Table8885 */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8887 /* Table8887 */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8889 /* Table8889 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8891 /* Table8891 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8893 /* Table8893 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8895 /* Table8895 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8897 /* Table8897 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8899 /* Table8899 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8901 /* Table8901 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8903 /* Table8903 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8905 /* Table8905 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8907 /* Table8907 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8909 /* Table8909 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8911 /* Table8911 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8913 /* Table8913 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8915 /* Table8915 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8917 /* Table8917 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8919 /* Table8919 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8921 /* Table8921 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8923 /* Table8923 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8925 /* Table8925 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8927 /* Table8927 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8929 /* Table8929 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8931 /* Table8931 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8933 /* Table8933 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8935 /* Table8935 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8937 /* Table8937 */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8939 /* Table8939 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8941 /* Table8941 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8943 /* Table8943 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8945 /* Table8945 */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8947 /* Table8947 */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8949 /* Table8949 */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8951 /* Table8951 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8953 /* Table8953 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8955 /* Table8955 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8957 /* Table8957 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8959 /* Table8959 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8961 /* Table8961 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8963 /* Table8963 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8965 /* Table8965 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8967 /* Table8967 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8969 /* Table8969 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8971 /* Table8971 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8973 /* Table8973 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8975 /* Table8975 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8977 /* Table8977 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8979 /* Table8979 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8981 /* Table8981 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8983 /* Table8983 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8985 /* Table8985 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8987 /* Table8987 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8989 /* Table8989 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8991 /* Table8991 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8993 /* Table8993 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8995 /* Table8995 */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8997 /* Table8997 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    8999 /* Table8999 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9001 /* Table9001 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9003 /* Table9003 */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9005 /* Table9005 */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9007 /* Table9007 */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9009 /* Table9009 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9011 /* Table9011 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9013 /* Table9013 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9015 /* Table9015 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9017 /* Table9017 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9019 /* Table9019 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9021 /* Table9021 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9023 /* Table9023 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9025 /* Table9025 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9027 /* Table9027 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9029 /* Table9029 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9031 /* Table9031 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9033 /* Table9033 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9035 /* Table9035 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9037 /* Table9037 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9039 /* Table9039 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9041 /* Table9041 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9043 /* Table9043 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9045 /* Table9045 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9047 /* Table9047 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9049 /* Table9049 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9051 /* Table9051 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9053 /* Table9053 */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9055 /* Table9055 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9057 /* Table9057 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9059 /* Table9059 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9061 /* Table9061 */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9063 /* Table9063 */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9065 /* Table9065 */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9067 /* Table9067 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9069 /* Table9069 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9071 /* Table9071 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9073 /* Table9073 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9075 /* Table9075 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9077 /* Table9077 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9079 /* Table9079 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9081 /* Table9081 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9083 /* Table9083 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9085 /* Table9085 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9087 /* Table9087 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9089 /* Table9089 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9091 /* Table9091 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9093 /* Table9093 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9095 /* Table9095 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9097 /* Table9097 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9099 /* Table9099 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9101 /* Table9101 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9103 /* Table9103 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9105 /* Table9105 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9107 /* Table9107 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9109 /* Table9109 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9111 /* Table9111 */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9113 /* Table9113 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9115 /* Table9115 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9117 /* Table9117 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9119 /* Table9119 */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9121 /* Table9121 */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9123 /* Table9123 */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9125 /* Table9125 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9127 /* Table9127 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9129 /* Table9129 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9131 /* Table9131 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9133 /* Table9133 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9135 /* Table9135 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9137 /* Table9137 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9139 /* Table9139 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9141 /* Table9141 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9143 /* Table9143 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9145 /* Table9145 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9147 /* Table9147 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9149 /* Table9149 */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9151 /* Table9151 */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9153 /* Table9153 */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9155 /* Table9155 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9157 /* Table9157 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9159 /* Table9159 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9161 /* Table9161 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9163 /* Table9163 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9165 /* Table9165 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9167 /* Table9167 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9169 /* Table9169 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9171 /* Table9171 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9173 /* Table9173 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9175 /* Table9175 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9177 /* Table9177 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9179 /* Table9179 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9181 /* Table9181 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9183 /* Table9183 */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9185 /* Table9185 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9187 /* Table9187 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9189 /* Table9189 */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9191 /* Table9191 */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9193 /* Table9193 */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9195 /* Table9195 */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9197 /* Table9197 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9199 /* Table9199 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9201 /* Table9201 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9203 /* Table9203 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9205 /* Table9205 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9207 /* Table9207 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9209 /* Table9209 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9211 /* Table9211 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9213 /* Table9213 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9215 /* Table9215 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9217 /* Table9217 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9219 /* Table9219 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9221 /* Table9221 */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9223 /* Table9223 */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9225 /* Table9225 */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9227 /* Table9227 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9229 /* Table9229 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9231 /* Table9231 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9233 /* Table9233 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9235 /* Table9235 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9237 /* Table9237 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9239 /* Table9239 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9241 /* Table9241 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9243 /* Table9243 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9245 /* Table9245 */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9247 /* Table9247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9249 /* Table9249 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9251 /* Table9251 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9253 /* Table9253 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9255 /* Table9255 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9257 /* Table9257 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9259 /* Table9259 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9261 /* Table9261 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9263 /* Table9263 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9265 /* Table9265 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9267 /* Table9267 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9269 /* Table9269 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9271 /* Table9271 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9273 /* Table9273 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9275 /* Table9275 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9277 /* Table9277 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9279 /* Table9279 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9281 /* Table9281 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9283 /* Table9283 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9285 /* Table9285 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9287 /* Table9287 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9289 /* Table9289 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9291 /* Table9291 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9293 /* Table9293 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9295 /* Table9295 */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9297 /* Table9297 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9299 /* Table9299 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9301 /* Table9301 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9303 /* Table9303 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9305 /* Table9305 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9307 /* Table9307 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9309 /* Table9309 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9311 /* Table9311 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9313 /* Table9313 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9315 /* Table9315 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9317 /* Table9317 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9319 /* Table9319 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9321 /* Table9321 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9323 /* Table9323 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9325 /* Table9325 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9327 /* Table9327 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9329 /* Table9329 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9331 /* Table9331 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9333 /* Table9333 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9335 /* Table9335 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9337 /* Table9337 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9339 /* Table9339 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9341 /* Table9341 */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9343 /* Table9343 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9345 /* Table9345 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9347 /* Table9347 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9349 /* Table9349 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9351 /* Table9351 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9353 /* Table9353 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9355 /* Table9355 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9357 /* Table9357 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9359 /* Table9359 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9361 /* Table9361 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9363 /* Table9363 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9365 /* Table9365 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9367 /* Table9367 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9369 /* Table9369 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9371 /* Table9371 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9373 /* Table9373 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9375 /* Table9375 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9377 /* Table9377 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9379 /* Table9379 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9381 /* Table9381 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9383 /* Table9383 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9385 /* Table9385 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9387 /* Table9387 */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9389 /* Table9389 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9391 /* Table9391 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9393 /* Table9393 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9395 /* Table9395 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9397 /* Table9397 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9399 /* Table9399 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9401 /* Table9401 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9403 /* Table9403 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9405 /* Table9405 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9407 /* Table9407 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9409 /* Table9409 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9411 /* Table9411 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9413 /* Table9413 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9415 /* Table9415 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9417 /* Table9417 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9419 /* Table9419 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9421 /* Table9421 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9423 /* Table9423 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9425 /* Table9425 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9427 /* Table9427 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9429 /* Table9429 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9431 /* Table9431 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9433 /* Table9433 */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9435 /* Table9435 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9437 /* Table9437 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9439 /* Table9439 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9441 /* Table9441 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9443 /* Table9443 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9445 /* Table9445 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9447 /* Table9447 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9449 /* Table9449 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9451 /* Table9451 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9453 /* Table9453 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9455 /* Table9455 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9457 /* Table9457 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9459 /* Table9459 */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9461 /* Table9461 */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9463 /* Table9463 */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9465 /* Table9465 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9467 /* Table9467 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9469 /* Table9469 */
   },
   /* 0x29 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9471 /* Table9471 */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9473 /* Table9473 */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9475 /* Table9475 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9477 /* Table9477 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9479 /* Table9479 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9481 /* Table9481 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9483 /* Table9483 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9485 /* Table9485 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9487 /* Table9487 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9489 /* Table9489 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9491 /* Table9491 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9493 /* Table9493 */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9495 /* Table9495 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9497 /* Table9497 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9499 /* Table9499 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9501 /* Table9501 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9503 /* Table9503 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9505 /* Table9505 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9507 /* Table9507 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9509 /* Table9509 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9511 /* Table9511 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9513 /* Table9513 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9515 /* Table9515 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9517 /* Table9517 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9519 /* Table9519 */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9521 /* Table9521 */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9523 /* Table9523 */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9525 /* Table9525 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9527 /* Table9527 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9529 /* Table9529 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9531 /* Table9531 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9533 /* Table9533 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9535 /* Table9535 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9537 /* Table9537 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9539 /* Table9539 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9541 /* Table9541 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9543 /* Table9543 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9545 /* Table9545 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9547 /* Table9547 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9549 /* Table9549 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9551 /* Table9551 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9553 /* Table9553 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9555 /* Table9555 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9557 /* Table9557 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9559 /* Table9559 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9561 /* Table9561 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9563 /* Table9563 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9565 /* Table9565 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9567 /* Table9567 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9569 /* Table9569 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9571 /* Table9571 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9573 /* Table9573 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9575 /* Table9575 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9577 /* Table9577 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9579 /* Table9579 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9581 /* Table9581 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9583 /* Table9583 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9585 /* Table9585 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9587 /* Table9587 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9589 /* Table9589 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9591 /* Table9591 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9593 /* Table9593 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9595 /* Table9595 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9597 /* Table9597 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9599 /* Table9599 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9601 /* Table9601 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9603 /* Table9603 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9605 /* Table9605 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9607 /* Table9607 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9609 /* Table9609 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9611 /* Table9611 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9613 /* Table9613 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9615 /* Table9615 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9617 /* Table9617 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9619 /* Table9619 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9621 /* Table9621 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9623 /* Table9623 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9625 /* Table9625 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9627 /* Table9627 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9629 /* Table9629 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9631 /* Table9631 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9633 /* Table9633 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9635 /* Table9635 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9637 /* Table9637 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9639 /* Table9639 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9641 /* Table9641 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9643 /* Table9643 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9645 /* Table9645 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9647 /* Table9647 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9649 /* Table9649 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9651 /* Table9651 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9653 /* Table9653 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9655 /* Table9655 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9657 /* Table9657 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9659 /* Table9659 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9661 /* Table9661 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9663 /* Table9663 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9665 /* Table9665 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9667 /* Table9667 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9669 /* Table9669 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9671 /* Table9671 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9673 /* Table9673 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9675 /* Table9675 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9677 /* Table9677 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9679 /* Table9679 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9681 /* Table9681 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9683 /* Table9683 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9685 /* Table9685 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9687 /* Table9687 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9689 /* Table9689 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9691 /* Table9691 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9693 /* Table9693 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9695 /* Table9695 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9697 /* Table9697 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9699 /* Table9699 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9701 /* Table9701 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9703 /* Table9703 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9705 /* Table9705 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9707 /* Table9707 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9709 /* Table9709 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9711 /* Table9711 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9713 /* Table9713 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9715 /* Table9715 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9717 /* Table9717 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9719 /* Table9719 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9721 /* Table9721 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9723 /* Table9723 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9725 /* Table9725 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9727 /* Table9727 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9729 /* Table9729 */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9731 /* Table9731 */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9733 /* Table9733 */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9735 /* Table9735 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9737 /* Table9737 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9739 /* Table9739 */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9741 /* Table9741 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9743 /* Table9743 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9745 /* Table9745 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9747 /* Table9747 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9749 /* Table9749 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9751 /* Table9751 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9753 /* Table9753 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9755 /* Table9755 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9757 /* Table9757 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9759 /* Table9759 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9761 /* Table9761 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9763 /* Table9763 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9765 /* Table9765 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9767 /* Table9767 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9769 /* Table9769 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9771 /* Table9771 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9773 /* Table9773 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9775 /* Table9775 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9777 /* Table9777 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9779 /* Table9779 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9781 /* Table9781 */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9783 /* Table9783 */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9785 /* Table9785 */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9787 /* Table9787 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9789 /* Table9789 */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9791 /* Table9791 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9793 /* Table9793 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9795 /* Table9795 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9797 /* Table9797 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9799 /* Table9799 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9801 /* Table9801 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9803 /* Table9803 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9805 /* Table9805 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9807 /* Table9807 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9809 /* Table9809 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9811 /* Table9811 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9813 /* Table9813 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9815 /* Table9815 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9817 /* Table9817 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9819 /* Table9819 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9821 /* Table9821 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9823 /* Table9823 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9825 /* Table9825 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9827 /* Table9827 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9829 /* Table9829 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9831 /* Table9831 */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9833 /* Table9833 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9835 /* Table9835 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9837 /* Table9837 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9839 /* Table9839 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9841 /* Table9841 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9843 /* Table9843 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9845 /* Table9845 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9847 /* Table9847 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9849 /* Table9849 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9851 /* Table9851 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9853 /* Table9853 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9855 /* Table9855 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9857 /* Table9857 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9859 /* Table9859 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9861 /* Table9861 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9863 /* Table9863 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9865 /* Table9865 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9867 /* Table9867 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9869 /* Table9869 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9871 /* Table9871 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9873 /* Table9873 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9875 /* Table9875 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9877 /* Table9877 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9879 /* Table9879 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9881 /* Table9881 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9883 /* Table9883 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9885 /* Table9885 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9887 /* Table9887 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9889 /* Table9889 */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9891 /* Table9891 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9893 /* Table9893 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9895 /* Table9895 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9897 /* Table9897 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9899 /* Table9899 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9901 /* Table9901 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9903 /* Table9903 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9905 /* Table9905 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9907 /* Table9907 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9909 /* Table9909 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9911 /* Table9911 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9913 /* Table9913 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9915 /* Table9915 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9917 /* Table9917 */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9919 /* Table9919 */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9921 /* Table9921 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9923 /* Table9923 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9925 /* Table9925 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9927 /* Table9927 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9929 /* Table9929 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9931 /* Table9931 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9933 /* Table9933 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9935 /* Table9935 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9937 /* Table9937 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9939 /* Table9939 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9941 /* Table9941 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9943 /* Table9943 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9945 /* Table9945 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9947 /* Table9947 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9949 /* Table9949 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9951 /* Table9951 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9953 /* Table9953 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9955 /* Table9955 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9957 /* Table9957 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9959 /* Table9959 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9961 /* Table9961 */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9963 /* Table9963 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9965 /* Table9965 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9967 /* Table9967 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9969 /* Table9969 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9971 /* Table9971 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9973 /* Table9973 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9975 /* Table9975 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9977 /* Table9977 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9979 /* Table9979 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9981 /* Table9981 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9983 /* Table9983 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9985 /* Table9985 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9987 /* Table9987 */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9989 /* Table9989 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9991 /* Table9991 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9993 /* Table9993 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9995 /* Table9995 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9997 /* Table9997 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    9999 /* Table9999 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10001 /* Table10001 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10003 /* Table10003 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10005 /* Table10005 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10007 /* Table10007 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10009 /* Table10009 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10011 /* Table10011 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10013 /* Table10013 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10015 /* Table10015 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10017 /* Table10017 */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10019 /* Table10019 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10021 /* Table10021 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10023 /* Table10023 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10025 /* Table10025 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10027 /* Table10027 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10029 /* Table10029 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10031 /* Table10031 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10033 /* Table10033 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10035 /* Table10035 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10037 /* Table10037 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10039 /* Table10039 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10041 /* Table10041 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_XS_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10043 /* Table10043 */
   },
   /* 0x12 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10045 /* Table10045 */
   },
   /* 0x13 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10047 /* Table10047 */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10049 /* Table10049 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10051 /* Table10051 */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10053 /* Table10053 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10055 /* Table10055 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10057 /* Table10057 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10059 /* Table10059 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10061 /* Table10061 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10063 /* Table10063 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10065 /* Table10065 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10067 /* Table10067 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10069 /* Table10069 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10071 /* Table10071 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10073 /* Table10073 */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10075 /* Table10075 */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10077 /* Table10077 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10079 /* Table10079 */
   },
   /* 0x23 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10081 /* Table10081 */
   },
   /* 0x24 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10083 /* Table10083 */
   },
   /* 0x25 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10085 /* Table10085 */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10087 /* Table10087 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10089 /* Table10089 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10091 /* Table10091 */
   },
   /* 0x34 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10093 /* Table10093 */
   },
   /* 0x35 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10095 /* Table10095 */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10097 /* Table10097 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10099 /* Table10099 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10101 /* Table10101 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10103 /* Table10103 */
   },
   /* 0x3c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10105 /* Table10105 */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10107 /* Table10107 */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10109 /* Table10109 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10111 /* Table10111 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10113 /* Table10113 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10115 /* Table10115 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10117 /* Table10117 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10119 /* Table10119 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10121 /* Table10121 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10123 /* Table10123 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10125 /* Table10125 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10127 /* Table10127 */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10129 /* Table10129 */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10131 /* Table10131 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10133 /* Table10133 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10135 /* Table10135 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10137 /* Table10137 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10139 /* Table10139 */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10141 /* Table10141 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10143 /* Table10143 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10145 /* Table10145 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10147 /* Table10147 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10149 /* Table10149 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10151 /* Table10151 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10153 /* Table10153 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10155 /* Table10155 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10157 /* Table10157 */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10159 /* Table10159 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10161 /* Table10161 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10163 /* Table10163 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10165 /* Table10165 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10167 /* Table10167 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10169 /* Table10169 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10171 /* Table10171 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10173 /* Table10173 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10175 /* Table10175 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10177 /* Table10177 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10179 /* Table10179 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10181 /* Table10181 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10183 /* Table10183 */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10185 /* Table10185 */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10187 /* Table10187 */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10189 /* Table10189 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10191 /* Table10191 */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10193 /* Table10193 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10195 /* Table10195 */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10197 /* Table10197 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10199 /* Table10199 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10201 /* Table10201 */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10203 /* Table10203 */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10205 /* Table10205 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10207 /* Table10207 */
   },
   /* 0x45 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10209 /* Table10209 */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10211 /* Table10211 */
   },
   /* 0x47 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10213 /* Table10213 */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10215 /* Table10215 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10217 /* Table10217 */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10219 /* Table10219 */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10221 /* Table10221 */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10223 /* Table10223 */
   },
   /* 0x65 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10225 /* Table10225 */
   },
   /* 0x66 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10227 /* Table10227 */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10229 /* Table10229 */
   },
   /* 0x77 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10231 /* Table10231 */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10233 /* Table10233 */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10235 /* Table10235 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10237 /* Table10237 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10239 /* Table10239 */
   },
   /* 0x89 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10241 /* Table10241 */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10243 /* Table10243 */
   },
   /* 0x8b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10245 /* Table10245 */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10247 /* Table10247 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10249 /* Table10249 */
   },
   /* 0xa8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10251 /* Table10251 */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10253 /* Table10253 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10255 /* Table10255 */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10257 /* Table10257 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10259 /* Table10259 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10261 /* Table10261 */
   },
   /* 0xb8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10263 /* Table10263 */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10265 /* Table10265 */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10267 /* Table10267 */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10269 /* Table10269 */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10271 /* Table10271 */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10273 /* Table10273 */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10275 /* Table10275 */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10277 /* Table10277 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 },
 /* IC_OF */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
, };
static const uint8_t index_x86DisassemblerThreeByte38Opcodes[] = {
1, 2, 3, 4, 0, 5, 6, 7, 8, 0, 9, 10, 11, 12, 13, 14, 15, 16, 0, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 0, 0, 0, 28, 0, 0, 0, 29, 0, 30, 0, 31, 0, 32, 0, 33, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 0, 0, 42, 0, 0, 0, 43, 0, 0, 0, 44, 0, 0, 0, 45, 0, 46, 0, 47, 0, 0, 0, 48, 0, 0, 0, 49, 0, 0, 0, 50, 0, 0, 0, 51, 0, 0, 0, 52, 0, 0, 0, 53, 0, 0, 0, 54, 0, 0, 0, 55, 0, 0, 0, 56, 0, 0, 0, 57, 0, 0, 0, 58, 0, 0, 0, 59, 0, 0, 0, 60, 0, 0, 0, 61, 0, 0, 0, 62, 0, 0, 0, 63, 0, 0, 0, 64, 0, 0, 0, 65, 0, 0, 0, 66, 0, 0, 0, 67, 0, 0, 0, 68, 0, 0, 0, 69, 0, 0, 0, 70, 0, 71, 0, 72, 0, 0, 0, 73, };
static const struct OpcodeDecision x86DisassemblerThreeByte3AOpcodes[] = {
 /* IC */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10279 /* Table10279 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10279 /* Table10279 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10283 /* Table10283 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10285 /* Table10285 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10287 /* Table10287 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10289 /* Table10289 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10291 /* Table10291 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10293 /* Table10293 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10295 /* Table10295 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10297 /* Table10297 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10299 /* Table10299 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10301 /* Table10301 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10303 /* Table10303 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10305 /* Table10305 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10307 /* Table10307 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10309 /* Table10309 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10311 /* Table10311 */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10313 /* Table10313 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10315 /* Table10315 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10317 /* Table10317 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10319 /* Table10319 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10321 /* Table10321 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10323 /* Table10323 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10325 /* Table10325 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10327 /* Table10327 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10329 /* Table10329 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10279 /* Table10279 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_OPSIZE_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10283 /* Table10283 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10285 /* Table10285 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10287 /* Table10287 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10289 /* Table10289 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10291 /* Table10291 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10293 /* Table10293 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10295 /* Table10295 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10297 /* Table10297 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10299 /* Table10299 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10301 /* Table10301 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10303 /* Table10303 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10305 /* Table10305 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10307 /* Table10307 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10309 /* Table10309 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10311 /* Table10311 */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10313 /* Table10313 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10315 /* Table10315 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10317 /* Table10317 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10319 /* Table10319 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10321 /* Table10321 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10323 /* Table10323 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10325 /* Table10325 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10327 /* Table10327 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10329 /* Table10329 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10279 /* Table10279 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10279 /* Table10279 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10279 /* Table10279 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10283 /* Table10283 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10285 /* Table10285 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10287 /* Table10287 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10289 /* Table10289 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10291 /* Table10291 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10293 /* Table10293 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10295 /* Table10295 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10297 /* Table10297 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10299 /* Table10299 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10301 /* Table10301 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10303 /* Table10303 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10305 /* Table10305 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10307 /* Table10307 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10309 /* Table10309 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10311 /* Table10311 */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10313 /* Table10313 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10315 /* Table10315 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10317 /* Table10317 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10319 /* Table10319 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10321 /* Table10321 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10323 /* Table10323 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10325 /* Table10325 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10327 /* Table10327 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10329 /* Table10329 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10283 /* Table10283 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10285 /* Table10285 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10287 /* Table10287 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10289 /* Table10289 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10291 /* Table10291 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10293 /* Table10293 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10295 /* Table10295 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10297 /* Table10297 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10299 /* Table10299 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10301 /* Table10301 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10303 /* Table10303 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10305 /* Table10305 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10307 /* Table10307 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10309 /* Table10309 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10311 /* Table10311 */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10313 /* Table10313 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10315 /* Table10315 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10317 /* Table10317 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10319 /* Table10319 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10321 /* Table10321 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10323 /* Table10323 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10325 /* Table10325 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10327 /* Table10327 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10329 /* Table10329 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10279 /* Table10279 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_OPSIZE_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10283 /* Table10283 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10285 /* Table10285 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10287 /* Table10287 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10289 /* Table10289 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10291 /* Table10291 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10293 /* Table10293 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10295 /* Table10295 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10297 /* Table10297 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10299 /* Table10299 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10301 /* Table10301 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10303 /* Table10303 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10305 /* Table10305 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10307 /* Table10307 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10309 /* Table10309 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10311 /* Table10311 */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10313 /* Table10313 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10315 /* Table10315 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10317 /* Table10317 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10319 /* Table10319 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10321 /* Table10321 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10323 /* Table10323 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10325 /* Table10325 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10327 /* Table10327 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10329 /* Table10329 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10279 /* Table10279 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10279 /* Table10279 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10279 /* Table10279 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10279 /* Table10279 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10283 /* Table10283 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10285 /* Table10285 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10287 /* Table10287 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10289 /* Table10289 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10291 /* Table10291 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10293 /* Table10293 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10295 /* Table10295 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10297 /* Table10297 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10299 /* Table10299 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10301 /* Table10301 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10331 /* Table10331 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10305 /* Table10305 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10307 /* Table10307 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10309 /* Table10309 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10333 /* Table10333 */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10313 /* Table10313 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10315 /* Table10315 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10317 /* Table10317 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10319 /* Table10319 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10321 /* Table10321 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10323 /* Table10323 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10325 /* Table10325 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10327 /* Table10327 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10281 /* Table10281 */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10329 /* Table10329 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10335 /* Table10335 */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10337 /* Table10337 */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10339 /* Table10339 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10341 /* Table10341 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10343 /* Table10343 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10345 /* Table10345 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10347 /* Table10347 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10349 /* Table10349 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10351 /* Table10351 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10353 /* Table10353 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10355 /* Table10355 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10357 /* Table10357 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10359 /* Table10359 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10361 /* Table10361 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10363 /* Table10363 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10365 /* Table10365 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10367 /* Table10367 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10369 /* Table10369 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10371 /* Table10371 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10373 /* Table10373 */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10375 /* Table10375 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10377 /* Table10377 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10379 /* Table10379 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10381 /* Table10381 */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10383 /* Table10383 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10385 /* Table10385 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10387 /* Table10387 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10389 /* Table10389 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10391 /* Table10391 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10393 /* Table10393 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10395 /* Table10395 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10397 /* Table10397 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10399 /* Table10399 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10401 /* Table10401 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10403 /* Table10403 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10405 /* Table10405 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10407 /* Table10407 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10409 /* Table10409 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10411 /* Table10411 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10413 /* Table10413 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10415 /* Table10415 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10417 /* Table10417 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10419 /* Table10419 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10421 /* Table10421 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10423 /* Table10423 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10425 /* Table10425 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10427 /* Table10427 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10429 /* Table10429 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10431 /* Table10431 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10433 /* Table10433 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10435 /* Table10435 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10437 /* Table10437 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10439 /* Table10439 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10441 /* Table10441 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10443 /* Table10443 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10445 /* Table10445 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10447 /* Table10447 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10449 /* Table10449 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_W_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10451 /* Table10451 */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10337 /* Table10337 */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10339 /* Table10339 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10341 /* Table10341 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10343 /* Table10343 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10345 /* Table10345 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10347 /* Table10347 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10349 /* Table10349 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10351 /* Table10351 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10353 /* Table10353 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10355 /* Table10355 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10357 /* Table10357 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10359 /* Table10359 */
   },
   /* 0x15 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10361 /* Table10361 */
   },
   /* 0x16 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10453 /* Table10453 */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10365 /* Table10365 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10367 /* Table10367 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10369 /* Table10369 */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10371 /* Table10371 */
   },
   /* 0x22 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10455 /* Table10455 */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10457 /* Table10457 */
   },
   /* 0x31 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10459 /* Table10459 */
   },
   /* 0x32 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10461 /* Table10461 */
   },
   /* 0x33 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10463 /* Table10463 */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10383 /* Table10383 */
   },
   /* 0x41 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10385 /* Table10385 */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10387 /* Table10387 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10389 /* Table10389 */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10465 /* Table10465 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10467 /* Table10467 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10395 /* Table10395 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10397 /* Table10397 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10399 /* Table10399 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10469 /* Table10469 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10471 /* Table10471 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10473 /* Table10473 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10475 /* Table10475 */
   },
   /* 0x60 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10409 /* Table10409 */
   },
   /* 0x61 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10411 /* Table10411 */
   },
   /* 0x62 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10413 /* Table10413 */
   },
   /* 0x63 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10415 /* Table10415 */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10477 /* Table10477 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10479 /* Table10479 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10481 /* Table10481 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10483 /* Table10483 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10485 /* Table10485 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10487 /* Table10487 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10489 /* Table10489 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10491 /* Table10491 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10493 /* Table10493 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10495 /* Table10495 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10497 /* Table10497 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10499 /* Table10499 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10501 /* Table10501 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10503 /* Table10503 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10505 /* Table10505 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10507 /* Table10507 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10449 /* Table10449 */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10509 /* Table10509 */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10511 /* Table10511 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10513 /* Table10513 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10515 /* Table10515 */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10517 /* Table10517 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10519 /* Table10519 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10347 /* Table10347 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10349 /* Table10349 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10521 /* Table10521 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10523 /* Table10523 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10525 /* Table10525 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10527 /* Table10527 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10529 /* Table10529 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10531 /* Table10531 */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10533 /* Table10533 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10535 /* Table10535 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10537 /* Table10537 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10539 /* Table10539 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10541 /* Table10541 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10543 /* Table10543 */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10545 /* Table10545 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10547 /* Table10547 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10549 /* Table10549 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10551 /* Table10551 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10553 /* Table10553 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10555 /* Table10555 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10557 /* Table10557 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10559 /* Table10559 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10561 /* Table10561 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10563 /* Table10563 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10565 /* Table10565 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10421 /* Table10421 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10423 /* Table10423 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10567 /* Table10567 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10569 /* Table10569 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10429 /* Table10429 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10431 /* Table10431 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10571 /* Table10571 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10573 /* Table10573 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10437 /* Table10437 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10439 /* Table10439 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10575 /* Table10575 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10577 /* Table10577 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10445 /* Table10445 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10447 /* Table10447 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10579 /* Table10579 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10581 /* Table10581 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10509 /* Table10509 */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10511 /* Table10511 */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10513 /* Table10513 */
   },
   /* 0x06 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10515 /* Table10515 */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10517 /* Table10517 */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10519 /* Table10519 */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10347 /* Table10347 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10349 /* Table10349 */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10521 /* Table10521 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10523 /* Table10523 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10525 /* Table10525 */
   },
   /* 0x0f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10527 /* Table10527 */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10529 /* Table10529 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10531 /* Table10531 */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10533 /* Table10533 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10535 /* Table10535 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10537 /* Table10537 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10539 /* Table10539 */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10541 /* Table10541 */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10543 /* Table10543 */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10583 /* Table10583 */
   },
   /* 0x49 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10585 /* Table10585 */
   },
   /* 0x4a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10549 /* Table10549 */
   },
   /* 0x4b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10551 /* Table10551 */
   },
   /* 0x4c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10553 /* Table10553 */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10587 /* Table10587 */
   },
   /* 0x5d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10589 /* Table10589 */
   },
   /* 0x5e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10591 /* Table10591 */
   },
   /* 0x5f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10593 /* Table10593 */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10595 /* Table10595 */
   },
   /* 0x69 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10597 /* Table10597 */
   },
   /* 0x6a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10481 /* Table10481 */
   },
   /* 0x6b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10483 /* Table10483 */
   },
   /* 0x6c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10599 /* Table10599 */
   },
   /* 0x6d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10601 /* Table10601 */
   },
   /* 0x6e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10489 /* Table10489 */
   },
   /* 0x6f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10491 /* Table10491 */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10603 /* Table10603 */
   },
   /* 0x79 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10605 /* Table10605 */
   },
   /* 0x7a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10497 /* Table10497 */
   },
   /* 0x7b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10499 /* Table10499 */
   },
   /* 0x7c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10607 /* Table10607 */
   },
   /* 0x7d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10609 /* Table10609 */
   },
   /* 0x7e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10505 /* Table10505 */
   },
   /* 0x7f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10507 /* Table10507 */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10611 /* Table10611 */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10613 /* Table10613 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10615 /* Table10615 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10617 /* Table10617 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10619 /* Table10619 */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10621 /* Table10621 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10623 /* Table10623 */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10611 /* Table10611 */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10625 /* Table10625 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10613 /* Table10613 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10627 /* Table10627 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10629 /* Table10629 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10619 /* Table10619 */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10631 /* Table10631 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10633 /* Table10633 */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10635 /* Table10635 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10637 /* Table10637 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10639 /* Table10639 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10641 /* Table10641 */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10611 /* Table10611 */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10613 /* Table10613 */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10643 /* Table10643 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10645 /* Table10645 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10619 /* Table10619 */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10647 /* Table10647 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10649 /* Table10649 */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10651 /* Table10651 */
   },
   /* 0x04 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10653 /* Table10653 */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10655 /* Table10655 */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10657 /* Table10657 */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10659 /* Table10659 */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10661 /* Table10661 */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10663 /* Table10663 */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10665 /* Table10665 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10667 /* Table10667 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10669 /* Table10669 */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10671 /* Table10671 */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10673 /* Table10673 */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10675 /* Table10675 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10677 /* Table10677 */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10679 /* Table10679 */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10681 /* Table10681 */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10683 /* Table10683 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10685 /* Table10685 */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10687 /* Table10687 */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10689 /* Table10689 */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10691 /* Table10691 */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10693 /* Table10693 */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10695 /* Table10695 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10697 /* Table10697 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10699 /* Table10699 */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10701 /* Table10701 */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10703 /* Table10703 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10705 /* Table10705 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10707 /* Table10707 */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10709 /* Table10709 */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10711 /* Table10711 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10713 /* Table10713 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10715 /* Table10715 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10717 /* Table10717 */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10719 /* Table10719 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10721 /* Table10721 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10723 /* Table10723 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10725 /* Table10725 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10727 /* Table10727 */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10729 /* Table10729 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10731 /* Table10731 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10733 /* Table10733 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10735 /* Table10735 */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10737 /* Table10737 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10739 /* Table10739 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10741 /* Table10741 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10743 /* Table10743 */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10745 /* Table10745 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10747 /* Table10747 */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10749 /* Table10749 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10751 /* Table10751 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10753 /* Table10753 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10755 /* Table10755 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10757 /* Table10757 */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_K */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10759 /* Table10759 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10761 /* Table10761 */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10763 /* Table10763 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10765 /* Table10765 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10767 /* Table10767 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10769 /* Table10769 */
   },
   /* 0x3f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10771 /* Table10771 */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10773 /* Table10773 */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10775 /* Table10775 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10777 /* Table10777 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10779 /* Table10779 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10781 /* Table10781 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10783 /* Table10783 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10785 /* Table10785 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10787 /* Table10787 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10789 /* Table10789 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10791 /* Table10791 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10793 /* Table10793 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10795 /* Table10795 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10797 /* Table10797 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10799 /* Table10799 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10801 /* Table10801 */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10803 /* Table10803 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10805 /* Table10805 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10807 /* Table10807 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10809 /* Table10809 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10811 /* Table10811 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10813 /* Table10813 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10815 /* Table10815 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L_W_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10817 /* Table10817 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10819 /* Table10819 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10821 /* Table10821 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10823 /* Table10823 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_K_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10825 /* Table10825 */
   },
   /* 0x1f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10827 /* Table10827 */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10829 /* Table10829 */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_KZ_B */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10831 /* Table10831 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10833 /* Table10833 */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_W_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10835 /* Table10835 */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10837 /* Table10837 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10839 /* Table10839 */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10841 /* Table10841 */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_EVEX_L2_W_OPSIZE_KZ */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10843 /* Table10843 */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10845 /* Table10845 */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10847 /* Table10847 */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 },
 /* IC_OF */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
, };
static const uint8_t index_x86DisassemblerThreeByte3AOpcodes[] = {
1, 2, 3, 4, 0, 5, 6, 7, 0, 0, 8, 9, 10, 11, 12, 13, 14, 0, 0, 15, 16, 17, 0, 0, 18, 19, 0, 0, 20, 21, 0, 0, 0, 22, 0, 0, 0, 23, 0, 0, 0, 24, 0, 0, 0, 25, 0, 0, 0, 26, 0, 0, 0, 27, 0, 0, 0, 28, 0, 0, 0, 29, 0, 0, 0, 30, 0, 0, 0, 31, 0, 0, 0, 32, 0, 0, 0, 33, 0, 0, 0, 34, 0, 0, 0, 35, 0, 0, 0, 36, 0, 0, 0, 37, 0, 0, 0, 38, 0, 0, 0, 39, 0, 0, 0, 40, 0, 0, 0, 41, 0, 0, 0, 42, 0, 0, 0, 43, 0, 0, 0, 44, 0, 0, 0, 45, 0, 0, 0, 46, 0, 0, 0, 47, 0, 0, 0, 48, 0, 0, 0, 49, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 50, 0, 0, 0, 51, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 52, 0, 0, 0, 53, };
static const struct OpcodeDecision x86DisassemblerXOP8Opcodes[] = {
 /* IC_VEX */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10849 /* Table10849 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10851 /* Table10851 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10853 /* Table10853 */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10855 /* Table10855 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10857 /* Table10857 */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10859 /* Table10859 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10861 /* Table10861 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10863 /* Table10863 */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10865 /* Table10865 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10867 /* Table10867 */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10869 /* Table10869 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10871 /* Table10871 */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10873 /* Table10873 */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10875 /* Table10875 */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10877 /* Table10877 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10879 /* Table10879 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10881 /* Table10881 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10883 /* Table10883 */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10885 /* Table10885 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10887 /* Table10887 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10889 /* Table10889 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10891 /* Table10891 */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10893 /* Table10893 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10895 /* Table10895 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10897 /* Table10897 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10899 /* Table10899 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_W */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10849 /* Table10849 */
   },
   /* 0x86 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10851 /* Table10851 */
   },
   /* 0x87 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10853 /* Table10853 */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10855 /* Table10855 */
   },
   /* 0x8f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10857 /* Table10857 */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10859 /* Table10859 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10861 /* Table10861 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10863 /* Table10863 */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10865 /* Table10865 */
   },
   /* 0x9f */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10867 /* Table10867 */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10901 /* Table10901 */
   },
   /* 0xa3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10903 /* Table10903 */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10873 /* Table10873 */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10875 /* Table10875 */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10877 /* Table10877 */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10879 /* Table10879 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10881 /* Table10881 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10883 /* Table10883 */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10885 /* Table10885 */
   },
   /* 0xcd */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10887 /* Table10887 */
   },
   /* 0xce */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10889 /* Table10889 */
   },
   /* 0xcf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10891 /* Table10891 */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10893 /* Table10893 */
   },
   /* 0xed */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10895 /* Table10895 */
   },
   /* 0xee */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10897 /* Table10897 */
   },
   /* 0xef */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10899 /* Table10899 */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10905 /* Table10905 */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L_W */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10907 /* Table10907 */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_OF */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
, };
static const uint8_t index_x86DisassemblerXOP8Opcodes[] = {
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, };
static const struct OpcodeDecision x86DisassemblerXOP9Opcodes[] = {
 /* IC_VEX */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    10909 /* Table10909 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    10925 /* Table10925 */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10941 /* Table10941 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10943 /* Table10943 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10945 /* Table10945 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10947 /* Table10947 */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10949 /* Table10949 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10951 /* Table10951 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10953 /* Table10953 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10955 /* Table10955 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10957 /* Table10957 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10959 /* Table10959 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10961 /* Table10961 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10963 /* Table10963 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10965 /* Table10965 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10967 /* Table10967 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10969 /* Table10969 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10971 /* Table10971 */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10973 /* Table10973 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10975 /* Table10975 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10977 /* Table10977 */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10979 /* Table10979 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10981 /* Table10981 */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10983 /* Table10983 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10985 /* Table10985 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10987 /* Table10987 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10989 /* Table10989 */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10991 /* Table10991 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10993 /* Table10993 */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10995 /* Table10995 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10997 /* Table10997 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10999 /* Table10999 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11001 /* Table11001 */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_W */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11003 /* Table11003 */
   },
   /* 0x02 */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11019 /* Table11019 */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10941 /* Table10941 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10943 /* Table10943 */
   },
   /* 0x82 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10945 /* Table10945 */
   },
   /* 0x83 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10947 /* Table10947 */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11035 /* Table11035 */
   },
   /* 0x91 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11037 /* Table11037 */
   },
   /* 0x92 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11039 /* Table11039 */
   },
   /* 0x93 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11041 /* Table11041 */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11043 /* Table11043 */
   },
   /* 0x95 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11045 /* Table11045 */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11047 /* Table11047 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11049 /* Table11049 */
   },
   /* 0x98 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11051 /* Table11051 */
   },
   /* 0x99 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11053 /* Table11053 */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11055 /* Table11055 */
   },
   /* 0x9b */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11057 /* Table11057 */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10973 /* Table10973 */
   },
   /* 0xc2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10975 /* Table10975 */
   },
   /* 0xc3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10977 /* Table10977 */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10979 /* Table10979 */
   },
   /* 0xc7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10981 /* Table10981 */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10983 /* Table10983 */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10985 /* Table10985 */
   },
   /* 0xd2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10987 /* Table10987 */
   },
   /* 0xd3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10989 /* Table10989 */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10991 /* Table10991 */
   },
   /* 0xd7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10993 /* Table10993 */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10995 /* Table10995 */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10997 /* Table10997 */
   },
   /* 0xe2 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    10999 /* Table10999 */
   },
   /* 0xe3 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11001 /* Table11001 */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11059 /* Table11059 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11061 /* Table11061 */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_L_W */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11059 /* Table11059 */
   },
   /* 0x81 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11061 /* Table11061 */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_OF */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
, };
static const uint8_t index_x86DisassemblerXOP9Opcodes[] = {
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, };
static const struct OpcodeDecision x86DisassemblerXOPAOpcodes[] = {
 /* IC_VEX */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11063 /* Table11063 */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_VEX_W */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11065 /* Table11065 */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_OF */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
, };
static const uint8_t index_x86DisassemblerXOPAOpcodes[] = {
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, };
static const struct OpcodeDecision x86DisassemblerT3DNOWOpcodes[] = {
 /* IC */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_OF */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11084 /* Table11084 */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11086 /* Table11086 */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11088 /* Table11088 */
   },
   /* 0x1d */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11090 /* Table11090 */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11092 /* Table11092 */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11094 /* Table11094 */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11096 /* Table11096 */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11098 /* Table11098 */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11100 /* Table11100 */
   },
   /* 0x97 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11102 /* Table11102 */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11104 /* Table11104 */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11106 /* Table11106 */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11108 /* Table11108 */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11110 /* Table11110 */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11112 /* Table11112 */
   },
   /* 0xa7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11114 /* Table11114 */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11116 /* Table11116 */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11118 /* Table11118 */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11120 /* Table11120 */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11122 /* Table11122 */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11124 /* Table11124 */
   },
   /* 0xb7 */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11126 /* Table11126 */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11128 /* Table11128 */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* struct ModRMDecision */
    MODRM_SPLITRM,
    11130 /* Table11130 */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_OPSIZE_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_OPSIZE_ADSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_XS */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_XD */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_64BIT_REXW_OPSIZE */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* struct ModRMDecision */
    MODRM_SPLITREG,
    11067 /* Table11067 */
   },
   /* 0x0e */
   { /* struct ModRMDecision */
    MODRM_ONEENTRY,
    11083 /* Table11083 */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
,  /* IC_OF */
 { /* struct OpcodeDecision */
  {
   /* 0x00 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x01 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x02 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x03 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x04 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x05 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x06 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x07 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x08 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x09 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x0f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x10 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x11 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x12 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x13 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x14 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x15 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x16 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x17 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x18 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x19 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x1f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x20 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x21 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x22 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x23 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x24 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x25 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x26 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x27 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x28 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x29 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x2f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x30 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x31 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x32 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x33 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x34 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x35 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x36 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x37 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x38 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x39 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x3f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x40 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x41 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x42 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x43 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x44 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x45 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x46 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x47 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x48 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x49 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x4f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x50 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x51 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x52 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x53 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x54 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x55 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x56 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x57 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x58 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x59 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x5f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x60 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x61 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x62 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x63 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x64 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x65 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x66 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x67 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x68 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x69 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x6f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x70 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x71 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x72 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x73 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x74 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x75 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x76 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x77 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x78 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x79 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x7f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x80 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x81 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x82 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x83 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x84 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x85 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x86 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x87 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x88 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x89 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x8f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x90 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x91 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x92 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x93 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x94 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x95 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x96 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x97 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x98 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x99 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9a */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9b */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9c */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9d */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9e */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0x9f */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xa9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xab */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xac */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xad */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xae */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xaf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xb9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xba */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xbf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xc9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xca */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xce */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xcf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xd9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xda */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xde */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xdf */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xe9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xea */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xeb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xec */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xed */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xee */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xef */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf0 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf1 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf2 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf3 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf4 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf5 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf6 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf7 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf8 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xf9 */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfa */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfb */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfc */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfd */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xfe */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   },
   /* 0xff */
   { /* ModRMDecision */
    MODRM_ONEENTRY,
    0 /* EmptyTable */
   }
  }
 }
, };
static const uint8_t index_x86DisassemblerT3DNOWOpcodes[] = {
1, 2, 3, 4, 5, 6, 7, 8, 0, 0, 9, 10, 11, 12, 13, 14, 15, 0, 0, 16, 17, 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, };

