// This is auto-gen data for Capstone disassembly engine (www.capstone-engine.org)
// By Nguyen Anh Quynh <aquynh@gmail.com>

{
	X86_AAA, X86_INS_AAA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_AAD8i8, X86_INS_AAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_AAM8i8, X86_INS_AAM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_AAS, X86_INS_AAS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_ABS_F, X86_INS_FABS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ADC16i16, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC16mi, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC16mi8, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC16mr, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC16ri, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC16ri8, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC16rm, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC16rr, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC16rr_REV, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC32i32, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC32mi, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC32mi8, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC32mr, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC32ri, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC32ri8, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC32rm, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC32rr, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC32rr_REV, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC64i32, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC64mi32, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC64mi8, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC64mr, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC64ri32, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC64ri8, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC64rm, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC64rr, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC64rr_REV, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC8i8, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC8mi, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC8mi8, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_ADC8mr, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC8ri, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC8ri8, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_ADC8rm, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC8rr, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADC8rr_REV, X86_INS_ADC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADCX32rm, X86_INS_ADCX,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_ADX, 0 }, 0, 0
#endif
},
{
	X86_ADCX32rr, X86_INS_ADCX,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_ADX, 0 }, 0, 0
#endif
},
{
	X86_ADCX64rm, X86_INS_ADCX,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_ADX, 0 }, 0, 0
#endif
},
{
	X86_ADCX64rr, X86_INS_ADCX,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_ADX, 0 }, 0, 0
#endif
},
{
	X86_ADD16i16, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD16mi, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD16mi8, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD16mr, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD16ri, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD16ri8, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD16rm, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD16rr, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD16rr_REV, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD32i32, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD32mi, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD32mi8, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD32mr, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD32ri, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD32ri8, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD32rm, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD32rr, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD32rr_REV, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD64i32, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD64mi32, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD64mi8, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD64mr, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD64ri32, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD64ri8, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD64rm, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD64rr, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD64rr_REV, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD8i8, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD8mi, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD8mi8, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_ADD8mr, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD8ri, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD8ri8, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_ADD8rm, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD8rr, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADD8rr_REV, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ADDPDrm, X86_INS_ADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_ADDPDrr, X86_INS_ADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_ADDPSrm, X86_INS_ADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_ADDPSrr, X86_INS_ADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_ADDSDrm, X86_INS_ADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_ADDSDrm_Int, X86_INS_ADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_ADDSDrr, X86_INS_ADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_ADDSDrr_Int, X86_INS_ADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_ADDSSrm, X86_INS_ADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_ADDSSrm_Int, X86_INS_ADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_ADDSSrr, X86_INS_ADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_ADDSSrr_Int, X86_INS_ADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_ADDSUBPDrm, X86_INS_ADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_ADDSUBPDrr, X86_INS_ADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_ADDSUBPSrm, X86_INS_ADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_ADDSUBPSrr, X86_INS_ADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_ADD_F32m, X86_INS_FADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ADD_F64m, X86_INS_FADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ADD_FI16m, X86_INS_FIADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ADD_FI32m, X86_INS_FIADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ADD_FPrST0, X86_INS_FADDP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ADD_FST0r, X86_INS_FADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ADD_FrST0, X86_INS_FADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ADOX32rm, X86_INS_ADOX,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_ADX, 0 }, 0, 0
#endif
},
{
	X86_ADOX32rr, X86_INS_ADOX,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_ADX, 0 }, 0, 0
#endif
},
{
	X86_ADOX64rm, X86_INS_ADOX,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_ADX, 0 }, 0, 0
#endif
},
{
	X86_ADOX64rr, X86_INS_ADOX,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_ADX, 0 }, 0, 0
#endif
},
{
	X86_AESDECLASTrm, X86_INS_AESDECLAST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_AESDECLASTrr, X86_INS_AESDECLAST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_AESDECrm, X86_INS_AESDEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_AESDECrr, X86_INS_AESDEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_AESENCLASTrm, X86_INS_AESENCLAST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_AESENCLASTrr, X86_INS_AESENCLAST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_AESENCrm, X86_INS_AESENC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_AESENCrr, X86_INS_AESENC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_AESIMCrm, X86_INS_AESIMC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_AESIMCrr, X86_INS_AESIMC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_AESKEYGENASSIST128rm, X86_INS_AESKEYGENASSIST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_AESKEYGENASSIST128rr, X86_INS_AESKEYGENASSIST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_AND16i16, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND16mi, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND16mi8, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND16mr, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND16ri, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND16ri8, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND16rm, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND16rr, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND16rr_REV, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND32i32, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND32mi, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND32mi8, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND32mr, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND32ri, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND32ri8, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND32rm, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND32rr, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND32rr_REV, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND64i32, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND64mi32, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND64mi8, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND64mr, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND64ri32, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND64ri8, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND64rm, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND64rr, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND64rr_REV, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND8i8, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND8mi, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND8mi8, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_AND8mr, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND8ri, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND8ri8, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_AND8rm, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND8rr, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_AND8rr_REV, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ANDN32rm, X86_INS_ANDN,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_ANDN32rr, X86_INS_ANDN,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_ANDN64rm, X86_INS_ANDN,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_ANDN64rr, X86_INS_ANDN,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_ANDNPDrm, X86_INS_ANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_ANDNPDrr, X86_INS_ANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_ANDNPSrm, X86_INS_ANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_ANDNPSrr, X86_INS_ANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_ANDPDrm, X86_INS_ANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_ANDPDrr, X86_INS_ANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_ANDPSrm, X86_INS_ANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_ANDPSrr, X86_INS_ANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_ARPL16mr, X86_INS_ARPL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_ARPL16rr, X86_INS_ARPL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_BEXTR32rm, X86_INS_BEXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BEXTR32rr, X86_INS_BEXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BEXTR64rm, X86_INS_BEXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BEXTR64rr, X86_INS_BEXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BEXTRI32mi, X86_INS_BEXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BEXTRI32ri, X86_INS_BEXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BEXTRI64mi, X86_INS_BEXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BEXTRI64ri, X86_INS_BEXTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCFILL32rm, X86_INS_BLCFILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCFILL32rr, X86_INS_BLCFILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCFILL64rm, X86_INS_BLCFILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCFILL64rr, X86_INS_BLCFILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCI32rm, X86_INS_BLCI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCI32rr, X86_INS_BLCI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCI64rm, X86_INS_BLCI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCI64rr, X86_INS_BLCI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCIC32rm, X86_INS_BLCIC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCIC32rr, X86_INS_BLCIC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCIC64rm, X86_INS_BLCIC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCIC64rr, X86_INS_BLCIC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCMSK32rm, X86_INS_BLCMSK,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCMSK32rr, X86_INS_BLCMSK,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCMSK64rm, X86_INS_BLCMSK,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCMSK64rr, X86_INS_BLCMSK,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCS32rm, X86_INS_BLCS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCS32rr, X86_INS_BLCS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCS64rm, X86_INS_BLCS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLCS64rr, X86_INS_BLCS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLENDPDrmi, X86_INS_BLENDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_BLENDPDrri, X86_INS_BLENDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_BLENDPSrmi, X86_INS_BLENDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_BLENDPSrri, X86_INS_BLENDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_BLENDVPDrm0, X86_INS_BLENDVPD,
#ifndef CAPSTONE_DIET
	{ X86_REG_XMM0, 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_BLENDVPDrr0, X86_INS_BLENDVPD,
#ifndef CAPSTONE_DIET
	{ X86_REG_XMM0, 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_BLENDVPSrm0, X86_INS_BLENDVPS,
#ifndef CAPSTONE_DIET
	{ X86_REG_XMM0, 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_BLENDVPSrr0, X86_INS_BLENDVPS,
#ifndef CAPSTONE_DIET
	{ X86_REG_XMM0, 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_BLSFILL32rm, X86_INS_BLSFILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLSFILL32rr, X86_INS_BLSFILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLSFILL64rm, X86_INS_BLSFILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLSFILL64rr, X86_INS_BLSFILL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLSI32rm, X86_INS_BLSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BLSI32rr, X86_INS_BLSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BLSI64rm, X86_INS_BLSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BLSI64rr, X86_INS_BLSI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BLSIC32rm, X86_INS_BLSIC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLSIC32rr, X86_INS_BLSIC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLSIC64rm, X86_INS_BLSIC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLSIC64rr, X86_INS_BLSIC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_BLSMSK32rm, X86_INS_BLSMSK,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BLSMSK32rr, X86_INS_BLSMSK,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BLSMSK64rm, X86_INS_BLSMSK,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BLSMSK64rr, X86_INS_BLSMSK,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BLSR32rm, X86_INS_BLSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BLSR32rr, X86_INS_BLSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BLSR64rm, X86_INS_BLSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BLSR64rr, X86_INS_BLSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_BOUNDS16rm, X86_INS_BOUND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_BOUNDS32rm, X86_INS_BOUND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_BSF16rm, X86_INS_BSF,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BSF16rr, X86_INS_BSF,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BSF32rm, X86_INS_BSF,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BSF32rr, X86_INS_BSF,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BSF64rm, X86_INS_BSF,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BSF64rr, X86_INS_BSF,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BSR16rm, X86_INS_BSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BSR16rr, X86_INS_BSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BSR32rm, X86_INS_BSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BSR32rr, X86_INS_BSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BSR64rm, X86_INS_BSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BSR64rr, X86_INS_BSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BSWAP32r, X86_INS_BSWAP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BSWAP64r, X86_INS_BSWAP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BT16mi8, X86_INS_BT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BT16mr, X86_INS_BT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BT16ri8, X86_INS_BT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BT16rr, X86_INS_BT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BT32mi8, X86_INS_BT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BT32mr, X86_INS_BT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BT32ri8, X86_INS_BT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BT32rr, X86_INS_BT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BT64mi8, X86_INS_BT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BT64mr, X86_INS_BT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BT64ri8, X86_INS_BT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BT64rr, X86_INS_BT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTC16mi8, X86_INS_BTC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTC16mr, X86_INS_BTC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTC16ri8, X86_INS_BTC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTC16rr, X86_INS_BTC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTC32mi8, X86_INS_BTC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTC32mr, X86_INS_BTC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTC32ri8, X86_INS_BTC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTC32rr, X86_INS_BTC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTC64mi8, X86_INS_BTC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTC64mr, X86_INS_BTC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTC64ri8, X86_INS_BTC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTC64rr, X86_INS_BTC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTR16mi8, X86_INS_BTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTR16mr, X86_INS_BTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTR16ri8, X86_INS_BTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTR16rr, X86_INS_BTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTR32mi8, X86_INS_BTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTR32mr, X86_INS_BTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTR32ri8, X86_INS_BTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTR32rr, X86_INS_BTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTR64mi8, X86_INS_BTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTR64mr, X86_INS_BTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTR64ri8, X86_INS_BTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTR64rr, X86_INS_BTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTS16mi8, X86_INS_BTS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTS16mr, X86_INS_BTS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTS16ri8, X86_INS_BTS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTS16rr, X86_INS_BTS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTS32mi8, X86_INS_BTS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTS32mr, X86_INS_BTS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTS32ri8, X86_INS_BTS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTS32rr, X86_INS_BTS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTS64mi8, X86_INS_BTS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTS64mr, X86_INS_BTS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTS64ri8, X86_INS_BTS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BTS64rr, X86_INS_BTS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_BZHI32rm, X86_INS_BZHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_BZHI32rr, X86_INS_BZHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_BZHI64rm, X86_INS_BZHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_BZHI64rr, X86_INS_BZHI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_CALL16m, X86_INS_CALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_CALL, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_CALL16r, X86_INS_CALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_CALL, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_CALL32m, X86_INS_CALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_CALL, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_CALL32r, X86_INS_CALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_CALL, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_CALL64m, X86_INS_CALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, 0 }, { X86_REG_RSP, 0 }, { X86_GRP_CALL, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_CALL64pcrel32, X86_INS_CALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, X86_REG_RIP, 0 }, { X86_REG_RSP, 0 }, { X86_GRP_CALL, X86_GRP_BRANCH_RELATIVE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_CALL64r, X86_INS_CALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, 0 }, { X86_REG_RSP, 0 }, { X86_GRP_CALL, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_CALLpcrel16, X86_INS_CALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, X86_REG_EIP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_CALL, X86_GRP_BRANCH_RELATIVE, 0 }, 0, 0
#endif
},
{
	X86_CALLpcrel32, X86_INS_CALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, X86_REG_EIP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_CALL, X86_GRP_BRANCH_RELATIVE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_CBW, X86_INS_CBW,
#ifndef CAPSTONE_DIET
	{ X86_REG_AL, 0 }, { X86_REG_AX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CDQ, X86_INS_CDQ,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { X86_REG_EAX, X86_REG_EDX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CDQE, X86_INS_CDQE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { X86_REG_RAX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CHS_F, X86_INS_FCHS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_CLAC, X86_INS_CLAC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_CLC, X86_INS_CLC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CLD, X86_INS_CLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CLFLUSH, X86_INS_CLFLUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CLFLUSHOPT, X86_INS_CLFLUSHOPT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CLGI, X86_INS_CLGI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, 0 }, 0, 0
#endif
},
{
	X86_CLI, X86_INS_CLI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_CLTS, X86_INS_CLTS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CLWB, X86_INS_CLWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMC, X86_INS_CMC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMOVA16rm, X86_INS_CMOVA,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVA16rr, X86_INS_CMOVA,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVA32rm, X86_INS_CMOVA,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVA32rr, X86_INS_CMOVA,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVA64rm, X86_INS_CMOVA,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVA64rr, X86_INS_CMOVA,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVAE16rm, X86_INS_CMOVAE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVAE16rr, X86_INS_CMOVAE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVAE32rm, X86_INS_CMOVAE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVAE32rr, X86_INS_CMOVAE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVAE64rm, X86_INS_CMOVAE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVAE64rr, X86_INS_CMOVAE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVB16rm, X86_INS_CMOVB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVB16rr, X86_INS_CMOVB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVB32rm, X86_INS_CMOVB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVB32rr, X86_INS_CMOVB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVB64rm, X86_INS_CMOVB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVB64rr, X86_INS_CMOVB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVBE16rm, X86_INS_CMOVBE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVBE16rr, X86_INS_CMOVBE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVBE32rm, X86_INS_CMOVBE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVBE32rr, X86_INS_CMOVBE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVBE64rm, X86_INS_CMOVBE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVBE64rr, X86_INS_CMOVBE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVBE_F, X86_INS_FCMOVBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_CMOV, X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_CMOVB_F, X86_INS_FCMOVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_CMOV, X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_CMOVE16rm, X86_INS_CMOVE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVE16rr, X86_INS_CMOVE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVE32rm, X86_INS_CMOVE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVE32rr, X86_INS_CMOVE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVE64rm, X86_INS_CMOVE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVE64rr, X86_INS_CMOVE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVE_F, X86_INS_FCMOVE,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_CMOV, X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_CMOVG16rm, X86_INS_CMOVG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVG16rr, X86_INS_CMOVG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVG32rm, X86_INS_CMOVG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVG32rr, X86_INS_CMOVG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVG64rm, X86_INS_CMOVG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVG64rr, X86_INS_CMOVG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVGE16rm, X86_INS_CMOVGE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVGE16rr, X86_INS_CMOVGE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVGE32rm, X86_INS_CMOVGE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVGE32rr, X86_INS_CMOVGE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVGE64rm, X86_INS_CMOVGE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVGE64rr, X86_INS_CMOVGE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVL16rm, X86_INS_CMOVL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVL16rr, X86_INS_CMOVL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVL32rm, X86_INS_CMOVL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVL32rr, X86_INS_CMOVL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVL64rm, X86_INS_CMOVL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVL64rr, X86_INS_CMOVL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVLE16rm, X86_INS_CMOVLE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVLE16rr, X86_INS_CMOVLE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVLE32rm, X86_INS_CMOVLE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVLE32rr, X86_INS_CMOVLE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVLE64rm, X86_INS_CMOVLE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVLE64rr, X86_INS_CMOVLE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNBE_F, X86_INS_FCMOVNBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_CMOV, X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_CMOVNB_F, X86_INS_FCMOVNB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNE16rm, X86_INS_CMOVNE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNE16rr, X86_INS_CMOVNE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNE32rm, X86_INS_CMOVNE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNE32rr, X86_INS_CMOVNE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNE64rm, X86_INS_CMOVNE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNE64rr, X86_INS_CMOVNE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNE_F, X86_INS_FCMOVNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_CMOV, X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_CMOVNO16rm, X86_INS_CMOVNO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNO16rr, X86_INS_CMOVNO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNO32rm, X86_INS_CMOVNO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNO32rr, X86_INS_CMOVNO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNO64rm, X86_INS_CMOVNO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNO64rr, X86_INS_CMOVNO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNP16rm, X86_INS_CMOVNP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNP16rr, X86_INS_CMOVNP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNP32rm, X86_INS_CMOVNP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNP32rr, X86_INS_CMOVNP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNP64rm, X86_INS_CMOVNP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNP64rr, X86_INS_CMOVNP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNP_F, X86_INS_FCMOVNU,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_CMOV, X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_CMOVNS16rm, X86_INS_CMOVNS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNS16rr, X86_INS_CMOVNS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNS32rm, X86_INS_CMOVNS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNS32rr, X86_INS_CMOVNS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNS64rm, X86_INS_CMOVNS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVNS64rr, X86_INS_CMOVNS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVO16rm, X86_INS_CMOVO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVO16rr, X86_INS_CMOVO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVO32rm, X86_INS_CMOVO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVO32rr, X86_INS_CMOVO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVO64rm, X86_INS_CMOVO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVO64rr, X86_INS_CMOVO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVP16rm, X86_INS_CMOVP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVP16rr, X86_INS_CMOVP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVP32rm, X86_INS_CMOVP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVP32rr, X86_INS_CMOVP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVP64rm, X86_INS_CMOVP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVP64rr, X86_INS_CMOVP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVP_F, X86_INS_FCMOVU,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_CMOV, X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_CMOVS16rm, X86_INS_CMOVS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVS16rr, X86_INS_CMOVS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVS32rm, X86_INS_CMOVS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVS32rr, X86_INS_CMOVS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVS64rm, X86_INS_CMOVS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMOVS64rr, X86_INS_CMOVS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_CMOV, 0 }, 0, 0
#endif
},
{
	X86_CMP16i16, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP16mi, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP16mi8, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP16mr, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP16ri, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP16ri8, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP16rm, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP16rr, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP16rr_REV, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP32i32, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP32mi, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP32mi8, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP32mr, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP32ri, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP32ri8, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP32rm, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP32rr, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP32rr_REV, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP64i32, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP64mi32, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP64mi8, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP64mr, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP64ri32, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP64ri8, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP64rm, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP64rr, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP64rr_REV, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP8i8, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP8mi, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP8mi8, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_CMP8mr, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP8ri, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP8ri8, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_CMP8rm, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP8rr, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMP8rr_REV, X86_INS_CMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPPDrmi, X86_INS_CMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CMPPDrmi_alt, X86_INS_CMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CMPPDrri, X86_INS_CMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CMPPDrri_alt, X86_INS_CMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CMPPSrmi, X86_INS_CMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CMPPSrmi_alt, X86_INS_CMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CMPPSrri, X86_INS_CMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CMPPSrri_alt, X86_INS_CMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CMPSB, X86_INS_CMPSB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDI, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPSDrm, X86_INS_CMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CMPSDrm_alt, X86_INS_CMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CMPSDrr, X86_INS_CMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CMPSDrr_alt, X86_INS_CMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CMPSL, X86_INS_CMPSD,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDI, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPSQ, X86_INS_CMPSQ,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDI, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPSSrm, X86_INS_CMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CMPSSrm_alt, X86_INS_CMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CMPSSrr, X86_INS_CMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CMPSSrr_alt, X86_INS_CMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CMPSW, X86_INS_CMPSW,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDI, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPXCHG16B, X86_INS_CMPXCHG16B,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, X86_REG_RBX, X86_REG_RCX, X86_REG_RDX, 0 }, { X86_REG_RAX, X86_REG_RDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPXCHG16rm, X86_INS_CMPXCHG,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPXCHG16rr, X86_INS_CMPXCHG,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPXCHG32rm, X86_INS_CMPXCHG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPXCHG32rr, X86_INS_CMPXCHG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPXCHG64rm, X86_INS_CMPXCHG,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPXCHG64rr, X86_INS_CMPXCHG,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPXCHG8B, X86_INS_CMPXCHG8B,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EBX, X86_REG_ECX, X86_REG_EDX, 0 }, { X86_REG_EAX, X86_REG_EDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPXCHG8rm, X86_INS_CMPXCHG,
#ifndef CAPSTONE_DIET
	{ X86_REG_AL, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CMPXCHG8rr, X86_INS_CMPXCHG,
#ifndef CAPSTONE_DIET
	{ X86_REG_AL, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_COMISDrm, X86_INS_COMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_COMISDrr, X86_INS_COMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_COMISSrm, X86_INS_COMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_COMISSrr, X86_INS_COMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_COMP_FST0r, X86_INS_FCOMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_COM_FIPr, X86_INS_FCOMIP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_COM_FIr, X86_INS_FCOMI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_COM_FST0r, X86_INS_FCOM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_COS_F, X86_INS_FCOS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_CPUID, X86_INS_CPUID,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_ECX, 0 }, { X86_REG_EAX, X86_REG_EBX, X86_REG_ECX, X86_REG_EDX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CQO, X86_INS_CQO,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, 0 }, { X86_REG_RAX, X86_REG_RDX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CRC32r32m16, X86_INS_CRC32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_CRC32r32m32, X86_INS_CRC32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_CRC32r32m8, X86_INS_CRC32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_CRC32r32r16, X86_INS_CRC32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_CRC32r32r32, X86_INS_CRC32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_CRC32r32r8, X86_INS_CRC32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_CRC32r64m64, X86_INS_CRC32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_CRC32r64m8, X86_INS_CRC32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_CRC32r64r64, X86_INS_CRC32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_CRC32r64r8, X86_INS_CRC32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_CVTDQ2PDrm, X86_INS_CVTDQ2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTDQ2PDrr, X86_INS_CVTDQ2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTDQ2PSrm, X86_INS_CVTDQ2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTDQ2PSrr, X86_INS_CVTDQ2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTPD2DQrm, X86_INS_CVTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTPD2DQrr, X86_INS_CVTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTPD2PSrm, X86_INS_CVTPD2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTPD2PSrr, X86_INS_CVTPD2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTPS2DQrm, X86_INS_CVTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTPS2DQrr, X86_INS_CVTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTPS2PDrm, X86_INS_CVTPS2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTPS2PDrr, X86_INS_CVTPS2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTSD2SI64rm, X86_INS_CVTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTSD2SI64rr, X86_INS_CVTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTSD2SIrm, X86_INS_CVTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTSD2SIrr, X86_INS_CVTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTSD2SSrm, X86_INS_CVTSD2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTSD2SSrr, X86_INS_CVTSD2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTSI2SD64rm, X86_INS_CVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTSI2SD64rr, X86_INS_CVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTSI2SDrm, X86_INS_CVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTSI2SDrr, X86_INS_CVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTSI2SS64rm, X86_INS_CVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CVTSI2SS64rr, X86_INS_CVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CVTSI2SSrm, X86_INS_CVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CVTSI2SSrr, X86_INS_CVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CVTSS2SDrm, X86_INS_CVTSS2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTSS2SDrr, X86_INS_CVTSS2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTSS2SI64rm, X86_INS_CVTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CVTSS2SI64rr, X86_INS_CVTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CVTSS2SIrm, X86_INS_CVTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CVTSS2SIrr, X86_INS_CVTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CVTTPD2DQrm, X86_INS_CVTTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTTPD2DQrr, X86_INS_CVTTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTTPS2DQrm, X86_INS_CVTTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTTPS2DQrr, X86_INS_CVTTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTTSD2SI64rm, X86_INS_CVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTTSD2SI64rr, X86_INS_CVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTTSD2SIrm, X86_INS_CVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTTSD2SIrr, X86_INS_CVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_CVTTSS2SI64rm, X86_INS_CVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CVTTSS2SI64rr, X86_INS_CVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CVTTSS2SIrm, X86_INS_CVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CVTTSS2SIrr, X86_INS_CVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_CWD, X86_INS_CWD,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { X86_REG_AX, X86_REG_DX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_CWDE, X86_INS_CWDE,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { X86_REG_EAX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DAA, X86_INS_DAA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_DAS, X86_INS_DAS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_DATA16_PREFIX, X86_INS_DATA16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DEC16m, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DEC16r, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DEC16r_alt, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_DEC32m, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DEC32r, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DEC32r_alt, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_DEC64m, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DEC64r, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DEC8m, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DEC8r, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DIV16m, X86_INS_DIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, X86_REG_DX, 0 }, { X86_REG_AX, X86_REG_DX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DIV16r, X86_INS_DIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, X86_REG_DX, 0 }, { X86_REG_AX, X86_REG_DX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DIV32m, X86_INS_DIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDX, 0 }, { X86_REG_EAX, X86_REG_EDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DIV32r, X86_INS_DIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDX, 0 }, { X86_REG_EAX, X86_REG_EDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DIV64m, X86_INS_DIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, X86_REG_RDX, 0 }, { X86_REG_RAX, X86_REG_RDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DIV64r, X86_INS_DIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, X86_REG_RDX, 0 }, { X86_REG_RAX, X86_REG_RDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DIV8m, X86_INS_DIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { X86_REG_AL, X86_REG_AH, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DIV8r, X86_INS_DIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { X86_REG_AL, X86_REG_AH, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_DIVPDrm, X86_INS_DIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_DIVPDrr, X86_INS_DIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_DIVPSrm, X86_INS_DIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_DIVPSrr, X86_INS_DIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_DIVR_F32m, X86_INS_FDIVR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DIVR_F64m, X86_INS_FDIVR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DIVR_FI16m, X86_INS_FIDIVR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DIVR_FI32m, X86_INS_FIDIVR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DIVR_FPrST0, X86_INS_FDIVRP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DIVR_FST0r, X86_INS_FDIVR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DIVR_FrST0, X86_INS_FDIVR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DIVSDrm, X86_INS_DIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_DIVSDrm_Int, X86_INS_DIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_DIVSDrr, X86_INS_DIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_DIVSDrr_Int, X86_INS_DIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_DIVSSrm, X86_INS_DIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_DIVSSrm_Int, X86_INS_DIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_DIVSSrr, X86_INS_DIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_DIVSSrr_Int, X86_INS_DIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_DIV_F32m, X86_INS_FDIV,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DIV_F64m, X86_INS_FDIV,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DIV_FI16m, X86_INS_FIDIV,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DIV_FI32m, X86_INS_FIDIV,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DIV_FPrST0, X86_INS_FDIVP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DIV_FST0r, X86_INS_FDIV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DIV_FrST0, X86_INS_FDIV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_DPPDrmi, X86_INS_DPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_DPPDrri, X86_INS_DPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_DPPSrmi, X86_INS_DPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_DPPSrri, X86_INS_DPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_ENCLS, X86_INS_ENCLS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ENCLU, X86_INS_ENCLU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ENTER, X86_INS_ENTER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_EXTRACTPSmr, X86_INS_EXTRACTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_EXTRACTPSrr, X86_INS_EXTRACTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_EXTRQ, X86_INS_EXTRQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE4A, 0 }, 0, 0
#endif
},
{
	X86_EXTRQI, X86_INS_EXTRQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE4A, 0 }, 0, 0
#endif
},
{
	X86_F2XM1, X86_INS_F2XM1,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FARCALL16i, X86_INS_LCALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { 0 }, { X86_GRP_CALL, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_FARCALL16m, X86_INS_LCALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { 0 }, { X86_GRP_CALL, 0 }, 0, 0
#endif
},
{
	X86_FARCALL32i, X86_INS_LCALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { 0 }, { X86_GRP_CALL, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_FARCALL32m, X86_INS_LCALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { 0 }, { X86_GRP_CALL, 0 }, 0, 0
#endif
},
{
	X86_FARCALL64, X86_INS_LCALL,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, 0 }, { 0 }, { X86_GRP_CALL, 0 }, 0, 0
#endif
},
{
	X86_FARJMP16i, X86_INS_LJMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 1, 1
#endif
},
{
	X86_FARJMP16m, X86_INS_LJMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	X86_FARJMP32i, X86_INS_LJMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 1, 1
#endif
},
{
	X86_FARJMP32m, X86_INS_LJMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	X86_FARJMP64, X86_INS_LJMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 1, 1
#endif
},
{
	X86_FBLDm, X86_INS_FBLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FBSTPm, X86_INS_FBSTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FCOM32m, X86_INS_FCOM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FCOM64m, X86_INS_FCOM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FCOMP32m, X86_INS_FCOMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FCOMP64m, X86_INS_FCOMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FCOMPP, X86_INS_FCOMPP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FDECSTP, X86_INS_FDECSTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FEMMS, X86_INS_FEMMS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_FFREE, X86_INS_FFREE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FICOM16m, X86_INS_FICOM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FICOM32m, X86_INS_FICOM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FICOMP16m, X86_INS_FICOMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FICOMP32m, X86_INS_FICOMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FINCSTP, X86_INS_FINCSTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FLDCW16m, X86_INS_FLDCW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FLDENVm, X86_INS_FLDENV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FLDL2E, X86_INS_FLDL2E,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_FLDL2T, X86_INS_FLDL2T,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_FLDLG2, X86_INS_FLDLG2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FLDLN2, X86_INS_FLDLN2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_FLDPI, X86_INS_FLDPI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FNCLEX, X86_INS_FNCLEX,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FNINIT, X86_INS_FNINIT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FNOP, X86_INS_FNOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FNSTCW16m, X86_INS_FNSTCW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_FNSTSW16r, X86_INS_FNSTSW,
#ifndef CAPSTONE_DIET
	{ X86_REG_FPSW, 0 }, { X86_REG_AX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_FNSTSWm, X86_INS_FNSTSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_FPATAN, X86_INS_FPATAN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FPREM, X86_INS_FPREM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FPREM1, X86_INS_FPREM1,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FPTAN, X86_INS_FPTAN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FP_FFREEP, X86_INS_FFREEP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_FRNDINT, X86_INS_FRNDINT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FRSTORm, X86_INS_FRSTOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FSAVEm, X86_INS_FNSAVE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FSCALE, X86_INS_FSCALE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FSETPM, X86_INS_FSETPM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_FSINCOS, X86_INS_FSINCOS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FSTENVm, X86_INS_FNSTENV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FXAM, X86_INS_FXAM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FXRSTOR, X86_INS_FXRSTOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_FXRSTOR64, X86_INS_FXRSTOR64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_FXSAVE, X86_INS_FXSAVE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_FXSAVE64, X86_INS_FXSAVE64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_FXTRACT, X86_INS_FXTRACT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FYL2X, X86_INS_FYL2X,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FYL2XP1, X86_INS_FYL2XP1,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_FsANDNPDrm, X86_INS_ANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FsANDNPDrr, X86_INS_ANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FsANDNPSrm, X86_INS_ANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FsANDNPSrr, X86_INS_ANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FsANDPDrm, X86_INS_ANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FsANDPDrr, X86_INS_ANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FsANDPSrm, X86_INS_ANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FsANDPSrr, X86_INS_ANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FsMOVAPDrm, X86_INS_MOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FsMOVAPSrm, X86_INS_MOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FsORPDrm, X86_INS_ORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FsORPDrr, X86_INS_ORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FsORPSrm, X86_INS_ORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FsORPSrr, X86_INS_ORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FsVMOVAPDrm, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_FsVMOVAPSrm, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_FsXORPDrm, X86_INS_XORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FsXORPDrr, X86_INS_XORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FsXORPSrm, X86_INS_XORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FsXORPSrr, X86_INS_XORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FvANDNPDrm, X86_INS_ANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FvANDNPDrr, X86_INS_ANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FvANDNPSrm, X86_INS_ANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FvANDNPSrr, X86_INS_ANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FvANDPDrm, X86_INS_ANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FvANDPDrr, X86_INS_ANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FvANDPSrm, X86_INS_ANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FvANDPSrr, X86_INS_ANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FvORPDrm, X86_INS_ORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FvORPDrr, X86_INS_ORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FvORPSrm, X86_INS_ORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FvORPSrr, X86_INS_ORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FvXORPDrm, X86_INS_XORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FvXORPDrr, X86_INS_XORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_FvXORPSrm, X86_INS_XORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_FvXORPSrr, X86_INS_XORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_GETSEC, X86_INS_GETSEC,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, X86_REG_RBX, X86_REG_RCX, X86_REG_RDX, 0 }, { X86_REG_RAX, X86_REG_RBX, X86_REG_RCX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_HADDPDrm, X86_INS_HADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_HADDPDrr, X86_INS_HADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_HADDPSrm, X86_INS_HADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_HADDPSrr, X86_INS_HADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_HLT, X86_INS_HLT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_HSUBPDrm, X86_INS_HSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_HSUBPDrr, X86_INS_HSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_HSUBPSrm, X86_INS_HSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_HSUBPSrr, X86_INS_HSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_IDIV16m, X86_INS_IDIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, X86_REG_DX, 0 }, { X86_REG_AX, X86_REG_DX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IDIV16r, X86_INS_IDIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, X86_REG_DX, 0 }, { X86_REG_AX, X86_REG_DX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IDIV32m, X86_INS_IDIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDX, 0 }, { X86_REG_EAX, X86_REG_EDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IDIV32r, X86_INS_IDIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDX, 0 }, { X86_REG_EAX, X86_REG_EDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IDIV64m, X86_INS_IDIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, X86_REG_RDX, 0 }, { X86_REG_RAX, X86_REG_RDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IDIV64r, X86_INS_IDIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, X86_REG_RDX, 0 }, { X86_REG_RAX, X86_REG_RDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IDIV8m, X86_INS_IDIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { X86_REG_AL, X86_REG_AH, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IDIV8r, X86_INS_IDIV,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { X86_REG_AL, X86_REG_AH, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ILD_F16m, X86_INS_FILD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ILD_F32m, X86_INS_FILD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ILD_F64m, X86_INS_FILD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_IMUL16m, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { X86_REG_AX, X86_REG_DX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL16r, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { X86_REG_AX, X86_REG_DX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL16rm, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL16rmi, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL16rmi8, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL16rr, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL16rri, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL16rri8, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL32m, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { X86_REG_EAX, X86_REG_EDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL32r, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { X86_REG_EAX, X86_REG_EDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL32rm, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL32rmi, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL32rmi8, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL32rr, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL32rri, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL32rri8, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL64m, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, 0 }, { X86_REG_RAX, X86_REG_RDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL64r, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, 0 }, { X86_REG_RAX, X86_REG_RDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL64rm, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL64rmi32, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL64rmi8, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL64rr, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL64rri32, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL64rri8, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL8m, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_AL, 0 }, { X86_REG_AL, X86_REG_EFLAGS, X86_REG_AX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IMUL8r, X86_INS_IMUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_AL, 0 }, { X86_REG_AL, X86_REG_EFLAGS, X86_REG_AX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IN16ri, X86_INS_IN,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_AX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IN16rr, X86_INS_IN,
#ifndef CAPSTONE_DIET
	{ X86_REG_DX, 0 }, { X86_REG_AX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IN32ri, X86_INS_IN,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EAX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IN32rr, X86_INS_IN,
#ifndef CAPSTONE_DIET
	{ X86_REG_DX, 0 }, { X86_REG_EAX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IN8ri, X86_INS_IN,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_AL, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_IN8rr, X86_INS_IN,
#ifndef CAPSTONE_DIET
	{ X86_REG_DX, 0 }, { X86_REG_AL, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_INC16m, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_INC16r, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_INC16r_alt, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_INC32m, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_INC32r, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_INC32r_alt, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_INC64m, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_INC64r, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_INC8m, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_INC8r, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_INSB, X86_INS_INSB,
#ifndef CAPSTONE_DIET
	{ X86_REG_DX, X86_REG_EDI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_INSERTPSrm, X86_INS_INSERTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_INSERTPSrr, X86_INS_INSERTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_INSERTQ, X86_INS_INSERTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE4A, 0 }, 0, 0
#endif
},
{
	X86_INSERTQI, X86_INS_INSERTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE4A, 0 }, 0, 0
#endif
},
{
	X86_INSL, X86_INS_INSD,
#ifndef CAPSTONE_DIET
	{ X86_REG_DX, X86_REG_EDI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_INSW, X86_INS_INSW,
#ifndef CAPSTONE_DIET
	{ X86_REG_DX, X86_REG_EDI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_INT, X86_INS_INT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_INT, 0 }, 0, 0
#endif
},
{
	X86_INT1, X86_INS_INT1,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_INT, 0 }, 0, 0
#endif
},
{
	X86_INT3, X86_INS_INT3,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_INT, 0 }, 0, 0
#endif
},
{
	X86_INTO, X86_INS_INTO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_INT, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_INVD, X86_INS_INVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_INVEPT32, X86_INS_INVEPT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_INVEPT64, X86_INS_INVEPT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_INVLPG, X86_INS_INVLPG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_INVLPGA32, X86_INS_INVLPGA,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_ECX, 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_INVLPGA64, X86_INS_INVLPGA,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, X86_REG_ECX, 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_INVPCID32, X86_INS_INVPCID,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_INVPCID64, X86_INS_INVPCID,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_INVVPID32, X86_INS_INVVPID,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_INVVPID64, X86_INS_INVVPID,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_IRET16, X86_INS_IRET,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_IRET, 0 }, 0, 0
#endif
},
{
	X86_IRET32, X86_INS_IRETD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_IRET, 0 }, 0, 0
#endif
},
{
	X86_IRET64, X86_INS_IRETQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_IRET, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_ISTT_FP16m, X86_INS_FISTTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ISTT_FP32m, X86_INS_FISTTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ISTT_FP64m, X86_INS_FISTTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_IST_F16m, X86_INS_FIST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_IST_F32m, X86_INS_FIST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_IST_FP16m, X86_INS_FISTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_IST_FP32m, X86_INS_FISTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_IST_FP64m, X86_INS_FISTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_Int_CMPSDrm, X86_INS_CMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CMPSDrr, X86_INS_CMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CMPSSrm, X86_INS_CMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_CMPSSrr, X86_INS_CMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_COMISDrm, X86_INS_COMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_COMISDrr, X86_INS_COMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_COMISSrm, X86_INS_COMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_COMISSrr, X86_INS_COMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTSD2SSrm, X86_INS_CVTSD2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTSD2SSrr, X86_INS_CVTSD2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTSI2SD64rm, X86_INS_CVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTSI2SD64rr, X86_INS_CVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTSI2SDrm, X86_INS_CVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTSI2SDrr, X86_INS_CVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTSI2SS64rm, X86_INS_CVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTSI2SS64rr, X86_INS_CVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTSI2SSrm, X86_INS_CVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTSI2SSrr, X86_INS_CVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTSS2SDrm, X86_INS_CVTSS2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTSS2SDrr, X86_INS_CVTSS2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTTSD2SI64rm, X86_INS_CVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTTSD2SI64rr, X86_INS_CVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTTSD2SIrm, X86_INS_CVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTTSD2SIrr, X86_INS_CVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTTSS2SI64rm, X86_INS_CVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTTSS2SI64rr, X86_INS_CVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTTSS2SIrm, X86_INS_CVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_CVTTSS2SIrr, X86_INS_CVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_UCOMISDrm, X86_INS_UCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_UCOMISDrr, X86_INS_UCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_Int_UCOMISSrm, X86_INS_UCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_UCOMISSrr, X86_INS_UCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_Int_VCMPSDrm, X86_INS_VCMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCMPSDrr, X86_INS_VCMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCMPSSrm, X86_INS_VCMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCMPSSrr, X86_INS_VCMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCOMISDZrm, X86_INS_VCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCOMISDZrr, X86_INS_VCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCOMISDrm, X86_INS_VCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCOMISDrr, X86_INS_VCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCOMISSZrm, X86_INS_VCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCOMISSZrr, X86_INS_VCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCOMISSrm, X86_INS_VCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCOMISSrr, X86_INS_VCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSD2SSrm, X86_INS_VCVTSD2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSD2SSrr, X86_INS_VCVTSD2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SD64Zrm, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SD64Zrr, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SD64rm, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SD64rr, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SDZrm, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SDZrr, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SDrm, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SDrr, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SS64Zrm, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SS64Zrr, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SS64rm, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SS64rr, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SSZrm, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SSZrr, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SSrm, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSI2SSrr, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSS2SDrm, X86_INS_VCVTSS2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTSS2SDrr, X86_INS_VCVTSS2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSD2SI64Zrm, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSD2SI64Zrr, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSD2SI64rm, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSD2SI64rr, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSD2SIZrm, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSD2SIZrr, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSD2SIrm, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSD2SIrr, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSD2USI64Zrm, X86_INS_VCVTTSD2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSD2USI64Zrr, X86_INS_VCVTTSD2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSD2USIZrm, X86_INS_VCVTTSD2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSD2USIZrr, X86_INS_VCVTTSD2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSS2SI64Zrm, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSS2SI64Zrr, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSS2SI64rm, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSS2SI64rr, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSS2SIZrm, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSS2SIZrr, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSS2SIrm, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSS2SIrr, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSS2USI64Zrm, X86_INS_VCVTTSS2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSS2USI64Zrr, X86_INS_VCVTTSS2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSS2USIZrm, X86_INS_VCVTTSS2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTTSS2USIZrr, X86_INS_VCVTTSS2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTUSI2SD64Zrm, X86_INS_VCVTUSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTUSI2SD64Zrr, X86_INS_VCVTUSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTUSI2SDZrm, X86_INS_VCVTUSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTUSI2SDZrr, X86_INS_VCVTUSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTUSI2SS64Zrm, X86_INS_VCVTUSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTUSI2SS64Zrr, X86_INS_VCVTUSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTUSI2SSZrm, X86_INS_VCVTUSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VCVTUSI2SSZrr, X86_INS_VCVTUSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VUCOMISDZrm, X86_INS_VUCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VUCOMISDZrr, X86_INS_VUCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VUCOMISDrm, X86_INS_VUCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VUCOMISDrr, X86_INS_VUCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VUCOMISSZrm, X86_INS_VUCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VUCOMISSZrr, X86_INS_VUCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_Int_VUCOMISSrm, X86_INS_VUCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_Int_VUCOMISSrr, X86_INS_VUCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_JAE_1, X86_INS_JAE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JAE_2, X86_INS_JAE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JAE_4, X86_INS_JAE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JA_1, X86_INS_JA,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JA_2, X86_INS_JA,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JA_4, X86_INS_JA,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JBE_1, X86_INS_JBE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JBE_2, X86_INS_JBE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JBE_4, X86_INS_JBE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JB_1, X86_INS_JB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JB_2, X86_INS_JB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JB_4, X86_INS_JB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JCXZ, X86_INS_JCXZ,
#ifndef CAPSTONE_DIET
	{ X86_REG_CX, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JECXZ, X86_INS_JECXZ,
#ifndef CAPSTONE_DIET
	{ X86_REG_ECX, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JE_1, X86_INS_JE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JE_2, X86_INS_JE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JE_4, X86_INS_JE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JGE_1, X86_INS_JGE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JGE_2, X86_INS_JGE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JGE_4, X86_INS_JGE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JG_1, X86_INS_JG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JG_2, X86_INS_JG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JG_4, X86_INS_JG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JLE_1, X86_INS_JLE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JLE_2, X86_INS_JLE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JLE_4, X86_INS_JLE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JL_1, X86_INS_JL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JL_2, X86_INS_JL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JL_4, X86_INS_JL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JMP16m, X86_INS_JMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 1, 1
#endif
},
{
	X86_JMP16r, X86_INS_JMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 1, 1
#endif
},
{
	X86_JMP32m, X86_INS_JMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 1, 1
#endif
},
{
	X86_JMP32r, X86_INS_JMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 1, 1
#endif
},
{
	X86_JMP64m, X86_INS_JMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 1, 1
#endif
},
{
	X86_JMP64r, X86_INS_JMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 1, 1
#endif
},
{
	X86_JMP_1, X86_INS_JMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JMP_2, X86_INS_JMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JMP_4, X86_INS_JMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JNE_1, X86_INS_JNE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JNE_2, X86_INS_JNE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JNE_4, X86_INS_JNE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JNO_1, X86_INS_JNO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JNO_2, X86_INS_JNO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JNO_4, X86_INS_JNO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JNP_1, X86_INS_JNP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JNP_2, X86_INS_JNP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JNP_4, X86_INS_JNP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JNS_1, X86_INS_JNS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JNS_2, X86_INS_JNS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JNS_4, X86_INS_JNS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JO_1, X86_INS_JO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JO_2, X86_INS_JO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JO_4, X86_INS_JO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JP_1, X86_INS_JP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JP_2, X86_INS_JP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JP_4, X86_INS_JP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JRCXZ, X86_INS_JRCXZ,
#ifndef CAPSTONE_DIET
	{ X86_REG_RCX, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JS_1, X86_INS_JS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JS_2, X86_INS_JS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_JS_4, X86_INS_JS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 1, 0
#endif
},
{
	X86_KANDBrr, X86_INS_KANDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KANDDrr, X86_INS_KANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KANDNBrr, X86_INS_KANDNB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KANDNDrr, X86_INS_KANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KANDNQrr, X86_INS_KANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KANDNWrr, X86_INS_KANDNW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KANDQrr, X86_INS_KANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KANDWrr, X86_INS_KANDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KMOVBkk, X86_INS_KMOVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KMOVBkm, X86_INS_KMOVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KMOVBkr, X86_INS_KMOVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KMOVBmk, X86_INS_KMOVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KMOVBrk, X86_INS_KMOVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KMOVDkk, X86_INS_KMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KMOVDkm, X86_INS_KMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KMOVDkr, X86_INS_KMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KMOVDmk, X86_INS_KMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KMOVDrk, X86_INS_KMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KMOVQkk, X86_INS_KMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KMOVQkm, X86_INS_KMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KMOVQkr, X86_INS_KMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KMOVQmk, X86_INS_KMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KMOVQrk, X86_INS_KMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KMOVWkk, X86_INS_KMOVW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KMOVWkm, X86_INS_KMOVW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KMOVWkr, X86_INS_KMOVW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KMOVWmk, X86_INS_KMOVW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KMOVWrk, X86_INS_KMOVW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KNOTBrr, X86_INS_KNOTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KNOTDrr, X86_INS_KNOTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KNOTQrr, X86_INS_KNOTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KNOTWrr, X86_INS_KNOTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KORBrr, X86_INS_KORB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KORDrr, X86_INS_KORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KORQrr, X86_INS_KORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KORTESTBrr, X86_INS_KORTESTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KORTESTDrr, X86_INS_KORTESTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KORTESTQrr, X86_INS_KORTESTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KORTESTWrr, X86_INS_KORTESTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KORWrr, X86_INS_KORW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KSHIFTLBri, X86_INS_KSHIFTLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KSHIFTLDri, X86_INS_KSHIFTLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KSHIFTLQri, X86_INS_KSHIFTLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KSHIFTLWri, X86_INS_KSHIFTLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KSHIFTRBri, X86_INS_KSHIFTRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KSHIFTRDri, X86_INS_KSHIFTRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KSHIFTRQri, X86_INS_KSHIFTRQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KSHIFTRWri, X86_INS_KSHIFTRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KUNPCKBWrr, X86_INS_KUNPCKBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KXNORBrr, X86_INS_KXNORB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KXNORDrr, X86_INS_KXNORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KXNORQrr, X86_INS_KXNORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KXNORWrr, X86_INS_KXNORW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_KXORBrr, X86_INS_KXORB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_KXORDrr, X86_INS_KXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KXORQrr, X86_INS_KXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_KXORWrr, X86_INS_KXORW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_LAHF, X86_INS_LAHF,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_AH, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LAR16rm, X86_INS_LAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LAR16rr, X86_INS_LAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LAR32rm, X86_INS_LAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LAR32rr, X86_INS_LAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LAR64rm, X86_INS_LAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LAR64rr, X86_INS_LAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LCMPXCHG16, X86_INS_CMPXCHG,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { X86_REG_AX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LCMPXCHG16B, X86_INS_CMPXCHG16B,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, X86_REG_RBX, X86_REG_RCX, X86_REG_RDX, 0 }, { X86_REG_RAX, X86_REG_RDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LCMPXCHG32, X86_INS_CMPXCHG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { X86_REG_EAX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LCMPXCHG64, X86_INS_CMPXCHG,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, 0 }, { X86_REG_RAX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LCMPXCHG8, X86_INS_CMPXCHG,
#ifndef CAPSTONE_DIET
	{ X86_REG_AL, 0 }, { X86_REG_AL, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LCMPXCHG8B, X86_INS_CMPXCHG8B,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EBX, X86_REG_ECX, X86_REG_EDX, 0 }, { X86_REG_EAX, X86_REG_EDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LDDQUrm, X86_INS_LDDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_LDMXCSR, X86_INS_LDMXCSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_LDS16rm, X86_INS_LDS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LDS32rm, X86_INS_LDS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LD_F0, X86_INS_FLDZ,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_LD_F1, X86_INS_FLD1,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_LD_F32m, X86_INS_FLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_LD_F64m, X86_INS_FLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_LD_F80m, X86_INS_FLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_LD_Frr, X86_INS_FLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_LEA16r, X86_INS_LEA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LEA32r, X86_INS_LEA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_LEA64_32r, X86_INS_LEA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_LEA64r, X86_INS_LEA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LEAVE, X86_INS_LEAVE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EBP, X86_REG_ESP, 0 }, { X86_REG_EBP, X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_LEAVE64, X86_INS_LEAVE,
#ifndef CAPSTONE_DIET
	{ X86_REG_RBP, X86_REG_RSP, 0 }, { X86_REG_RBP, X86_REG_RSP, 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_LES16rm, X86_INS_LES,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LES32rm, X86_INS_LES,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LFENCE, X86_INS_LFENCE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_LFS16rm, X86_INS_LFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LFS32rm, X86_INS_LFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LFS64rm, X86_INS_LFS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LGDT16m, X86_INS_LGDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_LGDT32m, X86_INS_LGDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_LGDT64m, X86_INS_LGDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_LGS16rm, X86_INS_LGS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LGS32rm, X86_INS_LGS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LGS64rm, X86_INS_LGS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LIDT16m, X86_INS_LIDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_LIDT32m, X86_INS_LIDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_LIDT64m, X86_INS_LIDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_LLDT16m, X86_INS_LLDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_LLDT16r, X86_INS_LLDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_LMSW16m, X86_INS_LMSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_LMSW16r, X86_INS_LMSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_LOCK_ADD16mi, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_ADD16mi8, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_ADD16mr, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_ADD32mi, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_ADD32mi8, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_ADD32mr, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_ADD64mi32, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_ADD64mi8, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_ADD64mr, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_ADD8mi, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_ADD8mr, X86_INS_ADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_AND16mi, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_AND16mi8, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_AND16mr, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_AND32mi, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_AND32mi8, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_AND32mr, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_AND64mi32, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_AND64mi8, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_AND64mr, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_AND8mi, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_AND8mr, X86_INS_AND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_DEC16m, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_DEC32m, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_DEC64m, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_DEC8m, X86_INS_DEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_INC16m, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_INC32m, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_INC64m, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_INC8m, X86_INS_INC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_OR16mi, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_OR16mi8, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_OR16mr, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_OR32mi, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_OR32mi8, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_OR32mr, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_OR64mi32, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_OR64mi8, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_OR64mr, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_OR8mi, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_OR8mr, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_SUB16mi, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_SUB16mi8, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_SUB16mr, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_SUB32mi, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_SUB32mi8, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_SUB32mr, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_SUB64mi32, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_SUB64mi8, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_SUB64mr, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_SUB8mi, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_SUB8mr, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_XOR16mi, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_XOR16mi8, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_XOR16mr, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_XOR32mi, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_XOR32mi8, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_XOR32mr, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_XOR64mi32, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_XOR64mi8, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_XOR64mr, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_XOR8mi, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOCK_XOR8mr, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LODSB, X86_INS_LODSB,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_AL, X86_REG_ESI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LODSL, X86_INS_LODSD,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_EAX, X86_REG_ESI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LODSQ, X86_INS_LODSQ,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_RAX, X86_REG_ESI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LODSW, X86_INS_LODSW,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_AX, X86_REG_ESI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LOOP, X86_INS_LOOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 0, 0
#endif
},
{
	X86_LOOPE, X86_INS_LOOPE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 0, 0
#endif
},
{
	X86_LOOPNE, X86_INS_LOOPNE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BRANCH_RELATIVE, 0 }, 0, 0
#endif
},
{
	X86_LRETIL, X86_INS_RETF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RET, 0 }, 0, 0
#endif
},
{
	X86_LRETIQ, X86_INS_RETFQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RET, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_LRETIW, X86_INS_RETF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RET, 0 }, 0, 0
#endif
},
{
	X86_LRETL, X86_INS_RETF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RET, 0 }, 0, 0
#endif
},
{
	X86_LRETQ, X86_INS_RETFQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RET, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_LRETW, X86_INS_RETF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RET, 0 }, 0, 0
#endif
},
{
	X86_LSL16rm, X86_INS_LSL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LSL16rr, X86_INS_LSL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LSL32rm, X86_INS_LSL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LSL32rr, X86_INS_LSL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LSL64rm, X86_INS_LSL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LSL64rr, X86_INS_LSL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LSS16rm, X86_INS_LSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LSS32rm, X86_INS_LSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LSS64rm, X86_INS_LSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LTRm, X86_INS_LTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_LTRr, X86_INS_LTR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_LXADD16, X86_INS_XADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LXADD32, X86_INS_XADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LXADD64, X86_INS_XADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LXADD8, X86_INS_XADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LZCNT16rm, X86_INS_LZCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LZCNT16rr, X86_INS_LZCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LZCNT32rm, X86_INS_LZCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LZCNT32rr, X86_INS_LZCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LZCNT64rm, X86_INS_LZCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_LZCNT64rr, X86_INS_LZCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MASKMOVDQU, X86_INS_MASKMOVDQU,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDI, 0 }, { 0 }, { X86_GRP_SSE2, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_MASKMOVDQU64, X86_INS_MASKMOVDQU,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDI, 0 }, { 0 }, { X86_GRP_SSE2, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_MAXCPDrm, X86_INS_MAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MAXCPDrr, X86_INS_MAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MAXCPSrm, X86_INS_MAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MAXCPSrr, X86_INS_MAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MAXCSDrm, X86_INS_MAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MAXCSDrr, X86_INS_MAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MAXCSSrm, X86_INS_MAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MAXCSSrr, X86_INS_MAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MAXPDrm, X86_INS_MAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MAXPDrr, X86_INS_MAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MAXPSrm, X86_INS_MAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MAXPSrr, X86_INS_MAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MAXSDrm, X86_INS_MAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MAXSDrm_Int, X86_INS_MAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MAXSDrr, X86_INS_MAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MAXSDrr_Int, X86_INS_MAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MAXSSrm, X86_INS_MAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MAXSSrm_Int, X86_INS_MAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MAXSSrr, X86_INS_MAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MAXSSrr_Int, X86_INS_MAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MFENCE, X86_INS_MFENCE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MINCPDrm, X86_INS_MINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MINCPDrr, X86_INS_MINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MINCPSrm, X86_INS_MINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MINCPSrr, X86_INS_MINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MINCSDrm, X86_INS_MINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MINCSDrr, X86_INS_MINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MINCSSrm, X86_INS_MINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MINCSSrr, X86_INS_MINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MINPDrm, X86_INS_MINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MINPDrr, X86_INS_MINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MINPSrm, X86_INS_MINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MINPSrr, X86_INS_MINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MINSDrm, X86_INS_MINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MINSDrm_Int, X86_INS_MINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MINSDrr, X86_INS_MINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MINSDrr_Int, X86_INS_MINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MINSSrm, X86_INS_MINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MINSSrm_Int, X86_INS_MINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MINSSrr, X86_INS_MINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MINSSrr_Int, X86_INS_MINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MMX_CVTPD2PIirm, X86_INS_CVTPD2PI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MMX_CVTPD2PIirr, X86_INS_CVTPD2PI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MMX_CVTPI2PDirm, X86_INS_CVTPI2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MMX_CVTPI2PDirr, X86_INS_CVTPI2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MMX_CVTPI2PSirm, X86_INS_CVTPI2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MMX_CVTPI2PSirr, X86_INS_CVTPI2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MMX_CVTPS2PIirm, X86_INS_CVTPS2PI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MMX_CVTPS2PIirr, X86_INS_CVTPS2PI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MMX_CVTTPD2PIirm, X86_INS_CVTTPD2PI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MMX_CVTTPD2PIirr, X86_INS_CVTTPD2PI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MMX_CVTTPS2PIirm, X86_INS_CVTTPS2PI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MMX_CVTTPS2PIirr, X86_INS_CVTTPS2PI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MMX_EMMS, X86_INS_EMMS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_MASKMOVQ, X86_INS_MASKMOVQ,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDI, 0 }, { 0 }, { X86_GRP_MMX, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_MMX_MASKMOVQ64, X86_INS_MASKMOVQ,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDI, 0 }, { 0 }, { X86_GRP_MMX, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVD64from64rm, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVD64from64rr, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVD64grr, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVD64mr, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVD64rm, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVD64rr, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVD64to64rm, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVD64to64rr, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVDQ2Qrr, X86_INS_MOVDQ2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVFR642Qrr, X86_INS_MOVDQ2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVNTQmr, X86_INS_MOVNTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVQ2DQrr, X86_INS_MOVQ2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVQ2FR64rr, X86_INS_MOVQ2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVQ64mr, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVQ64rm, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVQ64rr, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_MOVQ64rr_REV, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PABSBrm64, X86_INS_PABSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PABSBrr64, X86_INS_PABSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PABSDrm64, X86_INS_PABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PABSDrr64, X86_INS_PABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PABSWrm64, X86_INS_PABSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PABSWrr64, X86_INS_PABSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PACKSSDWirm, X86_INS_PACKSSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PACKSSDWirr, X86_INS_PACKSSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PACKSSWBirm, X86_INS_PACKSSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PACKSSWBirr, X86_INS_PACKSSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PACKUSWBirm, X86_INS_PACKUSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PACKUSWBirr, X86_INS_PACKUSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDBirm, X86_INS_PADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDBirr, X86_INS_PADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDDirm, X86_INS_PADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDDirr, X86_INS_PADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDQirm, X86_INS_PADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDQirr, X86_INS_PADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDSBirm, X86_INS_PADDSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDSBirr, X86_INS_PADDSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDSWirm, X86_INS_PADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDSWirr, X86_INS_PADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDUSBirm, X86_INS_PADDUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDUSBirr, X86_INS_PADDUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDUSWirm, X86_INS_PADDUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDUSWirr, X86_INS_PADDUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDWirm, X86_INS_PADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PADDWirr, X86_INS_PADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PALIGNR64irm, X86_INS_PALIGNR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PALIGNR64irr, X86_INS_PALIGNR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PANDNirm, X86_INS_PANDN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PANDNirr, X86_INS_PANDN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PANDirm, X86_INS_PAND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PANDirr, X86_INS_PAND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PAVGBirm, X86_INS_PAVGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PAVGBirr, X86_INS_PAVGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PAVGWirm, X86_INS_PAVGW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PAVGWirr, X86_INS_PAVGW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PCMPEQBirm, X86_INS_PCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PCMPEQBirr, X86_INS_PCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PCMPEQDirm, X86_INS_PCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PCMPEQDirr, X86_INS_PCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PCMPEQWirm, X86_INS_PCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PCMPEQWirr, X86_INS_PCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PCMPGTBirm, X86_INS_PCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PCMPGTBirr, X86_INS_PCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PCMPGTDirm, X86_INS_PCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PCMPGTDirr, X86_INS_PCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PCMPGTWirm, X86_INS_PCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PCMPGTWirr, X86_INS_PCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PEXTRWirri, X86_INS_PEXTRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PHADDSWrm64, X86_INS_PHADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PHADDSWrr64, X86_INS_PHADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PHADDWrm64, X86_INS_PHADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PHADDWrr64, X86_INS_PHADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PHADDrm64, X86_INS_PHADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PHADDrr64, X86_INS_PHADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PHSUBDrm64, X86_INS_PHSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PHSUBDrr64, X86_INS_PHSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PHSUBSWrm64, X86_INS_PHSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PHSUBSWrr64, X86_INS_PHSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PHSUBWrm64, X86_INS_PHSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PHSUBWrr64, X86_INS_PHSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PINSRWirmi, X86_INS_PINSRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PINSRWirri, X86_INS_PINSRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMADDUBSWrm64, X86_INS_PMADDUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMADDUBSWrr64, X86_INS_PMADDUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMADDWDirm, X86_INS_PMADDWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMADDWDirr, X86_INS_PMADDWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMAXSWirm, X86_INS_PMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMAXSWirr, X86_INS_PMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMAXUBirm, X86_INS_PMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMAXUBirr, X86_INS_PMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMINSWirm, X86_INS_PMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMINSWirr, X86_INS_PMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMINUBirm, X86_INS_PMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMINUBirr, X86_INS_PMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMOVMSKBrr, X86_INS_PMOVMSKB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMULHRSWrm64, X86_INS_PMULHRSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMULHRSWrr64, X86_INS_PMULHRSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMULHUWirm, X86_INS_PMULHUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMULHUWirr, X86_INS_PMULHUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMULHWirm, X86_INS_PMULHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMULHWirr, X86_INS_PMULHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMULLWirm, X86_INS_PMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMULLWirr, X86_INS_PMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMULUDQirm, X86_INS_PMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PMULUDQirr, X86_INS_PMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PORirm, X86_INS_POR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PORirr, X86_INS_POR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSADBWirm, X86_INS_PSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSADBWirr, X86_INS_PSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSHUFBrm64, X86_INS_PSHUFB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSHUFBrr64, X86_INS_PSHUFB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSHUFWmi, X86_INS_PSHUFW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSHUFWri, X86_INS_PSHUFW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSIGNBrm64, X86_INS_PSIGNB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSIGNBrr64, X86_INS_PSIGNB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSIGNDrm64, X86_INS_PSIGND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSIGNDrr64, X86_INS_PSIGND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSIGNWrm64, X86_INS_PSIGNW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSIGNWrr64, X86_INS_PSIGNW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSLLDri, X86_INS_PSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSLLDrm, X86_INS_PSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSLLDrr, X86_INS_PSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSLLQri, X86_INS_PSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSLLQrm, X86_INS_PSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSLLQrr, X86_INS_PSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSLLWri, X86_INS_PSLLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSLLWrm, X86_INS_PSLLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSLLWrr, X86_INS_PSLLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRADri, X86_INS_PSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRADrm, X86_INS_PSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRADrr, X86_INS_PSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRAWri, X86_INS_PSRAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRAWrm, X86_INS_PSRAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRAWrr, X86_INS_PSRAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRLDri, X86_INS_PSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRLDrm, X86_INS_PSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRLDrr, X86_INS_PSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRLQri, X86_INS_PSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRLQrm, X86_INS_PSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRLQrr, X86_INS_PSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRLWri, X86_INS_PSRLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRLWrm, X86_INS_PSRLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSRLWrr, X86_INS_PSRLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBBirm, X86_INS_PSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBBirr, X86_INS_PSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBDirm, X86_INS_PSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBDirr, X86_INS_PSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBQirm, X86_INS_PSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBQirr, X86_INS_PSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBSBirm, X86_INS_PSUBSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBSBirr, X86_INS_PSUBSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBSWirm, X86_INS_PSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBSWirr, X86_INS_PSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBUSBirm, X86_INS_PSUBUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBUSBirr, X86_INS_PSUBUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBUSWirm, X86_INS_PSUBUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBUSWirr, X86_INS_PSUBUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBWirm, X86_INS_PSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PSUBWirr, X86_INS_PSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PUNPCKHBWirm, X86_INS_PUNPCKHBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PUNPCKHBWirr, X86_INS_PUNPCKHBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PUNPCKHDQirm, X86_INS_PUNPCKHDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PUNPCKHDQirr, X86_INS_PUNPCKHDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PUNPCKHWDirm, X86_INS_PUNPCKHWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PUNPCKHWDirr, X86_INS_PUNPCKHWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PUNPCKLBWirm, X86_INS_PUNPCKLBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PUNPCKLBWirr, X86_INS_PUNPCKLBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PUNPCKLDQirm, X86_INS_PUNPCKLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PUNPCKLDQirr, X86_INS_PUNPCKLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PUNPCKLWDirm, X86_INS_PUNPCKLWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PUNPCKLWDirr, X86_INS_PUNPCKLWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PXORirm, X86_INS_PXOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MMX_PXORirr, X86_INS_PXOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MMX, 0 }, 0, 0
#endif
},
{
	X86_MONITORrrr, X86_INS_MONITOR,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_ECX, X86_REG_EDX, 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_MONTMUL, X86_INS_MONTMUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, X86_REG_RSI, 0 }, { X86_REG_RAX, X86_REG_RDX, X86_REG_RSI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16ao16, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16ao32, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16ao64, X86_INS_MOVABS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16mi, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16mr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16ms, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16o16a, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16o32a, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16o64a, X86_INS_MOVABS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16ri, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16ri_alt, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16rm, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16rr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16rr_REV, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16rs, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV16sm, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_MOV16sr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_MOV32ao16, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32ao32, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32ao64, X86_INS_MOVABS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32cr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_MOV32dr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_MOV32mi, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32mr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32ms, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32o16a, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32o32a, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32o64a, X86_INS_MOVABS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32rc, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_MOV32rd, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_MOV32ri, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32ri_alt, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32rm, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32rr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32rr_REV, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32rs, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV32sm, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_MOV32sr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_MOV64ao32, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV64ao64, X86_INS_MOVABS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV64cr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_MOV64dr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_MOV64mi32, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV64mr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV64ms, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV64o32a, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV64o64a, X86_INS_MOVABS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV64rc, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_MOV64rd, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_MOV64ri, X86_INS_MOVABS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV64ri32, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV64rm, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV64rr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV64rr_REV, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV64rs, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV64sm, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_MOV64sr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_MOV64toPQIrm, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOV64toPQIrr, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOV64toSDrm, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOV64toSDrr, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOV8ao16, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8ao32, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8ao64, X86_INS_MOVABS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8mi, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8mr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8mr_NOREX, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8o16a, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8o32a, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8o64a, X86_INS_MOVABS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8ri, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8ri_alt, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8rm, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8rm_NOREX, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8rr, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8rr_NOREX, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOV8rr_REV, X86_INS_MOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVAPDmr, X86_INS_MOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVAPDrm, X86_INS_MOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVAPDrr, X86_INS_MOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVAPDrr_REV, X86_INS_MOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVAPSmr, X86_INS_MOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVAPSrm, X86_INS_MOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVAPSrr, X86_INS_MOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVAPSrr_REV, X86_INS_MOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVBE16mr, X86_INS_MOVBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVBE16rm, X86_INS_MOVBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVBE32mr, X86_INS_MOVBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVBE32rm, X86_INS_MOVBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVBE64mr, X86_INS_MOVBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVBE64rm, X86_INS_MOVBE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVDDUPrm, X86_INS_MOVDDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_MOVDDUPrr, X86_INS_MOVDDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_MOVDI2PDIrm, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVDI2PDIrr, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVDI2SSrm, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVDI2SSrr, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVDQAmr, X86_INS_MOVDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVDQArm, X86_INS_MOVDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVDQArr, X86_INS_MOVDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVDQArr_REV, X86_INS_MOVDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVDQUmr, X86_INS_MOVDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVDQUrm, X86_INS_MOVDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVDQUrr, X86_INS_MOVDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVDQUrr_REV, X86_INS_MOVDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVHLPSrr, X86_INS_MOVHLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVHPDmr, X86_INS_MOVHPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVHPDrm, X86_INS_MOVHPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVHPSmr, X86_INS_MOVHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVHPSrm, X86_INS_MOVHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVLHPSrr, X86_INS_MOVLHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVLPDmr, X86_INS_MOVLPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVLPDrm, X86_INS_MOVLPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVLPSmr, X86_INS_MOVLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVLPSrm, X86_INS_MOVLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVMSKPDrr, X86_INS_MOVMSKPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVMSKPSrr, X86_INS_MOVMSKPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVNTDQArm, X86_INS_MOVNTDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_MOVNTDQmr, X86_INS_MOVNTDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVNTI_64mr, X86_INS_MOVNTI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVNTImr, X86_INS_MOVNTI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVNTPDmr, X86_INS_MOVNTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVNTPSmr, X86_INS_MOVNTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVNTSD, X86_INS_MOVNTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE4A, 0 }, 0, 0
#endif
},
{
	X86_MOVNTSS, X86_INS_MOVNTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE4A, 0 }, 0, 0
#endif
},
{
	X86_MOVPDI2DImr, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVPDI2DIrr, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVPQI2QImr, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVPQI2QIrr, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVPQIto64rm, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVPQIto64rr, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVQI2PQIrm, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVSB, X86_INS_MOVSB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDI, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, X86_REG_ESI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSDmr, X86_INS_MOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVSDrm, X86_INS_MOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVSDrr, X86_INS_MOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVSDrr_REV, X86_INS_MOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVSDto64mr, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVSDto64rr, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVSHDUPrm, X86_INS_MOVSHDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_MOVSHDUPrr, X86_INS_MOVSHDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_MOVSL, X86_INS_MOVSD,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDI, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, X86_REG_ESI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSLDUPrm, X86_INS_MOVSLDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_MOVSLDUPrr, X86_INS_MOVSLDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_MOVSQ, X86_INS_MOVSQ,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDI, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, X86_REG_ESI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSS2DImr, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVSS2DIrr, X86_INS_MOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVSSmr, X86_INS_MOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVSSrm, X86_INS_MOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVSSrr, X86_INS_MOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVSSrr_REV, X86_INS_MOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVSW, X86_INS_MOVSW,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDI, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, X86_REG_ESI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSX16rm8, X86_INS_MOVSX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSX16rr8, X86_INS_MOVSX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSX32_NOREXrm8, X86_INS_MOVSX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSX32_NOREXrr8, X86_INS_MOVSX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSX32rm16, X86_INS_MOVSX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSX32rm8, X86_INS_MOVSX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSX32rr16, X86_INS_MOVSX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSX32rr8, X86_INS_MOVSX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSX64_NOREXrr32, X86_INS_MOVSXD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_MOVSX64rm16, X86_INS_MOVSX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSX64rm32, X86_INS_MOVSXD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_MOVSX64rm32_alt, X86_INS_MOVSXD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_MOVSX64rm8, X86_INS_MOVSX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSX64rr16, X86_INS_MOVSX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVSX64rr32, X86_INS_MOVSXD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_MOVSX64rr8, X86_INS_MOVSX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVUPDmr, X86_INS_MOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVUPDrm, X86_INS_MOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVUPDrr, X86_INS_MOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVUPDrr_REV, X86_INS_MOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVUPSmr, X86_INS_MOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVUPSrm, X86_INS_MOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVUPSrr, X86_INS_MOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVUPSrr_REV, X86_INS_MOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MOVZPQILo2PQIrm, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVZPQILo2PQIrr, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVZQI2PQIrm, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVZQI2PQIrr, X86_INS_MOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MOVZX16rm8, X86_INS_MOVZX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVZX16rr8, X86_INS_MOVZX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVZX32_NOREXrm8, X86_INS_MOVZX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVZX32_NOREXrr8, X86_INS_MOVZX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVZX32rm16, X86_INS_MOVZX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVZX32rm8, X86_INS_MOVZX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVZX32rr16, X86_INS_MOVZX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVZX32rr8, X86_INS_MOVZX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVZX64rm16_Q, X86_INS_MOVZX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVZX64rm8_Q, X86_INS_MOVZX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVZX64rr16_Q, X86_INS_MOVZX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MOVZX64rr8_Q, X86_INS_MOVZX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MPSADBWrmi, X86_INS_MPSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_MPSADBWrri, X86_INS_MPSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_MUL16m, X86_INS_MUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { X86_REG_AX, X86_REG_DX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MUL16r, X86_INS_MUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { X86_REG_AX, X86_REG_DX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MUL32m, X86_INS_MUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { X86_REG_EAX, X86_REG_EDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MUL32r, X86_INS_MUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { X86_REG_EAX, X86_REG_EDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MUL64m, X86_INS_MUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, 0 }, { X86_REG_RAX, X86_REG_RDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MUL64r, X86_INS_MUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, 0 }, { X86_REG_RAX, X86_REG_RDX, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MUL8m, X86_INS_MUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_AL, 0 }, { X86_REG_AL, X86_REG_EFLAGS, X86_REG_AX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MUL8r, X86_INS_MUL,
#ifndef CAPSTONE_DIET
	{ X86_REG_AL, 0 }, { X86_REG_AL, X86_REG_EFLAGS, X86_REG_AX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_MULPDrm, X86_INS_MULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MULPDrr, X86_INS_MULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MULPSrm, X86_INS_MULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MULPSrr, X86_INS_MULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MULSDrm, X86_INS_MULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MULSDrm_Int, X86_INS_MULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MULSDrr, X86_INS_MULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MULSDrr_Int, X86_INS_MULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_MULSSrm, X86_INS_MULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MULSSrm_Int, X86_INS_MULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MULSSrr, X86_INS_MULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MULSSrr_Int, X86_INS_MULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_MULX32rm, X86_INS_MULX,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDX, 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_MULX32rr, X86_INS_MULX,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDX, 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_MULX64rm, X86_INS_MULX,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_MULX64rr, X86_INS_MULX,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_MUL_F32m, X86_INS_FMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_MUL_F64m, X86_INS_FMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_MUL_FI16m, X86_INS_FIMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_MUL_FI32m, X86_INS_FIMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_MUL_FPrST0, X86_INS_FMULP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_MUL_FST0r, X86_INS_FMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_MUL_FrST0, X86_INS_FMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_MWAITrr, X86_INS_MWAIT,
#ifndef CAPSTONE_DIET
	{ X86_REG_ECX, X86_REG_EAX, 0 }, { 0 }, { X86_GRP_SSE3, 0 }, 0, 0
#endif
},
{
	X86_NEG16m, X86_INS_NEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NEG16r, X86_INS_NEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NEG32m, X86_INS_NEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NEG32r, X86_INS_NEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NEG64m, X86_INS_NEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NEG64r, X86_INS_NEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NEG8m, X86_INS_NEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NEG8r, X86_INS_NEG,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_16m4, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_16m5, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_16m6, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_16m7, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_16r4, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_16r5, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_16r6, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_16r7, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_m4, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_m5, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_m6, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_m7, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_r4, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_r5, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_r6, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP18_r7, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOP19rr, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPL, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPL_19, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPL_1a, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPL_1b, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPL_1c, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPL_1d, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPL_1e, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPW, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPW_19, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPW_1a, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPW_1b, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPW_1c, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPW_1d, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOOPW_1e, X86_INS_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOT16m, X86_INS_NOT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOT16r, X86_INS_NOT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOT32m, X86_INS_NOT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOT32r, X86_INS_NOT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOT64m, X86_INS_NOT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOT64r, X86_INS_NOT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOT8m, X86_INS_NOT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_NOT8r, X86_INS_NOT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR16i16, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR16mi, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR16mi8, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR16mr, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR16ri, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR16ri8, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR16rm, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR16rr, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR16rr_REV, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR32i32, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR32mi, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR32mi8, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR32mr, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR32mrLocked, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_OR32ri, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR32ri8, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR32rm, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR32rr, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR32rr_REV, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR64i32, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR64mi32, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR64mi8, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR64mr, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR64ri32, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR64ri8, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR64rm, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR64rr, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR64rr_REV, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR8i8, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR8mi, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR8mi8, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_OR8mr, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR8ri, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR8ri8, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_OR8rm, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR8rr, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OR8rr_REV, X86_INS_OR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ORPDrm, X86_INS_ORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_ORPDrr, X86_INS_ORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_ORPSrm, X86_INS_ORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_ORPSrr, X86_INS_ORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_OUT16ir, X86_INS_OUT,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OUT16rr, X86_INS_OUT,
#ifndef CAPSTONE_DIET
	{ X86_REG_DX, X86_REG_AX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OUT32ir, X86_INS_OUT,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OUT32rr, X86_INS_OUT,
#ifndef CAPSTONE_DIET
	{ X86_REG_DX, X86_REG_EAX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OUT8ir, X86_INS_OUT,
#ifndef CAPSTONE_DIET
	{ X86_REG_AL, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OUT8rr, X86_INS_OUT,
#ifndef CAPSTONE_DIET
	{ X86_REG_DX, X86_REG_AL, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OUTSB, X86_INS_OUTSB,
#ifndef CAPSTONE_DIET
	{ X86_REG_DX, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_ESI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OUTSL, X86_INS_OUTSD,
#ifndef CAPSTONE_DIET
	{ X86_REG_DX, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_ESI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_OUTSW, X86_INS_OUTSW,
#ifndef CAPSTONE_DIET
	{ X86_REG_DX, X86_REG_ESI, X86_REG_EFLAGS, 0 }, { X86_REG_ESI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_PABSBrm128, X86_INS_PABSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PABSBrr128, X86_INS_PABSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PABSDrm128, X86_INS_PABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PABSDrr128, X86_INS_PABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PABSWrm128, X86_INS_PABSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PABSWrr128, X86_INS_PABSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PACKSSDWrm, X86_INS_PACKSSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PACKSSDWrr, X86_INS_PACKSSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PACKSSWBrm, X86_INS_PACKSSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PACKSSWBrr, X86_INS_PACKSSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PACKUSDWrm, X86_INS_PACKUSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PACKUSDWrr, X86_INS_PACKUSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PACKUSWBrm, X86_INS_PACKUSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PACKUSWBrr, X86_INS_PACKUSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDBrm, X86_INS_PADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDBrr, X86_INS_PADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDDrm, X86_INS_PADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDDrr, X86_INS_PADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDQrm, X86_INS_PADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDQrr, X86_INS_PADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDSBrm, X86_INS_PADDSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDSBrr, X86_INS_PADDSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDSWrm, X86_INS_PADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDSWrr, X86_INS_PADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDUSBrm, X86_INS_PADDUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDUSBrr, X86_INS_PADDUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDUSWrm, X86_INS_PADDUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDUSWrr, X86_INS_PADDUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDWrm, X86_INS_PADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PADDWrr, X86_INS_PADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PALIGNR128rm, X86_INS_PALIGNR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PALIGNR128rr, X86_INS_PALIGNR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PANDNrm, X86_INS_PANDN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PANDNrr, X86_INS_PANDN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PANDrm, X86_INS_PAND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PANDrr, X86_INS_PAND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PAUSE, X86_INS_PAUSE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PAVGBrm, X86_INS_PAVGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PAVGBrr, X86_INS_PAVGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PAVGUSBrm, X86_INS_PAVGUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PAVGUSBrr, X86_INS_PAVGUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PAVGWrm, X86_INS_PAVGW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PAVGWrr, X86_INS_PAVGW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PBLENDVBrm0, X86_INS_PBLENDVB,
#ifndef CAPSTONE_DIET
	{ X86_REG_XMM0, 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PBLENDVBrr0, X86_INS_PBLENDVB,
#ifndef CAPSTONE_DIET
	{ X86_REG_XMM0, 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PBLENDWrmi, X86_INS_PBLENDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PBLENDWrri, X86_INS_PBLENDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PCLMULQDQrm, X86_INS_PCLMULQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PCLMUL, 0 }, 0, 0
#endif
},
{
	X86_PCLMULQDQrr, X86_INS_PCLMULQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PCLMUL, 0 }, 0, 0
#endif
},
{
	X86_PCMPEQBrm, X86_INS_PCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PCMPEQBrr, X86_INS_PCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PCMPEQDrm, X86_INS_PCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PCMPEQDrr, X86_INS_PCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PCMPEQQrm, X86_INS_PCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PCMPEQQrr, X86_INS_PCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PCMPEQWrm, X86_INS_PCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PCMPEQWrr, X86_INS_PCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PCMPESTRIrm, X86_INS_PCMPESTRI,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDX, 0 }, { X86_REG_ECX, X86_REG_EFLAGS, 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_PCMPESTRIrr, X86_INS_PCMPESTRI,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDX, 0 }, { X86_REG_ECX, X86_REG_EFLAGS, 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_PCMPESTRM128rm, X86_INS_PCMPESTRM,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDX, 0 }, { X86_REG_XMM0, X86_REG_EFLAGS, 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_PCMPESTRM128rr, X86_INS_PCMPESTRM,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDX, 0 }, { X86_REG_XMM0, X86_REG_EFLAGS, 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_PCMPGTBrm, X86_INS_PCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PCMPGTBrr, X86_INS_PCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PCMPGTDrm, X86_INS_PCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PCMPGTDrr, X86_INS_PCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PCMPGTQrm, X86_INS_PCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_PCMPGTQrr, X86_INS_PCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_PCMPGTWrm, X86_INS_PCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PCMPGTWrr, X86_INS_PCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PCMPISTRIrm, X86_INS_PCMPISTRI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_ECX, X86_REG_EFLAGS, 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_PCMPISTRIrr, X86_INS_PCMPISTRI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_ECX, X86_REG_EFLAGS, 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_PCMPISTRM128rm, X86_INS_PCMPISTRM,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_XMM0, X86_REG_EFLAGS, 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_PCMPISTRM128rr, X86_INS_PCMPISTRM,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_XMM0, X86_REG_EFLAGS, 0 }, { X86_GRP_SSE42, 0 }, 0, 0
#endif
},
{
	X86_PCOMMIT, X86_INS_PCOMMIT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_PDEP32rm, X86_INS_PDEP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_PDEP32rr, X86_INS_PDEP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_PDEP64rm, X86_INS_PDEP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_PDEP64rr, X86_INS_PDEP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_PEXT32rm, X86_INS_PEXT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_PEXT32rr, X86_INS_PEXT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_PEXT64rm, X86_INS_PEXT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_PEXT64rr, X86_INS_PEXT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_PEXTRBmr, X86_INS_PEXTRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PEXTRBrr, X86_INS_PEXTRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PEXTRDmr, X86_INS_PEXTRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PEXTRDrr, X86_INS_PEXTRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PEXTRQmr, X86_INS_PEXTRQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PEXTRQrr, X86_INS_PEXTRQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PEXTRWmr, X86_INS_PEXTRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PEXTRWri, X86_INS_PEXTRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PEXTRWrr_REV, X86_INS_PEXTRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PF2IDrm, X86_INS_PF2ID,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PF2IDrr, X86_INS_PF2ID,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PF2IWrm, X86_INS_PF2IW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PF2IWrr, X86_INS_PF2IW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFACCrm, X86_INS_PFACC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFACCrr, X86_INS_PFACC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFADDrm, X86_INS_PFADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFADDrr, X86_INS_PFADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFCMPEQrm, X86_INS_PFCMPEQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFCMPEQrr, X86_INS_PFCMPEQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFCMPGErm, X86_INS_PFCMPGE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFCMPGErr, X86_INS_PFCMPGE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFCMPGTrm, X86_INS_PFCMPGT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFCMPGTrr, X86_INS_PFCMPGT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFMAXrm, X86_INS_PFMAX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFMAXrr, X86_INS_PFMAX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFMINrm, X86_INS_PFMIN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFMINrr, X86_INS_PFMIN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFMULrm, X86_INS_PFMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFMULrr, X86_INS_PFMUL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFNACCrm, X86_INS_PFNACC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFNACCrr, X86_INS_PFNACC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFPNACCrm, X86_INS_PFPNACC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFPNACCrr, X86_INS_PFPNACC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFRCPIT1rm, X86_INS_PFRCPIT1,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFRCPIT1rr, X86_INS_PFRCPIT1,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFRCPIT2rm, X86_INS_PFRCPIT2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFRCPIT2rr, X86_INS_PFRCPIT2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFRCPrm, X86_INS_PFRCP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFRCPrr, X86_INS_PFRCP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFRSQIT1rm, X86_INS_PFRSQIT1,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFRSQIT1rr, X86_INS_PFRSQIT1,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFRSQRTrm, X86_INS_PFRSQRT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFRSQRTrr, X86_INS_PFRSQRT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFSUBRrm, X86_INS_PFSUBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFSUBRrr, X86_INS_PFSUBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFSUBrm, X86_INS_PFSUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PFSUBrr, X86_INS_PFSUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PHADDDrm, X86_INS_PHADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PHADDDrr, X86_INS_PHADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PHADDSWrm128, X86_INS_PHADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PHADDSWrr128, X86_INS_PHADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PHADDWrm, X86_INS_PHADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PHADDWrr, X86_INS_PHADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PHMINPOSUWrm128, X86_INS_PHMINPOSUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PHMINPOSUWrr128, X86_INS_PHMINPOSUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PHSUBDrm, X86_INS_PHSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PHSUBDrr, X86_INS_PHSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PHSUBSWrm128, X86_INS_PHSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PHSUBSWrr128, X86_INS_PHSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PHSUBWrm, X86_INS_PHSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PHSUBWrr, X86_INS_PHSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PI2FDrm, X86_INS_PI2FD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PI2FDrr, X86_INS_PI2FD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PI2FWrm, X86_INS_PI2FW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PI2FWrr, X86_INS_PI2FW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PINSRBrm, X86_INS_PINSRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PINSRBrr, X86_INS_PINSRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PINSRDrm, X86_INS_PINSRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PINSRDrr, X86_INS_PINSRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PINSRQrm, X86_INS_PINSRQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PINSRQrr, X86_INS_PINSRQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PINSRWrmi, X86_INS_PINSRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PINSRWrri, X86_INS_PINSRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMADDUBSWrm128, X86_INS_PMADDUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PMADDUBSWrr128, X86_INS_PMADDUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PMADDWDrm, X86_INS_PMADDWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMADDWDrr, X86_INS_PMADDWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMAXSBrm, X86_INS_PMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMAXSBrr, X86_INS_PMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMAXSDrm, X86_INS_PMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMAXSDrr, X86_INS_PMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMAXSWrm, X86_INS_PMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMAXSWrr, X86_INS_PMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMAXUBrm, X86_INS_PMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMAXUBrr, X86_INS_PMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMAXUDrm, X86_INS_PMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMAXUDrr, X86_INS_PMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMAXUWrm, X86_INS_PMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMAXUWrr, X86_INS_PMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMINSBrm, X86_INS_PMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMINSBrr, X86_INS_PMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMINSDrm, X86_INS_PMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMINSDrr, X86_INS_PMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMINSWrm, X86_INS_PMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMINSWrr, X86_INS_PMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMINUBrm, X86_INS_PMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMINUBrr, X86_INS_PMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMINUDrm, X86_INS_PMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMINUDrr, X86_INS_PMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMINUWrm, X86_INS_PMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMINUWrr, X86_INS_PMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVMSKBrr, X86_INS_PMOVMSKB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMOVSXBDrm, X86_INS_PMOVSXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVSXBDrr, X86_INS_PMOVSXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVSXBQrm, X86_INS_PMOVSXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVSXBQrr, X86_INS_PMOVSXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVSXBWrm, X86_INS_PMOVSXBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVSXBWrr, X86_INS_PMOVSXBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVSXDQrm, X86_INS_PMOVSXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVSXDQrr, X86_INS_PMOVSXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVSXWDrm, X86_INS_PMOVSXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVSXWDrr, X86_INS_PMOVSXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVSXWQrm, X86_INS_PMOVSXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVSXWQrr, X86_INS_PMOVSXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVZXBDrm, X86_INS_PMOVZXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVZXBDrr, X86_INS_PMOVZXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVZXBQrm, X86_INS_PMOVZXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVZXBQrr, X86_INS_PMOVZXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVZXBWrm, X86_INS_PMOVZXBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVZXBWrr, X86_INS_PMOVZXBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVZXDQrm, X86_INS_PMOVZXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVZXDQrr, X86_INS_PMOVZXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVZXWDrm, X86_INS_PMOVZXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVZXWDrr, X86_INS_PMOVZXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVZXWQrm, X86_INS_PMOVZXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMOVZXWQrr, X86_INS_PMOVZXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMULDQrm, X86_INS_PMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMULDQrr, X86_INS_PMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMULHRSWrm128, X86_INS_PMULHRSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PMULHRSWrr128, X86_INS_PMULHRSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PMULHRWrm, X86_INS_PMULHRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PMULHRWrr, X86_INS_PMULHRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PMULHUWrm, X86_INS_PMULHUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMULHUWrr, X86_INS_PMULHUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMULHWrm, X86_INS_PMULHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMULHWrr, X86_INS_PMULHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMULLDrm, X86_INS_PMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMULLDrr, X86_INS_PMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PMULLWrm, X86_INS_PMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMULLWrr, X86_INS_PMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMULUDQrm, X86_INS_PMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PMULUDQrr, X86_INS_PMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_POP16r, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_POP16rmm, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_POP16rmr, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_POP32r, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_POP32rmm, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_POP32rmr, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_POP64r, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, 0 }, { X86_REG_RSP, 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_POP64rmm, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, 0 }, { X86_REG_RSP, 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_POP64rmr, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, 0 }, { X86_REG_RSP, 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_POPA16, X86_INS_POPAW,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_EDI, X86_REG_ESI, X86_REG_EBP, X86_REG_EBX, X86_REG_EDX, X86_REG_ECX, X86_REG_EAX, X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_POPA32, X86_INS_POPAL,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_EDI, X86_REG_ESI, X86_REG_EBP, X86_REG_EBX, X86_REG_EDX, X86_REG_ECX, X86_REG_EAX, X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_POPCNT16rm, X86_INS_POPCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_POPCNT16rr, X86_INS_POPCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_POPCNT32rm, X86_INS_POPCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_POPCNT32rr, X86_INS_POPCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_POPCNT64rm, X86_INS_POPCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_POPCNT64rr, X86_INS_POPCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_POPDS16, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_POPDS32, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_POPES16, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_POPES32, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_POPF16, X86_INS_POPF,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_POPF32, X86_INS_POPFD,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_POPF64, X86_INS_POPFQ,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, 0 }, { X86_REG_RSP, X86_REG_EFLAGS, 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_POPFS16, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_POPFS32, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_POPFS64, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_POPGS16, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_POPGS32, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_POPGS64, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_POPSS16, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_POPSS32, X86_INS_POP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PORrm, X86_INS_POR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PORrr, X86_INS_POR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PREFETCH, X86_INS_PREFETCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PREFETCHNTA, X86_INS_PREFETCHNTA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_PREFETCHT0, X86_INS_PREFETCHT0,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_PREFETCHT1, X86_INS_PREFETCHT1,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_PREFETCHT2, X86_INS_PREFETCHT2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_PREFETCHW, X86_INS_PREFETCHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_PSADBWrm, X86_INS_PSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSADBWrr, X86_INS_PSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSHUFBrm, X86_INS_PSHUFB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PSHUFBrr, X86_INS_PSHUFB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PSHUFDmi, X86_INS_PSHUFD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSHUFDri, X86_INS_PSHUFD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSHUFHWmi, X86_INS_PSHUFHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSHUFHWri, X86_INS_PSHUFHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSHUFLWmi, X86_INS_PSHUFLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSHUFLWri, X86_INS_PSHUFLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSIGNBrm, X86_INS_PSIGNB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PSIGNBrr, X86_INS_PSIGNB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PSIGNDrm, X86_INS_PSIGND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PSIGNDrr, X86_INS_PSIGND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PSIGNWrm, X86_INS_PSIGNW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PSIGNWrr, X86_INS_PSIGNW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSSE3, 0 }, 0, 0
#endif
},
{
	X86_PSLLDQri, X86_INS_PSLLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSLLDri, X86_INS_PSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSLLDrm, X86_INS_PSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSLLDrr, X86_INS_PSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSLLQri, X86_INS_PSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSLLQrm, X86_INS_PSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSLLQrr, X86_INS_PSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSLLWri, X86_INS_PSLLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSLLWrm, X86_INS_PSLLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSLLWrr, X86_INS_PSLLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRADri, X86_INS_PSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRADrm, X86_INS_PSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRADrr, X86_INS_PSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRAWri, X86_INS_PSRAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRAWrm, X86_INS_PSRAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRAWrr, X86_INS_PSRAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRLDQri, X86_INS_PSRLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRLDri, X86_INS_PSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRLDrm, X86_INS_PSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRLDrr, X86_INS_PSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRLQri, X86_INS_PSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRLQrm, X86_INS_PSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRLQrr, X86_INS_PSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRLWri, X86_INS_PSRLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRLWrm, X86_INS_PSRLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSRLWrr, X86_INS_PSRLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBBrm, X86_INS_PSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBBrr, X86_INS_PSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBDrm, X86_INS_PSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBDrr, X86_INS_PSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBQrm, X86_INS_PSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBQrr, X86_INS_PSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBSBrm, X86_INS_PSUBSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBSBrr, X86_INS_PSUBSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBSWrm, X86_INS_PSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBSWrr, X86_INS_PSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBUSBrm, X86_INS_PSUBUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBUSBrr, X86_INS_PSUBUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBUSWrm, X86_INS_PSUBUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBUSWrr, X86_INS_PSUBUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBWrm, X86_INS_PSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSUBWrr, X86_INS_PSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PSWAPDrm, X86_INS_PSWAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PSWAPDrr, X86_INS_PSWAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_3DNOW, 0 }, 0, 0
#endif
},
{
	X86_PTESTrm, X86_INS_PTEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PTESTrr, X86_INS_PTEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKHBWrm, X86_INS_PUNPCKHBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKHBWrr, X86_INS_PUNPCKHBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKHDQrm, X86_INS_PUNPCKHDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKHDQrr, X86_INS_PUNPCKHDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKHQDQrm, X86_INS_PUNPCKHQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKHQDQrr, X86_INS_PUNPCKHQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKHWDrm, X86_INS_PUNPCKHWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKHWDrr, X86_INS_PUNPCKHWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKLBWrm, X86_INS_PUNPCKLBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKLBWrr, X86_INS_PUNPCKLBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKLDQrm, X86_INS_PUNPCKLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKLDQrr, X86_INS_PUNPCKLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKLQDQrm, X86_INS_PUNPCKLQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKLQDQrr, X86_INS_PUNPCKLQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKLWDrm, X86_INS_PUNPCKLWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUNPCKLWDrr, X86_INS_PUNPCKLWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PUSH16i8, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSH16r, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_PUSH16rmm, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_PUSH16rmr, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_PUSH32i8, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSH32r, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSH32rmm, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSH32rmr, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSH64i16, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, 0 }, { X86_REG_RSP, 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_PUSH64i32, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, 0 }, { X86_REG_RSP, 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_PUSH64i8, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, 0 }, { X86_REG_RSP, 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_PUSH64r, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, 0 }, { X86_REG_RSP, 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_PUSH64rmm, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, 0 }, { X86_REG_RSP, 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_PUSH64rmr, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, 0 }, { X86_REG_RSP, 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_PUSHA16, X86_INS_PUSHAW,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDI, X86_REG_ESI, X86_REG_EBP, X86_REG_EBX, X86_REG_EDX, X86_REG_ECX, X86_REG_EAX, X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHA32, X86_INS_PUSHAL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDI, X86_REG_ESI, X86_REG_EBP, X86_REG_EBX, X86_REG_EDX, X86_REG_ECX, X86_REG_EAX, X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHCS16, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHCS32, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHDS16, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHDS32, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHES16, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHES32, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHF16, X86_INS_PUSHF,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, X86_REG_EFLAGS, 0 }, { X86_REG_ESP, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_PUSHF32, X86_INS_PUSHFD,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, X86_REG_EFLAGS, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHF64, X86_INS_PUSHFQ,
#ifndef CAPSTONE_DIET
	{ X86_REG_RSP, X86_REG_EFLAGS, 0 }, { X86_REG_RSP, 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_PUSHFS16, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_PUSHFS32, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHFS64, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_PUSHGS16, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_PUSHGS32, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHGS64, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_PUSHSS16, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHSS32, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHi16, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PUSHi32, X86_INS_PUSH,
#ifndef CAPSTONE_DIET
	{ X86_REG_ESP, 0 }, { X86_REG_ESP, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_PXORrm, X86_INS_PXOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_PXORrr, X86_INS_PXOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_RCL16m1, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL16mCL, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL16mi, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL16r1, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL16rCL, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL16ri, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL32m1, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL32mCL, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL32mi, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL32r1, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL32rCL, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL32ri, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL64m1, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL64mCL, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL64mi, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL64r1, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL64rCL, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL64ri, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL8m1, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL8mCL, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL8mi, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL8r1, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL8rCL, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCL8ri, X86_INS_RCL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCPPSm, X86_INS_RCPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_RCPPSm_Int, X86_INS_RCPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_RCPPSr, X86_INS_RCPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_RCPPSr_Int, X86_INS_RCPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_RCPSSm, X86_INS_RCPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_RCPSSm_Int, X86_INS_RCPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCPSSr, X86_INS_RCPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_RCPSSr_Int, X86_INS_RCPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR16m1, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR16mCL, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR16mi, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR16r1, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR16rCL, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR16ri, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR32m1, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR32mCL, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR32mi, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR32r1, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR32rCL, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR32ri, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR64m1, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR64mCL, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR64mi, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR64r1, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR64rCL, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR64ri, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR8m1, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR8mCL, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR8mi, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR8r1, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR8rCL, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RCR8ri, X86_INS_RCR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RDFSBASE, X86_INS_RDFSBASE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FSGSBASE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_RDFSBASE64, X86_INS_RDFSBASE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FSGSBASE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_RDGSBASE, X86_INS_RDGSBASE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FSGSBASE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_RDGSBASE64, X86_INS_RDGSBASE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FSGSBASE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_RDMSR, X86_INS_RDMSR,
#ifndef CAPSTONE_DIET
	{ X86_REG_ECX, 0 }, { X86_REG_EAX, X86_REG_EDX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RDPMC, X86_INS_RDPMC,
#ifndef CAPSTONE_DIET
	{ X86_REG_ECX, 0 }, { X86_REG_RAX, X86_REG_RDX, 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_RDRAND16r, X86_INS_RDRAND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RDRAND32r, X86_INS_RDRAND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RDRAND64r, X86_INS_RDRAND,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RDSEED16r, X86_INS_RDSEED,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RDSEED32r, X86_INS_RDSEED,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RDSEED64r, X86_INS_RDSEED,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RDTSC, X86_INS_RDTSC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_RAX, X86_REG_RDX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RDTSCP, X86_INS_RDTSCP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_RAX, X86_REG_RCX, X86_REG_RDX, 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_RETIL, X86_INS_RET,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RET, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_RETIQ, X86_INS_RET,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RET, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_RETIW, X86_INS_RET,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RET, 0 }, 0, 0
#endif
},
{
	X86_RETL, X86_INS_RET,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RET, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_RETQ, X86_INS_RET,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RET, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_RETW, X86_INS_RET,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RET, 0 }, 0, 0
#endif
},
{
	X86_ROL16m1, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL16mCL, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL16mi, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL16r1, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL16rCL, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL16ri, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL32m1, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL32mCL, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL32mi, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL32r1, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL32rCL, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL32ri, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL64m1, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL64mCL, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL64mi, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL64r1, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL64rCL, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL64ri, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL8m1, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL8mCL, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL8mi, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL8r1, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL8rCL, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROL8ri, X86_INS_ROL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR16m1, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR16mCL, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR16mi, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR16r1, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR16rCL, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR16ri, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR32m1, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR32mCL, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR32mi, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR32r1, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR32rCL, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR32ri, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR64m1, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR64mCL, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR64mi, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR64r1, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR64rCL, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR64ri, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR8m1, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR8mCL, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR8mi, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR8r1, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR8rCL, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ROR8ri, X86_INS_ROR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RORX32mi, X86_INS_RORX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_RORX32ri, X86_INS_RORX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_RORX64mi, X86_INS_RORX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_RORX64ri, X86_INS_RORX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_ROUNDPDm, X86_INS_ROUNDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_ROUNDPDr, X86_INS_ROUNDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_ROUNDPSm, X86_INS_ROUNDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_ROUNDPSr, X86_INS_ROUNDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_ROUNDSDm, X86_INS_ROUNDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_ROUNDSDr, X86_INS_ROUNDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_ROUNDSDr_Int, X86_INS_ROUNDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_ROUNDSSm, X86_INS_ROUNDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_ROUNDSSr, X86_INS_ROUNDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_ROUNDSSr_Int, X86_INS_ROUNDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE41, 0 }, 0, 0
#endif
},
{
	X86_RSM, X86_INS_RSM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_RSQRTPSm, X86_INS_RSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_RSQRTPSm_Int, X86_INS_RSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_RSQRTPSr, X86_INS_RSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_RSQRTPSr_Int, X86_INS_RSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_RSQRTSSm, X86_INS_RSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_RSQRTSSm_Int, X86_INS_RSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_RSQRTSSr, X86_INS_RSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_RSQRTSSr_Int, X86_INS_RSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAHF, X86_INS_SAHF,
#ifndef CAPSTONE_DIET
	{ X86_REG_AH, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL16m1, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL16mCL, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL16mi, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL16r1, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL16rCL, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL16ri, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL32m1, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL32mCL, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL32mi, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL32r1, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL32rCL, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL32ri, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL64m1, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL64mCL, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL64mi, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL64r1, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL64rCL, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL64ri, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL8m1, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL8mCL, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL8mi, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL8r1, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL8rCL, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAL8ri, X86_INS_SAL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SALC, X86_INS_SALC,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_AL, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_SAR16m1, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR16mCL, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR16mi, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR16r1, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR16rCL, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR16ri, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR32m1, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR32mCL, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR32mi, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR32r1, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR32rCL, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR32ri, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR64m1, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR64mCL, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR64mi, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR64r1, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR64rCL, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR64ri, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR8m1, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR8mCL, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR8mi, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR8r1, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR8rCL, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SAR8ri, X86_INS_SAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SARX32rm, X86_INS_SARX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_SARX32rr, X86_INS_SARX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_SARX64rm, X86_INS_SARX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_SARX64rr, X86_INS_SARX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_SBB16i16, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB16mi, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB16mi8, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB16mr, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB16ri, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB16ri8, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB16rm, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB16rr, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB16rr_REV, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB32i32, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB32mi, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB32mi8, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB32mr, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB32ri, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB32ri8, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB32rm, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB32rr, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB32rr_REV, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB64i32, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB64mi32, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB64mi8, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB64mr, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB64ri32, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB64ri8, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB64rm, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB64rr, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB64rr_REV, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB8i8, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB8mi, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB8mi8, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_SBB8mr, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB8ri, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB8ri8, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_SBB8rm, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB8rr, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SBB8rr_REV, X86_INS_SBB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SCASB, X86_INS_SCASB,
#ifndef CAPSTONE_DIET
	{ X86_REG_AL, X86_REG_EDI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SCASL, X86_INS_SCASD,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SCASQ, X86_INS_SCASQ,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, X86_REG_EDI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SCASW, X86_INS_SCASW,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, X86_REG_EDI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETAEm, X86_INS_SETAE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETAEr, X86_INS_SETAE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETAm, X86_INS_SETA,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETAr, X86_INS_SETA,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETBEm, X86_INS_SETBE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETBEr, X86_INS_SETBE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETBm, X86_INS_SETB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETBr, X86_INS_SETB,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETEm, X86_INS_SETE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETEr, X86_INS_SETE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETGEm, X86_INS_SETGE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETGEr, X86_INS_SETGE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETGm, X86_INS_SETG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETGr, X86_INS_SETG,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETLEm, X86_INS_SETLE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETLEr, X86_INS_SETLE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETLm, X86_INS_SETL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETLr, X86_INS_SETL,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETNEm, X86_INS_SETNE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETNEr, X86_INS_SETNE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETNOm, X86_INS_SETNO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETNOr, X86_INS_SETNO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETNPm, X86_INS_SETNP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETNPr, X86_INS_SETNP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETNSm, X86_INS_SETNS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETNSr, X86_INS_SETNS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETOm, X86_INS_SETO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETOr, X86_INS_SETO,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETPm, X86_INS_SETP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETPr, X86_INS_SETP,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETSm, X86_INS_SETS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SETSr, X86_INS_SETS,
#ifndef CAPSTONE_DIET
	{ X86_REG_EFLAGS, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SFENCE, X86_INS_SFENCE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_SGDT16m, X86_INS_SGDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_SGDT32m, X86_INS_SGDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_SGDT64m, X86_INS_SGDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_SHA1MSG1rm, X86_INS_SHA1MSG1,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHA1MSG1rr, X86_INS_SHA1MSG1,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHA1MSG2rm, X86_INS_SHA1MSG2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHA1MSG2rr, X86_INS_SHA1MSG2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHA1NEXTErm, X86_INS_SHA1NEXTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHA1NEXTErr, X86_INS_SHA1NEXTE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHA1RNDS4rmi, X86_INS_SHA1RNDS4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHA1RNDS4rri, X86_INS_SHA1RNDS4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHA256MSG1rm, X86_INS_SHA256MSG1,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHA256MSG1rr, X86_INS_SHA256MSG1,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHA256MSG2rm, X86_INS_SHA256MSG2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHA256MSG2rr, X86_INS_SHA256MSG2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHA256RNDS2rm, X86_INS_SHA256RNDS2,
#ifndef CAPSTONE_DIET
	{ X86_REG_XMM0, 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHA256RNDS2rr, X86_INS_SHA256RNDS2,
#ifndef CAPSTONE_DIET
	{ X86_REG_XMM0, 0 }, { 0 }, { X86_GRP_SHA, 0 }, 0, 0
#endif
},
{
	X86_SHL16m1, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL16mCL, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL16mi, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL16r1, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL16rCL, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL16ri, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL32m1, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL32mCL, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL32mi, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL32r1, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL32rCL, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL32ri, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL64m1, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL64mCL, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL64mi, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL64r1, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL64rCL, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL64ri, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL8m1, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL8mCL, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL8mi, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL8r1, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL8rCL, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHL8ri, X86_INS_SHL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHLD16mrCL, X86_INS_SHLD,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHLD16mri8, X86_INS_SHLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHLD16rrCL, X86_INS_SHLD,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHLD16rri8, X86_INS_SHLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHLD32mrCL, X86_INS_SHLD,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHLD32mri8, X86_INS_SHLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHLD32rrCL, X86_INS_SHLD,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHLD32rri8, X86_INS_SHLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHLD64mrCL, X86_INS_SHLD,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHLD64mri8, X86_INS_SHLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHLD64rrCL, X86_INS_SHLD,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHLD64rri8, X86_INS_SHLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHLX32rm, X86_INS_SHLX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_SHLX32rr, X86_INS_SHLX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_SHLX64rm, X86_INS_SHLX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_SHLX64rr, X86_INS_SHLX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_SHR16m1, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR16mCL, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR16mi, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR16r1, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR16rCL, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR16ri, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR32m1, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR32mCL, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR32mi, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR32r1, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR32rCL, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR32ri, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR64m1, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR64mCL, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR64mi, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR64r1, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR64rCL, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR64ri, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR8m1, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR8mCL, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR8mi, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR8r1, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR8rCL, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHR8ri, X86_INS_SHR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHRD16mrCL, X86_INS_SHRD,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHRD16mri8, X86_INS_SHRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHRD16rrCL, X86_INS_SHRD,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHRD16rri8, X86_INS_SHRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHRD32mrCL, X86_INS_SHRD,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHRD32mri8, X86_INS_SHRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHRD32rrCL, X86_INS_SHRD,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHRD32rri8, X86_INS_SHRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHRD64mrCL, X86_INS_SHRD,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHRD64mri8, X86_INS_SHRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHRD64rrCL, X86_INS_SHRD,
#ifndef CAPSTONE_DIET
	{ X86_REG_CL, 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHRD64rri8, X86_INS_SHRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SHRX32rm, X86_INS_SHRX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_SHRX32rr, X86_INS_SHRX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_SHRX64rm, X86_INS_SHRX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_SHRX64rr, X86_INS_SHRX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BMI2, 0 }, 0, 0
#endif
},
{
	X86_SHUFPDrmi, X86_INS_SHUFPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_SHUFPDrri, X86_INS_SHUFPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_SHUFPSrmi, X86_INS_SHUFPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_SHUFPSrri, X86_INS_SHUFPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_SIDT16m, X86_INS_SIDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_SIDT32m, X86_INS_SIDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_SIDT64m, X86_INS_SIDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_SIN_F, X86_INS_FSIN,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SKINIT, X86_INS_SKINIT,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, 0 }, 0, 0
#endif
},
{
	X86_SLDT16m, X86_INS_SLDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SLDT16r, X86_INS_SLDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SLDT32r, X86_INS_SLDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SLDT64m, X86_INS_SLDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SLDT64r, X86_INS_SLDT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SMSW16m, X86_INS_SMSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SMSW16r, X86_INS_SMSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SMSW32r, X86_INS_SMSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SMSW64r, X86_INS_SMSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SQRTPDm, X86_INS_SQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_SQRTPDr, X86_INS_SQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_SQRTPSm, X86_INS_SQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_SQRTPSr, X86_INS_SQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_SQRTSDm, X86_INS_SQRTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_SQRTSDm_Int, X86_INS_SQRTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SQRTSDr, X86_INS_SQRTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_SQRTSDr_Int, X86_INS_SQRTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SQRTSSm, X86_INS_SQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_SQRTSSm_Int, X86_INS_SQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SQRTSSr, X86_INS_SQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_SQRTSSr_Int, X86_INS_SQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SQRT_F, X86_INS_FSQRT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_STAC, X86_INS_STAC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_STC, X86_INS_STC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_STD, X86_INS_STD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_STGI, X86_INS_STGI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, 0 }, 0, 0
#endif
},
{
	X86_STI, X86_INS_STI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_STMXCSR, X86_INS_STMXCSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_STOSB, X86_INS_STOSB,
#ifndef CAPSTONE_DIET
	{ X86_REG_AL, X86_REG_EDI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_STOSL, X86_INS_STOSD,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_STOSQ, X86_INS_STOSQ,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, X86_REG_RCX, X86_REG_RDI, X86_REG_EFLAGS, 0 }, { X86_REG_RCX, X86_REG_RDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_STOSW, X86_INS_STOSW,
#ifndef CAPSTONE_DIET
	{ X86_REG_AX, X86_REG_EDI, X86_REG_EFLAGS, 0 }, { X86_REG_EDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_STR16r, X86_INS_STR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_STR32r, X86_INS_STR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_STR64r, X86_INS_STR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_STRm, X86_INS_STR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_ST_F32m, X86_INS_FST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ST_F64m, X86_INS_FST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ST_FCOMPST0r, X86_INS_FCOMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ST_FCOMPST0r_alt, X86_INS_FCOMP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ST_FCOMST0r, X86_INS_FCOM,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ST_FP32m, X86_INS_FSTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ST_FP64m, X86_INS_FSTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ST_FP80m, X86_INS_FSTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ST_FPNCEST0r, X86_INS_FSTPNCE,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ST_FPST0r, X86_INS_FSTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ST_FPST0r_alt, X86_INS_FSTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ST_FPrr, X86_INS_FSTP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ST_FXCHST0r, X86_INS_FXCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ST_FXCHST0r_alt, X86_INS_FXCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_ST_Frr, X86_INS_FST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUB16i16, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB16mi, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB16mi8, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB16mr, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB16ri, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB16ri8, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB16rm, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB16rr, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB16rr_REV, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB32i32, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB32mi, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB32mi8, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB32mr, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB32ri, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB32ri8, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB32rm, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB32rr, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB32rr_REV, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB64i32, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB64mi32, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB64mi8, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB64mr, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB64ri32, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB64ri8, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB64rm, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB64rr, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB64rr_REV, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB8i8, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB8mi, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB8mi8, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_SUB8mr, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB8ri, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB8ri8, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_SUB8rm, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB8rr, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUB8rr_REV, X86_INS_SUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_SUBPDrm, X86_INS_SUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_SUBPDrr, X86_INS_SUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_SUBPSrm, X86_INS_SUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_SUBPSrr, X86_INS_SUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_SUBR_F32m, X86_INS_FSUBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUBR_F64m, X86_INS_FSUBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUBR_FI16m, X86_INS_FISUBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUBR_FI32m, X86_INS_FISUBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUBR_FPrST0, X86_INS_FSUBRP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUBR_FST0r, X86_INS_FSUBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUBR_FrST0, X86_INS_FSUBR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUBSDrm, X86_INS_SUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_SUBSDrm_Int, X86_INS_SUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_SUBSDrr, X86_INS_SUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_SUBSDrr_Int, X86_INS_SUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_SUBSSrm, X86_INS_SUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_SUBSSrm_Int, X86_INS_SUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_SUBSSrr, X86_INS_SUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_SUBSSrr_Int, X86_INS_SUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_SUB_F32m, X86_INS_FSUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUB_F64m, X86_INS_FSUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUB_FI16m, X86_INS_FISUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUB_FI32m, X86_INS_FISUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUB_FPrST0, X86_INS_FSUBP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUB_FST0r, X86_INS_FSUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SUB_FrST0, X86_INS_FSUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_SWAPGS, X86_INS_SWAPGS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_SYSCALL, X86_INS_SYSCALL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_INT, 0 }, 0, 0
#endif
},
{
	X86_SYSENTER, X86_INS_SYSENTER,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_INT, 0 }, 0, 0
#endif
},
{
	X86_SYSEXIT, X86_INS_SYSEXIT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_IRET, 0 }, 0, 0
#endif
},
{
	X86_SYSEXIT64, X86_INS_SYSEXIT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_IRET, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_SYSRET, X86_INS_SYSRET,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_IRET, 0 }, 0, 0
#endif
},
{
	X86_SYSRET64, X86_INS_SYSRET,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_IRET, X86_GRP_PRIVILEGE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_T1MSKC32rm, X86_INS_T1MSKC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_T1MSKC32rr, X86_INS_T1MSKC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_T1MSKC64rm, X86_INS_T1MSKC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_T1MSKC64rr, X86_INS_T1MSKC,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_TEST16i16, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST16mi, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST16mi_alt, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST16ri, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST16ri_alt, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST16rm, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST16rr, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST32i32, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST32mi, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST32mi_alt, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST32ri, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST32ri_alt, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST32rm, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST32rr, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST64i32, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST64mi32, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST64mi32_alt, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST64ri32, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST64ri32_alt, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST64rm, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST64rr, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST8i8, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST8mi, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST8mi_alt, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST8ri, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST8ri_alt, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST8rm, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TEST8rr, X86_INS_TEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TRAP, X86_INS_UD2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_TST_F, X86_INS_FTST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_TZCNT16rm, X86_INS_TZCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_TZCNT16rr, X86_INS_TZCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_TZCNT32rm, X86_INS_TZCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_TZCNT32rr, X86_INS_TZCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_TZCNT64rm, X86_INS_TZCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_TZCNT64rr, X86_INS_TZCNT,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_BMI, 0 }, 0, 0
#endif
},
{
	X86_TZMSK32rm, X86_INS_TZMSK,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_TZMSK32rr, X86_INS_TZMSK,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_TZMSK64rm, X86_INS_TZMSK,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_TZMSK64rr, X86_INS_TZMSK,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_TBM, 0 }, 0, 0
#endif
},
{
	X86_UCOMISDrm, X86_INS_UCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_UCOMISDrr, X86_INS_UCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_UCOMISSrm, X86_INS_UCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_UCOMISSrr, X86_INS_UCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_UCOM_FIPr, X86_INS_FUCOMIP,
#ifndef CAPSTONE_DIET
	{ X86_REG_ST0, 0 }, { X86_REG_EFLAGS, X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_UCOM_FIr, X86_INS_FUCOMI,
#ifndef CAPSTONE_DIET
	{ X86_REG_ST0, 0 }, { X86_REG_EFLAGS, X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_UCOM_FPPr, X86_INS_FUCOMPP,
#ifndef CAPSTONE_DIET
	{ X86_REG_ST0, 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_UCOM_FPr, X86_INS_FUCOMP,
#ifndef CAPSTONE_DIET
	{ X86_REG_ST0, 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_UCOM_Fr, X86_INS_FUCOM,
#ifndef CAPSTONE_DIET
	{ X86_REG_ST0, 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_UD2B, X86_INS_UD2B,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_UNPCKHPDrm, X86_INS_UNPCKHPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_UNPCKHPDrr, X86_INS_UNPCKHPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_UNPCKHPSrm, X86_INS_UNPCKHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_UNPCKHPSrr, X86_INS_UNPCKHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_UNPCKLPDrm, X86_INS_UNPCKLPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_UNPCKLPDrr, X86_INS_UNPCKLPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_UNPCKLPSrm, X86_INS_UNPCKLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_UNPCKLPSrr, X86_INS_UNPCKLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_VADDPDYrm, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDYrr, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ128rm, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ128rmb, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ128rmbk, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ128rmbkz, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ128rmk, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ128rmkz, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ128rr, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ128rrk, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ128rrkz, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ256rm, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ256rmb, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ256rmbk, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ256rmbkz, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ256rmk, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ256rmkz, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ256rr, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ256rrk, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZ256rrkz, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZrb, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZrbk, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZrbkz, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZrm, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZrmb, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZrmbk, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZrmbkz, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZrmk, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZrmkz, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZrr, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZrrk, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPDZrrkz, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPDrm, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPDrr, X86_INS_VADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSYrm, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSYrr, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ128rm, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ128rmb, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ128rmbk, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ128rmbkz, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ128rmk, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ128rmkz, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ128rr, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ128rrk, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ128rrkz, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ256rm, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ256rmb, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ256rmbk, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ256rmbkz, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ256rmk, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ256rmkz, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ256rr, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ256rrk, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZ256rrkz, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZrb, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZrbk, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZrbkz, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZrm, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZrmb, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZrmbk, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZrmbkz, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZrmk, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZrmkz, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZrr, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZrrk, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPSZrrkz, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDPSrm, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VADDPSrr, X86_INS_VADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VADDSDZrm, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSDZrm_Int, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSDZrm_Intk, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSDZrm_Intkz, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSDZrr, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSDZrr_Int, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSDZrr_Intk, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSDZrr_Intkz, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSDZrrb, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSDZrrbk, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSDZrrbkz, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSDrm, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSDrm_Int, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSDrr, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSDrr_Int, X86_INS_VADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSSZrm, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSSZrm_Int, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSSZrm_Intk, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSSZrm_Intkz, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSSZrr, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSSZrr_Int, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSSZrr_Intk, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSSZrr_Intkz, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSSZrrb, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSSZrrbk, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSSZrrbkz, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VADDSSrm, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSSrm_Int, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSSrr, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSSrr_Int, X86_INS_VADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSUBPDYrm, X86_INS_VADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSUBPDYrr, X86_INS_VADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSUBPDrm, X86_INS_VADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSUBPDrr, X86_INS_VADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSUBPSYrm, X86_INS_VADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSUBPSYrr, X86_INS_VADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSUBPSrm, X86_INS_VADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VADDSUBPSrr, X86_INS_VADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VAESDECLASTrm, X86_INS_VAESDECLAST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_VAESDECLASTrr, X86_INS_VAESDECLAST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_VAESDECrm, X86_INS_VAESDEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_VAESDECrr, X86_INS_VAESDEC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_VAESENCLASTrm, X86_INS_VAESENCLAST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_VAESENCLASTrr, X86_INS_VAESENCLAST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_VAESENCrm, X86_INS_VAESENC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_VAESENCrr, X86_INS_VAESENC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_VAESIMCrm, X86_INS_VAESIMC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_VAESIMCrr, X86_INS_VAESIMC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_VAESKEYGENASSIST128rm, X86_INS_VAESKEYGENASSIST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_VAESKEYGENASSIST128rr, X86_INS_VAESKEYGENASSIST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_AES, 0 }, 0, 0
#endif
},
{
	X86_VALIGNDrmi, X86_INS_VALIGND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VALIGNDrri, X86_INS_VALIGND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VALIGNDrrik, X86_INS_VALIGND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VALIGNDrrikz, X86_INS_VALIGND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VALIGNQrmi, X86_INS_VALIGNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VALIGNQrri, X86_INS_VALIGNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VALIGNQrrik, X86_INS_VALIGNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VALIGNQrrikz, X86_INS_VALIGNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VANDNPDYrm, X86_INS_VANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDNPDYrr, X86_INS_VANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDNPDrm, X86_INS_VANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDNPDrr, X86_INS_VANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDNPSYrm, X86_INS_VANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDNPSYrr, X86_INS_VANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDNPSrm, X86_INS_VANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDNPSrr, X86_INS_VANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDPDYrm, X86_INS_VANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDPDYrr, X86_INS_VANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDPDrm, X86_INS_VANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDPDrr, X86_INS_VANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDPSYrm, X86_INS_VANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDPSYrr, X86_INS_VANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDPSrm, X86_INS_VANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VANDPSrr, X86_INS_VANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ128rm, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ128rmb, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ128rmbk, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ128rmk, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ128rmkz, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ128rr, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ128rrk, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ128rrkz, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ256rm, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ256rmb, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ256rmbk, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ256rmk, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ256rmkz, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ256rr, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ256rrk, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZ256rrkz, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZrm, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZrmb, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZrmbk, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZrmk, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZrmkz, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZrr, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZrrk, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPDZrrkz, X86_INS_VBLENDMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ128rm, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ128rmb, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ128rmbk, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ128rmk, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ128rmkz, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ128rr, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ128rrk, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ128rrkz, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ256rm, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ256rmb, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ256rmbk, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ256rmk, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ256rmkz, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ256rr, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ256rrk, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZ256rrkz, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZrm, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZrmb, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZrmbk, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZrmk, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZrmkz, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZrr, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZrrk, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDMPSZrrkz, X86_INS_VBLENDMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBLENDPDYrmi, X86_INS_VBLENDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDPDYrri, X86_INS_VBLENDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDPDrmi, X86_INS_VBLENDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDPDrri, X86_INS_VBLENDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDPSYrmi, X86_INS_VBLENDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDPSYrri, X86_INS_VBLENDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDPSrmi, X86_INS_VBLENDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDPSrri, X86_INS_VBLENDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDVPDYrm, X86_INS_VBLENDVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDVPDYrr, X86_INS_VBLENDVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDVPDrm, X86_INS_VBLENDVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDVPDrr, X86_INS_VBLENDVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDVPSYrm, X86_INS_VBLENDVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDVPSYrr, X86_INS_VBLENDVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDVPSrm, X86_INS_VBLENDVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBLENDVPSrr, X86_INS_VBLENDVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTF128, X86_INS_VBROADCASTF128,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTI32X4krm, X86_INS_VBROADCASTI32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTI32X4rm, X86_INS_VBROADCASTI32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTI64X4krm, X86_INS_VBROADCASTI64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTI64X4rm, X86_INS_VBROADCASTI64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDYrm, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDYrr, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDZ256m, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDZ256mk, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDZ256mkz, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDZ256r, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDZ256rk, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDZ256rkz, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDZm, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDZmk, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDZmkz, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDZr, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDZrk, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSDZrkz, X86_INS_VBROADCASTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSYrm, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSYrr, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZ128m, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZ128mk, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZ128mkz, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZ128r, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZ128rk, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZ128rkz, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZ256m, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZ256mk, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZ256mkz, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZ256r, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZ256rk, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZ256rkz, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZm, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZmk, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZmkz, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZr, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZrk, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSZrkz, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSrm, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VBROADCASTSSrr, X86_INS_VBROADCASTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDYrmi, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDYrmi_alt, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDYrri, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDYrri_alt, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDZrmi, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDZrmi_alt, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDZrri, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDZrri_alt, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDZrrib, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDZrrib_alt, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDrmi, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDrmi_alt, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDrri, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPDrri_alt, X86_INS_VCMPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSYrmi, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSYrmi_alt, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSYrri, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSYrri_alt, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSZrmi, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSZrmi_alt, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSZrri, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSZrri_alt, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSZrrib, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSZrrib_alt, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSrmi, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSrmi_alt, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSrri, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPPSrri_alt, X86_INS_VCMPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPSDZrm, X86_INS_VCMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPSDZrmi_alt, X86_INS_VCMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPSDZrr, X86_INS_VCMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPSDZrri_alt, X86_INS_VCMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPSDrm, X86_INS_VCMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPSDrm_alt, X86_INS_VCMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPSDrr, X86_INS_VCMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPSDrr_alt, X86_INS_VCMPSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPSSZrm, X86_INS_VCMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPSSZrmi_alt, X86_INS_VCMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPSSZrr, X86_INS_VCMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPSSZrri_alt, X86_INS_VCMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCMPSSrm, X86_INS_VCMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPSSrm_alt, X86_INS_VCMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPSSrr, X86_INS_VCMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCMPSSrr_alt, X86_INS_VCMPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCOMISDZrm, X86_INS_VCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCOMISDZrr, X86_INS_VCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCOMISDrm, X86_INS_VCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCOMISDrr, X86_INS_VCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCOMISSZrm, X86_INS_VCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCOMISSZrr, X86_INS_VCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCOMISSrm, X86_INS_VCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCOMISSrr, X86_INS_VCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPDZ128mrk, X86_INS_VCOMPRESSPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPDZ128rrk, X86_INS_VCOMPRESSPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPDZ128rrkz, X86_INS_VCOMPRESSPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPDZ256mrk, X86_INS_VCOMPRESSPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPDZ256rrk, X86_INS_VCOMPRESSPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPDZ256rrkz, X86_INS_VCOMPRESSPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPDZmrk, X86_INS_VCOMPRESSPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPDZrrk, X86_INS_VCOMPRESSPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPDZrrkz, X86_INS_VCOMPRESSPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPSZ128mrk, X86_INS_VCOMPRESSPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPSZ128rrk, X86_INS_VCOMPRESSPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPSZ128rrkz, X86_INS_VCOMPRESSPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPSZ256mrk, X86_INS_VCOMPRESSPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPSZ256rrk, X86_INS_VCOMPRESSPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPSZ256rrkz, X86_INS_VCOMPRESSPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPSZmrk, X86_INS_VCOMPRESSPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPSZrrk, X86_INS_VCOMPRESSPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCOMPRESSPSZrrkz, X86_INS_VCOMPRESSPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTDQ2PDYrm, X86_INS_VCVTDQ2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTDQ2PDYrr, X86_INS_VCVTDQ2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTDQ2PDZrm, X86_INS_VCVTDQ2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTDQ2PDZrr, X86_INS_VCVTDQ2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTDQ2PDrm, X86_INS_VCVTDQ2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTDQ2PDrr, X86_INS_VCVTDQ2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTDQ2PSYrm, X86_INS_VCVTDQ2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTDQ2PSYrr, X86_INS_VCVTDQ2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTDQ2PSZrm, X86_INS_VCVTDQ2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTDQ2PSZrr, X86_INS_VCVTDQ2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTDQ2PSZrrb, X86_INS_VCVTDQ2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTDQ2PSrm, X86_INS_VCVTDQ2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTDQ2PSrr, X86_INS_VCVTDQ2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2DQXrm, X86_INS_VCVTPD2DQX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2DQYrm, X86_INS_VCVTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2DQYrr, X86_INS_VCVTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2DQZrm, X86_INS_VCVTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2DQZrr, X86_INS_VCVTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2DQZrrb, X86_INS_VCVTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2DQrr, X86_INS_VCVTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2PSXrm, X86_INS_VCVTPD2PSX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2PSYrm, X86_INS_VCVTPD2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2PSYrr, X86_INS_VCVTPD2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2PSZrm, X86_INS_VCVTPD2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2PSZrr, X86_INS_VCVTPD2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2PSZrrb, X86_INS_VCVTPD2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2PSrr, X86_INS_VCVTPD2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2UDQZrm, X86_INS_VCVTPD2UDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2UDQZrr, X86_INS_VCVTPD2UDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPD2UDQZrrb, X86_INS_VCVTPD2UDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPH2PSYrm, X86_INS_VCVTPH2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_F16C, 0 }, 0, 0
#endif
},
{
	X86_VCVTPH2PSYrr, X86_INS_VCVTPH2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_F16C, 0 }, 0, 0
#endif
},
{
	X86_VCVTPH2PSZrm, X86_INS_VCVTPH2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPH2PSZrr, X86_INS_VCVTPH2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPH2PSrm, X86_INS_VCVTPH2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_F16C, 0 }, 0, 0
#endif
},
{
	X86_VCVTPH2PSrr, X86_INS_VCVTPH2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_F16C, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2DQYrm, X86_INS_VCVTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2DQYrr, X86_INS_VCVTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2DQZrm, X86_INS_VCVTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2DQZrr, X86_INS_VCVTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2DQZrrb, X86_INS_VCVTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2DQrm, X86_INS_VCVTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2DQrr, X86_INS_VCVTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2PDYrm, X86_INS_VCVTPS2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2PDYrr, X86_INS_VCVTPS2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2PDZrm, X86_INS_VCVTPS2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2PDZrr, X86_INS_VCVTPS2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2PDrm, X86_INS_VCVTPS2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2PDrr, X86_INS_VCVTPS2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2PHYmr, X86_INS_VCVTPS2PH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_F16C, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2PHYrr, X86_INS_VCVTPS2PH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_F16C, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2PHZmr, X86_INS_VCVTPS2PH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2PHZrr, X86_INS_VCVTPS2PH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2PHmr, X86_INS_VCVTPS2PH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_F16C, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2PHrr, X86_INS_VCVTPS2PH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_F16C, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2UDQZrm, X86_INS_VCVTPS2UDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2UDQZrr, X86_INS_VCVTPS2UDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTPS2UDQZrrb, X86_INS_VCVTPS2UDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2SI64Zrm, X86_INS_VCVTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2SI64Zrr, X86_INS_VCVTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2SI64rm, X86_INS_VCVTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2SI64rr, X86_INS_VCVTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2SIZrm, X86_INS_VCVTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2SIZrr, X86_INS_VCVTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2SIrm, X86_INS_VCVTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2SIrr, X86_INS_VCVTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2SSZrm, X86_INS_VCVTSD2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2SSZrr, X86_INS_VCVTSD2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2SSrm, X86_INS_VCVTSD2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2SSrr, X86_INS_VCVTSD2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2USI64Zrm, X86_INS_VCVTSD2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2USI64Zrr, X86_INS_VCVTSD2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2USIZrm, X86_INS_VCVTSD2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSD2USIZrr, X86_INS_VCVTSD2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI2SD64rm, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI2SD64rr, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI2SDZrm, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI2SDZrr, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI2SDrm, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI2SDrr, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI2SS64rm, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI2SS64rr, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI2SSZrm, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI2SSZrr, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI2SSrm, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI2SSrr, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI642SDZrm, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI642SDZrr, X86_INS_VCVTSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI642SSZrm, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSI642SSZrr, X86_INS_VCVTSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2SDZrm, X86_INS_VCVTSS2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2SDZrr, X86_INS_VCVTSS2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2SDrm, X86_INS_VCVTSS2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2SDrr, X86_INS_VCVTSS2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2SI64Zrm, X86_INS_VCVTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2SI64Zrr, X86_INS_VCVTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2SI64rm, X86_INS_VCVTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2SI64rr, X86_INS_VCVTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2SIZrm, X86_INS_VCVTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2SIZrr, X86_INS_VCVTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2SIrm, X86_INS_VCVTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2SIrr, X86_INS_VCVTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2USI64Zrm, X86_INS_VCVTSS2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2USI64Zrr, X86_INS_VCVTSS2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2USIZrm, X86_INS_VCVTSS2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTSS2USIZrr, X86_INS_VCVTSS2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPD2DQXrm, X86_INS_VCVTTPD2DQX,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPD2DQYrm, X86_INS_VCVTTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPD2DQYrr, X86_INS_VCVTTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPD2DQZrm, X86_INS_VCVTTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPD2DQZrr, X86_INS_VCVTTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPD2DQrr, X86_INS_VCVTTPD2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPD2UDQZrm, X86_INS_VCVTTPD2UDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPD2UDQZrr, X86_INS_VCVTTPD2UDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPS2DQYrm, X86_INS_VCVTTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPS2DQYrr, X86_INS_VCVTTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPS2DQZrm, X86_INS_VCVTTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPS2DQZrr, X86_INS_VCVTTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPS2DQrm, X86_INS_VCVTTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPS2DQrr, X86_INS_VCVTTPS2DQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPS2UDQZrm, X86_INS_VCVTTPS2UDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTPS2UDQZrr, X86_INS_VCVTTPS2UDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSD2SI64Zrm, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSD2SI64Zrr, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSD2SI64rm, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSD2SI64rr, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSD2SIZrm, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSD2SIZrr, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSD2SIrm, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSD2SIrr, X86_INS_VCVTTSD2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSD2USI64Zrm, X86_INS_VCVTTSD2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSD2USI64Zrr, X86_INS_VCVTTSD2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSD2USIZrm, X86_INS_VCVTTSD2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSD2USIZrr, X86_INS_VCVTTSD2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSS2SI64Zrm, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSS2SI64Zrr, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSS2SI64rm, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSS2SI64rr, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSS2SIZrm, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSS2SIZrr, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSS2SIrm, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSS2SIrr, X86_INS_VCVTTSS2SI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSS2USI64Zrm, X86_INS_VCVTTSS2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSS2USI64Zrr, X86_INS_VCVTTSS2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSS2USIZrm, X86_INS_VCVTTSS2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTTSS2USIZrr, X86_INS_VCVTTSS2USI,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTUDQ2PDZrm, X86_INS_VCVTUDQ2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTUDQ2PDZrr, X86_INS_VCVTUDQ2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTUDQ2PSZrm, X86_INS_VCVTUDQ2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTUDQ2PSZrr, X86_INS_VCVTUDQ2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTUDQ2PSZrrb, X86_INS_VCVTUDQ2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTUSI2SDZrm, X86_INS_VCVTUSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTUSI2SDZrr, X86_INS_VCVTUSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTUSI2SSZrm, X86_INS_VCVTUSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTUSI2SSZrr, X86_INS_VCVTUSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTUSI642SDZrm, X86_INS_VCVTUSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTUSI642SDZrr, X86_INS_VCVTUSI2SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTUSI642SSZrm, X86_INS_VCVTUSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VCVTUSI642SSZrr, X86_INS_VCVTUSI2SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDYrm, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDYrr, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ128rm, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ128rmb, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ128rmbk, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ128rmbkz, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ128rmk, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ128rmkz, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ128rr, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ128rrk, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ128rrkz, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ256rm, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ256rmb, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ256rmbk, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ256rmbkz, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ256rmk, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ256rmkz, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ256rr, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ256rrk, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZ256rrkz, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZrb, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZrbk, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZrbkz, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZrm, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZrmb, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZrmbk, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZrmbkz, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZrmk, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZrmkz, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZrr, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZrrk, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDZrrkz, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDrm, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPDrr, X86_INS_VDIVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSYrm, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSYrr, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ128rm, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ128rmb, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ128rmbk, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ128rmbkz, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ128rmk, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ128rmkz, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ128rr, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ128rrk, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ128rrkz, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ256rm, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ256rmb, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ256rmbk, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ256rmbkz, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ256rmk, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ256rmkz, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ256rr, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ256rrk, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZ256rrkz, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZrb, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZrbk, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZrbkz, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZrm, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZrmb, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZrmbk, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZrmbkz, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZrmk, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZrmkz, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZrr, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZrrk, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSZrrkz, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSrm, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVPSrr, X86_INS_VDIVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDZrm, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDZrm_Int, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDZrm_Intk, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDZrm_Intkz, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDZrr, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDZrr_Int, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDZrr_Intk, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDZrr_Intkz, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDZrrb, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDZrrbk, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDZrrbkz, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDrm, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDrm_Int, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDrr, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VDIVSDrr_Int, X86_INS_VDIVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSZrm, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSZrm_Int, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSZrm_Intk, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSZrm_Intkz, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSZrr, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSZrr_Int, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSZrr_Intk, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSZrr_Intkz, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSZrrb, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSZrrbk, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSZrrbkz, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSrm, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSrm_Int, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSrr, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VDIVSSrr_Int, X86_INS_VDIVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VDPPDrmi, X86_INS_VDPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VDPPDrri, X86_INS_VDPPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VDPPSYrmi, X86_INS_VDPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VDPPSYrri, X86_INS_VDPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VDPPSrmi, X86_INS_VDPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VDPPSrri, X86_INS_VDPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VERRm, X86_INS_VERR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VERRr, X86_INS_VERR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VERWm, X86_INS_VERW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VERWr, X86_INS_VERW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VEXP2PDm, X86_INS_VEXP2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PDmb, X86_INS_VEXP2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PDmbk, X86_INS_VEXP2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PDmbkz, X86_INS_VEXP2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PDmk, X86_INS_VEXP2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PDmkz, X86_INS_VEXP2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PDr, X86_INS_VEXP2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PDrb, X86_INS_VEXP2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PDrbk, X86_INS_VEXP2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PDrbkz, X86_INS_VEXP2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PDrk, X86_INS_VEXP2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PDrkz, X86_INS_VEXP2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PSm, X86_INS_VEXP2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PSmb, X86_INS_VEXP2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PSmbk, X86_INS_VEXP2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PSmbkz, X86_INS_VEXP2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PSmk, X86_INS_VEXP2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PSmkz, X86_INS_VEXP2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PSr, X86_INS_VEXP2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PSrb, X86_INS_VEXP2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PSrbk, X86_INS_VEXP2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PSrbkz, X86_INS_VEXP2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PSrk, X86_INS_VEXP2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXP2PSrkz, X86_INS_VEXP2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPDZ128rmk, X86_INS_VEXPANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPDZ128rmkz, X86_INS_VEXPANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPDZ128rrk, X86_INS_VEXPANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPDZ128rrkz, X86_INS_VEXPANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPDZ256rmk, X86_INS_VEXPANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPDZ256rmkz, X86_INS_VEXPANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPDZ256rrk, X86_INS_VEXPANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPDZ256rrkz, X86_INS_VEXPANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPDZrmk, X86_INS_VEXPANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPDZrmkz, X86_INS_VEXPANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPDZrrk, X86_INS_VEXPANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPDZrrkz, X86_INS_VEXPANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPSZ128rmk, X86_INS_VEXPANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPSZ128rmkz, X86_INS_VEXPANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPSZ128rrk, X86_INS_VEXPANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPSZ128rrkz, X86_INS_VEXPANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPSZ256rmk, X86_INS_VEXPANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPSZ256rmkz, X86_INS_VEXPANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPSZ256rrk, X86_INS_VEXPANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPSZ256rrkz, X86_INS_VEXPANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPSZrmk, X86_INS_VEXPANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPSZrmkz, X86_INS_VEXPANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPSZrrk, X86_INS_VEXPANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXPANDPSZrrkz, X86_INS_VEXPANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTF128mr, X86_INS_VEXTRACTF128,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTF128rr, X86_INS_VEXTRACTF128,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTF32x4rm, X86_INS_VEXTRACTF32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTF32x4rr, X86_INS_VEXTRACTF32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTF32x4rrk, X86_INS_VEXTRACTF32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTF32x4rrkz, X86_INS_VEXTRACTF32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTF64x4rm, X86_INS_VEXTRACTF64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTF64x4rr, X86_INS_VEXTRACTF64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTF64x4rrk, X86_INS_VEXTRACTF64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTF64x4rrkz, X86_INS_VEXTRACTF64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTI128mr, X86_INS_VEXTRACTI128,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTI128rr, X86_INS_VEXTRACTI128,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTI32x4rm, X86_INS_VEXTRACTI32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTI32x4rr, X86_INS_VEXTRACTI32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTI32x4rrk, X86_INS_VEXTRACTI32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTI32x4rrkz, X86_INS_VEXTRACTI32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTI64x4rm, X86_INS_VEXTRACTI64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTI64x4rr, X86_INS_VEXTRACTI64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTI64x4rrk, X86_INS_VEXTRACTI64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTI64x4rrkz, X86_INS_VEXTRACTI64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTPSmr, X86_INS_VEXTRACTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTPSrr, X86_INS_VEXTRACTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTPSzmr, X86_INS_VEXTRACTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VEXTRACTPSzrr, X86_INS_VEXTRACTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADD132PDZ128m, X86_INS_VFMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADD132PDZ128mb, X86_INS_VFMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADD132PDZ256m, X86_INS_VFMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADD132PDZ256mb, X86_INS_VFMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADD132PDZm, X86_INS_VFMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADD132PDZmb, X86_INS_VFMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADD132PSZ128m, X86_INS_VFMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADD132PSZ128mb, X86_INS_VFMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADD132PSZ256m, X86_INS_VFMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADD132PSZ256mb, X86_INS_VFMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADD132PSZm, X86_INS_VFMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADD132PSZmb, X86_INS_VFMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPD4mr, X86_INS_VFMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPD4mrY, X86_INS_VFMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPD4rm, X86_INS_VFMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPD4rmY, X86_INS_VFMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPD4rr, X86_INS_VFMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPD4rrY, X86_INS_VFMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPD4rrY_REV, X86_INS_VFMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPD4rr_REV, X86_INS_VFMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v213rm, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v213rmb, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v213rmbk, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v213rmbkz, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v213rmk, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v213rmkz, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v213rr, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v213rrk, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v213rrkz, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v231rm, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v231rmb, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v231rmbk, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v231rmbkz, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v231rmk, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v231rmkz, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v231rr, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v231rrk, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ128v231rrkz, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v213rm, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v213rmb, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v213rmbk, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v213rmbkz, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v213rmk, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v213rmkz, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v213rr, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v213rrk, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v213rrkz, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v231rm, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v231rmb, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v231rmbk, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v231rmbkz, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v231rmk, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v231rmkz, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v231rr, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v231rrk, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZ256v231rrkz, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv213rm, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv213rmb, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv213rmbk, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv213rmbkz, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv213rmk, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv213rmkz, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv213rr, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv213rrb, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv213rrbk, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv213rrbkz, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv213rrk, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv213rrkz, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv231rm, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv231rmb, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv231rmbk, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv231rmbkz, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv231rmk, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv231rmkz, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv231rr, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv231rrk, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDZv231rrkz, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDr132m, X86_INS_VFMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDr132mY, X86_INS_VFMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDr132r, X86_INS_VFMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDr132rY, X86_INS_VFMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDr213m, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDr213mY, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDr213r, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDr213rY, X86_INS_VFMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDr231m, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDr231mY, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDr231r, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPDr231rY, X86_INS_VFMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPS4mr, X86_INS_VFMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPS4mrY, X86_INS_VFMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPS4rm, X86_INS_VFMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPS4rmY, X86_INS_VFMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPS4rr, X86_INS_VFMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPS4rrY, X86_INS_VFMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPS4rrY_REV, X86_INS_VFMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPS4rr_REV, X86_INS_VFMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v213rm, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v213rmb, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v213rmbk, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v213rmbkz, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v213rmk, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v213rmkz, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v213rr, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v213rrk, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v213rrkz, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v231rm, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v231rmb, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v231rmbk, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v231rmbkz, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v231rmk, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v231rmkz, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v231rr, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v231rrk, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ128v231rrkz, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v213rm, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v213rmb, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v213rmbk, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v213rmbkz, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v213rmk, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v213rmkz, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v213rr, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v213rrk, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v213rrkz, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v231rm, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v231rmb, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v231rmbk, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v231rmbkz, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v231rmk, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v231rmkz, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v231rr, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v231rrk, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZ256v231rrkz, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv213rm, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv213rmb, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv213rmbk, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv213rmbkz, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv213rmk, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv213rmkz, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv213rr, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv213rrb, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv213rrbk, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv213rrbkz, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv213rrk, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv213rrkz, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv231rm, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv231rmb, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv231rmbk, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv231rmbkz, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv231rmk, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv231rmkz, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv231rr, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv231rrk, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSZv231rrkz, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSr132m, X86_INS_VFMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSr132mY, X86_INS_VFMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSr132r, X86_INS_VFMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSr132rY, X86_INS_VFMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSr213m, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSr213mY, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSr213r, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSr213rY, X86_INS_VFMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSr231m, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSr231mY, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSr231r, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDPSr231rY, X86_INS_VFMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSD4mr, X86_INS_VFMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSD4mr_Int, X86_INS_VFMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSD4rm, X86_INS_VFMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSD4rm_Int, X86_INS_VFMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSD4rr, X86_INS_VFMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSD4rr_Int, X86_INS_VFMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSD4rr_REV, X86_INS_VFMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSDZm, X86_INS_VFMADD213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSDZr, X86_INS_VFMADD213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSDr132m, X86_INS_VFMADD132SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSDr132r, X86_INS_VFMADD132SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSDr213m, X86_INS_VFMADD213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSDr213r, X86_INS_VFMADD213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSDr231m, X86_INS_VFMADD231SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSDr231r, X86_INS_VFMADD231SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSS4mr, X86_INS_VFMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSS4mr_Int, X86_INS_VFMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSS4rm, X86_INS_VFMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSS4rm_Int, X86_INS_VFMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSS4rr, X86_INS_VFMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSS4rr_Int, X86_INS_VFMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSS4rr_REV, X86_INS_VFMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSSZm, X86_INS_VFMADD213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSSZr, X86_INS_VFMADD213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSSr132m, X86_INS_VFMADD132SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSSr132r, X86_INS_VFMADD132SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSSr213m, X86_INS_VFMADD213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSSr213r, X86_INS_VFMADD213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSSr231m, X86_INS_VFMADD231SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSSr231r, X86_INS_VFMADD231SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUB132PDZ128m, X86_INS_VFMADDSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUB132PDZ128mb, X86_INS_VFMADDSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUB132PDZ256m, X86_INS_VFMADDSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUB132PDZ256mb, X86_INS_VFMADDSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUB132PDZm, X86_INS_VFMADDSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUB132PDZmb, X86_INS_VFMADDSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUB132PSZ128m, X86_INS_VFMADDSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUB132PSZ128mb, X86_INS_VFMADDSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUB132PSZ256m, X86_INS_VFMADDSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUB132PSZ256mb, X86_INS_VFMADDSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUB132PSZm, X86_INS_VFMADDSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUB132PSZmb, X86_INS_VFMADDSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPD4mr, X86_INS_VFMADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPD4mrY, X86_INS_VFMADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPD4rm, X86_INS_VFMADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPD4rmY, X86_INS_VFMADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPD4rr, X86_INS_VFMADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPD4rrY, X86_INS_VFMADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPD4rrY_REV, X86_INS_VFMADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPD4rr_REV, X86_INS_VFMADDSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v213rm, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v213rmb, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v213rmbk, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v213rmbkz, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v213rmk, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v213rmkz, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v213rr, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v213rrk, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v213rrkz, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v231rm, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v231rmb, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v231rmbk, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v231rmbkz, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v231rmk, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v231rmkz, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v231rr, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v231rrk, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ128v231rrkz, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v213rm, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v213rmb, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v213rmbk, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v213rmbkz, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v213rmk, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v213rmkz, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v213rr, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v213rrk, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v213rrkz, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v231rm, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v231rmb, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v231rmbk, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v231rmbkz, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v231rmk, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v231rmkz, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v231rr, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v231rrk, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZ256v231rrkz, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv213rm, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv213rmb, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv213rmbk, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv213rmbkz, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv213rmk, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv213rmkz, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv213rr, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv213rrb, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv213rrbk, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv213rrbkz, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv213rrk, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv213rrkz, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv231rm, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv231rmb, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv231rmbk, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv231rmbkz, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv231rmk, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv231rmkz, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv231rr, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv231rrk, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDZv231rrkz, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDr132m, X86_INS_VFMADDSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDr132mY, X86_INS_VFMADDSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDr132r, X86_INS_VFMADDSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDr132rY, X86_INS_VFMADDSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDr213m, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDr213mY, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDr213r, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDr213rY, X86_INS_VFMADDSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDr231m, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDr231mY, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDr231r, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPDr231rY, X86_INS_VFMADDSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPS4mr, X86_INS_VFMADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPS4mrY, X86_INS_VFMADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPS4rm, X86_INS_VFMADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPS4rmY, X86_INS_VFMADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPS4rr, X86_INS_VFMADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPS4rrY, X86_INS_VFMADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPS4rrY_REV, X86_INS_VFMADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPS4rr_REV, X86_INS_VFMADDSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v213rm, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v213rmb, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v213rmbk, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v213rmbkz, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v213rmk, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v213rmkz, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v213rr, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v213rrk, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v213rrkz, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v231rm, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v231rmb, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v231rmbk, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v231rmbkz, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v231rmk, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v231rmkz, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v231rr, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v231rrk, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ128v231rrkz, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v213rm, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v213rmb, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v213rmbk, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v213rmbkz, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v213rmk, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v213rmkz, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v213rr, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v213rrk, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v213rrkz, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v231rm, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v231rmb, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v231rmbk, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v231rmbkz, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v231rmk, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v231rmkz, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v231rr, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v231rrk, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZ256v231rrkz, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv213rm, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv213rmb, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv213rmbk, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv213rmbkz, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv213rmk, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv213rmkz, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv213rr, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv213rrb, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv213rrbk, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv213rrbkz, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv213rrk, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv213rrkz, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv231rm, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv231rmb, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv231rmbk, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv231rmbkz, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv231rmk, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv231rmkz, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv231rr, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv231rrk, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSZv231rrkz, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSr132m, X86_INS_VFMADDSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSr132mY, X86_INS_VFMADDSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSr132r, X86_INS_VFMADDSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSr132rY, X86_INS_VFMADDSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSr213m, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSr213mY, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSr213r, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSr213rY, X86_INS_VFMADDSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSr231m, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSr231mY, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSr231r, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMADDSUBPSr231rY, X86_INS_VFMADDSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUB132PDZ128m, X86_INS_VFMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUB132PDZ128mb, X86_INS_VFMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUB132PDZ256m, X86_INS_VFMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUB132PDZ256mb, X86_INS_VFMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUB132PDZm, X86_INS_VFMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUB132PDZmb, X86_INS_VFMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUB132PSZ128m, X86_INS_VFMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUB132PSZ128mb, X86_INS_VFMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUB132PSZ256m, X86_INS_VFMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUB132PSZ256mb, X86_INS_VFMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUB132PSZm, X86_INS_VFMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUB132PSZmb, X86_INS_VFMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADD132PDZ128m, X86_INS_VFMSUBADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADD132PDZ128mb, X86_INS_VFMSUBADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADD132PDZ256m, X86_INS_VFMSUBADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADD132PDZ256mb, X86_INS_VFMSUBADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADD132PDZm, X86_INS_VFMSUBADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADD132PDZmb, X86_INS_VFMSUBADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADD132PSZ128m, X86_INS_VFMSUBADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADD132PSZ128mb, X86_INS_VFMSUBADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADD132PSZ256m, X86_INS_VFMSUBADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADD132PSZ256mb, X86_INS_VFMSUBADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADD132PSZm, X86_INS_VFMSUBADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADD132PSZmb, X86_INS_VFMSUBADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPD4mr, X86_INS_VFMSUBADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPD4mrY, X86_INS_VFMSUBADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPD4rm, X86_INS_VFMSUBADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPD4rmY, X86_INS_VFMSUBADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPD4rr, X86_INS_VFMSUBADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPD4rrY, X86_INS_VFMSUBADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPD4rrY_REV, X86_INS_VFMSUBADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPD4rr_REV, X86_INS_VFMSUBADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v213rm, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v213rmb, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v213rmbk, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v213rmbkz, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v213rmk, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v213rmkz, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v213rr, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v213rrk, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v213rrkz, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v231rm, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v231rmb, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v231rmbk, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v231rmbkz, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v231rmk, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v231rmkz, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v231rr, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v231rrk, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ128v231rrkz, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v213rm, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v213rmb, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v213rmbk, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v213rmbkz, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v213rmk, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v213rmkz, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v213rr, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v213rrk, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v213rrkz, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v231rm, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v231rmb, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v231rmbk, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v231rmbkz, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v231rmk, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v231rmkz, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v231rr, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v231rrk, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZ256v231rrkz, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv213rm, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv213rmb, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv213rmbk, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv213rmbkz, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv213rmk, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv213rmkz, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv213rr, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv213rrb, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv213rrbk, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv213rrbkz, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv213rrk, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv213rrkz, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv231rm, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv231rmb, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv231rmbk, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv231rmbkz, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv231rmk, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv231rmkz, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv231rr, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv231rrk, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDZv231rrkz, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDr132m, X86_INS_VFMSUBADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDr132mY, X86_INS_VFMSUBADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDr132r, X86_INS_VFMSUBADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDr132rY, X86_INS_VFMSUBADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDr213m, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDr213mY, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDr213r, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDr213rY, X86_INS_VFMSUBADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDr231m, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDr231mY, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDr231r, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPDr231rY, X86_INS_VFMSUBADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPS4mr, X86_INS_VFMSUBADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPS4mrY, X86_INS_VFMSUBADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPS4rm, X86_INS_VFMSUBADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPS4rmY, X86_INS_VFMSUBADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPS4rr, X86_INS_VFMSUBADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPS4rrY, X86_INS_VFMSUBADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPS4rrY_REV, X86_INS_VFMSUBADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPS4rr_REV, X86_INS_VFMSUBADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v213rm, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v213rmb, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v213rmbk, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v213rmbkz, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v213rmk, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v213rmkz, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v213rr, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v213rrk, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v213rrkz, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v231rm, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v231rmb, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v231rmbk, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v231rmbkz, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v231rmk, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v231rmkz, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v231rr, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v231rrk, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ128v231rrkz, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v213rm, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v213rmb, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v213rmbk, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v213rmbkz, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v213rmk, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v213rmkz, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v213rr, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v213rrk, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v213rrkz, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v231rm, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v231rmb, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v231rmbk, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v231rmbkz, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v231rmk, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v231rmkz, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v231rr, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v231rrk, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZ256v231rrkz, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv213rm, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv213rmb, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv213rmbk, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv213rmbkz, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv213rmk, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv213rmkz, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv213rr, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv213rrb, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv213rrbk, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv213rrbkz, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv213rrk, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv213rrkz, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv231rm, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv231rmb, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv231rmbk, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv231rmbkz, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv231rmk, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv231rmkz, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv231rr, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv231rrk, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSZv231rrkz, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSr132m, X86_INS_VFMSUBADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSr132mY, X86_INS_VFMSUBADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSr132r, X86_INS_VFMSUBADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSr132rY, X86_INS_VFMSUBADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSr213m, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSr213mY, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSr213r, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSr213rY, X86_INS_VFMSUBADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSr231m, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSr231mY, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSr231r, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBADDPSr231rY, X86_INS_VFMSUBADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPD4mr, X86_INS_VFMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPD4mrY, X86_INS_VFMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPD4rm, X86_INS_VFMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPD4rmY, X86_INS_VFMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPD4rr, X86_INS_VFMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPD4rrY, X86_INS_VFMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPD4rrY_REV, X86_INS_VFMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPD4rr_REV, X86_INS_VFMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v213rm, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v213rmb, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v213rmbk, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v213rmbkz, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v213rmk, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v213rmkz, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v213rr, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v213rrk, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v213rrkz, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v231rm, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v231rmb, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v231rmbk, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v231rmbkz, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v231rmk, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v231rmkz, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v231rr, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v231rrk, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ128v231rrkz, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v213rm, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v213rmb, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v213rmbk, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v213rmbkz, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v213rmk, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v213rmkz, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v213rr, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v213rrk, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v213rrkz, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v231rm, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v231rmb, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v231rmbk, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v231rmbkz, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v231rmk, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v231rmkz, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v231rr, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v231rrk, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZ256v231rrkz, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv213rm, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv213rmb, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv213rmbk, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv213rmbkz, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv213rmk, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv213rmkz, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv213rr, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv213rrb, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv213rrbk, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv213rrbkz, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv213rrk, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv213rrkz, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv231rm, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv231rmb, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv231rmbk, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv231rmbkz, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv231rmk, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv231rmkz, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv231rr, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv231rrk, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDZv231rrkz, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDr132m, X86_INS_VFMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDr132mY, X86_INS_VFMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDr132r, X86_INS_VFMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDr132rY, X86_INS_VFMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDr213m, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDr213mY, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDr213r, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDr213rY, X86_INS_VFMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDr231m, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDr231mY, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDr231r, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPDr231rY, X86_INS_VFMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPS4mr, X86_INS_VFMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPS4mrY, X86_INS_VFMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPS4rm, X86_INS_VFMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPS4rmY, X86_INS_VFMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPS4rr, X86_INS_VFMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPS4rrY, X86_INS_VFMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPS4rrY_REV, X86_INS_VFMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPS4rr_REV, X86_INS_VFMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v213rm, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v213rmb, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v213rmbk, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v213rmbkz, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v213rmk, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v213rmkz, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v213rr, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v213rrk, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v213rrkz, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v231rm, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v231rmb, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v231rmbk, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v231rmbkz, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v231rmk, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v231rmkz, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v231rr, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v231rrk, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ128v231rrkz, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v213rm, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v213rmb, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v213rmbk, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v213rmbkz, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v213rmk, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v213rmkz, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v213rr, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v213rrk, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v213rrkz, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v231rm, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v231rmb, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v231rmbk, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v231rmbkz, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v231rmk, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v231rmkz, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v231rr, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v231rrk, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZ256v231rrkz, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv213rm, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv213rmb, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv213rmbk, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv213rmbkz, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv213rmk, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv213rmkz, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv213rr, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv213rrb, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv213rrbk, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv213rrbkz, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv213rrk, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv213rrkz, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv231rm, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv231rmb, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv231rmbk, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv231rmbkz, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv231rmk, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv231rmkz, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv231rr, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv231rrk, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSZv231rrkz, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSr132m, X86_INS_VFMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSr132mY, X86_INS_VFMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSr132r, X86_INS_VFMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSr132rY, X86_INS_VFMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSr213m, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSr213mY, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSr213r, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSr213rY, X86_INS_VFMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSr231m, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSr231mY, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSr231r, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBPSr231rY, X86_INS_VFMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSD4mr, X86_INS_VFMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSD4mr_Int, X86_INS_VFMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSD4rm, X86_INS_VFMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSD4rm_Int, X86_INS_VFMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSD4rr, X86_INS_VFMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSD4rr_Int, X86_INS_VFMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSD4rr_REV, X86_INS_VFMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSDZm, X86_INS_VFMSUB213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSDZr, X86_INS_VFMSUB213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSDr132m, X86_INS_VFMSUB132SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSDr132r, X86_INS_VFMSUB132SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSDr213m, X86_INS_VFMSUB213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSDr213r, X86_INS_VFMSUB213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSDr231m, X86_INS_VFMSUB231SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSDr231r, X86_INS_VFMSUB231SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSS4mr, X86_INS_VFMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSS4mr_Int, X86_INS_VFMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSS4rm, X86_INS_VFMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSS4rm_Int, X86_INS_VFMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSS4rr, X86_INS_VFMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSS4rr_Int, X86_INS_VFMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSS4rr_REV, X86_INS_VFMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSSZm, X86_INS_VFMSUB213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSSZr, X86_INS_VFMSUB213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSSr132m, X86_INS_VFMSUB132SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSSr132r, X86_INS_VFMSUB132SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSSr213m, X86_INS_VFMSUB213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSSr213r, X86_INS_VFMSUB213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSSr231m, X86_INS_VFMSUB231SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFMSUBSSr231r, X86_INS_VFMSUB231SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADD132PDZ128m, X86_INS_VFNMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADD132PDZ128mb, X86_INS_VFNMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADD132PDZ256m, X86_INS_VFNMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADD132PDZ256mb, X86_INS_VFNMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADD132PDZm, X86_INS_VFNMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADD132PDZmb, X86_INS_VFNMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADD132PSZ128m, X86_INS_VFNMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADD132PSZ128mb, X86_INS_VFNMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADD132PSZ256m, X86_INS_VFNMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADD132PSZ256mb, X86_INS_VFNMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADD132PSZm, X86_INS_VFNMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADD132PSZmb, X86_INS_VFNMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPD4mr, X86_INS_VFNMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPD4mrY, X86_INS_VFNMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPD4rm, X86_INS_VFNMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPD4rmY, X86_INS_VFNMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPD4rr, X86_INS_VFNMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPD4rrY, X86_INS_VFNMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPD4rrY_REV, X86_INS_VFNMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPD4rr_REV, X86_INS_VFNMADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v213rm, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v213rmb, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v213rmbk, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v213rmbkz, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v213rmk, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v213rmkz, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v213rr, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v213rrk, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v213rrkz, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v231rm, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v231rmb, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v231rmbk, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v231rmbkz, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v231rmk, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v231rmkz, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v231rr, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v231rrk, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ128v231rrkz, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v213rm, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v213rmb, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v213rmbk, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v213rmbkz, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v213rmk, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v213rmkz, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v213rr, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v213rrk, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v213rrkz, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v231rm, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v231rmb, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v231rmbk, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v231rmbkz, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v231rmk, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v231rmkz, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v231rr, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v231rrk, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZ256v231rrkz, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv213rm, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv213rmb, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv213rmbk, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv213rmbkz, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv213rmk, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv213rmkz, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv213rr, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv213rrb, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv213rrbk, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv213rrbkz, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv213rrk, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv213rrkz, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv231rm, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv231rmb, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv231rmbk, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv231rmbkz, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv231rmk, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv231rmkz, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv231rr, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv231rrk, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDZv231rrkz, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDr132m, X86_INS_VFNMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDr132mY, X86_INS_VFNMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDr132r, X86_INS_VFNMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDr132rY, X86_INS_VFNMADD132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDr213m, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDr213mY, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDr213r, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDr213rY, X86_INS_VFNMADD213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDr231m, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDr231mY, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDr231r, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPDr231rY, X86_INS_VFNMADD231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPS4mr, X86_INS_VFNMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPS4mrY, X86_INS_VFNMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPS4rm, X86_INS_VFNMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPS4rmY, X86_INS_VFNMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPS4rr, X86_INS_VFNMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPS4rrY, X86_INS_VFNMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPS4rrY_REV, X86_INS_VFNMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPS4rr_REV, X86_INS_VFNMADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v213rm, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v213rmb, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v213rmbk, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v213rmbkz, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v213rmk, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v213rmkz, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v213rr, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v213rrk, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v213rrkz, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v231rm, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v231rmb, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v231rmbk, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v231rmbkz, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v231rmk, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v231rmkz, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v231rr, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v231rrk, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ128v231rrkz, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v213rm, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v213rmb, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v213rmbk, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v213rmbkz, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v213rmk, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v213rmkz, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v213rr, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v213rrk, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v213rrkz, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v231rm, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v231rmb, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v231rmbk, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v231rmbkz, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v231rmk, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v231rmkz, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v231rr, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v231rrk, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZ256v231rrkz, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv213rm, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv213rmb, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv213rmbk, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv213rmbkz, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv213rmk, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv213rmkz, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv213rr, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv213rrb, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv213rrbk, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv213rrbkz, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv213rrk, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv213rrkz, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv231rm, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv231rmb, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv231rmbk, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv231rmbkz, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv231rmk, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv231rmkz, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv231rr, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv231rrk, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSZv231rrkz, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSr132m, X86_INS_VFNMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSr132mY, X86_INS_VFNMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSr132r, X86_INS_VFNMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSr132rY, X86_INS_VFNMADD132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSr213m, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSr213mY, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSr213r, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSr213rY, X86_INS_VFNMADD213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSr231m, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSr231mY, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSr231r, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDPSr231rY, X86_INS_VFNMADD231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSD4mr, X86_INS_VFNMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSD4mr_Int, X86_INS_VFNMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSD4rm, X86_INS_VFNMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSD4rm_Int, X86_INS_VFNMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSD4rr, X86_INS_VFNMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSD4rr_Int, X86_INS_VFNMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSD4rr_REV, X86_INS_VFNMADDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSDZm, X86_INS_VFNMADD213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSDZr, X86_INS_VFNMADD213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSDr132m, X86_INS_VFNMADD132SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSDr132r, X86_INS_VFNMADD132SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSDr213m, X86_INS_VFNMADD213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSDr213r, X86_INS_VFNMADD213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSDr231m, X86_INS_VFNMADD231SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSDr231r, X86_INS_VFNMADD231SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSS4mr, X86_INS_VFNMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSS4mr_Int, X86_INS_VFNMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSS4rm, X86_INS_VFNMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSS4rm_Int, X86_INS_VFNMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSS4rr, X86_INS_VFNMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSS4rr_Int, X86_INS_VFNMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSS4rr_REV, X86_INS_VFNMADDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSSZm, X86_INS_VFNMADD213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSSZr, X86_INS_VFNMADD213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSSr132m, X86_INS_VFNMADD132SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSSr132r, X86_INS_VFNMADD132SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSSr213m, X86_INS_VFNMADD213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSSr213r, X86_INS_VFNMADD213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSSr231m, X86_INS_VFNMADD231SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMADDSSr231r, X86_INS_VFNMADD231SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUB132PDZ128m, X86_INS_VFNMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUB132PDZ128mb, X86_INS_VFNMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUB132PDZ256m, X86_INS_VFNMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUB132PDZ256mb, X86_INS_VFNMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUB132PDZm, X86_INS_VFNMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUB132PDZmb, X86_INS_VFNMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUB132PSZ128m, X86_INS_VFNMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUB132PSZ128mb, X86_INS_VFNMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUB132PSZ256m, X86_INS_VFNMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUB132PSZ256mb, X86_INS_VFNMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUB132PSZm, X86_INS_VFNMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUB132PSZmb, X86_INS_VFNMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPD4mr, X86_INS_VFNMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPD4mrY, X86_INS_VFNMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPD4rm, X86_INS_VFNMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPD4rmY, X86_INS_VFNMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPD4rr, X86_INS_VFNMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPD4rrY, X86_INS_VFNMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPD4rrY_REV, X86_INS_VFNMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPD4rr_REV, X86_INS_VFNMSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v213rm, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v213rmb, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v213rmbk, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v213rmbkz, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v213rmk, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v213rmkz, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v213rr, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v213rrk, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v213rrkz, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v231rm, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v231rmb, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v231rmbk, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v231rmbkz, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v231rmk, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v231rmkz, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v231rr, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v231rrk, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ128v231rrkz, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v213rm, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v213rmb, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v213rmbk, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v213rmbkz, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v213rmk, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v213rmkz, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v213rr, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v213rrk, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v213rrkz, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v231rm, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v231rmb, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v231rmbk, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v231rmbkz, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v231rmk, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v231rmkz, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v231rr, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v231rrk, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZ256v231rrkz, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv213rm, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv213rmb, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv213rmbk, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv213rmbkz, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv213rmk, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv213rmkz, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv213rr, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv213rrb, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv213rrbk, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv213rrbkz, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv213rrk, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv213rrkz, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv231rm, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv231rmb, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv231rmbk, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv231rmbkz, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv231rmk, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv231rmkz, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv231rr, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv231rrk, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDZv231rrkz, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDr132m, X86_INS_VFNMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDr132mY, X86_INS_VFNMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDr132r, X86_INS_VFNMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDr132rY, X86_INS_VFNMSUB132PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDr213m, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDr213mY, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDr213r, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDr213rY, X86_INS_VFNMSUB213PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDr231m, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDr231mY, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDr231r, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPDr231rY, X86_INS_VFNMSUB231PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPS4mr, X86_INS_VFNMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPS4mrY, X86_INS_VFNMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPS4rm, X86_INS_VFNMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPS4rmY, X86_INS_VFNMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPS4rr, X86_INS_VFNMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPS4rrY, X86_INS_VFNMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPS4rrY_REV, X86_INS_VFNMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPS4rr_REV, X86_INS_VFNMSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v213rm, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v213rmb, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v213rmbk, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v213rmbkz, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v213rmk, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v213rmkz, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v213rr, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v213rrk, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v213rrkz, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v231rm, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v231rmb, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v231rmbk, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v231rmbkz, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v231rmk, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v231rmkz, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v231rr, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v231rrk, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ128v231rrkz, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v213rm, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v213rmb, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v213rmbk, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v213rmbkz, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v213rmk, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v213rmkz, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v213rr, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v213rrk, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v213rrkz, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v231rm, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v231rmb, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v231rmbk, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v231rmbkz, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v231rmk, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v231rmkz, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v231rr, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v231rrk, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZ256v231rrkz, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv213rm, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv213rmb, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv213rmbk, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv213rmbkz, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv213rmk, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv213rmkz, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv213rr, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv213rrb, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv213rrbk, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv213rrbkz, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv213rrk, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv213rrkz, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv231rm, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv231rmb, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv231rmbk, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv231rmbkz, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv231rmk, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv231rmkz, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv231rr, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv231rrk, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSZv231rrkz, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSr132m, X86_INS_VFNMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSr132mY, X86_INS_VFNMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSr132r, X86_INS_VFNMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSr132rY, X86_INS_VFNMSUB132PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSr213m, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSr213mY, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSr213r, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSr213rY, X86_INS_VFNMSUB213PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSr231m, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSr231mY, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSr231r, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBPSr231rY, X86_INS_VFNMSUB231PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSD4mr, X86_INS_VFNMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSD4mr_Int, X86_INS_VFNMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSD4rm, X86_INS_VFNMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSD4rm_Int, X86_INS_VFNMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSD4rr, X86_INS_VFNMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSD4rr_Int, X86_INS_VFNMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSD4rr_REV, X86_INS_VFNMSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSDZm, X86_INS_VFNMSUB213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSDZr, X86_INS_VFNMSUB213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSDr132m, X86_INS_VFNMSUB132SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSDr132r, X86_INS_VFNMSUB132SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSDr213m, X86_INS_VFNMSUB213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSDr213r, X86_INS_VFNMSUB213SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSDr231m, X86_INS_VFNMSUB231SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSDr231r, X86_INS_VFNMSUB231SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSS4mr, X86_INS_VFNMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSS4mr_Int, X86_INS_VFNMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSS4rm, X86_INS_VFNMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSS4rm_Int, X86_INS_VFNMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSS4rr, X86_INS_VFNMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSS4rr_Int, X86_INS_VFNMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSS4rr_REV, X86_INS_VFNMSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA4, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSSZm, X86_INS_VFNMSUB213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSSZr, X86_INS_VFNMSUB213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSSr132m, X86_INS_VFNMSUB132SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSSr132r, X86_INS_VFNMSUB132SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSSr213m, X86_INS_VFNMSUB213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSSr213r, X86_INS_VFNMSUB213SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSSr231m, X86_INS_VFNMSUB231SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFNMSUBSSr231r, X86_INS_VFNMSUB231SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FMA, 0 }, 0, 0
#endif
},
{
	X86_VFRCZPDrm, X86_INS_VFRCZPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VFRCZPDrmY, X86_INS_VFRCZPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VFRCZPDrr, X86_INS_VFRCZPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VFRCZPDrrY, X86_INS_VFRCZPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VFRCZPSrm, X86_INS_VFRCZPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VFRCZPSrmY, X86_INS_VFRCZPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VFRCZPSrr, X86_INS_VFRCZPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VFRCZPSrrY, X86_INS_VFRCZPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VFRCZSDrm, X86_INS_VFRCZSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VFRCZSDrr, X86_INS_VFRCZSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VFRCZSSrm, X86_INS_VFRCZSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VFRCZSSrr, X86_INS_VFRCZSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VFsANDNPDrm, X86_INS_VANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsANDNPDrr, X86_INS_VANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsANDNPSrm, X86_INS_VANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsANDNPSrr, X86_INS_VANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsANDPDrm, X86_INS_VANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsANDPDrr, X86_INS_VANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsANDPSrm, X86_INS_VANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsANDPSrr, X86_INS_VANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsORPDrm, X86_INS_VORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsORPDrr, X86_INS_VORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsORPSrm, X86_INS_VORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsORPSrr, X86_INS_VORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsXORPDrm, X86_INS_VXORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsXORPDrr, X86_INS_VXORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsXORPSrm, X86_INS_VXORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFsXORPSrr, X86_INS_VXORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VFvANDNPDrm, X86_INS_VANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvANDNPDrr, X86_INS_VANDNPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvANDNPSrm, X86_INS_VANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvANDNPSrr, X86_INS_VANDNPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvANDPDrm, X86_INS_VANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvANDPDrr, X86_INS_VANDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvANDPSrm, X86_INS_VANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvANDPSrr, X86_INS_VANDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvORPDrm, X86_INS_VORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvORPDrr, X86_INS_VORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvORPSrm, X86_INS_VORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvORPSrr, X86_INS_VORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvXORPDrm, X86_INS_VXORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvXORPDrr, X86_INS_VXORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvXORPSrm, X86_INS_VXORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VFvXORPSrr, X86_INS_VXORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VGATHERDPDYrm, X86_INS_VGATHERDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VGATHERDPDZrm, X86_INS_VGATHERDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VGATHERDPDrm, X86_INS_VGATHERDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VGATHERDPSYrm, X86_INS_VGATHERDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VGATHERDPSZrm, X86_INS_VGATHERDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VGATHERDPSrm, X86_INS_VGATHERDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VGATHERPF0DPDm, X86_INS_VGATHERPF0DPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VGATHERPF0DPSm, X86_INS_VGATHERPF0DPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VGATHERPF0QPDm, X86_INS_VGATHERPF0QPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VGATHERPF0QPSm, X86_INS_VGATHERPF0QPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VGATHERPF1DPDm, X86_INS_VGATHERPF1DPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VGATHERPF1DPSm, X86_INS_VGATHERPF1DPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VGATHERPF1QPDm, X86_INS_VGATHERPF1QPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VGATHERPF1QPSm, X86_INS_VGATHERPF1QPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VGATHERQPDYrm, X86_INS_VGATHERQPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VGATHERQPDZrm, X86_INS_VGATHERQPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VGATHERQPDrm, X86_INS_VGATHERQPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VGATHERQPSYrm, X86_INS_VGATHERQPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VGATHERQPSZrm, X86_INS_VGATHERQPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VGATHERQPSrm, X86_INS_VGATHERQPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VHADDPDYrm, X86_INS_VHADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHADDPDYrr, X86_INS_VHADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHADDPDrm, X86_INS_VHADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHADDPDrr, X86_INS_VHADDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHADDPSYrm, X86_INS_VHADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHADDPSYrr, X86_INS_VHADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHADDPSrm, X86_INS_VHADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHADDPSrr, X86_INS_VHADDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHSUBPDYrm, X86_INS_VHSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHSUBPDYrr, X86_INS_VHSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHSUBPDrm, X86_INS_VHSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHSUBPDrr, X86_INS_VHSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHSUBPSYrm, X86_INS_VHSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHSUBPSYrr, X86_INS_VHSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHSUBPSrm, X86_INS_VHSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VHSUBPSrr, X86_INS_VHSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VINSERTF128rm, X86_INS_VINSERTF128,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VINSERTF128rr, X86_INS_VINSERTF128,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VINSERTF32x4rm, X86_INS_VINSERTF32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VINSERTF32x4rr, X86_INS_VINSERTF32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VINSERTF32x8rm, X86_INS_VINSERTF32X8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VINSERTF32x8rr, X86_INS_VINSERTF32X8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VINSERTF64x2rm, X86_INS_VINSERTF64X2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VINSERTF64x2rr, X86_INS_VINSERTF64X2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VINSERTF64x4rm, X86_INS_VINSERTF64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VINSERTF64x4rr, X86_INS_VINSERTF64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VINSERTI128rm, X86_INS_VINSERTI128,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VINSERTI128rr, X86_INS_VINSERTI128,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VINSERTI32x4rm, X86_INS_VINSERTI32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VINSERTI32x4rr, X86_INS_VINSERTI32X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VINSERTI32x8rm, X86_INS_VINSERTI32X8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VINSERTI32x8rr, X86_INS_VINSERTI32X8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VINSERTI64x2rm, X86_INS_VINSERTI64X2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VINSERTI64x2rr, X86_INS_VINSERTI64X2,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VINSERTI64x4rm, X86_INS_VINSERTI64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VINSERTI64x4rr, X86_INS_VINSERTI64X4,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VINSERTPSrm, X86_INS_VINSERTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VINSERTPSrr, X86_INS_VINSERTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VINSERTPSzrm, X86_INS_VINSERTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VINSERTPSzrr, X86_INS_VINSERTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VLDDQUYrm, X86_INS_VLDDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VLDDQUrm, X86_INS_VLDDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VLDMXCSR, X86_INS_VLDMXCSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMASKMOVDQU, X86_INS_VMASKMOVDQU,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDI, 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_VMASKMOVDQU64, X86_INS_VMASKMOVDQU,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDI, 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_VMASKMOVPDYmr, X86_INS_VMASKMOVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMASKMOVPDYrm, X86_INS_VMASKMOVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMASKMOVPDmr, X86_INS_VMASKMOVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMASKMOVPDrm, X86_INS_VMASKMOVPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMASKMOVPSYmr, X86_INS_VMASKMOVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMASKMOVPSYrm, X86_INS_VMASKMOVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMASKMOVPSmr, X86_INS_VMASKMOVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMASKMOVPSrm, X86_INS_VMASKMOVPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMAXCPDYrm, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXCPDYrr, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXCPDrm, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXCPDrr, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXCPSYrm, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXCPSYrr, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXCPSrm, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXCPSrr, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXCSDrm, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMAXCSDrr, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMAXCSSrm, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMAXCSSrr, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDYrm, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDYrr, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ128rm, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ128rmb, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ128rmbk, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ128rmbkz, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ128rmk, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ128rmkz, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ128rr, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ128rrk, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ128rrkz, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ256rm, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ256rmb, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ256rmbk, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ256rmbkz, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ256rmk, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ256rmkz, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ256rr, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ256rrk, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZ256rrkz, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZrm, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZrmb, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZrmbk, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZrmbkz, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZrmk, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZrmkz, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZrr, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZrrk, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDZrrkz, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDrm, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPDrr, X86_INS_VMAXPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSYrm, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSYrr, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ128rm, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ128rmb, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ128rmbk, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ128rmbkz, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ128rmk, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ128rmkz, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ128rr, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ128rrk, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ128rrkz, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ256rm, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ256rmb, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ256rmbk, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ256rmbkz, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ256rmk, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ256rmkz, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ256rr, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ256rrk, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZ256rrkz, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZrm, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZrmb, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZrmbk, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZrmbkz, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZrmk, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZrmkz, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZrr, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZrrk, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSZrrkz, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSrm, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXPSrr, X86_INS_VMAXPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDZrm, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDZrm_Int, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDZrm_Intk, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDZrm_Intkz, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDZrr, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDZrr_Int, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDZrr_Intk, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDZrr_Intkz, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDZrrb, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDZrrbk, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDZrrbkz, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDrm, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDrm_Int, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDrr, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMAXSDrr_Int, X86_INS_VMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSZrm, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSZrm_Int, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSZrm_Intk, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSZrm_Intkz, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSZrr, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSZrr_Int, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSZrr_Intk, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSZrr_Intkz, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSZrrb, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSZrrbk, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSZrrbkz, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSrm, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSrm_Int, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSrr, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMAXSSrr_Int, X86_INS_VMAXSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMCALL, X86_INS_VMCALL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, 0 }, 0, 0
#endif
},
{
	X86_VMCLEARm, X86_INS_VMCLEAR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, 0 }, 0, 0
#endif
},
{
	X86_VMFUNC, X86_INS_VMFUNC,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, 0 }, 0, 0
#endif
},
{
	X86_VMINCPDYrm, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINCPDYrr, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINCPDrm, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINCPDrr, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINCPSYrm, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINCPSYrr, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINCPSrm, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINCPSrr, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINCSDrm, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMINCSDrr, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMINCSSrm, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMINCSSrr, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDYrm, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDYrr, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ128rm, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ128rmb, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ128rmbk, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ128rmbkz, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ128rmk, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ128rmkz, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ128rr, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ128rrk, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ128rrkz, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ256rm, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ256rmb, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ256rmbk, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ256rmbkz, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ256rmk, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ256rmkz, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ256rr, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ256rrk, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZ256rrkz, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZrm, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZrmb, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZrmbk, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZrmbkz, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZrmk, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZrmkz, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZrr, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZrrk, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPDZrrkz, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPDrm, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPDrr, X86_INS_VMINPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSYrm, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSYrr, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ128rm, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ128rmb, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ128rmbk, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ128rmbkz, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ128rmk, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ128rmkz, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ128rr, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ128rrk, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ128rrkz, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ256rm, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ256rmb, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ256rmbk, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ256rmbkz, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ256rmk, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ256rmkz, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ256rr, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ256rrk, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZ256rrkz, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZrm, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZrmb, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZrmbk, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZrmbkz, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZrmk, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZrmkz, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZrr, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZrrk, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPSZrrkz, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINPSrm, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINPSrr, X86_INS_VMINPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMINSDZrm, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSDZrm_Int, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSDZrm_Intk, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSDZrm_Intkz, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSDZrr, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSDZrr_Int, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSDZrr_Intk, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSDZrr_Intkz, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSDZrrb, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSDZrrbk, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSDZrrbkz, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSDrm, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMINSDrm_Int, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMINSDrr, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMINSDrr_Int, X86_INS_VMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMINSSZrm, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSSZrm_Int, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSSZrm_Intk, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSSZrm_Intkz, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSSZrr, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSSZrr_Int, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSSZrr_Intk, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSSZrr_Intkz, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSSZrrb, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSSZrrbk, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSSZrrbkz, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMINSSrm, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMINSSrm_Int, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMINSSrr, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMINSSrr_Int, X86_INS_VMINSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMLAUNCH, X86_INS_VMLAUNCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, 0 }, 0, 0
#endif
},
{
	X86_VMLOAD32, X86_INS_VMLOAD,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_VMLOAD64, X86_INS_VMLOAD,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_VMMCALL, X86_INS_VMMCALL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, 0 }, 0, 0
#endif
},
{
	X86_VMOV64toPQIZrr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOV64toPQIrm, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOV64toPQIrr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOV64toSDZrr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOV64toSDrm, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOV64toSDrr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDYmr, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDYrm, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDYrr, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDYrr_REV, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ128mr, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ128mrk, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ128rm, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ128rmk, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ128rmkz, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ128rr, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ128rr_alt, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ128rrk, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ128rrk_alt, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ128rrkz, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ128rrkz_alt, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ256mr, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ256mrk, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ256rm, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ256rmk, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ256rmkz, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ256rr, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ256rr_alt, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ256rrk, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ256rrk_alt, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ256rrkz, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZ256rrkz_alt, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZmr, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZmrk, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZrm, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZrmk, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZrmkz, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZrr, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZrr_alt, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZrrk, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZrrk_alt, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZrrkz, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDZrrkz_alt, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDmr, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDrm, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDrr, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPDrr_REV, X86_INS_VMOVAPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSYmr, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSYrm, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSYrr, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSYrr_REV, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ128mr, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ128mrk, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ128rm, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ128rmk, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ128rmkz, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ128rr, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ128rr_alt, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ128rrk, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ128rrk_alt, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ128rrkz, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ128rrkz_alt, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ256mr, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ256mrk, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ256rm, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ256rmk, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ256rmkz, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ256rr, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ256rr_alt, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ256rrk, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ256rrk_alt, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ256rrkz, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZ256rrkz_alt, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZmr, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZmrk, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZrm, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZrmk, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZrmkz, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZrr, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZrr_alt, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZrrk, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZrrk_alt, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZrrkz, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSZrrkz_alt, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSmr, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSrm, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSrr, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVAPSrr_REV, X86_INS_VMOVAPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDDUPYrm, X86_INS_VMOVDDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDDUPYrr, X86_INS_VMOVDDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDDUPZrm, X86_INS_VMOVDDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDDUPZrr, X86_INS_VMOVDDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDDUPrm, X86_INS_VMOVDDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDDUPrr, X86_INS_VMOVDDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDI2PDIZrm, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDI2PDIZrr, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDI2PDIrm, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDI2PDIrr, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDI2SSZrm, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDI2SSZrr, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDI2SSrm, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDI2SSrr, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z128mr, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z128mrk, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z128rm, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z128rmk, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z128rmkz, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z128rr, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z128rr_alt, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z128rrk, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z128rrk_alt, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z128rrkz, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z128rrkz_alt, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z256mr, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z256mrk, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z256rm, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z256rmk, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z256rmkz, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z256rr, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z256rr_alt, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z256rrk, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z256rrk_alt, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z256rrkz, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Z256rrkz_alt, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Zmr, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Zmrk, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Zrm, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Zrmk, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Zrmkz, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Zrr, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Zrr_alt, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Zrrk, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Zrrk_alt, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Zrrkz, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA32Zrrkz_alt, X86_INS_VMOVDQA32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z128mr, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z128mrk, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z128rm, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z128rmk, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z128rmkz, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z128rr, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z128rr_alt, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z128rrk, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z128rrk_alt, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z128rrkz, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z128rrkz_alt, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z256mr, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z256mrk, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z256rm, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z256rmk, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z256rmkz, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z256rr, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z256rr_alt, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z256rrk, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z256rrk_alt, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z256rrkz, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Z256rrkz_alt, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Zmr, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Zmrk, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Zrm, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Zrmk, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Zrmkz, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Zrr, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Zrr_alt, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Zrrk, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Zrrk_alt, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Zrrkz, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQA64Zrrkz_alt, X86_INS_VMOVDQA64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQAYmr, X86_INS_VMOVDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQAYrm, X86_INS_VMOVDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQAYrr, X86_INS_VMOVDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQAYrr_REV, X86_INS_VMOVDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQAmr, X86_INS_VMOVDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQArm, X86_INS_VMOVDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQArr, X86_INS_VMOVDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQArr_REV, X86_INS_VMOVDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z128mr, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z128mrk, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z128rm, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z128rmk, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z128rmkz, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z128rr, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z128rr_alt, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z128rrk, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z128rrk_alt, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z128rrkz, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z128rrkz_alt, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z256mr, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z256mrk, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z256rm, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z256rmk, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z256rmkz, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z256rr, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z256rr_alt, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z256rrk, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z256rrk_alt, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z256rrkz, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Z256rrkz_alt, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Zmr, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Zmrk, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Zrm, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Zrmk, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Zrmkz, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Zrr, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Zrr_alt, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Zrrk, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Zrrk_alt, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Zrrkz, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU16Zrrkz_alt, X86_INS_VMOVDQU16,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z128mr, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z128mrk, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z128rm, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z128rmk, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z128rmkz, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z128rr, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z128rr_alt, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z128rrk, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z128rrk_alt, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z128rrkz, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z128rrkz_alt, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z256mr, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z256mrk, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z256rm, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z256rmk, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z256rmkz, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z256rr, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z256rr_alt, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z256rrk, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z256rrk_alt, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z256rrkz, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Z256rrkz_alt, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Zmr, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Zmrk, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Zrm, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Zrmk, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Zrmkz, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Zrr, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Zrr_alt, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Zrrk, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Zrrk_alt, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Zrrkz, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU32Zrrkz_alt, X86_INS_VMOVDQU32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z128mr, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z128mrk, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z128rm, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z128rmk, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z128rmkz, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z128rr, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z128rr_alt, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z128rrk, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z128rrk_alt, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z128rrkz, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z128rrkz_alt, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z256mr, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z256mrk, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z256rm, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z256rmk, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z256rmkz, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z256rr, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z256rr_alt, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z256rrk, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z256rrk_alt, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z256rrkz, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Z256rrkz_alt, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Zmr, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Zmrk, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Zrm, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Zrmk, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Zrmkz, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Zrr, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Zrr_alt, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Zrrk, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Zrrk_alt, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Zrrkz, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU64Zrrkz_alt, X86_INS_VMOVDQU64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z128mr, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z128mrk, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z128rm, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z128rmk, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z128rmkz, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z128rr, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z128rr_alt, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z128rrk, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z128rrk_alt, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z128rrkz, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z128rrkz_alt, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z256mr, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z256mrk, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z256rm, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z256rmk, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z256rmkz, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z256rr, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z256rr_alt, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z256rrk, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z256rrk_alt, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z256rrkz, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Z256rrkz_alt, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Zmr, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Zmrk, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Zrm, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Zrmk, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Zrmkz, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Zrr, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Zrr_alt, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Zrrk, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Zrrk_alt, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Zrrkz, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQU8Zrrkz_alt, X86_INS_VMOVDQU8,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQUYmr, X86_INS_VMOVDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQUYrm, X86_INS_VMOVDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQUYrr, X86_INS_VMOVDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQUYrr_REV, X86_INS_VMOVDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQUmr, X86_INS_VMOVDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQUrm, X86_INS_VMOVDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQUrr, X86_INS_VMOVDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVDQUrr_REV, X86_INS_VMOVDQU,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVHLPSZrr, X86_INS_VMOVHLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVHLPSrr, X86_INS_VMOVHLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVHPDmr, X86_INS_VMOVHPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVHPDrm, X86_INS_VMOVHPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVHPSmr, X86_INS_VMOVHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVHPSrm, X86_INS_VMOVHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVLHPSZrr, X86_INS_VMOVLHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVLHPSrr, X86_INS_VMOVLHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVLPDmr, X86_INS_VMOVLPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVLPDrm, X86_INS_VMOVLPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVLPSmr, X86_INS_VMOVLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVLPSrm, X86_INS_VMOVLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVMSKPDYrr, X86_INS_VMOVMSKPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVMSKPDrr, X86_INS_VMOVMSKPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVMSKPSYrr, X86_INS_VMOVMSKPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVMSKPSrr, X86_INS_VMOVMSKPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTDQAYrm, X86_INS_VMOVNTDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTDQAZ128rm, X86_INS_VMOVNTDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTDQAZ256rm, X86_INS_VMOVNTDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTDQAZrm, X86_INS_VMOVNTDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTDQArm, X86_INS_VMOVNTDQA,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTDQYmr, X86_INS_VMOVNTDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTDQZ128mr, X86_INS_VMOVNTDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTDQZ256mr, X86_INS_VMOVNTDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTDQZmr, X86_INS_VMOVNTDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTDQmr, X86_INS_VMOVNTDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTPDYmr, X86_INS_VMOVNTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTPDZ128mr, X86_INS_VMOVNTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTPDZ256mr, X86_INS_VMOVNTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTPDZmr, X86_INS_VMOVNTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTPDmr, X86_INS_VMOVNTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTPSYmr, X86_INS_VMOVNTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTPSZ128mr, X86_INS_VMOVNTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTPSZ256mr, X86_INS_VMOVNTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTPSZmr, X86_INS_VMOVNTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVNTPSmr, X86_INS_VMOVNTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVPDI2DIZmr, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVPDI2DIZrr, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVPDI2DImr, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVPDI2DIrr, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVPQI2QImr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVPQI2QIrr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVPQIto64Zmr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_VMOVPQIto64Zrr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_VMOVPQIto64rm, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVPQIto64rr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVQI2PQIZrm, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVQI2PQIrm, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDZmr, X86_INS_VMOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDZmrk, X86_INS_VMOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDZrm, X86_INS_VMOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDZrr, X86_INS_VMOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDZrr_REV, X86_INS_VMOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDZrrk, X86_INS_VMOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDmr, X86_INS_VMOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDrm, X86_INS_VMOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDrr, X86_INS_VMOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDrr_REV, X86_INS_VMOVSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDto64Zmr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDto64Zrr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDto64mr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSDto64rr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSHDUPYrm, X86_INS_VMOVSHDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSHDUPYrr, X86_INS_VMOVSHDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSHDUPZrm, X86_INS_VMOVSHDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSHDUPZrr, X86_INS_VMOVSHDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSHDUPrm, X86_INS_VMOVSHDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSHDUPrr, X86_INS_VMOVSHDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSLDUPYrm, X86_INS_VMOVSLDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSLDUPYrr, X86_INS_VMOVSLDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSLDUPZrm, X86_INS_VMOVSLDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSLDUPZrr, X86_INS_VMOVSLDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSLDUPrm, X86_INS_VMOVSLDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSLDUPrr, X86_INS_VMOVSLDUP,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSS2DIZmr, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSS2DIZrr, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSS2DImr, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSS2DIrr, X86_INS_VMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSSZmr, X86_INS_VMOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSSZmrk, X86_INS_VMOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSSZrm, X86_INS_VMOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSSZrr, X86_INS_VMOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSSZrr_REV, X86_INS_VMOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSSZrrk, X86_INS_VMOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVSSmr, X86_INS_VMOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSSrm, X86_INS_VMOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSSrr, X86_INS_VMOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVSSrr_REV, X86_INS_VMOVSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDYmr, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDYrm, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDYrr, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDYrr_REV, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ128mr, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ128mrk, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ128rm, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ128rmk, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ128rmkz, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ128rr, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ128rr_alt, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ128rrk, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ128rrk_alt, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ128rrkz, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ128rrkz_alt, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ256mr, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ256mrk, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ256rm, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ256rmk, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ256rmkz, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ256rr, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ256rr_alt, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ256rrk, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ256rrk_alt, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ256rrkz, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZ256rrkz_alt, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZmr, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZmrk, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZrm, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZrmk, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZrmkz, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZrr, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZrr_alt, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZrrk, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZrrk_alt, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZrrkz, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDZrrkz_alt, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDmr, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDrm, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDrr, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPDrr_REV, X86_INS_VMOVUPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSYmr, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSYrm, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSYrr, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSYrr_REV, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ128mr, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ128mrk, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ128rm, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ128rmk, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ128rmkz, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ128rr, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ128rr_alt, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ128rrk, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ128rrk_alt, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ128rrkz, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ128rrkz_alt, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ256mr, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ256mrk, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ256rm, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ256rmk, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ256rmkz, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ256rr, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ256rr_alt, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ256rrk, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ256rrk_alt, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ256rrkz, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZ256rrkz_alt, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZmr, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZmrk, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZrm, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZrmk, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZrmkz, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZrr, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZrr_alt, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZrrk, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZrrk_alt, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZrrkz, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSZrrkz_alt, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSmr, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSrm, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSrr, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMOVUPSrr_REV, X86_INS_VMOVUPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVZPQILo2PQIZrm, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVZPQILo2PQIZrr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMOVZPQILo2PQIrm, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVZPQILo2PQIrr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVZQI2PQIrm, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMOVZQI2PQIrr, X86_INS_VMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMPSADBWYrmi, X86_INS_VMPSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VMPSADBWYrri, X86_INS_VMPSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VMPSADBWrmi, X86_INS_VMPSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMPSADBWrri, X86_INS_VMPSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMPTRLDm, X86_INS_VMPTRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, 0 }, 0, 0
#endif
},
{
	X86_VMPTRSTm, X86_INS_VMPTRST,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, 0 }, 0, 0
#endif
},
{
	X86_VMREAD32rm, X86_INS_VMREAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_VMREAD32rr, X86_INS_VMREAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_VMREAD64rm, X86_INS_VMREAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_VMREAD64rr, X86_INS_VMREAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_VMRESUME, X86_INS_VMRESUME,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, 0 }, 0, 0
#endif
},
{
	X86_VMRUN32, X86_INS_VMRUN,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_VMRUN64, X86_INS_VMRUN,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_VMSAVE32, X86_INS_VMSAVE,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_VMSAVE64, X86_INS_VMSAVE,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_VMULPDYrm, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDYrr, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ128rm, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ128rmb, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ128rmbk, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ128rmbkz, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ128rmk, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ128rmkz, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ128rr, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ128rrk, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ128rrkz, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ256rm, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ256rmb, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ256rmbk, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ256rmbkz, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ256rmk, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ256rmkz, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ256rr, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ256rrk, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZ256rrkz, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZrb, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZrbk, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZrbkz, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZrm, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZrmb, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZrmbk, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZrmbkz, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZrmk, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZrmkz, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZrr, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZrrk, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPDZrrkz, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPDrm, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPDrr, X86_INS_VMULPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSYrm, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSYrr, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ128rm, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ128rmb, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ128rmbk, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ128rmbkz, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ128rmk, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ128rmkz, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ128rr, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ128rrk, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ128rrkz, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ256rm, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ256rmb, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ256rmbk, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ256rmbkz, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ256rmk, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ256rmkz, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ256rr, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ256rrk, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZ256rrkz, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZrb, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZrbk, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZrbkz, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZrm, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZrmb, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZrmbk, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZrmbkz, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZrmk, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZrmkz, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZrr, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZrrk, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPSZrrkz, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULPSrm, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMULPSrr, X86_INS_VMULPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VMULSDZrm, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSDZrm_Int, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSDZrm_Intk, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSDZrm_Intkz, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSDZrr, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSDZrr_Int, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSDZrr_Intk, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSDZrr_Intkz, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSDZrrb, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSDZrrbk, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSDZrrbkz, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSDrm, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMULSDrm_Int, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMULSDrr, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMULSDrr_Int, X86_INS_VMULSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMULSSZrm, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSSZrm_Int, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSSZrm_Intk, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSSZrm_Intkz, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSSZrr, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSSZrr_Int, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSSZrr_Intk, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSSZrr_Intkz, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSSZrrb, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSSZrrbk, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSSZrrbkz, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VMULSSrm, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMULSSrm_Int, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMULSSrr, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMULSSrr_Int, X86_INS_VMULSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VMWRITE32rm, X86_INS_VMWRITE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_VMWRITE32rr, X86_INS_VMWRITE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_VMWRITE64rm, X86_INS_VMWRITE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_VMWRITE64rr, X86_INS_VMWRITE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_VMXOFF, X86_INS_VMXOFF,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, 0 }, 0, 0
#endif
},
{
	X86_VMXON, X86_INS_VMXON,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_VM, 0 }, 0, 0
#endif
},
{
	X86_VORPDYrm, X86_INS_VORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VORPDYrr, X86_INS_VORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VORPDrm, X86_INS_VORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VORPDrr, X86_INS_VORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VORPSYrm, X86_INS_VORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VORPSYrr, X86_INS_VORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VORPSrm, X86_INS_VORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VORPSrr, X86_INS_VORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPABSBrm128, X86_INS_VPABSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPABSBrm256, X86_INS_VPABSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPABSBrr128, X86_INS_VPABSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPABSBrr256, X86_INS_VPABSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPABSDZrm, X86_INS_VPABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSDZrmb, X86_INS_VPABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSDZrmbk, X86_INS_VPABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSDZrmbkz, X86_INS_VPABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSDZrmk, X86_INS_VPABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSDZrmkz, X86_INS_VPABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSDZrr, X86_INS_VPABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSDZrrk, X86_INS_VPABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSDZrrkz, X86_INS_VPABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSDrm128, X86_INS_VPABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPABSDrm256, X86_INS_VPABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPABSDrr128, X86_INS_VPABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPABSDrr256, X86_INS_VPABSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPABSQZrm, X86_INS_VPABSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSQZrmb, X86_INS_VPABSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSQZrmbk, X86_INS_VPABSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSQZrmbkz, X86_INS_VPABSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSQZrmk, X86_INS_VPABSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSQZrmkz, X86_INS_VPABSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSQZrr, X86_INS_VPABSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSQZrrk, X86_INS_VPABSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSQZrrkz, X86_INS_VPABSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPABSWrm128, X86_INS_VPABSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPABSWrm256, X86_INS_VPABSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPABSWrr128, X86_INS_VPABSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPABSWrr256, X86_INS_VPABSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPACKSSDWYrm, X86_INS_VPACKSSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPACKSSDWYrr, X86_INS_VPACKSSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPACKSSDWrm, X86_INS_VPACKSSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPACKSSDWrr, X86_INS_VPACKSSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPACKSSWBYrm, X86_INS_VPACKSSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPACKSSWBYrr, X86_INS_VPACKSSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPACKSSWBrm, X86_INS_VPACKSSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPACKSSWBrr, X86_INS_VPACKSSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPACKUSDWYrm, X86_INS_VPACKUSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPACKUSDWYrr, X86_INS_VPACKUSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPACKUSDWrm, X86_INS_VPACKUSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPACKUSDWrr, X86_INS_VPACKUSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPACKUSWBYrm, X86_INS_VPACKUSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPACKUSWBYrr, X86_INS_VPACKUSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPACKUSWBrm, X86_INS_VPACKUSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPACKUSWBrr, X86_INS_VPACKUSWB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBYrm, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBYrr, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZ128rm, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZ128rmk, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZ128rmkz, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZ128rr, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZ128rrk, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZ128rrkz, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZ256rm, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZ256rmk, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZ256rmkz, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZ256rr, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZ256rrk, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZ256rrkz, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZrm, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZrmk, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZrmkz, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZrr, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZrrk, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPADDBZrrkz, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPADDBrm, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDBrr, X86_INS_VPADDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDYrm, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDYrr, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ128rm, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ128rmb, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ128rmbk, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ128rmbkz, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ128rmk, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ128rmkz, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ128rr, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ128rrk, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ128rrkz, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ256rm, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ256rmb, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ256rmbk, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ256rmbkz, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ256rmk, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ256rmkz, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ256rr, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ256rrk, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZ256rrkz, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZrm, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZrmb, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZrmbk, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZrmbkz, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZrmk, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZrmkz, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZrr, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZrrk, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDDZrrkz, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDDrm, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDDrr, X86_INS_VPADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQYrm, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQYrr, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ128rm, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ128rmb, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ128rmbk, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ128rmbkz, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ128rmk, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ128rmkz, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ128rr, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ128rrk, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ128rrkz, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ256rm, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ256rmb, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ256rmbk, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ256rmbkz, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ256rmk, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ256rmkz, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ256rr, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ256rrk, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZ256rrkz, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZrm, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZrmb, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZrmbk, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZrmbkz, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZrmk, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZrmkz, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZrr, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZrrk, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDQZrrkz, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPADDQrm, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDQrr, X86_INS_VPADDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDSBYrm, X86_INS_VPADDSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPADDSBYrr, X86_INS_VPADDSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPADDSBrm, X86_INS_VPADDSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPADDSBrr, X86_INS_VPADDSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPADDSWYrm, X86_INS_VPADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPADDSWYrr, X86_INS_VPADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPADDSWrm, X86_INS_VPADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPADDSWrr, X86_INS_VPADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPADDUSBYrm, X86_INS_VPADDUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPADDUSBYrr, X86_INS_VPADDUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPADDUSBrm, X86_INS_VPADDUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPADDUSBrr, X86_INS_VPADDUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPADDUSWYrm, X86_INS_VPADDUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPADDUSWYrr, X86_INS_VPADDUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPADDUSWrm, X86_INS_VPADDUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPADDUSWrr, X86_INS_VPADDUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWYrm, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWYrr, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZ128rm, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZ128rmk, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZ128rmkz, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZ128rr, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZ128rrk, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZ128rrkz, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZ256rm, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZ256rmk, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZ256rmkz, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZ256rr, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZ256rrk, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZ256rrkz, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZrm, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZrmk, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZrmkz, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZrr, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZrrk, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPADDWZrrkz, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPADDWrm, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPADDWrr, X86_INS_VPADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPALIGNR128rm, X86_INS_VPALIGNR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPALIGNR128rr, X86_INS_VPALIGNR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPALIGNR256rm, X86_INS_VPALIGNR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPALIGNR256rr, X86_INS_VPALIGNR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ128rm, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ128rmb, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ128rmbk, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ128rmbkz, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ128rmk, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ128rmkz, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ128rr, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ128rrk, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ128rrkz, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ256rm, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ256rmb, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ256rmbk, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ256rmbkz, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ256rmk, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ256rmkz, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ256rr, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ256rrk, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZ256rrkz, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZrm, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZrmb, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZrmbk, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZrmbkz, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZrmk, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZrmkz, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZrr, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZrrk, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDDZrrkz, X86_INS_VPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ128rm, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ128rmb, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ128rmbk, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ128rmbkz, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ128rmk, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ128rmkz, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ128rr, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ128rrk, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ128rrkz, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ256rm, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ256rmb, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ256rmbk, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ256rmbkz, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ256rmk, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ256rmkz, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ256rr, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ256rrk, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZ256rrkz, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZrm, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZrmb, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZrmbk, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZrmbkz, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZrmk, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZrmkz, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZrr, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZrrk, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNDZrrkz, X86_INS_VPANDND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ128rm, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ128rmb, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ128rmbk, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ128rmbkz, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ128rmk, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ128rmkz, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ128rr, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ128rrk, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ128rrkz, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ256rm, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ256rmb, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ256rmbk, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ256rmbkz, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ256rmk, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ256rmkz, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ256rr, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ256rrk, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZ256rrkz, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZrm, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZrmb, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZrmbk, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZrmbkz, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZrmk, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZrmkz, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZrr, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZrrk, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNQZrrkz, X86_INS_VPANDNQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDNYrm, X86_INS_VPANDN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNYrr, X86_INS_VPANDN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNrm, X86_INS_VPANDN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDNrr, X86_INS_VPANDN,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ128rm, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ128rmb, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ128rmbk, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ128rmbkz, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ128rmk, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ128rmkz, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ128rr, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ128rrk, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ128rrkz, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ256rm, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ256rmb, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ256rmbk, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ256rmbkz, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ256rmk, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ256rmkz, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ256rr, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ256rrk, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZ256rrkz, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZrm, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZrmb, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZrmbk, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZrmbkz, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZrmk, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZrmkz, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZrr, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZrrk, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDQZrrkz, X86_INS_VPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPANDYrm, X86_INS_VPAND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDYrr, X86_INS_VPAND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDrm, X86_INS_VPAND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPANDrr, X86_INS_VPAND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPAVGBYrm, X86_INS_VPAVGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPAVGBYrr, X86_INS_VPAVGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPAVGBrm, X86_INS_VPAVGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPAVGBrr, X86_INS_VPAVGB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPAVGWYrm, X86_INS_VPAVGW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPAVGWYrr, X86_INS_VPAVGW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPAVGWrm, X86_INS_VPAVGW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPAVGWrr, X86_INS_VPAVGW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDDYrmi, X86_INS_VPBLENDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDDYrri, X86_INS_VPBLENDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDDrmi, X86_INS_VPBLENDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDDrri, X86_INS_VPBLENDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZ128rm, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZ128rmk, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZ128rmkz, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZ128rr, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZ128rrk, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZ128rrkz, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZ256rm, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZ256rmk, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZ256rmkz, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZ256rr, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZ256rrk, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZ256rrkz, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZrm, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZrmk, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZrmkz, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZrr, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZrrk, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMBZrrkz, X86_INS_VPBLENDMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ128rm, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ128rmb, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ128rmbk, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ128rmk, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ128rmkz, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ128rr, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ128rrk, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ128rrkz, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ256rm, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ256rmb, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ256rmbk, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ256rmk, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ256rmkz, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ256rr, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ256rrk, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZ256rrkz, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZrm, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZrmb, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZrmbk, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZrmk, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZrmkz, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZrr, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZrrk, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMDZrrkz, X86_INS_VPBLENDMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ128rm, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ128rmb, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ128rmbk, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ128rmk, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ128rmkz, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ128rr, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ128rrk, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ128rrkz, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ256rm, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ256rmb, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ256rmbk, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ256rmk, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ256rmkz, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ256rr, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ256rrk, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZ256rrkz, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZrm, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZrmb, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZrmbk, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZrmk, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZrmkz, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZrr, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZrrk, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMQZrrkz, X86_INS_VPBLENDMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZ128rm, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZ128rmk, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZ128rmkz, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZ128rr, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZ128rrk, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZ128rrkz, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZ256rm, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZ256rmk, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZ256rmkz, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZ256rr, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZ256rrk, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZ256rrkz, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZrm, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZrmk, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZrmkz, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZrr, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZrrk, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDMWZrrkz, X86_INS_VPBLENDMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDVBYrm, X86_INS_VPBLENDVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDVBYrr, X86_INS_VPBLENDVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDVBrm, X86_INS_VPBLENDVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDVBrr, X86_INS_VPBLENDVB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDWYrmi, X86_INS_VPBLENDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDWYrri, X86_INS_VPBLENDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDWrmi, X86_INS_VPBLENDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPBLENDWrri, X86_INS_VPBLENDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTBYrm, X86_INS_VPBROADCASTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTBYrr, X86_INS_VPBROADCASTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTBrZ128r, X86_INS_VPBROADCASTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTBrZ128rk, X86_INS_VPBROADCASTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTBrZ128rkz, X86_INS_VPBROADCASTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTBrZ256r, X86_INS_VPBROADCASTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTBrZ256rk, X86_INS_VPBROADCASTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTBrZ256rkz, X86_INS_VPBROADCASTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTBrZr, X86_INS_VPBROADCASTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTBrZrk, X86_INS_VPBROADCASTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTBrZrkz, X86_INS_VPBROADCASTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTBrm, X86_INS_VPBROADCASTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTBrr, X86_INS_VPBROADCASTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDYrm, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDYrr, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDZkrm, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDZkrr, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDZrm, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDZrr, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDrZ128r, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDrZ128rk, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDrZ128rkz, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDrZ256r, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDrZ256rk, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDrZ256rkz, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDrZr, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDrZrk, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDrZrkz, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDrm, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTDrr, X86_INS_VPBROADCASTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTMB2QZ128rr, X86_INS_VPBROADCASTMB2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTMB2QZ256rr, X86_INS_VPBROADCASTMB2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTMB2QZrr, X86_INS_VPBROADCASTMB2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTMW2DZ128rr, X86_INS_VPBROADCASTMW2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTMW2DZ256rr, X86_INS_VPBROADCASTMW2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTMW2DZrr, X86_INS_VPBROADCASTMW2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQYrm, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQYrr, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQZkrm, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQZkrr, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQZrm, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQZrr, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQrZ128r, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQrZ128rk, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQrZ128rkz, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQrZ256r, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQrZ256rk, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQrZ256rkz, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQrZr, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQrZrk, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQrZrkz, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQrm, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTQrr, X86_INS_VPBROADCASTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTWYrm, X86_INS_VPBROADCASTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTWYrr, X86_INS_VPBROADCASTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTWrZ128r, X86_INS_VPBROADCASTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTWrZ128rk, X86_INS_VPBROADCASTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTWrZ128rkz, X86_INS_VPBROADCASTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTWrZ256r, X86_INS_VPBROADCASTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTWrZ256rk, X86_INS_VPBROADCASTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTWrZ256rkz, X86_INS_VPBROADCASTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTWrZr, X86_INS_VPBROADCASTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTWrZrk, X86_INS_VPBROADCASTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTWrZrkz, X86_INS_VPBROADCASTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTWrm, X86_INS_VPBROADCASTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPBROADCASTWrr, X86_INS_VPBROADCASTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPCLMULQDQrm, X86_INS_VPCLMULQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_PCLMUL, 0 }, 0, 0
#endif
},
{
	X86_VPCLMULQDQrr, X86_INS_VPCLMULQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_PCLMUL, 0 }, 0, 0
#endif
},
{
	X86_VPCMOVmr, X86_INS_VPCMOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCMOVmrY, X86_INS_VPCMOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCMOVrm, X86_INS_VPCMOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCMOVrmY, X86_INS_VPCMOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCMOVrr, X86_INS_VPCMOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCMOVrrY, X86_INS_VPCMOV,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ128rmi, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ128rmi_alt, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ128rmik, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ128rmik_alt, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ128rri, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ128rri_alt, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ128rrik, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ128rrik_alt, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ256rmi, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ256rmi_alt, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ256rmik, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ256rmik_alt, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ256rri, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ256rri_alt, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ256rrik, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZ256rrik_alt, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZrmi, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZrmi_alt, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZrmik, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZrmik_alt, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZrri, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZrri_alt, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZrrik, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPBZrrik_alt, X86_INS_VPCMPB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ128rmi, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ128rmi_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ128rmib, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ128rmib_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ128rmibk, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ128rmibk_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ128rmik, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ128rmik_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ128rri, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ128rri_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ128rrik, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ128rrik_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ256rmi, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ256rmi_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ256rmib, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ256rmib_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ256rmibk, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ256rmibk_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ256rmik, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ256rmik_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ256rri, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ256rri_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ256rrik, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZ256rrik_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZrmi, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZrmi_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZrmib, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZrmib_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZrmibk, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZrmibk_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZrmik, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZrmik_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZrri, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZrri_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZrrik, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPDZrrik_alt, X86_INS_VPCMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBYrm, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBYrr, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBZ128rm, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBZ128rmk, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBZ128rr, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBZ128rrk, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBZ256rm, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBZ256rmk, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBZ256rr, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBZ256rrk, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBZrm, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBZrmk, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBZrr, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBZrrk, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBrm, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQBrr, X86_INS_VPCMPEQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDYrm, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDYrr, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZ128rm, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZ128rmb, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZ128rmbk, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZ128rmk, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZ128rr, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZ128rrk, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZ256rm, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZ256rmb, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZ256rmbk, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZ256rmk, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZ256rr, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZ256rrk, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZrm, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZrmb, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZrmbk, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZrmk, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZrr, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDZrrk, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDrm, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQDrr, X86_INS_VPCMPEQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQYrm, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQYrr, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZ128rm, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZ128rmb, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZ128rmbk, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZ128rmk, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZ128rr, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZ128rrk, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZ256rm, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZ256rmb, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZ256rmbk, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZ256rmk, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZ256rr, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZ256rrk, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZrm, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZrmb, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZrmbk, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZrmk, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZrr, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQZrrk, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQrm, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQQrr, X86_INS_VPCMPEQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWYrm, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWYrr, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWZ128rm, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWZ128rmk, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWZ128rr, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWZ128rrk, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWZ256rm, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWZ256rmk, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWZ256rr, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWZ256rrk, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWZrm, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWZrmk, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWZrr, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWZrrk, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWrm, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPEQWrr, X86_INS_VPCMPEQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPESTRIrm, X86_INS_VPCMPESTRI,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDX, 0 }, { X86_REG_ECX, X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPESTRIrr, X86_INS_VPCMPESTRI,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDX, 0 }, { X86_REG_ECX, X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPESTRM128rm, X86_INS_VPCMPESTRM,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDX, 0 }, { X86_REG_XMM0, X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPESTRM128rr, X86_INS_VPCMPESTRM,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_EDX, 0 }, { X86_REG_XMM0, X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBYrm, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBYrr, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBZ128rm, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBZ128rmk, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBZ128rr, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBZ128rrk, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBZ256rm, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBZ256rmk, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBZ256rr, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBZ256rrk, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBZrm, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBZrmk, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBZrr, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBZrrk, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBrm, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTBrr, X86_INS_VPCMPGTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDYrm, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDYrr, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZ128rm, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZ128rmb, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZ128rmbk, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZ128rmk, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZ128rr, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZ128rrk, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZ256rm, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZ256rmb, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZ256rmbk, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZ256rmk, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZ256rr, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZ256rrk, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZrm, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZrmb, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZrmbk, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZrmk, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZrr, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDZrrk, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDrm, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTDrr, X86_INS_VPCMPGTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQYrm, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQYrr, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZ128rm, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZ128rmb, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZ128rmbk, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZ128rmk, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZ128rr, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZ128rrk, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZ256rm, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZ256rmb, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZ256rmbk, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZ256rmk, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZ256rr, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZ256rrk, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZrm, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZrmb, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZrmbk, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZrmk, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZrr, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQZrrk, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQrm, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTQrr, X86_INS_VPCMPGTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWYrm, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWYrr, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWZ128rm, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWZ128rmk, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWZ128rr, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWZ128rrk, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWZ256rm, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWZ256rmk, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWZ256rr, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWZ256rrk, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWZrm, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWZrmk, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWZrr, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWZrrk, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWrm, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPGTWrr, X86_INS_VPCMPGTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPISTRIrm, X86_INS_VPCMPISTRI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_ECX, X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPISTRIrr, X86_INS_VPCMPISTRI,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_ECX, X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPISTRM128rm, X86_INS_VPCMPISTRM,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_XMM0, X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPISTRM128rr, X86_INS_VPCMPISTRM,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_XMM0, X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ128rmi, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ128rmi_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ128rmib, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ128rmib_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ128rmibk, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ128rmibk_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ128rmik, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ128rmik_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ128rri, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ128rri_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ128rrik, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ128rrik_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ256rmi, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ256rmi_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ256rmib, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ256rmib_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ256rmibk, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ256rmibk_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ256rmik, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ256rmik_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ256rri, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ256rri_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ256rrik, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZ256rrik_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZrmi, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZrmi_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZrmib, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZrmib_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZrmibk, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZrmibk_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZrmik, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZrmik_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZrri, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZrri_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZrrik, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPQZrrik_alt, X86_INS_VPCMPQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ128rmi, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ128rmi_alt, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ128rmik, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ128rmik_alt, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ128rri, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ128rri_alt, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ128rrik, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ128rrik_alt, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ256rmi, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ256rmi_alt, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ256rmik, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ256rmik_alt, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ256rri, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ256rri_alt, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ256rrik, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZ256rrik_alt, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZrmi, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZrmi_alt, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZrmik, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZrmik_alt, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZrri, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZrri_alt, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZrrik, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUBZrrik_alt, X86_INS_VPCMPUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ128rmi, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ128rmi_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ128rmib, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ128rmib_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ128rmibk, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ128rmibk_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ128rmik, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ128rmik_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ128rri, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ128rri_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ128rrik, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ128rrik_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ256rmi, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ256rmi_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ256rmib, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ256rmib_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ256rmibk, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ256rmibk_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ256rmik, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ256rmik_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ256rri, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ256rri_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ256rrik, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZ256rrik_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZrmi, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZrmi_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZrmib, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZrmib_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZrmibk, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZrmibk_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZrmik, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZrmik_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZrri, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZrri_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZrrik, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUDZrrik_alt, X86_INS_VPCMPUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ128rmi, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ128rmi_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ128rmib, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ128rmib_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ128rmibk, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ128rmibk_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ128rmik, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ128rmik_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ128rri, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ128rri_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ128rrik, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ128rrik_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ256rmi, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ256rmi_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ256rmib, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ256rmib_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ256rmibk, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ256rmibk_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ256rmik, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ256rmik_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ256rri, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ256rri_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ256rrik, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZ256rrik_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZrmi, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZrmi_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZrmib, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZrmib_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZrmibk, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZrmibk_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZrmik, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZrmik_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZrri, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZrri_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZrrik, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUQZrrik_alt, X86_INS_VPCMPUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ128rmi, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ128rmi_alt, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ128rmik, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ128rmik_alt, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ128rri, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ128rri_alt, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ128rrik, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ128rrik_alt, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ256rmi, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ256rmi_alt, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ256rmik, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ256rmik_alt, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ256rri, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ256rri_alt, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ256rrik, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZ256rrik_alt, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZrmi, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZrmi_alt, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZrmik, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZrmik_alt, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZrri, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZrri_alt, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZrrik, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPUWZrrik_alt, X86_INS_VPCMPUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ128rmi, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ128rmi_alt, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ128rmik, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ128rmik_alt, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ128rri, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ128rri_alt, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ128rrik, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ128rrik_alt, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ256rmi, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ256rmi_alt, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ256rmik, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ256rmik_alt, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ256rri, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ256rri_alt, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ256rrik, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZ256rrik_alt, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZrmi, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZrmi_alt, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZrmik, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZrmik_alt, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZrri, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZrri_alt, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZrrik, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCMPWZrrik_alt, X86_INS_VPCMPW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPCOMBmi, X86_INS_VPCOMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMBmi_alt, X86_INS_VPCOMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMBri, X86_INS_VPCOMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMBri_alt, X86_INS_VPCOMB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMDmi, X86_INS_VPCOMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMDmi_alt, X86_INS_VPCOMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMDri, X86_INS_VPCOMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMDri_alt, X86_INS_VPCOMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSDZ128mrk, X86_INS_VPCOMPRESSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSDZ128rrk, X86_INS_VPCOMPRESSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSDZ128rrkz, X86_INS_VPCOMPRESSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSDZ256mrk, X86_INS_VPCOMPRESSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSDZ256rrk, X86_INS_VPCOMPRESSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSDZ256rrkz, X86_INS_VPCOMPRESSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSDZmrk, X86_INS_VPCOMPRESSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSDZrrk, X86_INS_VPCOMPRESSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSDZrrkz, X86_INS_VPCOMPRESSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSQZ128mrk, X86_INS_VPCOMPRESSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSQZ128rrk, X86_INS_VPCOMPRESSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSQZ128rrkz, X86_INS_VPCOMPRESSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSQZ256mrk, X86_INS_VPCOMPRESSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSQZ256rrk, X86_INS_VPCOMPRESSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSQZ256rrkz, X86_INS_VPCOMPRESSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSQZmrk, X86_INS_VPCOMPRESSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSQZrrk, X86_INS_VPCOMPRESSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCOMPRESSQZrrkz, X86_INS_VPCOMPRESSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPCOMQmi, X86_INS_VPCOMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMQmi_alt, X86_INS_VPCOMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMQri, X86_INS_VPCOMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMQri_alt, X86_INS_VPCOMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUBmi, X86_INS_VPCOMUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUBmi_alt, X86_INS_VPCOMUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUBri, X86_INS_VPCOMUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUBri_alt, X86_INS_VPCOMUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUDmi, X86_INS_VPCOMUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUDmi_alt, X86_INS_VPCOMUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUDri, X86_INS_VPCOMUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUDri_alt, X86_INS_VPCOMUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUQmi, X86_INS_VPCOMUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUQmi_alt, X86_INS_VPCOMUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUQri, X86_INS_VPCOMUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUQri_alt, X86_INS_VPCOMUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUWmi, X86_INS_VPCOMUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUWmi_alt, X86_INS_VPCOMUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUWri, X86_INS_VPCOMUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMUWri_alt, X86_INS_VPCOMUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMWmi, X86_INS_VPCOMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMWmi_alt, X86_INS_VPCOMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMWri, X86_INS_VPCOMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCOMWri_alt, X86_INS_VPCOMW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTDrm, X86_INS_VPCONFLICTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTDrmb, X86_INS_VPCONFLICTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTDrmbk, X86_INS_VPCONFLICTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTDrmbkz, X86_INS_VPCONFLICTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTDrmk, X86_INS_VPCONFLICTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTDrmkz, X86_INS_VPCONFLICTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTDrr, X86_INS_VPCONFLICTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTDrrk, X86_INS_VPCONFLICTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTDrrkz, X86_INS_VPCONFLICTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTQrm, X86_INS_VPCONFLICTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTQrmb, X86_INS_VPCONFLICTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTQrmbk, X86_INS_VPCONFLICTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTQrmbkz, X86_INS_VPCONFLICTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTQrmk, X86_INS_VPCONFLICTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTQrmkz, X86_INS_VPCONFLICTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTQrr, X86_INS_VPCONFLICTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTQrrk, X86_INS_VPCONFLICTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPCONFLICTQrrkz, X86_INS_VPCONFLICTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPERM2F128rm, X86_INS_VPERM2F128,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERM2F128rr, X86_INS_VPERM2F128,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERM2I128rm, X86_INS_VPERM2I128,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPERM2I128rr, X86_INS_VPERM2I128,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPERMDYrm, X86_INS_VPERMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPERMDYrr, X86_INS_VPERMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPERMDZrm, X86_INS_VPERMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMDZrr, X86_INS_VPERMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2Drm, X86_INS_VPERMI2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2Drmk, X86_INS_VPERMI2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2Drmkz, X86_INS_VPERMI2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2Drr, X86_INS_VPERMI2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2Drrk, X86_INS_VPERMI2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2Drrkz, X86_INS_VPERMI2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2PDrm, X86_INS_VPERMI2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2PDrmk, X86_INS_VPERMI2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2PDrmkz, X86_INS_VPERMI2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2PDrr, X86_INS_VPERMI2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2PDrrk, X86_INS_VPERMI2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2PDrrkz, X86_INS_VPERMI2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2PSrm, X86_INS_VPERMI2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2PSrmk, X86_INS_VPERMI2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2PSrmkz, X86_INS_VPERMI2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2PSrr, X86_INS_VPERMI2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2PSrrk, X86_INS_VPERMI2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2PSrrkz, X86_INS_VPERMI2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2Qrm, X86_INS_VPERMI2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2Qrmk, X86_INS_VPERMI2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2Qrmkz, X86_INS_VPERMI2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2Qrr, X86_INS_VPERMI2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2Qrrk, X86_INS_VPERMI2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMI2Qrrkz, X86_INS_VPERMI2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMIL2PDmr, X86_INS_VPERMIL2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPERMIL2PDmrY, X86_INS_VPERMIL2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPERMIL2PDrm, X86_INS_VPERMIL2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPERMIL2PDrmY, X86_INS_VPERMIL2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPERMIL2PDrr, X86_INS_VPERMIL2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPERMIL2PDrrY, X86_INS_VPERMIL2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPERMIL2PSmr, X86_INS_VPERMIL2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPERMIL2PSmrY, X86_INS_VPERMIL2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPERMIL2PSrm, X86_INS_VPERMIL2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPERMIL2PSrmY, X86_INS_VPERMIL2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPERMIL2PSrr, X86_INS_VPERMIL2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPERMIL2PSrrY, X86_INS_VPERMIL2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPDYmi, X86_INS_VPERMILPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPDYri, X86_INS_VPERMILPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPDYrm, X86_INS_VPERMILPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPDYrr, X86_INS_VPERMILPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPDZmi, X86_INS_VPERMILPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPDZri, X86_INS_VPERMILPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPDZrm, X86_INS_VPERMILPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPDZrr, X86_INS_VPERMILPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPDmi, X86_INS_VPERMILPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPDri, X86_INS_VPERMILPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPDrm, X86_INS_VPERMILPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPDrr, X86_INS_VPERMILPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPSYmi, X86_INS_VPERMILPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPSYri, X86_INS_VPERMILPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPSYrm, X86_INS_VPERMILPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPSYrr, X86_INS_VPERMILPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPSZmi, X86_INS_VPERMILPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPSZri, X86_INS_VPERMILPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPSZrm, X86_INS_VPERMILPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPSZrr, X86_INS_VPERMILPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPSmi, X86_INS_VPERMILPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPSri, X86_INS_VPERMILPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPSrm, X86_INS_VPERMILPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMILPSrr, X86_INS_VPERMILPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPERMPDYmi, X86_INS_VPERMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPERMPDYri, X86_INS_VPERMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPERMPDZmi, X86_INS_VPERMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMPDZri, X86_INS_VPERMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMPDZrm, X86_INS_VPERMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMPDZrr, X86_INS_VPERMPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMPSYrm, X86_INS_VPERMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPERMPSYrr, X86_INS_VPERMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPERMPSZrm, X86_INS_VPERMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMPSZrr, X86_INS_VPERMPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMQYmi, X86_INS_VPERMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPERMQYri, X86_INS_VPERMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPERMQZmi, X86_INS_VPERMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMQZri, X86_INS_VPERMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMQZrm, X86_INS_VPERMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMQZrr, X86_INS_VPERMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2Drm, X86_INS_VPERMT2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2Drmk, X86_INS_VPERMT2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2Drmkz, X86_INS_VPERMT2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2Drr, X86_INS_VPERMT2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2Drrk, X86_INS_VPERMT2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2Drrkz, X86_INS_VPERMT2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2PDrm, X86_INS_VPERMT2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2PDrmk, X86_INS_VPERMT2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2PDrmkz, X86_INS_VPERMT2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2PDrr, X86_INS_VPERMT2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2PDrrk, X86_INS_VPERMT2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2PDrrkz, X86_INS_VPERMT2PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2PSrm, X86_INS_VPERMT2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2PSrmk, X86_INS_VPERMT2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2PSrmkz, X86_INS_VPERMT2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2PSrr, X86_INS_VPERMT2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2PSrrk, X86_INS_VPERMT2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2PSrrkz, X86_INS_VPERMT2PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2Qrm, X86_INS_VPERMT2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2Qrmk, X86_INS_VPERMT2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2Qrmkz, X86_INS_VPERMT2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2Qrr, X86_INS_VPERMT2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2Qrrk, X86_INS_VPERMT2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPERMT2Qrrkz, X86_INS_VPERMT2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDDZ128rmk, X86_INS_VPEXPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDDZ128rmkz, X86_INS_VPEXPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDDZ128rrk, X86_INS_VPEXPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDDZ128rrkz, X86_INS_VPEXPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDDZ256rmk, X86_INS_VPEXPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDDZ256rmkz, X86_INS_VPEXPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDDZ256rrk, X86_INS_VPEXPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDDZ256rrkz, X86_INS_VPEXPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDDZrmk, X86_INS_VPEXPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDDZrmkz, X86_INS_VPEXPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDDZrrk, X86_INS_VPEXPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDDZrrkz, X86_INS_VPEXPANDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDQZ128rmk, X86_INS_VPEXPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDQZ128rmkz, X86_INS_VPEXPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDQZ128rrk, X86_INS_VPEXPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDQZ128rrkz, X86_INS_VPEXPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDQZ256rmk, X86_INS_VPEXPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDQZ256rmkz, X86_INS_VPEXPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDQZ256rrk, X86_INS_VPEXPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDQZ256rrkz, X86_INS_VPEXPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDQZrmk, X86_INS_VPEXPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDQZrmkz, X86_INS_VPEXPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDQZrrk, X86_INS_VPEXPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPEXPANDQZrrkz, X86_INS_VPEXPANDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPEXTRBmr, X86_INS_VPEXTRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPEXTRBrr, X86_INS_VPEXTRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPEXTRDmr, X86_INS_VPEXTRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPEXTRDrr, X86_INS_VPEXTRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPEXTRQmr, X86_INS_VPEXTRQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPEXTRQrr, X86_INS_VPEXTRQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPEXTRWmr, X86_INS_VPEXTRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPEXTRWri, X86_INS_VPEXTRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPEXTRWrr_REV, X86_INS_VPEXTRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPGATHERDDYrm, X86_INS_VPGATHERDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPGATHERDDZrm, X86_INS_VPGATHERDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPGATHERDDrm, X86_INS_VPGATHERDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPGATHERDQYrm, X86_INS_VPGATHERDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPGATHERDQZrm, X86_INS_VPGATHERDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPGATHERDQrm, X86_INS_VPGATHERDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPGATHERQDYrm, X86_INS_VPGATHERQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPGATHERQDZrm, X86_INS_VPGATHERQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPGATHERQDrm, X86_INS_VPGATHERQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPGATHERQQYrm, X86_INS_VPGATHERQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPGATHERQQZrm, X86_INS_VPGATHERQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPGATHERQQrm, X86_INS_VPGATHERQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPHADDBDrm, X86_INS_VPHADDBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDBDrr, X86_INS_VPHADDBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDBQrm, X86_INS_VPHADDBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDBQrr, X86_INS_VPHADDBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDBWrm, X86_INS_VPHADDBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDBWrr, X86_INS_VPHADDBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDDQrm, X86_INS_VPHADDDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDDQrr, X86_INS_VPHADDDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDDYrm, X86_INS_VPHADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPHADDDYrr, X86_INS_VPHADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPHADDDrm, X86_INS_VPHADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPHADDDrr, X86_INS_VPHADDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPHADDSWrm128, X86_INS_VPHADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPHADDSWrm256, X86_INS_VPHADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPHADDSWrr128, X86_INS_VPHADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPHADDSWrr256, X86_INS_VPHADDSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPHADDUBDrm, X86_INS_VPHADDUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDUBDrr, X86_INS_VPHADDUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDUBQrm, X86_INS_VPHADDUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDUBQrr, X86_INS_VPHADDUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDUBWrm, X86_INS_VPHADDUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDUBWrr, X86_INS_VPHADDUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDUDQrm, X86_INS_VPHADDUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDUDQrr, X86_INS_VPHADDUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDUWDrm, X86_INS_VPHADDUWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDUWDrr, X86_INS_VPHADDUWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDUWQrm, X86_INS_VPHADDUWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDUWQrr, X86_INS_VPHADDUWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDWDrm, X86_INS_VPHADDWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDWDrr, X86_INS_VPHADDWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDWQrm, X86_INS_VPHADDWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDWQrr, X86_INS_VPHADDWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHADDWYrm, X86_INS_VPHADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPHADDWYrr, X86_INS_VPHADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPHADDWrm, X86_INS_VPHADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPHADDWrr, X86_INS_VPHADDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPHMINPOSUWrm128, X86_INS_VPHMINPOSUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPHMINPOSUWrr128, X86_INS_VPHMINPOSUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBBWrm, X86_INS_VPHSUBBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBBWrr, X86_INS_VPHSUBBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBDQrm, X86_INS_VPHSUBDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBDQrr, X86_INS_VPHSUBDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBDYrm, X86_INS_VPHSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBDYrr, X86_INS_VPHSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBDrm, X86_INS_VPHSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBDrr, X86_INS_VPHSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBSWrm128, X86_INS_VPHSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBSWrm256, X86_INS_VPHSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBSWrr128, X86_INS_VPHSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBSWrr256, X86_INS_VPHSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBWDrm, X86_INS_VPHSUBWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBWDrr, X86_INS_VPHSUBWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBWYrm, X86_INS_VPHSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBWYrr, X86_INS_VPHSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBWrm, X86_INS_VPHSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPHSUBWrr, X86_INS_VPHSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPINSRBrm, X86_INS_VPINSRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPINSRBrr, X86_INS_VPINSRB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPINSRDrm, X86_INS_VPINSRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPINSRDrr, X86_INS_VPINSRD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPINSRQrm, X86_INS_VPINSRQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPINSRQrr, X86_INS_VPINSRQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPINSRWrmi, X86_INS_VPINSRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPINSRWrri, X86_INS_VPINSRW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTDrm, X86_INS_VPLZCNTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTDrmb, X86_INS_VPLZCNTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTDrmbk, X86_INS_VPLZCNTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTDrmbkz, X86_INS_VPLZCNTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTDrmk, X86_INS_VPLZCNTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTDrmkz, X86_INS_VPLZCNTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTDrr, X86_INS_VPLZCNTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTDrrk, X86_INS_VPLZCNTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTDrrkz, X86_INS_VPLZCNTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTQrm, X86_INS_VPLZCNTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTQrmb, X86_INS_VPLZCNTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTQrmbk, X86_INS_VPLZCNTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTQrmbkz, X86_INS_VPLZCNTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTQrmk, X86_INS_VPLZCNTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTQrmkz, X86_INS_VPLZCNTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTQrr, X86_INS_VPLZCNTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTQrrk, X86_INS_VPLZCNTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPLZCNTQrrkz, X86_INS_VPLZCNTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPMACSDDrm, X86_INS_VPMACSDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSDDrr, X86_INS_VPMACSDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSDQHrm, X86_INS_VPMACSDQH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSDQHrr, X86_INS_VPMACSDQH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSDQLrm, X86_INS_VPMACSDQL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSDQLrr, X86_INS_VPMACSDQL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSSDDrm, X86_INS_VPMACSSDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSSDDrr, X86_INS_VPMACSSDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSSDQHrm, X86_INS_VPMACSSDQH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSSDQHrr, X86_INS_VPMACSSDQH,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSSDQLrm, X86_INS_VPMACSSDQL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSSDQLrr, X86_INS_VPMACSSDQL,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSSWDrm, X86_INS_VPMACSSWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSSWDrr, X86_INS_VPMACSSWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSSWWrm, X86_INS_VPMACSSWW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSSWWrr, X86_INS_VPMACSSWW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSWDrm, X86_INS_VPMACSWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSWDrr, X86_INS_VPMACSWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSWWrm, X86_INS_VPMACSWW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMACSWWrr, X86_INS_VPMACSWW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMADCSSWDrm, X86_INS_VPMADCSSWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMADCSSWDrr, X86_INS_VPMADCSSWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMADCSWDrm, X86_INS_VPMADCSWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMADCSWDrr, X86_INS_VPMADCSWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPMADDUBSWrm128, X86_INS_VPMADDUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMADDUBSWrm256, X86_INS_VPMADDUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMADDUBSWrr128, X86_INS_VPMADDUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMADDUBSWrr256, X86_INS_VPMADDUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMADDWDYrm, X86_INS_VPMADDWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMADDWDYrr, X86_INS_VPMADDWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMADDWDrm, X86_INS_VPMADDWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMADDWDrr, X86_INS_VPMADDWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMASKMOVDYmr, X86_INS_VPMASKMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMASKMOVDYrm, X86_INS_VPMASKMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMASKMOVDmr, X86_INS_VPMASKMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMASKMOVDrm, X86_INS_VPMASKMOVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMASKMOVQYmr, X86_INS_VPMASKMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMASKMOVQYrm, X86_INS_VPMASKMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMASKMOVQmr, X86_INS_VPMASKMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMASKMOVQrm, X86_INS_VPMASKMOVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBYrm, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBYrr, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZ128rm, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZ128rmk, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZ128rmkz, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZ128rr, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZ128rrk, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZ128rrkz, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZ256rm, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZ256rmk, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZ256rmkz, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZ256rr, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZ256rrk, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZ256rrkz, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZrm, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZrmk, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZrmkz, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZrr, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZrrk, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBZrrkz, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBrm, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSBrr, X86_INS_VPMAXSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDYrm, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDYrr, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ128rm, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ128rmb, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ128rmbk, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ128rmbkz, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ128rmk, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ128rmkz, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ128rr, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ128rrk, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ128rrkz, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ256rm, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ256rmb, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ256rmbk, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ256rmbkz, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ256rmk, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ256rmkz, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ256rr, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ256rrk, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZ256rrkz, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZrm, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZrmb, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZrmbk, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZrmbkz, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZrmk, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZrmkz, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZrr, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZrrk, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDZrrkz, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDrm, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSDrr, X86_INS_VPMAXSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ128rm, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ128rmb, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ128rmbk, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ128rmbkz, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ128rmk, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ128rmkz, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ128rr, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ128rrk, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ128rrkz, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ256rm, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ256rmb, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ256rmbk, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ256rmbkz, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ256rmk, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ256rmkz, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ256rr, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ256rrk, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZ256rrkz, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZrm, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZrmb, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZrmbk, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZrmbkz, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZrmk, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZrmkz, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZrr, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZrrk, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSQZrrkz, X86_INS_VPMAXSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWYrm, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWYrr, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZ128rm, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZ128rmk, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZ128rmkz, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZ128rr, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZ128rrk, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZ128rrkz, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZ256rm, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZ256rmk, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZ256rmkz, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZ256rr, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZ256rrk, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZ256rrkz, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZrm, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZrmk, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZrmkz, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZrr, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZrrk, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWZrrkz, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWrm, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXSWrr, X86_INS_VPMAXSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBYrm, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBYrr, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZ128rm, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZ128rmk, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZ128rmkz, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZ128rr, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZ128rrk, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZ128rrkz, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZ256rm, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZ256rmk, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZ256rmkz, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZ256rr, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZ256rrk, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZ256rrkz, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZrm, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZrmk, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZrmkz, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZrr, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZrrk, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBZrrkz, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBrm, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUBrr, X86_INS_VPMAXUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDYrm, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDYrr, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ128rm, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ128rmb, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ128rmbk, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ128rmbkz, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ128rmk, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ128rmkz, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ128rr, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ128rrk, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ128rrkz, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ256rm, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ256rmb, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ256rmbk, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ256rmbkz, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ256rmk, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ256rmkz, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ256rr, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ256rrk, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZ256rrkz, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZrm, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZrmb, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZrmbk, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZrmbkz, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZrmk, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZrmkz, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZrr, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZrrk, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDZrrkz, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDrm, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUDrr, X86_INS_VPMAXUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ128rm, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ128rmb, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ128rmbk, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ128rmbkz, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ128rmk, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ128rmkz, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ128rr, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ128rrk, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ128rrkz, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ256rm, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ256rmb, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ256rmbk, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ256rmbkz, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ256rmk, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ256rmkz, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ256rr, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ256rrk, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZ256rrkz, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZrm, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZrmb, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZrmbk, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZrmbkz, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZrmk, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZrmkz, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZrr, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZrrk, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUQZrrkz, X86_INS_VPMAXUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWYrm, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWYrr, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZ128rm, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZ128rmk, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZ128rmkz, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZ128rr, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZ128rrk, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZ128rrkz, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZ256rm, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZ256rmk, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZ256rmkz, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZ256rr, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZ256rrk, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZ256rrkz, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZrm, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZrmk, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZrmkz, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZrr, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZrrk, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWZrrkz, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWrm, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMAXUWrr, X86_INS_VPMAXUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBYrm, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBYrr, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZ128rm, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZ128rmk, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZ128rmkz, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZ128rr, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZ128rrk, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZ128rrkz, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZ256rm, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZ256rmk, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZ256rmkz, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZ256rr, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZ256rrk, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZ256rrkz, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZrm, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZrmk, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZrmkz, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZrr, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZrrk, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBZrrkz, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBrm, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSBrr, X86_INS_VPMINSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDYrm, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDYrr, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ128rm, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ128rmb, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ128rmbk, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ128rmbkz, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ128rmk, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ128rmkz, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ128rr, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ128rrk, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ128rrkz, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ256rm, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ256rmb, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ256rmbk, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ256rmbkz, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ256rmk, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ256rmkz, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ256rr, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ256rrk, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZ256rrkz, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZrm, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZrmb, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZrmbk, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZrmbkz, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZrmk, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZrmkz, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZrr, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZrrk, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDZrrkz, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDrm, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSDrr, X86_INS_VPMINSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ128rm, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ128rmb, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ128rmbk, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ128rmbkz, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ128rmk, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ128rmkz, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ128rr, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ128rrk, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ128rrkz, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ256rm, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ256rmb, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ256rmbk, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ256rmbkz, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ256rmk, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ256rmkz, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ256rr, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ256rrk, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZ256rrkz, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZrm, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZrmb, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZrmbk, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZrmbkz, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZrmk, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZrmkz, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZrr, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZrrk, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSQZrrkz, X86_INS_VPMINSQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWYrm, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWYrr, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZ128rm, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZ128rmk, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZ128rmkz, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZ128rr, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZ128rrk, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZ128rrkz, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZ256rm, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZ256rmk, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZ256rmkz, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZ256rr, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZ256rrk, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZ256rrkz, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZrm, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZrmk, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZrmkz, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZrr, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZrrk, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWZrrkz, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWrm, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINSWrr, X86_INS_VPMINSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBYrm, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBYrr, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZ128rm, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZ128rmk, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZ128rmkz, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZ128rr, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZ128rrk, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZ128rrkz, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZ256rm, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZ256rmk, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZ256rmkz, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZ256rr, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZ256rrk, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZ256rrkz, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZrm, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZrmk, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZrmkz, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZrr, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZrrk, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBZrrkz, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBrm, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUBrr, X86_INS_VPMINUB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDYrm, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDYrr, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ128rm, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ128rmb, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ128rmbk, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ128rmbkz, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ128rmk, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ128rmkz, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ128rr, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ128rrk, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ128rrkz, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ256rm, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ256rmb, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ256rmbk, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ256rmbkz, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ256rmk, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ256rmkz, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ256rr, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ256rrk, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZ256rrkz, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZrm, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZrmb, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZrmbk, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZrmbkz, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZrmk, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZrmkz, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZrr, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZrrk, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDZrrkz, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDrm, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUDrr, X86_INS_VPMINUD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ128rm, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ128rmb, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ128rmbk, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ128rmbkz, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ128rmk, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ128rmkz, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ128rr, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ128rrk, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ128rrkz, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ256rm, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ256rmb, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ256rmbk, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ256rmbkz, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ256rmk, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ256rmkz, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ256rr, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ256rrk, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZ256rrkz, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZrm, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZrmb, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZrmbk, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZrmbkz, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZrmk, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZrmkz, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZrr, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZrrk, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUQZrrkz, X86_INS_VPMINUQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWYrm, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWYrr, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZ128rm, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZ128rmk, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZ128rmkz, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZ128rr, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZ128rrk, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZ128rrkz, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZ256rm, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZ256rmk, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZ256rmkz, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZ256rr, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZ256rrk, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZ256rrkz, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZrm, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZrmk, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZrmkz, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZrr, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZrrk, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWZrrkz, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWrm, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMINUWrr, X86_INS_VPMINUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVDBmr, X86_INS_VPMOVDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVDBmrk, X86_INS_VPMOVDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVDBrr, X86_INS_VPMOVDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVDBrrk, X86_INS_VPMOVDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVDBrrkz, X86_INS_VPMOVDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVDWmr, X86_INS_VPMOVDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVDWmrk, X86_INS_VPMOVDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVDWrr, X86_INS_VPMOVDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVDWrrk, X86_INS_VPMOVDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVDWrrkz, X86_INS_VPMOVDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVM2BZ128rr, X86_INS_VPMOVM2B,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVM2BZ256rr, X86_INS_VPMOVM2B,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVM2BZrr, X86_INS_VPMOVM2B,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMOVM2DZ128rr, X86_INS_VPMOVM2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVM2DZ256rr, X86_INS_VPMOVM2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVM2DZrr, X86_INS_VPMOVM2D,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VPMOVM2QZ128rr, X86_INS_VPMOVM2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVM2QZ256rr, X86_INS_VPMOVM2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVM2QZrr, X86_INS_VPMOVM2Q,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VPMOVM2WZ128rr, X86_INS_VPMOVM2W,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVM2WZ256rr, X86_INS_VPMOVM2W,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVM2WZrr, X86_INS_VPMOVM2W,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMOVMSKBYrr, X86_INS_VPMOVMSKB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVMSKBrr, X86_INS_VPMOVMSKB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQBmr, X86_INS_VPMOVQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQBmrk, X86_INS_VPMOVQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQBrr, X86_INS_VPMOVQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQBrrk, X86_INS_VPMOVQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQBrrkz, X86_INS_VPMOVQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQDmr, X86_INS_VPMOVQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQDmrk, X86_INS_VPMOVQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQDrr, X86_INS_VPMOVQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQDrrk, X86_INS_VPMOVQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQDrrkz, X86_INS_VPMOVQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQWmr, X86_INS_VPMOVQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQWmrk, X86_INS_VPMOVQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQWrr, X86_INS_VPMOVQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQWrrk, X86_INS_VPMOVQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVQWrrkz, X86_INS_VPMOVQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSDBmr, X86_INS_VPMOVSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSDBmrk, X86_INS_VPMOVSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSDBrr, X86_INS_VPMOVSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSDBrrk, X86_INS_VPMOVSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSDBrrkz, X86_INS_VPMOVSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSDWmr, X86_INS_VPMOVSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSDWmrk, X86_INS_VPMOVSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSDWrr, X86_INS_VPMOVSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSDWrrk, X86_INS_VPMOVSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSDWrrkz, X86_INS_VPMOVSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQBmr, X86_INS_VPMOVSQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQBmrk, X86_INS_VPMOVSQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQBrr, X86_INS_VPMOVSQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQBrrk, X86_INS_VPMOVSQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQBrrkz, X86_INS_VPMOVSQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQDmr, X86_INS_VPMOVSQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQDmrk, X86_INS_VPMOVSQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQDrr, X86_INS_VPMOVSQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQDrrk, X86_INS_VPMOVSQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQDrrkz, X86_INS_VPMOVSQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQWmr, X86_INS_VPMOVSQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQWmrk, X86_INS_VPMOVSQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQWrr, X86_INS_VPMOVSQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQWrrk, X86_INS_VPMOVSQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSQWrrkz, X86_INS_VPMOVSQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBDYrm, X86_INS_VPMOVSXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBDYrr, X86_INS_VPMOVSXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBDZrm, X86_INS_VPMOVSXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBDZrmk, X86_INS_VPMOVSXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBDZrmkz, X86_INS_VPMOVSXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBDZrr, X86_INS_VPMOVSXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBDZrrk, X86_INS_VPMOVSXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBDZrrkz, X86_INS_VPMOVSXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBDrm, X86_INS_VPMOVSXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBDrr, X86_INS_VPMOVSXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBQYrm, X86_INS_VPMOVSXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBQYrr, X86_INS_VPMOVSXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBQZrm, X86_INS_VPMOVSXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBQZrmk, X86_INS_VPMOVSXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBQZrmkz, X86_INS_VPMOVSXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBQZrr, X86_INS_VPMOVSXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBQZrrk, X86_INS_VPMOVSXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBQZrrkz, X86_INS_VPMOVSXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBQrm, X86_INS_VPMOVSXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBQrr, X86_INS_VPMOVSXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBWYrm, X86_INS_VPMOVSXBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBWYrr, X86_INS_VPMOVSXBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBWrm, X86_INS_VPMOVSXBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXBWrr, X86_INS_VPMOVSXBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXDQYrm, X86_INS_VPMOVSXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXDQYrr, X86_INS_VPMOVSXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXDQZrm, X86_INS_VPMOVSXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXDQZrmk, X86_INS_VPMOVSXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXDQZrmkz, X86_INS_VPMOVSXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXDQZrr, X86_INS_VPMOVSXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXDQZrrk, X86_INS_VPMOVSXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXDQZrrkz, X86_INS_VPMOVSXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXDQrm, X86_INS_VPMOVSXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXDQrr, X86_INS_VPMOVSXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWDYrm, X86_INS_VPMOVSXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWDYrr, X86_INS_VPMOVSXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWDZrm, X86_INS_VPMOVSXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWDZrmk, X86_INS_VPMOVSXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWDZrmkz, X86_INS_VPMOVSXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWDZrr, X86_INS_VPMOVSXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWDZrrk, X86_INS_VPMOVSXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWDZrrkz, X86_INS_VPMOVSXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWDrm, X86_INS_VPMOVSXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWDrr, X86_INS_VPMOVSXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWQYrm, X86_INS_VPMOVSXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWQYrr, X86_INS_VPMOVSXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWQZrm, X86_INS_VPMOVSXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWQZrmk, X86_INS_VPMOVSXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWQZrmkz, X86_INS_VPMOVSXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWQZrr, X86_INS_VPMOVSXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWQZrrk, X86_INS_VPMOVSXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWQZrrkz, X86_INS_VPMOVSXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWQrm, X86_INS_VPMOVSXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVSXWQrr, X86_INS_VPMOVSXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSDBmr, X86_INS_VPMOVUSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSDBmrk, X86_INS_VPMOVUSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSDBrr, X86_INS_VPMOVUSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSDBrrk, X86_INS_VPMOVUSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSDBrrkz, X86_INS_VPMOVUSDB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSDWmr, X86_INS_VPMOVUSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSDWmrk, X86_INS_VPMOVUSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSDWrr, X86_INS_VPMOVUSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSDWrrk, X86_INS_VPMOVUSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSDWrrkz, X86_INS_VPMOVUSDW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQBmr, X86_INS_VPMOVUSQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQBmrk, X86_INS_VPMOVUSQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQBrr, X86_INS_VPMOVUSQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQBrrk, X86_INS_VPMOVUSQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQBrrkz, X86_INS_VPMOVUSQB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQDmr, X86_INS_VPMOVUSQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQDmrk, X86_INS_VPMOVUSQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQDrr, X86_INS_VPMOVUSQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQDrrk, X86_INS_VPMOVUSQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQDrrkz, X86_INS_VPMOVUSQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQWmr, X86_INS_VPMOVUSQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQWmrk, X86_INS_VPMOVUSQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQWrr, X86_INS_VPMOVUSQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQWrrk, X86_INS_VPMOVUSQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVUSQWrrkz, X86_INS_VPMOVUSQW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBDYrm, X86_INS_VPMOVZXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBDYrr, X86_INS_VPMOVZXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBDZrm, X86_INS_VPMOVZXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBDZrmk, X86_INS_VPMOVZXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBDZrmkz, X86_INS_VPMOVZXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBDZrr, X86_INS_VPMOVZXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBDZrrk, X86_INS_VPMOVZXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBDZrrkz, X86_INS_VPMOVZXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBDrm, X86_INS_VPMOVZXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBDrr, X86_INS_VPMOVZXBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBQYrm, X86_INS_VPMOVZXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBQYrr, X86_INS_VPMOVZXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBQZrm, X86_INS_VPMOVZXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBQZrmk, X86_INS_VPMOVZXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBQZrmkz, X86_INS_VPMOVZXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBQZrr, X86_INS_VPMOVZXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBQZrrk, X86_INS_VPMOVZXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBQZrrkz, X86_INS_VPMOVZXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBQrm, X86_INS_VPMOVZXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBQrr, X86_INS_VPMOVZXBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBWYrm, X86_INS_VPMOVZXBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBWYrr, X86_INS_VPMOVZXBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBWrm, X86_INS_VPMOVZXBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXBWrr, X86_INS_VPMOVZXBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXDQYrm, X86_INS_VPMOVZXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXDQYrr, X86_INS_VPMOVZXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXDQZrm, X86_INS_VPMOVZXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXDQZrmk, X86_INS_VPMOVZXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXDQZrmkz, X86_INS_VPMOVZXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXDQZrr, X86_INS_VPMOVZXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXDQZrrk, X86_INS_VPMOVZXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXDQZrrkz, X86_INS_VPMOVZXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXDQrm, X86_INS_VPMOVZXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXDQrr, X86_INS_VPMOVZXDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWDYrm, X86_INS_VPMOVZXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWDYrr, X86_INS_VPMOVZXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWDZrm, X86_INS_VPMOVZXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWDZrmk, X86_INS_VPMOVZXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWDZrmkz, X86_INS_VPMOVZXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWDZrr, X86_INS_VPMOVZXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWDZrrk, X86_INS_VPMOVZXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWDZrrkz, X86_INS_VPMOVZXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWDrm, X86_INS_VPMOVZXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWDrr, X86_INS_VPMOVZXWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWQYrm, X86_INS_VPMOVZXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWQYrr, X86_INS_VPMOVZXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWQZrm, X86_INS_VPMOVZXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWQZrmk, X86_INS_VPMOVZXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWQZrmkz, X86_INS_VPMOVZXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWQZrr, X86_INS_VPMOVZXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWQZrrk, X86_INS_VPMOVZXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWQZrrkz, X86_INS_VPMOVZXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWQrm, X86_INS_VPMOVZXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMOVZXWQrr, X86_INS_VPMOVZXWQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMULDQYrm, X86_INS_VPMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULDQYrr, X86_INS_VPMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULDQZrm, X86_INS_VPMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULDQZrmb, X86_INS_VPMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULDQZrmbk, X86_INS_VPMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULDQZrmbkz, X86_INS_VPMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULDQZrmk, X86_INS_VPMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULDQZrmkz, X86_INS_VPMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULDQZrr, X86_INS_VPMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULDQZrrk, X86_INS_VPMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULDQZrrkz, X86_INS_VPMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULDQrm, X86_INS_VPMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULDQrr, X86_INS_VPMULDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULHRSWrm128, X86_INS_VPMULHRSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMULHRSWrm256, X86_INS_VPMULHRSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMULHRSWrr128, X86_INS_VPMULHRSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMULHRSWrr256, X86_INS_VPMULHRSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMULHUWYrm, X86_INS_VPMULHUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULHUWYrr, X86_INS_VPMULHUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULHUWrm, X86_INS_VPMULHUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULHUWrr, X86_INS_VPMULHUW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULHWYrm, X86_INS_VPMULHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULHWYrr, X86_INS_VPMULHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULHWrm, X86_INS_VPMULHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULHWrr, X86_INS_VPMULHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDYrm, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDYrr, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ128rm, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ128rmb, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ128rmbk, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ128rmbkz, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ128rmk, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ128rmkz, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ128rr, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ128rrk, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ128rrkz, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ256rm, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ256rmb, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ256rmbk, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ256rmbkz, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ256rmk, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ256rmkz, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ256rr, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ256rrk, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZ256rrkz, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZrm, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZrmb, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZrmbk, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZrmbkz, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZrmk, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZrmkz, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZrr, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZrrk, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDZrrkz, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDrm, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLDrr, X86_INS_VPMULLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ128rm, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ128rmb, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ128rmbk, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ128rmbkz, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ128rmk, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ128rmkz, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ128rr, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ128rrk, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ128rrkz, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ256rm, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ256rmb, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ256rmbk, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ256rmbkz, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ256rmk, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ256rmkz, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ256rr, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ256rrk, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZ256rrkz, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZrm, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZrmb, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZrmbk, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZrmbkz, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZrmk, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZrmkz, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZrr, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZrrk, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLQZrrkz, X86_INS_VPMULLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_DQI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWYrm, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWYrr, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZ128rm, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZ128rmk, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZ128rmkz, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZ128rr, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZ128rrk, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZ128rrkz, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZ256rm, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZ256rmk, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZ256rmkz, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZ256rr, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZ256rrk, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZ256rrkz, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZrm, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZrmk, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZrmkz, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZrr, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZrrk, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWZrrkz, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWrm, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULLWrr, X86_INS_VPMULLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPMULUDQYrm, X86_INS_VPMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMULUDQYrr, X86_INS_VPMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPMULUDQZrm, X86_INS_VPMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULUDQZrmb, X86_INS_VPMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULUDQZrmbk, X86_INS_VPMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULUDQZrmbkz, X86_INS_VPMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULUDQZrmk, X86_INS_VPMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULUDQZrmkz, X86_INS_VPMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULUDQZrr, X86_INS_VPMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULUDQZrrk, X86_INS_VPMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULUDQZrrkz, X86_INS_VPMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPMULUDQrm, X86_INS_VPMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPMULUDQrr, X86_INS_VPMULUDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ128rm, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ128rmb, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ128rmbk, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ128rmbkz, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ128rmk, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ128rmkz, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ128rr, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ128rrk, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ128rrkz, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ256rm, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ256rmb, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ256rmbk, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ256rmbkz, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ256rmk, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ256rmkz, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ256rr, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ256rrk, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZ256rrkz, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORDZrm, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORDZrmb, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORDZrmbk, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORDZrmbkz, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORDZrmk, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORDZrmkz, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORDZrr, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORDZrrk, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORDZrrkz, X86_INS_VPORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ128rm, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ128rmb, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ128rmbk, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ128rmbkz, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ128rmk, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ128rmkz, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ128rr, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ128rrk, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ128rrkz, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ256rm, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ256rmb, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ256rmbk, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ256rmbkz, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ256rmk, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ256rmkz, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ256rr, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ256rrk, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZ256rrkz, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPORQZrm, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORQZrmb, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORQZrmbk, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORQZrmbkz, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORQZrmk, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORQZrmkz, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORQZrr, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORQZrrk, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORQZrrkz, X86_INS_VPORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPORYrm, X86_INS_VPOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPORYrr, X86_INS_VPOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPORrm, X86_INS_VPOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPORrr, X86_INS_VPOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPPERMmr, X86_INS_VPPERM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPPERMrm, X86_INS_VPPERM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPPERMrr, X86_INS_VPPERM,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTBmi, X86_INS_VPROTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTBmr, X86_INS_VPROTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTBri, X86_INS_VPROTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTBrm, X86_INS_VPROTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTBrr, X86_INS_VPROTB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTDmi, X86_INS_VPROTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTDmr, X86_INS_VPROTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTDri, X86_INS_VPROTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTDrm, X86_INS_VPROTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTDrr, X86_INS_VPROTD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTQmi, X86_INS_VPROTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTQmr, X86_INS_VPROTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTQri, X86_INS_VPROTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTQrm, X86_INS_VPROTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTQrr, X86_INS_VPROTQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTWmi, X86_INS_VPROTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTWmr, X86_INS_VPROTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTWri, X86_INS_VPROTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTWrm, X86_INS_VPROTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPROTWrr, X86_INS_VPROTW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSADBWYrm, X86_INS_VPSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSADBWYrr, X86_INS_VPSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSADBWrm, X86_INS_VPSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSADBWrr, X86_INS_VPSADBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSCATTERDDZmr, X86_INS_VPSCATTERDD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSCATTERDQZmr, X86_INS_VPSCATTERDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSCATTERQDZmr, X86_INS_VPSCATTERQD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSCATTERQQZmr, X86_INS_VPSCATTERQQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSHABmr, X86_INS_VPSHAB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHABrm, X86_INS_VPSHAB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHABrr, X86_INS_VPSHAB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHADmr, X86_INS_VPSHAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHADrm, X86_INS_VPSHAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHADrr, X86_INS_VPSHAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHAQmr, X86_INS_VPSHAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHAQrm, X86_INS_VPSHAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHAQrr, X86_INS_VPSHAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHAWmr, X86_INS_VPSHAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHAWrm, X86_INS_VPSHAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHAWrr, X86_INS_VPSHAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHLBmr, X86_INS_VPSHLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHLBrm, X86_INS_VPSHLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHLBrr, X86_INS_VPSHLB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHLDmr, X86_INS_VPSHLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHLDrm, X86_INS_VPSHLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHLDrr, X86_INS_VPSHLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHLQmr, X86_INS_VPSHLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHLQrm, X86_INS_VPSHLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHLQrr, X86_INS_VPSHLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHLWmr, X86_INS_VPSHLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHLWrm, X86_INS_VPSHLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHLWrr, X86_INS_VPSHLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_XOP, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFBYrm, X86_INS_VPSHUFB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFBYrr, X86_INS_VPSHUFB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFBrm, X86_INS_VPSHUFB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFBrr, X86_INS_VPSHUFB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFDYmi, X86_INS_VPSHUFD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFDYri, X86_INS_VPSHUFD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFDZmi, X86_INS_VPSHUFD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFDZri, X86_INS_VPSHUFD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFDmi, X86_INS_VPSHUFD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFDri, X86_INS_VPSHUFD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFHWYmi, X86_INS_VPSHUFHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFHWYri, X86_INS_VPSHUFHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFHWmi, X86_INS_VPSHUFHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFHWri, X86_INS_VPSHUFHW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFLWYmi, X86_INS_VPSHUFLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFLWYri, X86_INS_VPSHUFLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFLWmi, X86_INS_VPSHUFLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSHUFLWri, X86_INS_VPSHUFLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSIGNBYrm, X86_INS_VPSIGNB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSIGNBYrr, X86_INS_VPSIGNB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSIGNBrm, X86_INS_VPSIGNB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSIGNBrr, X86_INS_VPSIGNB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSIGNDYrm, X86_INS_VPSIGND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSIGNDYrr, X86_INS_VPSIGND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSIGNDrm, X86_INS_VPSIGND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSIGNDrr, X86_INS_VPSIGND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSIGNWYrm, X86_INS_VPSIGNW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSIGNWYrr, X86_INS_VPSIGNW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSIGNWrm, X86_INS_VPSIGNW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSIGNWrr, X86_INS_VPSIGNW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDQYri, X86_INS_VPSLLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDQri, X86_INS_VPSLLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDYri, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDYrm, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDYrr, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDZmi, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDZmik, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDZmikz, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDZri, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDZrik, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDZrikz, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDZrm, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDZrmk, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDZrmkz, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDZrr, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDZrrk, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDZrrkz, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDri, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDrm, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSLLDrr, X86_INS_VPSLLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQYri, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQYrm, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQYrr, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQZmi, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQZmik, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQZmikz, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQZri, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQZrik, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQZrikz, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQZrm, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQZrmk, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQZrmkz, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQZrr, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQZrrk, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQZrrkz, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQri, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQrm, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSLLQrr, X86_INS_VPSLLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVDYrm, X86_INS_VPSLLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVDYrr, X86_INS_VPSLLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVDZrm, X86_INS_VPSLLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVDZrmk, X86_INS_VPSLLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVDZrmkz, X86_INS_VPSLLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVDZrr, X86_INS_VPSLLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVDZrrk, X86_INS_VPSLLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVDZrrkz, X86_INS_VPSLLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVDrm, X86_INS_VPSLLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVDrr, X86_INS_VPSLLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVQYrm, X86_INS_VPSLLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVQYrr, X86_INS_VPSLLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVQZrm, X86_INS_VPSLLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVQZrmk, X86_INS_VPSLLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVQZrmkz, X86_INS_VPSLLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVQZrr, X86_INS_VPSLLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVQZrrk, X86_INS_VPSLLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVQZrrkz, X86_INS_VPSLLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVQrm, X86_INS_VPSLLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLVQrr, X86_INS_VPSLLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLWYri, X86_INS_VPSLLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLWYrm, X86_INS_VPSLLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLWYrr, X86_INS_VPSLLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSLLWri, X86_INS_VPSLLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSLLWrm, X86_INS_VPSLLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSLLWrr, X86_INS_VPSLLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRADYri, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRADYrm, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRADYrr, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRADZmi, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRADZmik, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRADZmikz, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRADZri, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRADZrik, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRADZrikz, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRADZrm, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRADZrmk, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRADZrmkz, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRADZrr, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRADZrrk, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRADZrrkz, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRADri, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRADrm, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRADrr, X86_INS_VPSRAD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRAQZmi, X86_INS_VPSRAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAQZmik, X86_INS_VPSRAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAQZmikz, X86_INS_VPSRAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAQZri, X86_INS_VPSRAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAQZrik, X86_INS_VPSRAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAQZrikz, X86_INS_VPSRAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAQZrm, X86_INS_VPSRAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAQZrmk, X86_INS_VPSRAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAQZrmkz, X86_INS_VPSRAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAQZrr, X86_INS_VPSRAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAQZrrk, X86_INS_VPSRAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAQZrrkz, X86_INS_VPSRAQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVDYrm, X86_INS_VPSRAVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVDYrr, X86_INS_VPSRAVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVDZrm, X86_INS_VPSRAVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVDZrmk, X86_INS_VPSRAVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVDZrmkz, X86_INS_VPSRAVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVDZrr, X86_INS_VPSRAVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVDZrrk, X86_INS_VPSRAVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVDZrrkz, X86_INS_VPSRAVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVDrm, X86_INS_VPSRAVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVDrr, X86_INS_VPSRAVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVQZrm, X86_INS_VPSRAVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVQZrmk, X86_INS_VPSRAVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVQZrmkz, X86_INS_VPSRAVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVQZrr, X86_INS_VPSRAVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVQZrrk, X86_INS_VPSRAVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAVQZrrkz, X86_INS_VPSRAVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRAWYri, X86_INS_VPSRAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRAWYrm, X86_INS_VPSRAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRAWYrr, X86_INS_VPSRAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRAWri, X86_INS_VPSRAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRAWrm, X86_INS_VPSRAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRAWrr, X86_INS_VPSRAW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDQYri, X86_INS_VPSRLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDQri, X86_INS_VPSRLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDYri, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDYrm, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDYrr, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDZmi, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDZmik, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDZmikz, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDZri, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDZrik, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDZrikz, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDZrm, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDZrmk, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDZrmkz, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDZrr, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDZrrk, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDZrrkz, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDri, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDrm, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRLDrr, X86_INS_VPSRLD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQYri, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQYrm, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQYrr, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQZmi, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQZmik, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQZmikz, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQZri, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQZrik, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQZrikz, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQZrm, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQZrmk, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQZrmkz, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQZrr, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQZrrk, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQZrrkz, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQri, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQrm, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRLQrr, X86_INS_VPSRLQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVDYrm, X86_INS_VPSRLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVDYrr, X86_INS_VPSRLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVDZrm, X86_INS_VPSRLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVDZrmk, X86_INS_VPSRLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVDZrmkz, X86_INS_VPSRLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVDZrr, X86_INS_VPSRLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVDZrrk, X86_INS_VPSRLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVDZrrkz, X86_INS_VPSRLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVDrm, X86_INS_VPSRLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVDrr, X86_INS_VPSRLVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVQYrm, X86_INS_VPSRLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVQYrr, X86_INS_VPSRLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVQZrm, X86_INS_VPSRLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVQZrmk, X86_INS_VPSRLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVQZrmkz, X86_INS_VPSRLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVQZrr, X86_INS_VPSRLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVQZrrk, X86_INS_VPSRLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVQZrrkz, X86_INS_VPSRLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVQrm, X86_INS_VPSRLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLVQrr, X86_INS_VPSRLVQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLWYri, X86_INS_VPSRLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLWYrm, X86_INS_VPSRLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLWYrr, X86_INS_VPSRLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSRLWri, X86_INS_VPSRLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRLWrm, X86_INS_VPSRLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSRLWrr, X86_INS_VPSRLW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBYrm, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBYrr, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZ128rm, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZ128rmk, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZ128rmkz, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZ128rr, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZ128rrk, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZ128rrkz, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZ256rm, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZ256rmk, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZ256rmkz, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZ256rr, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZ256rrk, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZ256rrkz, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZrm, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZrmk, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZrmkz, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZrr, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZrrk, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBZrrkz, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBrm, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBBrr, X86_INS_VPSUBB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDYrm, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDYrr, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ128rm, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ128rmb, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ128rmbk, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ128rmbkz, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ128rmk, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ128rmkz, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ128rr, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ128rrk, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ128rrkz, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ256rm, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ256rmb, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ256rmbk, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ256rmbkz, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ256rmk, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ256rmkz, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ256rr, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ256rrk, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZ256rrkz, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZrm, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZrmb, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZrmbk, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZrmbkz, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZrmk, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZrmkz, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZrr, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZrrk, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDZrrkz, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDrm, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBDrr, X86_INS_VPSUBD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQYrm, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQYrr, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ128rm, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ128rmb, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ128rmbk, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ128rmbkz, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ128rmk, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ128rmkz, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ128rr, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ128rrk, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ128rrkz, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ256rm, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ256rmb, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ256rmbk, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ256rmbkz, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ256rmk, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ256rmkz, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ256rr, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ256rrk, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZ256rrkz, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZrm, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZrmb, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZrmbk, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZrmbkz, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZrmk, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZrmkz, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZrr, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZrrk, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQZrrkz, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQrm, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBQrr, X86_INS_VPSUBQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBSBYrm, X86_INS_VPSUBSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSUBSBYrr, X86_INS_VPSUBSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSUBSBrm, X86_INS_VPSUBSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBSBrr, X86_INS_VPSUBSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBSWYrm, X86_INS_VPSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSUBSWYrr, X86_INS_VPSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPSUBSWrm, X86_INS_VPSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBSWrr, X86_INS_VPSUBSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBUSBYrm, X86_INS_VPSUBUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBUSBYrr, X86_INS_VPSUBUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBUSBrm, X86_INS_VPSUBUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBUSBrr, X86_INS_VPSUBUSB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBUSWYrm, X86_INS_VPSUBUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBUSWYrr, X86_INS_VPSUBUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBUSWrm, X86_INS_VPSUBUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBUSWrr, X86_INS_VPSUBUSW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWYrm, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWYrr, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZ128rm, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZ128rmk, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZ128rmkz, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZ128rr, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZ128rrk, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZ128rrkz, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZ256rm, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZ256rmk, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZ256rmkz, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZ256rr, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZ256rrk, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZ256rrkz, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZrm, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZrmk, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZrmkz, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZrr, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZrrk, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWZrrkz, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_BWI, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWrm, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPSUBWrr, X86_INS_VPSUBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPTESTMDZrm, X86_INS_VPTESTMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPTESTMDZrr, X86_INS_VPTESTMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPTESTMQZrm, X86_INS_VPTESTMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPTESTMQZrr, X86_INS_VPTESTMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPTESTNMDZrm, X86_INS_VPTESTNMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPTESTNMDZrr, X86_INS_VPTESTNMD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPTESTNMQZrm, X86_INS_VPTESTNMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPTESTNMQZrr, X86_INS_VPTESTNMQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_CDI, 0 }, 0, 0
#endif
},
{
	X86_VPTESTYrm, X86_INS_VPTEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPTESTYrr, X86_INS_VPTEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPTESTrm, X86_INS_VPTEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPTESTrr, X86_INS_VPTEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHBWYrm, X86_INS_VPUNPCKHBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHBWYrr, X86_INS_VPUNPCKHBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHBWrm, X86_INS_VPUNPCKHBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHBWrr, X86_INS_VPUNPCKHBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHDQYrm, X86_INS_VPUNPCKHDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHDQYrr, X86_INS_VPUNPCKHDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHDQZrm, X86_INS_VPUNPCKHDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHDQZrr, X86_INS_VPUNPCKHDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHDQrm, X86_INS_VPUNPCKHDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHDQrr, X86_INS_VPUNPCKHDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHQDQYrm, X86_INS_VPUNPCKHQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHQDQYrr, X86_INS_VPUNPCKHQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHQDQZrm, X86_INS_VPUNPCKHQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHQDQZrr, X86_INS_VPUNPCKHQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHQDQrm, X86_INS_VPUNPCKHQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHQDQrr, X86_INS_VPUNPCKHQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHWDYrm, X86_INS_VPUNPCKHWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHWDYrr, X86_INS_VPUNPCKHWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHWDrm, X86_INS_VPUNPCKHWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKHWDrr, X86_INS_VPUNPCKHWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLBWYrm, X86_INS_VPUNPCKLBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLBWYrr, X86_INS_VPUNPCKLBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLBWrm, X86_INS_VPUNPCKLBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLBWrr, X86_INS_VPUNPCKLBW,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLDQYrm, X86_INS_VPUNPCKLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLDQYrr, X86_INS_VPUNPCKLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLDQZrm, X86_INS_VPUNPCKLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLDQZrr, X86_INS_VPUNPCKLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLDQrm, X86_INS_VPUNPCKLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLDQrr, X86_INS_VPUNPCKLDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLQDQYrm, X86_INS_VPUNPCKLQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLQDQYrr, X86_INS_VPUNPCKLQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLQDQZrm, X86_INS_VPUNPCKLQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLQDQZrr, X86_INS_VPUNPCKLQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLQDQrm, X86_INS_VPUNPCKLQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLQDQrr, X86_INS_VPUNPCKLQDQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLWDYrm, X86_INS_VPUNPCKLWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLWDYrr, X86_INS_VPUNPCKLWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLWDrm, X86_INS_VPUNPCKLWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPUNPCKLWDrr, X86_INS_VPUNPCKLWD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ128rm, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ128rmb, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ128rmbk, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ128rmbkz, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ128rmk, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ128rmkz, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ128rr, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ128rrk, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ128rrkz, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ256rm, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ256rmb, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ256rmbk, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ256rmbkz, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ256rmk, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ256rmkz, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ256rr, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ256rrk, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZ256rrkz, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZrm, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZrmb, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZrmbk, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZrmbkz, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZrmk, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZrmkz, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZrr, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZrrk, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORDZrrkz, X86_INS_VPXORD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ128rm, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ128rmb, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ128rmbk, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ128rmbkz, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ128rmk, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ128rmkz, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ128rr, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ128rrk, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ128rrkz, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ256rm, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ256rmb, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ256rmbk, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ256rmbkz, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ256rmk, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ256rmkz, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ256rr, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ256rrk, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZ256rrkz, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZrm, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZrmb, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZrmbk, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZrmbkz, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZrmk, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZrmkz, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZrr, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZrrk, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORQZrrkz, X86_INS_VPXORQ,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VPXORYrm, X86_INS_VPXOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORYrr, X86_INS_VPXOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX2, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORrm, X86_INS_VPXOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VPXORrr, X86_INS_VPXOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ128m, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ128mb, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ128mbk, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ128mbkz, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ128mk, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ128mkz, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ128r, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ128rk, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ128rkz, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ256m, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ256mb, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ256mbk, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ256mbkz, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ256mk, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ256mkz, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ256r, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ256rk, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZ256rkz, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZm, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZmb, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZmbk, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZmbkz, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZmk, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZmkz, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZr, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZrk, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PDZrkz, X86_INS_VRCP14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ128m, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ128mb, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ128mbk, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ128mbkz, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ128mk, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ128mkz, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ128r, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ128rk, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ128rkz, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ256m, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ256mb, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ256mbk, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ256mbkz, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ256mk, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ256mkz, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ256r, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ256rk, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZ256rkz, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZm, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZmb, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZmbk, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZmbkz, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZmk, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZmkz, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZr, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZrk, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14PSZrkz, X86_INS_VRCP14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14SDrm, X86_INS_VRCP14SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14SDrr, X86_INS_VRCP14SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14SSrm, X86_INS_VRCP14SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP14SSrr, X86_INS_VRCP14SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PDm, X86_INS_VRCP28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PDmb, X86_INS_VRCP28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PDmbk, X86_INS_VRCP28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PDmbkz, X86_INS_VRCP28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PDmk, X86_INS_VRCP28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PDmkz, X86_INS_VRCP28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PDr, X86_INS_VRCP28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PDrb, X86_INS_VRCP28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PDrbk, X86_INS_VRCP28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PDrbkz, X86_INS_VRCP28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PDrk, X86_INS_VRCP28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PDrkz, X86_INS_VRCP28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PSm, X86_INS_VRCP28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PSmb, X86_INS_VRCP28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PSmbk, X86_INS_VRCP28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PSmbkz, X86_INS_VRCP28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PSmk, X86_INS_VRCP28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PSmkz, X86_INS_VRCP28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PSr, X86_INS_VRCP28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PSrb, X86_INS_VRCP28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PSrbk, X86_INS_VRCP28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PSrbkz, X86_INS_VRCP28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PSrk, X86_INS_VRCP28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28PSrkz, X86_INS_VRCP28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SDm, X86_INS_VRCP28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SDmk, X86_INS_VRCP28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SDmkz, X86_INS_VRCP28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SDr, X86_INS_VRCP28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SDrb, X86_INS_VRCP28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SDrbk, X86_INS_VRCP28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SDrbkz, X86_INS_VRCP28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SDrk, X86_INS_VRCP28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SDrkz, X86_INS_VRCP28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SSm, X86_INS_VRCP28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SSmk, X86_INS_VRCP28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SSmkz, X86_INS_VRCP28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SSr, X86_INS_VRCP28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SSrb, X86_INS_VRCP28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SSrbk, X86_INS_VRCP28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SSrbkz, X86_INS_VRCP28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SSrk, X86_INS_VRCP28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCP28SSrkz, X86_INS_VRCP28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRCPPSYm, X86_INS_VRCPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRCPPSYm_Int, X86_INS_VRCPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRCPPSYr, X86_INS_VRCPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRCPPSYr_Int, X86_INS_VRCPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRCPPSm, X86_INS_VRCPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRCPPSm_Int, X86_INS_VRCPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRCPPSr, X86_INS_VRCPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRCPPSr_Int, X86_INS_VRCPPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRCPSSm, X86_INS_VRCPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VRCPSSm_Int, X86_INS_VRCPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VRCPSSr, X86_INS_VRCPSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALEPDZm, X86_INS_VRNDSCALEPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALEPDZr, X86_INS_VRNDSCALEPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALEPSZm, X86_INS_VRNDSCALEPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALEPSZr, X86_INS_VRNDSCALEPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESDm, X86_INS_VRNDSCALESD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESDmk, X86_INS_VRNDSCALESD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESDmkz, X86_INS_VRNDSCALESD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESDr, X86_INS_VRNDSCALESD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESDrb, X86_INS_VRNDSCALESD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESDrbk, X86_INS_VRNDSCALESD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESDrbkz, X86_INS_VRNDSCALESD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESDrk, X86_INS_VRNDSCALESD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESDrkz, X86_INS_VRNDSCALESD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESSm, X86_INS_VRNDSCALESS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESSmk, X86_INS_VRNDSCALESS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESSmkz, X86_INS_VRNDSCALESS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESSr, X86_INS_VRNDSCALESS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESSrb, X86_INS_VRNDSCALESS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESSrbk, X86_INS_VRNDSCALESS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESSrbkz, X86_INS_VRNDSCALESS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESSrk, X86_INS_VRNDSCALESS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRNDSCALESSrkz, X86_INS_VRNDSCALESS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VROUNDPDm, X86_INS_VROUNDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VROUNDPDr, X86_INS_VROUNDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VROUNDPSm, X86_INS_VROUNDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VROUNDPSr, X86_INS_VROUNDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VROUNDSDm, X86_INS_VROUNDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VROUNDSDr, X86_INS_VROUNDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VROUNDSDr_Int, X86_INS_VROUNDSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VROUNDSSm, X86_INS_VROUNDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VROUNDSSr, X86_INS_VROUNDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VROUNDSSr_Int, X86_INS_VROUNDSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VROUNDYPDm, X86_INS_VROUNDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VROUNDYPDr, X86_INS_VROUNDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VROUNDYPSm, X86_INS_VROUNDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VROUNDYPSr, X86_INS_VROUNDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ128m, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ128mb, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ128mbk, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ128mbkz, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ128mk, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ128mkz, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ128r, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ128rk, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ128rkz, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ256m, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ256mb, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ256mbk, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ256mbkz, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ256mk, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ256mkz, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ256r, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ256rk, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZ256rkz, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZm, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZmb, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZmbk, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZmbkz, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZmk, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZmkz, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZr, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZrk, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PDZrkz, X86_INS_VRSQRT14PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ128m, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ128mb, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ128mbk, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ128mbkz, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ128mk, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ128mkz, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ128r, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ128rk, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ128rkz, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ256m, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ256mb, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ256mbk, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ256mbkz, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ256mk, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ256mkz, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ256r, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ256rk, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZ256rkz, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZm, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZmb, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZmbk, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZmbkz, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZmk, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZmkz, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZr, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZrk, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14PSZrkz, X86_INS_VRSQRT14PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14SDrm, X86_INS_VRSQRT14SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14SDrr, X86_INS_VRSQRT14SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14SSrm, X86_INS_VRSQRT14SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT14SSrr, X86_INS_VRSQRT14SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PDm, X86_INS_VRSQRT28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PDmb, X86_INS_VRSQRT28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PDmbk, X86_INS_VRSQRT28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PDmbkz, X86_INS_VRSQRT28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PDmk, X86_INS_VRSQRT28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PDmkz, X86_INS_VRSQRT28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PDr, X86_INS_VRSQRT28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PDrb, X86_INS_VRSQRT28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PDrbk, X86_INS_VRSQRT28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PDrbkz, X86_INS_VRSQRT28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PDrk, X86_INS_VRSQRT28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PDrkz, X86_INS_VRSQRT28PD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PSm, X86_INS_VRSQRT28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PSmb, X86_INS_VRSQRT28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PSmbk, X86_INS_VRSQRT28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PSmbkz, X86_INS_VRSQRT28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PSmk, X86_INS_VRSQRT28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PSmkz, X86_INS_VRSQRT28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PSr, X86_INS_VRSQRT28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PSrb, X86_INS_VRSQRT28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PSrbk, X86_INS_VRSQRT28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PSrbkz, X86_INS_VRSQRT28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PSrk, X86_INS_VRSQRT28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28PSrkz, X86_INS_VRSQRT28PS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SDm, X86_INS_VRSQRT28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SDmk, X86_INS_VRSQRT28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SDmkz, X86_INS_VRSQRT28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SDr, X86_INS_VRSQRT28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SDrb, X86_INS_VRSQRT28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SDrbk, X86_INS_VRSQRT28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SDrbkz, X86_INS_VRSQRT28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SDrk, X86_INS_VRSQRT28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SDrkz, X86_INS_VRSQRT28SD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SSm, X86_INS_VRSQRT28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SSmk, X86_INS_VRSQRT28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SSmkz, X86_INS_VRSQRT28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SSr, X86_INS_VRSQRT28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SSrb, X86_INS_VRSQRT28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SSrbk, X86_INS_VRSQRT28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SSrbkz, X86_INS_VRSQRT28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SSrk, X86_INS_VRSQRT28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRT28SSrkz, X86_INS_VRSQRT28SS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_ERI, 0 }, 0, 0
#endif
},
{
	X86_VRSQRTPSYm, X86_INS_VRSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRTPSYm_Int, X86_INS_VRSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRTPSYr, X86_INS_VRSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRTPSYr_Int, X86_INS_VRSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRTPSm, X86_INS_VRSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRTPSm_Int, X86_INS_VRSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRTPSr, X86_INS_VRSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRTPSr_Int, X86_INS_VRSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VRSQRTSSm, X86_INS_VRSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VRSQRTSSm_Int, X86_INS_VRSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VRSQRTSSr, X86_INS_VRSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VSCATTERDPDZmr, X86_INS_VSCATTERDPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSCATTERDPSZmr, X86_INS_VSCATTERDPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSCATTERPF0DPDm, X86_INS_VSCATTERPF0DPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VSCATTERPF0DPSm, X86_INS_VSCATTERPF0DPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VSCATTERPF0QPDm, X86_INS_VSCATTERPF0QPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VSCATTERPF0QPSm, X86_INS_VSCATTERPF0QPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VSCATTERPF1DPDm, X86_INS_VSCATTERPF1DPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VSCATTERPF1DPSm, X86_INS_VSCATTERPF1DPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VSCATTERPF1QPDm, X86_INS_VSCATTERPF1QPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VSCATTERPF1QPSm, X86_INS_VSCATTERPF1QPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PFI, 0 }, 0, 0
#endif
},
{
	X86_VSCATTERQPDZmr, X86_INS_VSCATTERQPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSCATTERQPSZmr, X86_INS_VSCATTERQPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSHUFPDYrmi, X86_INS_VSHUFPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSHUFPDYrri, X86_INS_VSHUFPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSHUFPDZrmi, X86_INS_VSHUFPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSHUFPDZrri, X86_INS_VSHUFPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSHUFPDrmi, X86_INS_VSHUFPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSHUFPDrri, X86_INS_VSHUFPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSHUFPSYrmi, X86_INS_VSHUFPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSHUFPSYrri, X86_INS_VSHUFPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSHUFPSZrmi, X86_INS_VSHUFPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSHUFPSZrri, X86_INS_VSHUFPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSHUFPSrmi, X86_INS_VSHUFPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSHUFPSrri, X86_INS_VSHUFPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDYm, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDYr, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ128m, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ128mb, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ128mbk, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ128mbkz, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ128mk, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ128mkz, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ128r, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ128rk, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ128rkz, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ256m, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ256mb, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ256mbk, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ256mbkz, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ256mk, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ256mkz, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ256r, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ256rk, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZ256rkz, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZm, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZmb, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZmbk, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZmbkz, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZmk, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZmkz, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZr, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZrk, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDZrkz, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDm, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPDr, X86_INS_VSQRTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSYm, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSYr, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ128m, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ128mb, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ128mbk, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ128mbkz, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ128mk, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ128mkz, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ128r, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ128rk, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ128rkz, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ256m, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ256mb, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ256mbk, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ256mbkz, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ256mk, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ256mkz, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ256r, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ256rk, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZ256rkz, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZm, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZmb, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZmbk, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZmbkz, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZmk, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZmkz, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZr, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZrk, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSZrkz, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSm, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTPSr, X86_INS_VSQRTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSQRTSDZm, X86_INS_VSQRTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTSDZm_Int, X86_INS_VSQRTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTSDZr, X86_INS_VSQRTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTSDZr_Int, X86_INS_VSQRTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTSDm, X86_INS_VSQRTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VSQRTSDm_Int, X86_INS_VSQRTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VSQRTSDr, X86_INS_VSQRTSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VSQRTSSZm, X86_INS_VSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTSSZm_Int, X86_INS_VSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTSSZr, X86_INS_VSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTSSZr_Int, X86_INS_VSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSQRTSSm, X86_INS_VSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VSQRTSSm_Int, X86_INS_VSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VSQRTSSr, X86_INS_VSQRTSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_VSTMXCSR, X86_INS_VSTMXCSR,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDYrm, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDYrr, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ128rm, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ128rmb, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ128rmbk, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ128rmbkz, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ128rmk, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ128rmkz, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ128rr, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ128rrk, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ128rrkz, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ256rm, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ256rmb, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ256rmbk, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ256rmbkz, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ256rmk, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ256rmkz, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ256rr, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ256rrk, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZ256rrkz, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZrb, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZrbk, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZrbkz, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZrm, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZrmb, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZrmbk, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZrmbkz, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZrmk, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZrmkz, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZrr, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZrrk, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDZrrkz, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDrm, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPDrr, X86_INS_VSUBPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSYrm, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSYrr, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ128rm, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ128rmb, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ128rmbk, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ128rmbkz, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ128rmk, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ128rmkz, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ128rr, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ128rrk, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ128rrkz, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ256rm, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ256rmb, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ256rmbk, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ256rmbkz, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ256rmk, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ256rmkz, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ256rr, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ256rrk, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZ256rrkz, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_VLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZrb, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZrbk, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZrbkz, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZrm, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZrmb, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZrmbk, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZrmbkz, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZrmk, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZrmkz, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZrr, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZrrk, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSZrrkz, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSrm, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBPSrr, X86_INS_VSUBPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDZrm, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDZrm_Int, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDZrm_Intk, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDZrm_Intkz, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDZrr, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDZrr_Int, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDZrr_Intk, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDZrr_Intkz, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDZrrb, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDZrrbk, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDZrrbkz, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDrm, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDrm_Int, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDrr, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSUBSDrr_Int, X86_INS_VSUBSD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSZrm, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSZrm_Int, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSZrm_Intk, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSZrm_Intkz, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSZrr, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSZrr_Int, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSZrr_Intk, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSZrr_Intkz, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSZrrb, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSZrrbk, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSZrrbkz, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSrm, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSrm_Int, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSrr, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VSUBSSrr_Int, X86_INS_VSUBSS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VTESTPDYrm, X86_INS_VTESTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VTESTPDYrr, X86_INS_VTESTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VTESTPDrm, X86_INS_VTESTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VTESTPDrr, X86_INS_VTESTPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VTESTPSYrm, X86_INS_VTESTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VTESTPSYrr, X86_INS_VTESTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VTESTPSrm, X86_INS_VTESTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VTESTPSrr, X86_INS_VTESTPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUCOMISDZrm, X86_INS_VUCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VUCOMISDZrr, X86_INS_VUCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VUCOMISDrm, X86_INS_VUCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUCOMISDrr, X86_INS_VUCOMISD,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUCOMISSZrm, X86_INS_VUCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VUCOMISSZrr, X86_INS_VUCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VUCOMISSrm, X86_INS_VUCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUCOMISSrr, X86_INS_VUCOMISS,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKHPDYrm, X86_INS_VUNPCKHPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKHPDYrr, X86_INS_VUNPCKHPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKHPDZrm, X86_INS_VUNPCKHPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKHPDZrr, X86_INS_VUNPCKHPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKHPDrm, X86_INS_VUNPCKHPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKHPDrr, X86_INS_VUNPCKHPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKHPSYrm, X86_INS_VUNPCKHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKHPSYrr, X86_INS_VUNPCKHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKHPSZrm, X86_INS_VUNPCKHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKHPSZrr, X86_INS_VUNPCKHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKHPSrm, X86_INS_VUNPCKHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKHPSrr, X86_INS_VUNPCKHPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKLPDYrm, X86_INS_VUNPCKLPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKLPDYrr, X86_INS_VUNPCKLPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKLPDZrm, X86_INS_VUNPCKLPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKLPDZrr, X86_INS_VUNPCKLPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKLPDrm, X86_INS_VUNPCKLPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKLPDrr, X86_INS_VUNPCKLPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKLPSYrm, X86_INS_VUNPCKLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKLPSYrr, X86_INS_VUNPCKLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKLPSZrm, X86_INS_VUNPCKLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKLPSZrr, X86_INS_VUNPCKLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX512, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKLPSrm, X86_INS_VUNPCKLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VUNPCKLPSrr, X86_INS_VUNPCKLPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VXORPDYrm, X86_INS_VXORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VXORPDYrr, X86_INS_VXORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VXORPDrm, X86_INS_VXORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VXORPDrr, X86_INS_VXORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VXORPSYrm, X86_INS_VXORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VXORPSYrr, X86_INS_VXORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VXORPSrm, X86_INS_VXORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VXORPSrr, X86_INS_VXORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_AVX, X86_GRP_NOVLX, 0 }, 0, 0
#endif
},
{
	X86_VZEROALL, X86_INS_VZEROALL,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_YMM0, X86_REG_YMM1, X86_REG_YMM2, X86_REG_YMM3, X86_REG_YMM4, X86_REG_YMM5, X86_REG_YMM6, X86_REG_YMM7, X86_REG_YMM8, X86_REG_YMM9, X86_REG_YMM10, X86_REG_YMM11, X86_REG_YMM12, X86_REG_YMM13, X86_REG_YMM14, X86_REG_YMM15, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_VZEROUPPER, X86_INS_VZEROUPPER,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_YMM0, X86_REG_YMM1, X86_REG_YMM2, X86_REG_YMM3, X86_REG_YMM4, X86_REG_YMM5, X86_REG_YMM6, X86_REG_YMM7, X86_REG_YMM8, X86_REG_YMM9, X86_REG_YMM10, X86_REG_YMM11, X86_REG_YMM12, X86_REG_YMM13, X86_REG_YMM14, X86_REG_YMM15, 0 }, { X86_GRP_AVX, 0 }, 0, 0
#endif
},
{
	X86_WAIT, X86_INS_WAIT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_WBINVD, X86_INS_WBINVD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_WRFSBASE, X86_INS_WRFSBASE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FSGSBASE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_WRFSBASE64, X86_INS_WRFSBASE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FSGSBASE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_WRGSBASE, X86_INS_WRGSBASE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FSGSBASE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_WRGSBASE64, X86_INS_WRGSBASE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_FSGSBASE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_WRMSR, X86_INS_WRMSR,
#ifndef CAPSTONE_DIET
	{ X86_REG_EAX, X86_REG_ECX, X86_REG_EDX, 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_XABORT, X86_INS_XABORT,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RTM, 0 }, 0, 0
#endif
},
{
	X86_XACQUIRE_PREFIX, X86_INS_XACQUIRE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_HLE, 0 }, 0, 0
#endif
},
{
	X86_XADD16rm, X86_INS_XADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XADD16rr, X86_INS_XADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XADD32rm, X86_INS_XADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XADD32rr, X86_INS_XADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XADD64rm, X86_INS_XADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XADD64rr, X86_INS_XADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XADD8rm, X86_INS_XADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XADD8rr, X86_INS_XADD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XBEGIN_2, X86_INS_XBEGIN,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EAX, 0 }, { X86_GRP_BRANCH_RELATIVE, X86_GRP_RTM, 0 }, 1, 0
#endif
},
{
	X86_XBEGIN_4, X86_INS_XBEGIN,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EAX, 0 }, { X86_GRP_BRANCH_RELATIVE, X86_GRP_RTM, 0 }, 1, 0
#endif
},
{
	X86_XCHG16ar, X86_INS_XCHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCHG16rm, X86_INS_XCHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCHG16rr, X86_INS_XCHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCHG32ar, X86_INS_XCHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_XCHG32ar64, X86_INS_XCHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_XCHG32rm, X86_INS_XCHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCHG32rr, X86_INS_XCHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCHG64ar, X86_INS_XCHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCHG64rm, X86_INS_XCHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCHG64rr, X86_INS_XCHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCHG8rm, X86_INS_XCHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCHG8rr, X86_INS_XCHG,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCH_F, X86_INS_FXCH,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { X86_GRP_FPU, 0 }, 0, 0
#endif
},
{
	X86_XCRYPTCBC, X86_INS_XCRYPTCBC,
#ifndef CAPSTONE_DIET
	{ X86_REG_RBX, X86_REG_RDX, X86_REG_RSI, X86_REG_RDI, 0 }, { X86_REG_RSI, X86_REG_RDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCRYPTCFB, X86_INS_XCRYPTCFB,
#ifndef CAPSTONE_DIET
	{ X86_REG_RBX, X86_REG_RDX, X86_REG_RSI, X86_REG_RDI, 0 }, { X86_REG_RSI, X86_REG_RDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCRYPTCTR, X86_INS_XCRYPTCTR,
#ifndef CAPSTONE_DIET
	{ X86_REG_RBX, X86_REG_RDX, X86_REG_RSI, X86_REG_RDI, 0 }, { X86_REG_RSI, X86_REG_RDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCRYPTECB, X86_INS_XCRYPTECB,
#ifndef CAPSTONE_DIET
	{ X86_REG_RBX, X86_REG_RDX, X86_REG_RSI, X86_REG_RDI, 0 }, { X86_REG_RSI, X86_REG_RDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XCRYPTOFB, X86_INS_XCRYPTOFB,
#ifndef CAPSTONE_DIET
	{ X86_REG_RBX, X86_REG_RDX, X86_REG_RSI, X86_REG_RDI, 0 }, { X86_REG_RSI, X86_REG_RDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XEND, X86_INS_XEND,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_RTM, 0 }, 0, 0
#endif
},
{
	X86_XGETBV, X86_INS_XGETBV,
#ifndef CAPSTONE_DIET
	{ X86_REG_ECX, 0 }, { X86_REG_EDX, X86_REG_EAX, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XLAT, X86_INS_XLATB,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR16i16, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR16mi, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR16mi8, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR16mr, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR16ri, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR16ri8, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR16rm, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR16rr, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR16rr_REV, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR32i32, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR32mi, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR32mi8, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR32mr, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR32ri, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR32ri8, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR32rm, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR32rr, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR32rr_REV, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR64i32, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR64mi32, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR64mi8, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR64mr, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR64ri32, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR64ri8, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR64rm, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR64rr, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR64rr_REV, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR8i8, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR8mi, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR8mi8, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_XOR8mr, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR8ri, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR8ri8, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { X86_GRP_NOT64BITMODE, 0 }, 0, 0
#endif
},
{
	X86_XOR8rm, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR8rr, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XOR8rr_REV, X86_INS_XOR,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XORPDrm, X86_INS_XORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_XORPDrr, X86_INS_XORPD,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE2, 0 }, 0, 0
#endif
},
{
	X86_XORPSrm, X86_INS_XORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_XORPSrr, X86_INS_XORPS,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_SSE1, 0 }, 0, 0
#endif
},
{
	X86_XRELEASE_PREFIX, X86_INS_XRELEASE,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { X86_GRP_HLE, 0 }, 0, 0
#endif
},
{
	X86_XRSTOR, X86_INS_XRSTOR,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, X86_REG_RAX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XRSTOR64, X86_INS_XRSTOR64,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, X86_REG_RAX, 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_XRSTORS, X86_INS_XRSTORS,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, X86_REG_RAX, 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_XRSTORS64, X86_INS_XRSTORS64,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, X86_REG_RAX, 0 }, { 0 }, { X86_GRP_PRIVILEGE, X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_XSAVE, X86_INS_XSAVE,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, X86_REG_RAX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XSAVE64, X86_INS_XSAVE64,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, X86_REG_RAX, 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_XSAVEC, X86_INS_XSAVEC,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, X86_REG_RAX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XSAVEC64, X86_INS_XSAVEC64,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, X86_REG_RAX, 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_XSAVEOPT, X86_INS_XSAVEOPT,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, X86_REG_RAX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XSAVEOPT64, X86_INS_XSAVEOPT64,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, X86_REG_RAX, 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_XSAVES, X86_INS_XSAVES,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, X86_REG_RAX, 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XSAVES64, X86_INS_XSAVES64,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, X86_REG_RAX, 0 }, { 0 }, { X86_GRP_MODE64, 0 }, 0, 0
#endif
},
{
	X86_XSETBV, X86_INS_XSETBV,
#ifndef CAPSTONE_DIET
	{ X86_REG_EDX, X86_REG_EAX, X86_REG_ECX, 0 }, { 0 }, { X86_GRP_PRIVILEGE, 0 }, 0, 0
#endif
},
{
	X86_XSHA1, X86_INS_XSHA1,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, X86_REG_RSI, X86_REG_RDI, 0 }, { X86_REG_RAX, X86_REG_RSI, X86_REG_RDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XSHA256, X86_INS_XSHA256,
#ifndef CAPSTONE_DIET
	{ X86_REG_RAX, X86_REG_RSI, X86_REG_RDI, 0 }, { X86_REG_RAX, X86_REG_RSI, X86_REG_RDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XSTORE, X86_INS_XSTORE,
#ifndef CAPSTONE_DIET
	{ X86_REG_RDX, X86_REG_RDI, 0 }, { X86_REG_RAX, X86_REG_RDI, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_XTEST, X86_INS_XTEST,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_EFLAGS, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_fdisi8087_nop, X86_INS_FDISI8087_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_feni8087_nop, X86_INS_FENI8087_NOP,
#ifndef CAPSTONE_DIET
	{ 0 }, { X86_REG_FPSW, 0 }, { 0 }, 0, 0
#endif
},
{
	X86_UD0, X86_INS_UD0,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ENDBR32, X86_INS_ENDBR32,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
{
	X86_ENDBR64, X86_INS_ENDBR64,
#ifndef CAPSTONE_DIET
	{ 0 }, { 0 }, { 0 }, 0, 0
#endif
},
